<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: /admin/apps_manage.php 2012-01-09$
 */

include "../init.php";

$OS = getOS();

$osUser = $OS->getUser();
$osUser->forceUserAdmin();

//get current app
if (!empty($_GET['app'])) $appName = $_GET['app'];
elseif (!empty($_POST['app'])) $appName = $_POST['app'];
else $appName = false;
if(!$appName) die("Application name not provided");

//get current view
$currentView = ''; 
$availableViews = array('details', 'check_update', 'check_uninstall', 'accept_update', 'accept_uninstall');
if (!empty($_GET['current_view'])) if(in_array($_GET['current_view'],$availableViews)) $currentView = $_GET['current_view'];
if(empty($currentView)) $currentView = 'details';

//get apps handler operations
$osAppOps = $OS->getAppOps();

//get app details
$appIsValid = false; $appIsInstalled = false;
$oneApp = $osAppOps->getAppByName($appName);
if($oneApp !== false)
{
	if($oneApp->isValid())
	{
		$appIsValid = true; 
		$appIsInstalled = true;
	}
}
else 
{
	//get  uninstalled apps info
	$uninstalledApps = $osAppOps->getUninstalledApps();
	if($uninstalledApps !== false)
	{
		if(isset($uninstalledApps[$appName]))
		{
			$appPath = $uninstalledApps[$appName];
			
			//check if has manifest and load it
			
			$validateResult = $osAppOps->validateAppKit($appPath);
			
			if($validateResult['result'])
			{
				$appInfo = $osAppOps->buildAppInfo($appPath);
				$appInfo['details']['kitname'] = $appName;
				
				$oneApp = new OS_App();
				$oneApp->set($appInfo['details']);
				
				if($oneApp->isValid()) $appIsValid = true;
			}
		}
	}
}

if(!$appIsValid) die("Application not found");


$appDetails = array(
	'app_icon_board' => $oneApp->getAppUrl()."/resources/app_icon_board.png",
	'uninstall_link' => "#uninstall_link",
	'update_link' => "#update_link",
	'app_name' => $oneApp->name,
	'app_version' => $oneApp->version,
	'company_name' => $oneApp->name,
	'description' => $oneApp->description,
	'title' => $oneApp->title,
	'status' => $oneApp->status,
	'app_action' => ($appIsInstalled ? 'up2date' : 'install')
	);
	
$testDetails = array();	


//check if app needs updating  from cached appstore details
//$appDetails['app_action'] = 'update';

//get app dependencies
$appDependenciesResult = false;
$oneAppManifest = json_decode($oneApp->manifest, true);
if(!is_null($oneAppManifest))
{
	$appRequirementsResult = $osAppOps->checkAppRequirements($oneAppManifest);
	
	$appDependenciesResult = $appRequirementsResult['result'];
	$testDetails['requirements'] = array('tests'=> $appRequirementsResult['tests']);
}


$root_url = $OS->getConfigVar('root_url');


if ($_SERVER['REQUEST_METHOD']=='POST')
{
	if(isset($_POST['check_update_btn']))
	{
		$currentView = 'check_update';
	}
	elseif(isset($_POST['check_uninstall_btn']))
	{
		$currentView = 'check_uninstall';
	}	
	elseif(isset($_POST['accept_install_btn']))
	{
		$currentView = 'accept_install';
		
		$appPath = $oneApp->getAppPath();
		
		$installResult = $osAppOps->installAppFromPath($appPath);
		
		if($installResult['result'])
		{
			$OS->addInfo("App Installed Successfully !");
		}
		
		if(isset($installResult['tests']))
		{
			$testDetails['install'] = array('name'=>"App Install Details", 'tests'=> $installResult['tests']);
		}
		 
	}
	elseif(isset($_POST['accept_update_btn']))
	{
		$currentView = 'accept_update';	
		
		$updateResult = $osAppOps->updateAppStoreApp($oneApp->name);
		
		if($updateResult['result'])
		{
			$OS->addInfo("App updated Successfully !");
		}
		else
		{
			if(isset($updateResult['tests']))
			{
				$testDetails['update'] = array('name'=>"App Update Details", 'tests'=> $updateResult['tests']);
			}
			
			if(isset($updateResult['notifications']))
			{
				foreach($updateResult['notifications'] as $notification)
				{
					if($notification['type']=='error')
					{
						$OS->addBoxError($notification['message']);	
					}
					elseif($notification['type']=='success')
					{
						$OS->addInfo($notification['message']);
					}
				}
			}
			
		}
	}
	elseif(isset($_POST['accept_uninstall_btn']))
	{
		$currentView = 'accept_uninstall';
		
		//uninstall current app
		$uninstallResult = $osAppOps->uninstallApp($oneApp->name);
		
		if($uninstallResult['result'])
		{
			$OS->addInfo("App uninstalled Successfully !");
		}
		else
		{
			$OS->addBoxError("App cannot be uninstalled");
			
			if(isset($uninstallResult['tests']))
			{
				$testDetails['uninstall'] = array('name'=>"App Uninstall Details", 'tests'=> $uninstallResult['tests']);
			}
		}
	}
}

	
$tpl = $OS->getTemplate();

$root_url = $OS->getConfigVar('root_url');

$headContents = array(
	'css' => array(
		'kickstart-buttons.css' => $root_url.'/lib/css/kickstart-buttons.css',
		'kickstart-forms.css' => $root_url.'/lib/css/kickstart-forms.css',
		'kickstart-menus.css' => $root_url.'/lib/css/kickstart-menus.css',
		'kickstart-grid.css' => $root_url.'/lib/css/kickstart-grid.css',
		'kickstart-icons.css' => $root_url.'/lib/css/kickstart-icons.css',
		'jquery.fancybox.css' => $root_url.'/lib/css/jquery.fancybox-1.3.4.css',
		'prettify.css' => $root_url.'/lib/css/prettify.css',
		'chosen.css' => $root_url.'/lib/css/chosen.css',
		'tiptip.css' => $root_url.'/lib/css/tiptip.css',
		'kickstart-strip.css' => $root_url.'/lib/css/kickstart-strip.css',
		'style.css' => $root_url.'/lib/css/style.css',
		'style_stripped.css' => $root_url.'/lib/css/style_stripped.css',
		),
	'js' => array(
		'jquery.min.js' => "https://ajax.googleapis.com/ajax/libs/jquery/1.6.4/jquery.min.js",
		'prettify.js' => $root_url.'/lib/javascript/kickstart/prettify.js',
		'kickstart.js' => $root_url.'/lib/javascript/kickstart/kickstart.js',
		'kernel.boot.js' => $root_url.'/lib/javascript/core/kernel.boot.js',
		),
	'html5shiv.googlecode.com' => '<!--[if lt IE 9]><script src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script><![endif]-->'	
	);

$tpl->setHeadContents($headContents);	

$tpl->setVar('template_path', $OS->getConfigVar('template_url'));

$tpl->setVar('errors',$OS->errorMessages);
$tpl->setVar('info',$OS->infoMessages);

$tpl->setVar('appDependenciesResult', $appDependenciesResult);

$tpl->setVar('testDetails', $testDetails);

$appTabs = array(
	'stats' => array('name'=>"App Stats", 'content'=>"App Stats Demo"),
	'description' => array('name'=>"Description", 'content'=>$oneApp->description),
	//'version_updates' => array('name'=>"What's New", 'content'=>"What's New Demo"),
	'dependinces' => array('name'=>"Dependinces", 'content'=> $tpl->getTemplate('testdisplay')),
	);
	
$tpl->setVar('appTabs', $appTabs);	

$tpl->setVar('appDetails', $appDetails);

$tpl->setVar('back_link', ($currentView != 'details' ? "?current_view=details&app={$appName}" : false));

$tpl->setVar('appName', $appName);

$tpl->setVar('currentView', $currentView);

$tpl->bodyTemplateName = "admin_apps_manage";

echo $tpl->mainTemplateRender('main_stripped');
?>