<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: /admin/widgets_manage.php 2012-01-09$
 */

include "../init.php";

$OS = getOS();

$osUser = $OS->getUser();
$osUser->forceUserAdmin();

//get current widget
if (!empty($_GET['widget'])) $widgetName = $_GET['widget'];
elseif (!empty($_POST['widget'])) $widgetName = $_POST['widget'];
else $widgetName = false;
if(!$widgetName) die("Widget name not provided");

//get current view
$currentView = ''; 
$availableViews = array('details', 'check_update', 'check_uninstall', 'accept_update', 'accept_uninstall');
if (!empty($_GET['current_view'])) if(in_array($_GET['current_view'],$availableViews)) $currentView = $_GET['current_view'];
if(empty($currentView)) $currentView = 'details';

//get widgets handler operations
$osWidgetOps = $OS->getWidgetOps();

//get widget details
$widgetIsValid = false; $widgetIsInstalled = false;
$oneWidget = $osWidgetOps->getWidgetByName($widgetName);
if($oneWidget !== false)
{
	if($oneWidget->isValid())
	{
		$widgetIsValid = true; 
		$widgetIsInstalled = true;
	}
}
else 
{
	//get  uninstalled widgets info
	$uninstalledWidgets = $osWidgetOps->getUninstalledWidgets();
	if($uninstalledWidgets !== false)
	{
		if(isset($uninstalledWidgets[$widgetName]))
		{
			$widgetPath = $uninstalledWidgets[$widgetName];
			
			//check if has manifest and load it
			
			$validateResult = $osWidgetOps->validateWidgetKit($widgetPath);
			
			if($validateResult['result'])
			{
				$widgetInfo = $osWidgetOps->buildWidgetInfo($widgetPath);
				$widgetInfo['details']['kitname'] = $widgetName;
				
				$oneWidget = new OS_Widget();
				$oneWidget->set($widgetInfo['details']);
				
				if($oneWidget->isValid()) $widgetIsValid = true;
			}
		}
	}
}

if(!$widgetIsValid) die("Widget not found");


$widgetDetails = array(
	'widget_icon_board' => $oneWidget->getWidgetUrl()."/resources/widget_icon_board.png",
	'uninstall_link' => "#uninstall_link",
	'update_link' => "#update_link",
	'widget_name' => $oneWidget->name,
	'widget_version' => $oneWidget->version,
	'company_name' => $oneWidget->name,
	'description' => $oneWidget->description,
	'title' => $oneWidget->title,
	'status' => $oneWidget->status,
	'widget_action' => ($widgetIsInstalled ? 'up2date' : 'install')
	);
	
$testDetails = array();	


//get widgets handler operations
$osAppStore = $OS->getAppStoreApi();

//here should get info from appstore api
$appStoreDetails = false; 
$asResponse = $osAppStore->getWidgetDetails(array('widget_name'=>$oneWidget->name));
if($osAppStore->success)
{
	if(isset($asResponse['widget']))
	{
		$osUtils = $OS->getUtils();
		
		$appStoreDetails = array(
    		'version' => $asResponse['widget']['version'],
    		'review_stars' => $asResponse['widget']['review_stars'],
    		'review_total' => $asResponse['widget']['review_total'],
    		'total_installs' => $asResponse['widget']['total_installs'],
    		'last_update_date' => date("F, d Y", strtotime($asResponse['widget']['last_update_date'])),
			'kit_size' =>  $osUtils->humanizeSize($asResponse['widget']['widget_kit_size']),
			);
			
		//check appstore details (widget_version)
		if($oneWidget->requireUpdate($appStoreDetails['version']))
		{
			$widgetDetails['widget_action'] = 'update';
		}
	}
}

//get app dependencies
$widgetDependenciesResult = false;
$oneWidgetManifest = json_decode($oneWidget->manifest, true);

if(!is_null($oneWidgetManifest))
{
	$widgetRequirementsResult = $osWidgetOps->checkWidgetRequirements($oneWidgetManifest);
	
	$widgetDependenciesResult = $widgetRequirementsResult['result'];
	$testDetails['requirements'] = array('tests'=> $widgetRequirementsResult['tests']);
}

$root_url = $OS->getConfigVar('root_url');


if ($_SERVER['REQUEST_METHOD']=='POST')
{
	if(isset($_POST['check_update_btn']))
	{
		$currentView = 'check_update';
	}
	elseif(isset($_POST['check_uninstall_btn']))
	{
		$currentView = 'check_uninstall';
	}	
	elseif(isset($_POST['accept_install_btn']))
	{
		$currentView = 'accept_install';
		
		$widgetPath = $oneWidget->getWidgetPath();
		
		$installResult = $osWidgetOps->installWidgetFromPath($widgetPath);
		
		if($installResult['result'])
		{
			$OS->addInfo("Widget Installed Successfully !");
		}
		
		if(isset($installResult['tests']))
		{
			$testDetails['install'] = array('name'=>"Widget Install Details", 'tests'=> $installResult['tests']);
		}
		 
	}
	elseif(isset($_POST['accept_update_btn']))
	{
		$currentView = 'accept_update';	
		
		$updateResult = $osWidgetOps->updateAppStoreWidget($oneWidget->name);
		
		if($updateResult['result'])
		{
			$OS->addInfo("Widget updated Successfully !");
		}
		else
		{
			if(isset($updateResult['tests']))
			{
				$testDetails['update'] = array('name'=>"Widget Update Details", 'tests'=> $updateResult['tests']);
			}
			
			if(isset($updateResult['notifications']))
			{
				foreach($updateResult['notifications'] as $notification)
				{
					if($notification['type']=='error')
					{
						$OS->addBoxError($notification['message']);	
					}
					elseif($notification['type']=='success')
					{
						$OS->addInfo($notification['message']);
					}
				}
			}
			
		}
	}
	elseif(isset($_POST['accept_uninstall_btn']))
	{
		$currentView = 'accept_uninstall';
		
		//uninstall current widget
		$uninstallResult = $osWidgetOps->uninstallWidget($oneWidget->name);
		
		if($uninstallResult['result'])
		{
			$OS->addInfo("Widget uninstalled Successfully !");
		}
		else
		{
			$OS->addBoxError("Widget cannot be uninstalled");
			
			if(isset($uninstallResult['tests']))
			{
				$testDetails['uninstall'] = array('name'=>"Widget Uninstall Details", 'tests'=> $uninstallResult['tests']);
			}
		}
	}
}

	


$tpl = $OS->getTemplate();

$root_url = $OS->getConfigVar('root_url');

$headContents = array(
	'css' => array(
		'kickstart-buttons.css' => $root_url.'/lib/css/kickstart-buttons.css',
		'kickstart-forms.css' => $root_url.'/lib/css/kickstart-forms.css',
		'kickstart-menus.css' => $root_url.'/lib/css/kickstart-menus.css',
		'kickstart-grid.css' => $root_url.'/lib/css/kickstart-grid.css',
		'kickstart-icons.css' => $root_url.'/lib/css/kickstart-icons.css',
		'jquery.fancybox.css' => $root_url.'/lib/css/jquery.fancybox-1.3.4.css',
		'prettify.css' => $root_url.'/lib/css/prettify.css',
		'chosen.css' => $root_url.'/lib/css/chosen.css',
		'tiptip.css' => $root_url.'/lib/css/tiptip.css',
		'kickstart-strip.css' => $root_url.'/lib/css/kickstart-strip.css',
		'style.css' => $root_url.'/lib/css/style.css',
		'style_stripped.css' => $root_url.'/lib/css/style_stripped.css',
		),
	'js' => array(
		'jquery.min.js' => "https://ajax.googleapis.com/ajax/libs/jquery/1.6.4/jquery.min.js",
		'prettify.js' => $root_url.'/lib/javascript/kickstart/prettify.js',
		'kickstart.js' => $root_url.'/lib/javascript/kickstart/kickstart.js',
		'kernel.boot.js' => $root_url.'/lib/javascript/core/kernel.boot.js',
		),
	'html5shiv.googlecode.com' => '<!--[if lt IE 9]><script src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script><![endif]-->'	
	);

$tpl->setHeadContents($headContents);	

$tpl->setVar('template_path', $OS->getConfigVar('template_url'));

$tpl->setVar('errors',$OS->errorMessages);
$tpl->setVar('info',$OS->infoMessages);

$tpl->setVar('widgetDetails', $widgetDetails);

$tpl->setVar('appStoreDetails', $appStoreDetails);

$tpl->setVar('testDetails', $testDetails);

$tpl->setVar('widgetDependenciesResult', $widgetDependenciesResult);

$widgetTabs = array(
	'stats' => array('name'=>"Widget Stats", 'content'=>"Widget Stats Demo"),
	'description' => array('name'=>"Description", 'content'=>$oneWidget->description),
	'dependinces' => array('name'=>"Dependinces", 'content'=> $tpl->getTemplate('testdisplay')),
	);

$tpl->setVar('widgetTabs', $widgetTabs);


$tpl->setVar('back_link', ($currentView != 'details' ? "?current_view=details&widget={$widgetName}" : false));

$tpl->setVar('widgetName', $widgetName);

$tpl->setVar('currentView', $currentView);

$tpl->bodyTemplateName = "admin_widgets_manage";

echo $tpl->mainTemplateRender('main_stripped');
?>