<?php
include "../../init.php";

class osAjaxAdminAppsManager
{
	public function __construct()
	{
		$this->permissionsRequired = array('checkUserLogged', 'checkUserAdmin', 'checkAppstore');
	}

	public function getAppboardDetails()
	{
		$responseData =  array('actionStatus' => false);

		$OS = getOS();
		
		//process installed apps
		$installedApps = array();
		$installedDetails = $this->getInstalledAppsDetails();
		if($installedDetails['actionStatus'])
		{
			$responseData['actionStatus'] = true;
			$installedApps = $installedDetails['actionData']['collectionDetails'];
		}
		
		//process uninstalled apps
		$uninstalledApps = array();
		$uninstalledDetails = $this->getUninstalledAppsDetails();
		if($uninstalledDetails['actionStatus'])
		{
			$responseData['actionStatus'] = true;
			$uninstalledApps = $uninstalledDetails['actionData']['collectionDetails'];
		} 
		
		
		//get app names
		if($installedDetails['actionStatus'])
		{
			$installed_apps_names = array();
			foreach($installedDetails['actionData']['collectionDetails'] as $appData)
			{
				$installed_apps_names[] = $appData['name'];
			}
			
			//get details about app versions from Appstore
			$osAppStore = $OS->getAppStoreApi();
			$asResponse = $osAppStore->getAppsVersions(array('apps'=>$installed_apps_names));
			if($osAppStore->success)
			{
				$appsVersions = $asResponse;
				
				foreach($installedApps as $index => $appData)
				{
					$install_type = "up2date";
					
					if(isset($appsVersions[$appData['name']]))
					{
						if($appData['version'] < $appsVersions[$appData['name']])
						{
							$install_type = "update";
						}
					}
					
					$installedApps[$index]['install_type'] = $install_type;
				}
			}
			else
			{
				$responseData['actionData']['notifications'][] = array('type' => 'error', 'message' => _("Could not connect to Appstore"));	
			}
		}
		
		
		//build Admin Boards
		$adminBoards = array();
		$parentItems = $OS->getMenu()->getParentItems('admin_apps_manager');
		if(!empty($parentItems))
		{
			foreach($parentItems as $item => $details)
			{
				$adminBoards[] = array('title' => $details['title'], 'name' => $item);
			}
		}
		
		$responseData['actionData']['modelDetails'] = array('installedApps'=> $installedApps, 'uninstalledApps' => $uninstalledApps, 'boards' => $adminBoards);
			
		return $responseData;
	}
	
	public function getInstalledAppsDetails()
	{
		$OS = getOS();
		
		$responseData = array('actionStatus' => false);

		//get apps handler operations
		$osAppOps = $OS->getAppOps();
		
		$osAvailableApplications = $osAppOps->getAvailableApps();

		$appboardData = array(); $counter = 0;
		
		if(!empty($osAvailableApplications))
		{
			foreach($osAvailableApplications as $app_id => $oneAppHandler)
			{
				$counter++;
				
				$tmpDetails = array(
					'id' => $app_id,
					'app_icon_board' => $oneAppHandler->getAppUrl()."/resources/app_icon_board.png",
					'app_link' => $OS->getConfigVar('root_url')."/admin/apps_manage.php?app=".$oneAppHandler->name,
					'name' => $oneAppHandler->name,
					'description' => $oneAppHandler->description,
					'title' => $oneAppHandler->title,
					'version' => $oneAppHandler->version,
					'status' => $oneAppHandler->status,
					'position' => $counter,
					);
							
 				$appboardData[] = $tmpDetails;
			}
			
			$responseData['actionStatus'] = true;
		}
		
		uasort($appboardData,array($this,'sortAppboard'));

		$responseData['actionData']['collectionDetails'] = $appboardData;
		
		return $responseData;
	}
	
	public function getUninstalledAppsDetails()
	{
		$OS = getOS();
		
		$responseData = array('actionStatus' => false);
		
		//get apps handler operations
		$osAppOps = $OS->getAppOps();
		
		//get  uninstalled apps info
		$uninstalledApps = $osAppOps->getUninstalledApps();
		
		$uninstalledAppsCollection = array(); $counter = 0;
		if(!empty($uninstalledApps))
		{
			foreach ($uninstalledApps as $appName=>$appPath)
			{
				$counter++;
				
				$appIconPath = (file_exists("{$appPath}/app/resources/app_icon_board.png") ? $OS->getConfigVar('root_url')."/apps/{$appName}_unistalled/app/resources/app_icon_board.png" : "#");
				
				$uninstalledAppsCollection[] = array(
					'app_icon_board' => $appIconPath,
					'name' => $appName,
					'title' => $appName,
					'position' => $counter,
					'app_link' => $OS->getConfigVar('root_url')."/admin/apps_manage.php?app=".$appName	
					);
			}
			
			$responseData['actionStatus'] = true;
		}
		
		$responseData['actionData']['collectionDetails'] =  $uninstalledAppsCollection;
		
		return $responseData;
	}
	
	public function updateAppDetails($params)
	{
		$responseData = array('actionStatus' => false, 'actionData'=> array());
		
		$valid_op = false;
		
		//check operations
		if(isset($params['current_op'], $params['name']))
		{
			$OS = getOS();
			
			//get apps handler operations
			$osAppStore = $OS->getAppStoreApi();
			
			//here should get info from appstore api
			$asResponse = $osAppStore->getAppDetails(array('app_name'=>$params['name']));
			if(!$osAppStore->success)
			{
				$error = $osAppStore->getError();
				$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => $error['message']);
			}
			else
			{
				if(isset($asResponse['app']))
				{
					$appDetails = $this->buildAppDetails($asResponse['app']);
					
					$responseData['actionData']['modelDetails'] = $appDetails;
					
					$osAppOps =  $OS->getAppOps();
					
					if($params['current_op'] == 'update')
					{
						$valid_op = true;
						$updateResult = $osAppOps->updateAppStoreApp($appDetails['name']);
						
						$responseData['actionStatus'] = $updateResult['result'];
						$responseData['actionData'] = array_merge($responseData['actionData'], $updateResult); 
					}
				}
			}
		}

		
		if(!$valid_op)
		{
			$responseData['actionData']['notifications'][] = array("type" => "error", "message" => _("Invalid Operation"));	
		}
		
		return $responseData;
	} 
	
	public function updateNewAppDetails($params)
	{
		$responseData = array('actionStatus'=> false, 'actionData'=> array());
		$valid_step = false;
		
		//check operations
		if(isset($params['current_step']))
		{
			$OS = getOS();
			$osAppOps = $OS->getAppOps();
			
			if($params['current_step'] == 'validate')
			{
				$valid_step = true;
				
				if(!empty($params['get_app_url_box']))
				{
					$unpackResponse = $osAppOps->getAppFromURL($params['get_app_url_box']);
					
					$responseData['actionStatus'] = $unpackResponse['result'];
					
					$responseData['actionData']['modelDetails'] = array(
						'unpackTests' => $unpackResponse['tests'],
						'current_step'=> $params['current_step']
						);
						
					//add notifications if available
					if(isset($unpackResponse['notifications']))
					{
						foreach($unpackResponse['notifications'] as $notification)
						{
							$responseData['actionData']['notifications'][] = $notification;	
						}
					}	
					
					//add appKitName if provided
					if(isset($unpackResponse['appKitName']))
					{
						$responseData['actionData']['modelDetails']['appInfo'] = $unpackResponse['appInfo'];
					}	
					
					//add appInfo if provided
					if(isset($unpackResponse['appInfo']))
					{
						$responseData['actionData']['modelDetails']['appInfo'] = $unpackResponse['appInfo'];	
					} 
					
					if(isset($unpackResponse['validationResult']))
					{
						$responseData['actionData']['modelDetails']['validationResult'] = $unpackResponse['validationResult'];	
					} 
					
					//throw notification
					if($unpackResponse['result'])
					{
						$responseData['actionData']['notifications'][] = array('type'=>'info', 'message'=> _("Application Downloaded"));	
					}
					else
					{
						$responseData['actionData']['notifications'][] = array('type'=>'error', 'message'=> _("Application could not be downloaded"));
					}
				}
				else
				{
					$responseData['actionData']['notifications'][] = array('type'=>'info', 'message'=> _("App URL field is empty"));
				}
			}
			elseif($params['current_step'] == 'install')
			{
				$valid_step = true;
				
				$installResponse = $osAppOps->installAppFromPath($params['appKitName']);
				
				$responseData['actionStatus'] = $installResponse['result'];
				
				$responseData['actionData']['modelDetails'] = array(
					'installTests' => $installResponse['tests'], 
					'current_step'=> $params['current_step'],
					'installResult' => $installResponse['result']
					);
				
				//add appInfo if provided
				if(isset($installResponse['appInfo']))
				{
					$responseData['actionData']['modelDetails']['appInfo'] = $installResponse['appInfo'];	
				} 
				
				//throw notification
				if($installResponse['result'])
				{
					$responseData['actionData']['notifications'][] = array('type'=>'success', 'message'=> _("App Successfully Installed"));	
				}
				else
				{
					$responseData['actionData']['notifications'][] = array('type'=>'error', 'message'=> _("App could not be installed"));
				}
			}
		}
		
		if(!$valid_step)
		{
			$responseData['actionData']['notifications'][] = array('type'=>'error', 'message'=> _("Invalid Action"));
		}
			
		return $responseData;
	}
	
	
	public function doAppUpload($params)
	{
		$responseData = array('actionStatus'=> false, 'actionData'=> array());
		
		if(empty($_FILES))
		{
			$responseData['actionData']['notifications'][] = array('type'=>'error', 'message' => _('There are no uploaded files')); 
		}
		elseif(!isset($_FILES['get_app_upload_box']))
		{
			$responseData['actionData']['notifications'][] = array('type'=>'error', 'message' => _('There are no uploaded files'));
		}
		else
		{
			$OS = getOS();
			
			$osAppOps = $OS->getAppOps();
			
			$unpackResponse = $osAppOps->getAppFromUpload($_FILES['get_app_upload_box']);
			
			$responseData['actionStatus'] = $unpackResponse['result'];
			
			$responseData['unpackResponse'] = $unpackResponse;
			
			//handle app upload notifications
			if(!empty($unpackResponse['notifications']))
			{
				$responseData['actionData']['notifications'] = $unpackResponse['notifications'];
			}

			if(!empty($unpackResponse['tests']))
			{
				$responseData['actionData']['tests'] = $unpackResponse['tests'];
			}
			
			
			$responseData['actionData']['modelDetails'] = array('unpackTests' => $unpackResponse['tests'], 'current_step'=>'validate', 'appKitName' => $unpackResponse['appKitName']);
			
			if(isset($unpackResponse['appInfo']))
			{
				$responseData['actionData']['modelDetails']['appInfo'] = $unpackResponse['appInfo'];	
			} 
			
			if(isset($unpackResponse['validationResult']))
			{
				$responseData['actionData']['modelDetails']['validationResult'] = $unpackResponse['validationResult'];	
			} 
				
			//throw notification
			if($unpackResponse['result'])
			{
				$responseData['actionData']['notifications'][] = array('type'=>'info', 'message'=> _("Application Downloaded"));	
			}
		}
		
		return $responseData; 
	}
	
	private function buildAppDetails($appStoreData)
	{
		$OS = getOS();
		$osUtils = $OS->getUtils();
		$osAppOps = $OS->getAppOps();
		
		$appDetails = array(
    		'icon_board' => $appStoreData['icon_board'], 
    		'name' => $appStoreData['name'],
			'category' => $appStoreData['category'],
			'title' => $appStoreData['title'],
    		'developer_name' => $appStoreData['developer_name'],
    		'version' => $appStoreData['version'],
    		'review_stars' => $appStoreData['review_stars'],
    		'review_total' => $appStoreData['review_total'],
    		'total_installs' => $appStoreData['total_installs'],
    		'last_update_date' => date("F, d Y", strtotime($appStoreData['last_update_date'])),
			'kit_size' =>  $osUtils->humanizeSize($appStoreData['app_kit_size']),
    		'description' => $appStoreData['description'],
			'app_action' => 'install',
			'is_logged' => true,
			'app_is_installed' => true
			);
			
			
		//check if current app has reviews
		if(isset($appStoreData['reviews']))
		{
			foreach($appStoreData['reviews'] as $review_id => $reviewData)
			{
			$appDetails['reviews'][$review_id] = array(
				'stars' => $reviewData['stars'],
				'stars_total' => ($reviewData['stars']*2),
				'review_date' => date('d F Y, H:i', strtotime($reviewData['update_dt'])),
				'title' => $reviewData['title'],
				'message' =>$reviewData['message'],
				'reviewer_user' =>$reviewData['reviewer_user'],
				);
			}
		} 
		
		if(isset($appStoreData['my_review'])) $appDetails['my_review'] = $appStoreData['my_review'];
		
		
		//check if has version details
		if(isset($appStoreData['manifest']['changelog'])) $appDetails['changelog'] = $appStoreData['manifest']['changelog'];
		
		
		$appRequirementsResult = $osAppOps->checkAppRequirements($appStoreData['manifest']);
		
		$appDetails['dependencies'] = $appRequirementsResult['tests'];
		$appDetails['dependencies_result'] = $appRequirementsResult['result'];
		
		return $appDetails;			
	}
	
	
	private function sortAppboard($app1,$app2)
	{
		if ($app1['position']<$app2['position']) return -1;
		else return 1;
	}	
}

//set the ajax server
$OS = getOS();
$osAjax = $OS->getAjax();
$osAjax->setClass("osAjaxAdminAppsManager");
$osAjax->handle();
?>