<?php
include "../../init.php";

class osAjaxAdminConnectorsManager
{
	public function __construct()
	{
		$this->permissionsRequired = array('checkUserLogged', 'checkUserAdmin');
	}
	
	public function getConnectorsDetails($params)
	{
		$OS = getOS();
		
		$result = false;
		
		$availableConnectors = array();
		$connectorTypes=array('backlinks'=>"Backlinks");
		$systemConnectors=array();
		
		$osBacklinks=$OS->getBacklinks();
		$osBacklinksOps=$OS->getBacklinksOps();
		
		if ($blEngines=$osBacklinks->getEngines())
		{
			$blAuthData=$osBacklinksOps->getEnginesAuthData();
			
			foreach ($blEngines as $engine=>$details)
			{
				if ($details['hasAuth'])
				{
					$systemConnectors['backlinks'][$engine]['engineDetails']=$details['engineDetails'];
					$systemConnectors['backlinks'][$engine]['currentData']=(isset($blAuthData[$engine])?$blAuthData[$engine]:false);
				}
			}
		}
		
		//handle crons
		if($systemConnectors)
		{
			$osUtils = $OS->getUtils();
			
			foreach ($systemConnectors as $type=>$typeConnectors)
			{
				foreach ($typeConnectors as $engine=>$connector_details)
				{
					$connectorData = array(
						'id' => "{$type}_{$engine}",
						'type'=>$type,
						'type_title'=>$connectorTypes[$type],
						'name'=>$connector_details['engineDetails']['name'],
						'title'=>$connector_details['engineDetails']['title'],
						'currentDataAvailable'=>(empty($connector_details['currentData'])?false:true),
						'auth'=>array(
							'type'=>$connector_details['engineDetails']['auth']['type'],
							'external_link'=>$connector_details['engineDetails']['auth']['external_link'],
							'fields'=>array()
						)
					);
					
					foreach ($connector_details['engineDetails']['auth']['fields'] as $field=>$details)
					{
						$value=(isset($connector_details['currentData'][$field])?$connector_details['currentData'][$field]:'');
						
						$connectorData['auth']['fields'][$field]=array(
							'name'=>$details['name'],
							'value'=>$value,
							'required'=>$details['required']
						);
					}
						
					$availableConnectors["{$type}_{$engine}"] = $connectorData;
				}	
			}
		}

		
		//build Admin Boards
		$adminBoards = array();
		$parentItems = $OS->getMenu()->getParentItems('admin_apps_manager');
		if(!empty($parentItems))
		{
			foreach($parentItems as $item => $details)
			{
				$adminBoards[] = array('title' => $details['title'], 'name' => $item);
			}
		}
		
		$responseData =  array(
			'actionStatus' => $result,
			'actionData' => array('availableConnectors' => $availableConnectors,  'boards' => $adminBoards)
		);
		
		return $responseData;
	}
	
	public function updateConnectorsDetails($params)
	{
		$responseData = array('actionStatus' => false, 'actionData'=> array());
		
		if(isset($params['current_op']))
		{
			$OS = getOS();
			
			if($params['current_op']=='save_details')
			{
				$actionStatus=false;
				
				if ($params['type']=='backlinks')
				{
					$osBacklinks=$OS->getBacklinks();
					
					if ($blEngines=$osBacklinks->getEngines())
					{
						if (isset($blEngines[$params['name']]) AND $blEngines[$params['name']]['hasAuth'] AND $blEngines[$params['name']]['engineDetails']['auth']['type']=='input')
						{
							$connectorAuthData=array();
							$validAuthData=true;
							
							foreach ($blEngines[$params['name']]['engineDetails']['auth']['fields'] as $field=>$details)
							{
								if (!empty($params['auth']['fields'][$field]['value']))
								{
									$connectorAuthData[$field]=$params['auth']['fields'][$field]['value'];
								}
								elseif ($details['required'])
								{
									$validAuthData=false;
									break;
								}
								else
								{
									$connectorAuthData[$field]='';
								}
							}
							
							if ($validAuthData)
							{
								$osBacklinksOps=$OS->getBacklinksOps();
								
								$actionStatus=$osBacklinksOps->setEngineAuthData($params['name'],$connectorAuthData);
							}
							else
							{
								$actionStatus=false;
							}
						}
					}
				}
				
				$responseData['actionStatus']=$actionStatus;
				
				if ($actionStatus)
				{
					$responseData['actionData']['modelDetails']['currentDataAvailable'] = true;
					$responseData['actionData']['modelDetails']['auth']=$params['auth'];
					
					$responseData['actionData']['notifications'] = array(array('type'=> 'success', 'message' => _("Connector details saved successfully")));
				}
				else
				{
					$responseData['actionData']['notifications'] = array(array('type'=> 'error', 'message' => _("Unable to save connector details")));
				}
			}
			elseif($params['current_op']=='delete_details')
			{
				$actionStatus=false;
				
				if ($params['type']=='backlinks')
				{
					$osBacklinksOps=$OS->getBacklinksOps();
					
					$actionStatus=$osBacklinksOps->deleteEngineAuthData($params['name']);
				}
				
				$responseData['actionStatus']=$actionStatus;
				
				if ($actionStatus)
				{
					$responseData['actionData']['modelDetails']['currentDataAvailable'] = false;
					$auth=$params['auth'];
					foreach ($auth['fields'] as $field=>$details)
					{
						$auth['fields'][$field]['value']='';
					}
					$responseData['actionData']['modelDetails']['auth']=$auth;
					 
					$responseData['actionData']['notifications'] = array(array('type'=> 'success', 'message' => _("Connector details deleted successfully")));
				}
				else
				{
					$responseData['actionData']['notifications'] = array(array('type'=> 'error', 'message' => _("Unable to delete connector details")));
				}
			}
		}
	
		return $responseData;
	}
}

//set the ajax server
$OS = getOS();
$osAjax = $OS->getAjax();
$osAjax->setClass("osAjaxAdminConnectorsManager");
$osAjax->handle();
?>