<?php
include "../../init.php";

class osAjaxAdminCredentialsManager
{
	public function __construct()
	{
		$this->permissionsRequired = array('checkUserLogged', 'checkUserAdmin');
	}
	
	public function getCredentialsDetails($params)
	{
		$OS = getOS();
		
		$responseData = array('actionStatus' => false);
		
		$modelDetails = array(
			'checkDetails' => array(
				'osc_username' => '',
				'osc_password' => '',
				), 
			'createDetails' => array(
				'osc_username' => '',
				'osc_email' => '',
				'osc_password' => '',
				'osc_password2' => '',
				)
			);
		
		//get user email from osUser and check against appstore api
		
		$responseData['actionData']['modelDetails'] = $modelDetails;
		
		return $responseData;
	}
	
	public function updateCredentialsDetails($params)
	{
		$responseData = array('actionStatus' => false);
		
		$validAction = false;
		
		$OS = getOS();
		
		$osValidator = $OS->getValidator();
		
		if(isset($params['current_op']))
		{
			if($params['current_op'] == 'create_account')
			{
				$details = $params['createDetails'];
				
				$validAction = true;
				
				$osUserOps = $OS->getUserOps();
				
				//validate input
				if (empty($details['osc_username'])) 
				{
					$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Username missing"));	
				}
				else
				{
					$details['osc_username'] = os_clean_value($details['osc_username']);
					
					if (strlen($details['osc_username'])<3) 
					{
						$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Username too short"));
					}
					elseif (!$osUserOps->isValidUsername($details['osc_username'])) 
					{
						$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Invalid Username"));	
					}
				}
				
				if (empty($details['osc_email']))
				{
					$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Email missing"));	
				} 
				else
				{
					$details['osc_email'] = os_clean_email($details['osc_email']);
					
					if (!$osValidator->is_email($details['osc_email']))
					{
						$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Invalid email")." (".$osValidator->ERROR.")");
					}
				}
			
			
				if (empty($details['osc_password'])) 
				{
					$details['osc_password'] = '';
					$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Password is missing"));
				}
				if (empty($details['osc_password2'])) 
				{
					$details['osc_password2'] = '';
					$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Password is missing"));
				}
				elseif (strlen($details['osc_password'])<6)
				{
					$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Password too short"));
				}
				elseif ($details['osc_password'] != $details['osc_password2']) 
				{
					$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Passwords do not match"));	
				}
				
				if(!isset($responseData['actionData']['notifications']))
				{
					//register user via AppStore API
					$osAppStore = $OS->getAppStoreApi();
					
					$asResponse = $osAppStore->validateUserDetails(array('user'=> $details['osc_username'], 'email'=> $details['osc_email']));
					if(!$osAppStore->success)
					{
						$apiError = $osAppStore->getError();
						$OS->addBoxError($apiError['message']);
					}
					else
					{
						if(!isset($asResponse['user']))
						{
							$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("This username is already registered"));	
						}
						elseif($asResponse['user'] !== true)
						{
							$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("This username is already registered"));
						}
						elseif(!isset($asResponse['email']))
						{
							$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("This email is already registered"));
						}
						elseif($asResponse['email'] !== true)
						{
							$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("This email is already registered"));
						}
						else
						{
							$asResponse = $osAppStore->registerApiUser(array('user'=> $details['osc_username'], 'email'=> $details['osc_email'], 'password'=> $details['osc_password']));
							if(!$osAppStore->success)
							{
								$apiError = $osAppStore->getError();
								$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => $apiError['message']);
							}
							else
							{
								//add AppStore API credentials to settings file
								$osSettings = $OS->getSettings();
								
								$osSettings->setParam('osc_user', $asResponse['user_details']['user']);
								$osSettings->setParam('osc_api_key', $asResponse['user_details']['api_key']);
	
								//save current settings to file 
								$saveResult = $osSettings->save();
								
								$responseData['actionData']['notifications'][] = array('type'=> 'success', 'message' => _("AppStore profile successfully created !"));
								
								//flush createAccount object
								$details['osc_password'] = "";
								$details['osc_password2'] = "";
								$responseData['actionData']['modelDetails']['createAccount'] = $details;
							}
						}
					}
				}
			}
			elseif($params['current_op'] == 'check_account')
			{
				$details = $params['checkDetails'];
				
				$osUserOps = $OS->getUserOps();
				
				$validAction = true;
				//validate input
				
				if(empty($details['osc_username']))
				{
					$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Username missing !"));	
				} 
				else
				{
					$submitData['os_check_user'] = os_clean_value($details['osc_username']);
					
					if(!$osUserOps->isValidUsername($submitData['os_check_user']))
					{
						$details['osc_username']='';
						$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Username is wrong !"));
					}
				}
			
				if(empty($details['osc_password']))
				{
					$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Password missing !"));	
				} 
				else
				{
					$details['osc_password'] = os_clean_value($details['osc_password']);
					
					if((strlen($details['osc_password'])<3))
					{
						$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Password too short (min 3 characters)!"));
					}	
				} 
				
				if(!isset($responseData['actionData']['notifications']))
				{
					//check credentials via OpenS API
					$osAppStore = $OS->getAppStoreApi();
					
					$asResponse = $osAppStore->checkUser(array('user'=> $details['osc_username'], 'password'=> $details['osc_password']));
					if(!$osAppStore->success)
					{
						$apiError = $osAppStore->getError();
						$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => $apiError['message']);
					}
					else
					{
						if(!isset($asResponse['user_details']))
						{
							$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Invalid User Credentials"));
						}
						else
						{
							//add OpenS API credentials to settings file
							$osSettings = $OS->getSettings();
							
							$osSettings->setParam('osc_user', $asResponse['user_details']['user']);
							$osSettings->setParam('osc_api_key', $asResponse['user_details']['api_key']);

							//save current settings to file 
							$saveResult = $osSettings->save();
							
							$responseData['actionData']['notifications'][] = array('type'=> 'success', 'message' => _("AppStore profile successfully verified !"));
							
							//flush checkAccount object
							$details['osc_username'] = "";
							$details['osc_password'] = "";
							$responseData['actionData']['modelDetails']['checkDetails'] = $details;					
						}
					}
				}
			}
		}	
		
		if(!$validAction)
		{
			$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Current action not defined"));	
		}
		
		return $responseData;
	}
}

//set the ajax server
$OS = getOS();
$osAjax = $OS->getAjax();
$osAjax->setClass("osAjaxAdminCredentialsManager");
$osAjax->handle();
?>