<?php
include "../../init.php";

class osAjaxAdminCronsManager
{
	public function __construct()
	{
		$this->permissionsRequired = array('checkUserLogged', 'checkUserAdmin');
	}
	
	public function getCronsDetails($params)
	{
		$OS = getOS();
		
		$result = false;
		
		$availableCrons = array();
		$systemCrons = OS_Crons::getCrons();
		$interval_types = OS_Crons::getIntervalTypesHuman();
		
		//handle crons
		if($systemCrons !== false)
		{
			$osUtils = $OS->getUtils();
			
			foreach ($systemCrons as $cron_id=>$cron_details)
			{
				$cronData = array(
					'id' => $cron_id,
					'runs' => $cron_details['runs'],
					'fails' => $cron_details['fails'],
					'title' => $cron_details['title'],
					'action' => $cron_details['action'],
					'status' => $cron_details['status'],
					);
					
				$osAppOps = $OS->getAppOps();	
				
				if ($cron_details['module']=='app')
				{
					if (!isset($availableApps[$cron_details['module_name']]))
					{
						$availableApps[$cron_details['module_name']] = $osAppOps->getAppByName($cron_details['module_name']);
					}
			
					if (isset($availableApps[$cron_details['module_name']]))
					{
						$cronData['_module_title'] = $availableApps[$cron_details['module_name']]->title;
					}
					else
					{
						$cronData['_module_title'] = 'Unknown application';
					}
				}
				else
				{
					$cronData['_module_title']='CORE';
				}
				
				$cronData['_interval_human']='Every '.($cron_details['interval']==1?$interval_types[$cron_details['interval_type']]['singular']:$cron_details['interval'].' '.$interval_types[$cron_details['interval_type']]['plural']);
			
				if ($cron_details['runs']>0)
				{
					$cronData['_run_dt_human']= $osUtils->humanizeDate($cron_details['run_dt']);
				}
				
				if ($cron_details['fails']>0)
				{
					$cronData['_fail_dt_human'] = $osUtils->humanizeDate($cron_details['fail_dt']);
				}
				
				$availableCrons[$cron_id] = $cronData;
			}			
		}

		
		//build Admin Boards
		$adminBoards = array();
		$parentItems = $OS->getMenu()->getParentItems('admin_apps_manager');
		if(!empty($parentItems))
		{
			foreach($parentItems as $item => $details)
			{
				$adminBoards[] = array('title' => $details['title'], 'name' => $item);
			}
		}
		
		$responseData =  array(
			'actionStatus' => $result,
			'actionData' => array('availableCrons' => $availableCrons,  'boards' => $adminBoards)
		);
			
		return $responseData;
	}
	
	public function updateCronsDetails($params)
	{
		$responseData = array('actionStatus' => false, 'actionData'=> array());
		
		if(isset($params['current_op']))
		{
			if($params['current_op']=='disable_cron')
			{
				$cronResult = $this->handleDisableCron($params);
				
				$responseData['actionStatus'] = $cronResult['result'];
				$responseData['actionData'] = array_merge($responseData['actionData'], $cronResult);
			}
			elseif($params['current_op']=='enable_cron')
			{
				$cronResult = $this->handleEnableCron($params);
				
				$responseData['actionStatus'] = $cronResult['result'];
				$responseData['actionData'] = array_merge($responseData['actionData'], $cronResult);
			}
		}
	
		return $responseData;
	}
	
	public function handleEnableCron($params)
	{
		$responseData = array('result'=> false);
		
		$cronDetails = OS_Crons::getCronByID($params['id']);
		
		if($cronDetails !== false)
		{
			$result = OS_Crons::enableCron($cronDetails['action'], $cronDetails['module'], $cronDetails['module_name']);	

			$responseData['result'] = $result;
			if($responseData['result'])
			{
				$responseData['modelDetails']['status'] = "E";
				$responseData['notifications'][] = array('type'=> 'success', 'message' => _("Cron enabled successfully"));	
			}
			else
			{
				$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Unable to enable cron"));	
			}
		}
		
		return $responseData;
	}

	public function handleDisableCron($params)
	{
		$responseData = array('result'=> false);
		
		$cronDetails = OS_Crons::getCronByID($params['id']);
		
		if($cronDetails !== false)
		{
			$result = OS_Crons::disableCron($cronDetails['action'], $cronDetails['module'], $cronDetails['module_name']);	

			$responseData['result'] = $result;
			if($responseData['result'])
			{
				$responseData['modelDetails']['status'] = "D";
				$responseData['notifications'][] = array('type'=> 'success', 'message' => _("Cron disabled successfully"));	
			}
			else
			{
				$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Unable to disable cron"));	
			}
		}
		
		return $responseData;
	}	
}

//set the ajax server
$OS = getOS();
$osAjax = $OS->getAjax();
$osAjax->setClass("osAjaxAdminCronsManager");
$osAjax->handle();
?>