<?php
include "../../init.php";

class osAjaxAdminDatasourcesManager
{
	public function __construct()
	{
		$this->permissionsRequired = array('checkUserLogged', 'checkUserAdmin');
	}

	public function getDataSourcesDetails()
	{
		$OS = getOS();
		
		$result = false;
		
		//set initial values
		$availableDatasources = array();
		$availableConnections = array();
		$availableApps = array();
		
		//get available details
		$osDatasourceOps = $OS->getDatasourceOps();
		$osDatasources = $osDatasourceOps->getDatasources();
		
		$osAppOps = $OS->getAppOps();
		
		if($osDatasources !== false)
		{
			foreach ($osDatasources as $datasource_id=>$datasource)
			{
				//handle datasource details
				$datasource_details = $datasource->toTemplate();
				
				if ($datasource_details['module']=='app')
				{
					if (!isset($availableApps[$datasource_details['module_name']]))
					{
						$availableApps[$datasource_details['module_name']] = $osAppOps->getAppByName($datasource_details['module_name']);
					}
			
					if (isset($availableApps[$datasource_details['module_name']]))
					{
						$datasource_details['_module_title'] = $availableApps[$datasource_details['module_name']]->title;
					}
					else
					{
						$datasource_details['_module_title'] = 'Unknown application';
					}
				}
				else
				{
					$datasource_details['_module_title'] = 'CORE';
				}
				
				$availableDatasources[$datasource_id] = $datasource_details;
				
				//handle connections details
				$datasourceConnections = $osDatasourceOps->getDatasourceConnections($datasource);
				
				if ($datasourceConnections !== false)
				{
					foreach($datasourceConnections as $connection_id => $connection_details)
					{
						if ($connection_details['module']=='app')
						{
							if (!isset($availableApps[$connection_details['module_name']]))
							{
								$availableApps[$connection_details['module_name']]=$osAppOps->getAppByName($connection_details['module_name']);
							}
					
							if (isset($availableApps[$connection_details['module_name']]))
							{
								$connection_details['_module_title']=$availableApps[$connection_details['module_name']]->title;
							}
							else
							{
								$connection_details['_module_title']='Unknown application';
							}
						}
						else
						{
							$connection_details['_module_title']='CORE';
						}
						
						$availableConnections[$datasource->name][$connection_id] = $connection_details;
					}
				}
			}
			
			$result = true;
		}
		
		//build Admin Boards
		$adminBoards = array();
		$parentItems = $OS->getMenu()->getParentItems('admin_apps_manager');
		if(!empty($parentItems))
		{
			foreach($parentItems as $item => $details)
			{
				$adminBoards[] = array('title' => $details['title'], 'name' => $item);
			}
		}
				
		
		$responseData =  array(
			'actionStatus' => $result,
			'actionData' => array('boards' => $adminBoards, 'availableDatasources' => $availableDatasources, 'availableConnections' => $availableConnections)
		);
			
		return $responseData;
	}
	
	public function updateDatasourcesDetails($params)
	{
		$responseData = array('actionStatus' => false, 'actionData'=> array());
		
		if(isset($params['current_op']))
		{
			if($params['current_op']=='disable_datasource')
			{
				$datasourceResult = $this->handleDisableDatasource($params);
				
				$responseData['actionStatus'] = $datasourceResult['result'];
				$responseData['actionData'] = array_merge($responseData['actionData'], $datasourceResult);
			}
			elseif($params['current_op']=='enable_datasource')
			{
				$datasourceResult = $this->handleEnableDatasource($params);
				
				$responseData['actionStatus'] = $datasourceResult['result'];
				$responseData['actionData'] = array_merge($responseData['actionData'], $datasourceResult);
			}
		}
		else
		{
			$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Current action is not defined"));
		}
		
		return $responseData;
	}
	
	public function handleEnableDatasource($params)
	{
		$responseData = array('result'=> false);
		
		$osDatasourceOps = getOS()->getDatasourceOps();
		$datasourceDetails = $osDatasourceOps->getDatasourceByName($params['name']);
		
		if($datasourceDetails !== false)
		{
			$result = $datasourceDetails->enable();	

			$responseData['result'] = $result;
			if($responseData['result'])
			{
				$responseData['modelDetails']['status'] = "E";
				$responseData['notifications'][] = array('type'=> 'success', 'message' => _("Datasource enabled successfully"));
			}
		}
		
		if(!$responseData['result'])
		{
			$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Unable to enable datasource"));
		}
		
		return $responseData;
	}
	
	public function handleDisableDatasource($params)
	{
		$responseData = array('result'=> false);
		
		$osDatasourceOps = getOS()->getDatasourceOps();
		$datasourceDetails = $osDatasourceOps->getDatasourceByName($params['name']);
				
		if($datasourceDetails !== false)
		{
			$result = $datasourceDetails->disable();	

			$responseData['result'] = $result;
			if($responseData['result'])
			{
				$responseData['modelDetails']['status'] = "D";
				$responseData['notifications'][] = array('type'=> 'success', 'message' => _("Datasource disabled successfully"));
			}
		}

		if(!$responseData['result'])
		{
			$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Unable to disable datasource"));	
		}
		
		return $responseData;
	}	
}

//set the ajax server
$OS = getOS();
$osAjax = $OS->getAjax();
$osAjax->setClass("osAjaxAdminDatasourcesManager");
$osAjax->handle();
?>