<?php
include "../../init.php";

class osAjaxAdminEventsManager
{
	private $osUser;
	
	public function __construct()
	{
		$this->permissionsRequired = array('checkUserLogged', 'checkUserAdmin');
		$this->osUser = getOS()->getUser();  
	}

	public function getEventsDetails()
	{
		$OS = getOS();
		
		$result = false;
		
		//get available details
		$availableEvents = array();
		$osEvents = OS_Events::getEvents();
		
		if($osEvents !== false)
		{
			foreach ($osEvents as $event_id=>$event_details)
			{
				$availableEvents[$event_id] = $event_details;
				$availableEvents[$event_id]['_handlers'] = OS_Events::getEventHandlers($event_details['name']);
			}
			
			$result = true;
		}
		
		//build Admin Boards
		$adminBoards = array();
		$parentItems = $OS->getMenu()->getParentItems('admin_apps_manager');
		if(!empty($parentItems))
		{
			foreach($parentItems as $item => $details)
			{
				$adminBoards[] = array('title' => $details['title'], 'name' => $item);
			}
		}
		
		$responseData['actionStatus'] = $result;
		$responseData['actionData']['availableEvents'] = $availableEvents;
		$responseData['actionData']['boards'] = $adminBoards;
			
		return $responseData;
	}
	
	public function updateEventsDetails($params)
	{
		$responseData = array('actionStatus' => false, 'actionData'=> array());
		
		if(isset($params['current_op']))
		{
			if($params['current_op']=='disable_event')
			{
				$eventResult = $this->handleDisableEvent($params);
				
				$responseData['actionStatus'] = $eventResult['result'];
				$responseData['actionData'] = array_merge($responseData['actionData'], $eventResult);
			}
			elseif($params['current_op']=='enable_event')
			{
				$eventResult = $this->handleEnableEvent($params);
				
				$responseData['actionStatus'] = $eventResult['result'];
				$responseData['actionData'] = array_merge($responseData['actionData'], $eventResult);
			}
		}
		else
		{
			$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Current action not defined"));
		}	
	
		return $responseData;
	}
	
	public function handleEnableEvent($params)
	{
		$responseData = array('result'=> false);
		
		$eventDetails = OS_Events::getEventByID($params['id']);
		
		if($eventDetails !== false)
		{
			$result = OS_Events::enableEvent($eventDetails['name']);	

			$responseData['result'] = $result;
			if($responseData['result'])
			{
				$responseData['modelDetails']['status'] = "E";
				$responseData['notifications'][] = array('type'=> 'success', 'message' => _("Event enabled successfully"));	
			}
		}
		
		if(!$responseData['result'])
		{
			$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Unable to enable event"));	
		}
		
		return $responseData;
	}
	
	public function handleDisableEvent($params)
	{
		$responseData = array('result'=> false);
		
		$eventDetails = OS_Events::getEventByID($params['id']);
		
		if($eventDetails !== false)
		{
			$result = OS_Events::disableEvent($eventDetails['name']);	

			$responseData['result'] = $result;
			
			if($responseData['result'])
			{
				$responseData['modelDetails']['status'] = "D";
				$responseData['notifications'][] = array('type'=> 'success', 'message' => _("Event disabled successfully"));	
			}
		}
		
		if(!$responseData['result'])
		{
			$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Unable to disable event"));	
		}
		
		return $responseData;
	}	
}

//set the ajax server
$OS = getOS();
$osAjax = $OS->getAjax();
$osAjax->setClass("osAjaxAdminEventsManager");
$osAjax->handle();
?>