<?php
include "../../init.php";

class osAjaxAdminAppStore
{
	public function __construct()
	{
		$this->permissionsRequired = array('checkUserLogged', 'checkUserAdmin', 'checkAppstore');
	}

	public function getAppstoreDetails($params)
	{
		$OS = getOS();
		
		$responseData = array('actionStatus' => false);

		$osAppStore = $OS->getAppStoreApi();
		
		//get apps handler operations
		$osAppOps = $OS->getAppOps();
		
		//get system apps
		

		$appStoreData = array();
		
		$categoriesData = array();
		$oscResponse = $osAppStore->getCategories(array());
		if(!$osAppStore->success)
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'error', 'message' => _("Could not connect to Appstore"));
		}
		else
		{
			$categoriesData = $oscResponse;
			$firstCategory = current($oscResponse);
			$first_category_name = $firstCategory['name'];
			
			$oscResponse = $osAppStore->getApps(array('category'=>$first_category_name,'filter'=>false,'offset'=>false,'length'=>false));
			if(!$osAppStore->success)
			{
				$responseData['actionData']['notifications'][] =  array('type' => 'error', 'message' => _("Could not connect to Appstore"));
			}
			else  
			{
				if(isset($oscResponse['apps']))
				{
					//get appstore api apps
					$osAvailableApplications = $osAppOps->getAvailableApps();
					
					$intalledApps = array();
					if($osAvailableApplications !== false)
					{
						foreach($osAvailableApplications as $app_id=>$oneAppHandler)
						{
							$intalledApps[$oneAppHandler->name] = $oneAppHandler->version; 
						}
					}
					
					foreach($oscResponse['apps'] as $appName => $appDetails)
					{
						$appDetails['app_action'] = 'install';
						 
						if(isset($intalledApps[$appName]))
						{
							$installedAppVersion = $intalledApps[$appName];

							$appDetails['app_action'] = 'up2date';
							if (version_compare($appDetails['version'],$installedAppVersion) < 0)
							{
								$appDetails['app_action'] = 'update';
							}
						}
						
						$appStoreData[$appName] = $appDetails;
					}
					
					$responseData['actionStatus'] = true;
				}
			}
		}
		
		$responseData['actionData']['modelDetails'] = array('featuredItems'=>$appStoreData, 'categoriesItems'=> $categoriesData);
		
		return $responseData;
	}
	
	public function getCategoryDetails($params)
	{
		$responseData = array('actionStatus' => false);
		
		$appStoreData = array();
		
		if(isset($params['categoryName']))
		{
			$OS = getOS();
			
			$currentCategoryName = $params['categoryName'];
			
			$osAppStore = $OS->getAppStoreApi();
			$oscResponse = $osAppStore->getApps(array('category'=>$currentCategoryName,'filter'=>false,'offset'=>false,'length'=>false));
			if($osAppStore->success) 
			{
				if(isset($oscResponse['apps']))
				{
					//get apps handler operations
					$osAppOps = $OS->getAppOps();
					
					$osAvailableApplications = $osAppOps->getAvailableApps();
					
					$intalledApps = array();
					if($osAvailableApplications !== false)
					{
						foreach($osAvailableApplications as $app_id=>$oneAppHandler)
						{
							$intalledApps[$oneAppHandler->name] = $oneAppHandler->version; 
						}
					}
					
					foreach($oscResponse['apps'] as $appName => $appDetails)
					{
						$appDetails['app_action'] = 'install'; 
						if(isset($intalledApps[$appName]))
						{
							$installedAppVersion = $intalledApps[$appName];
							
							$appDetails['app_action'] = 'up2date';
							if (version_compare($appDetails['version'],$installedAppVersion) < 0)
							{
								$appDetails['app_action'] = 'update';
							}
						}
						
						$appStoreData[$appName] = $appDetails;
					}
					
					$responseData['actionStatus'] = true;
				}
			}
		}
		
		$responseData['actionData']['collectionDetails'] = array_values($appStoreData);
			
		return $responseData;
	}
	
	public function getAppDetails($params)
	{
		$result = false;
		
		$appDetails = array();
		
		if(isset($params['appName']))
		{
			$OS = getOS();
			
			//get apps handler operations
			$osAppStore = $OS->getAppStoreApi();
			
			//here should get info from appstore api
			$asResponse = $osAppStore->getAppDetails(array('app_name'=>$params['appName']));
			if($osAppStore->success)
			{
				if(isset($asResponse['app']))
				{
					$appDetails = $this->buildAppDetails($asResponse['app']);
					
					//get local data info for comparison
					$osAppOps = $OS->getAppOps();
						
					$oneApp = $osAppOps->getAppByName($params['appName']);
					if($oneApp !== false)
					{
						$appDetails['app_action'] = 'up2date';
						if (version_compare($appDetails['version'],$oneApp->version) < 0)
						{
							$appDetails['app_action'] = 'update';
						}
					}
						
					$result = true;
				}
			}
		}
		
		$responseData = array(
			'actionStatus' => $result,
			'actionData' => array('modelDetails' => $appDetails),
		);
			
		return $responseData;
	}
	
	private function buildAppDetails($appStoreData)
	{
		$OS = getOS();
		$osUtils = $OS->getUtils();
		$osAppOps = $OS->getAppOps();
		
		$appDetails = array(
    		'icon_board' => $appStoreData['icon_board'], 
    		'name' => $appStoreData['name'],
			'category' => $appStoreData['category'],
			'title' => $appStoreData['title'],
    		'developer_name' => $appStoreData['developer_name'],
    		'version' => $appStoreData['version'],
    		'review_stars' => $appStoreData['review_stars'],
    		'review_total' => $appStoreData['review_total'],
    		'total_installs' => $appStoreData['total_installs'],
    		'last_update_date' => date("F, d Y", strtotime($appStoreData['last_update_date'])),
			'kit_size' =>  $osUtils->humanizeSize($appStoreData['app_kit_size']),
    		'description' => $appStoreData['description'],
			'app_action' => 'install',
			'is_logged' => true,
			'app_is_installed' => true
			);
			
			
		//check if current app has reviews
		if(isset($appStoreData['reviews']))
		{
			foreach($appStoreData['reviews'] as $review_id => $reviewData)
			{
			$appDetails['reviews'][$review_id] = array(
				'stars' => $reviewData['stars'],
				'stars_total' => ($reviewData['stars']*2),
				'review_date' => date('d F Y, H:i', strtotime($reviewData['update_dt'])),
				'title' => $reviewData['title'],
				'message' =>$reviewData['message'],
				'reviewer_user' =>$reviewData['reviewer_name'],
				);
			}
		} 
		
		if(isset($appStoreData['my_review'])) $appDetails['my_review'] = $appStoreData['my_review'];
		
		
		//check if has version details
		if(isset($appStoreData['manifest']['changelog'])) $appDetails['changelog'] = $appStoreData['manifest']['changelog'];
		
		
		$appRequirementsResult = $osAppOps->checkAppRequirements($appStoreData['manifest']);
		
		$appDetails['dependencies'] = $appRequirementsResult['tests'];
		$appDetails['dependencies_result'] = $appRequirementsResult['result'];
		
		return $appDetails;			
	}
	
	public function updateAppDetails($params)
	{
		$responseData = array('actionStatus' => false, 'actionData'=> array());
		
		//check operations
		if(isset($params['current_op']))
		{
			$OS = getOS();
			
			//get apps handler operations
			$osAppStore = $OS->getAppStoreApi();
			
			//here should get info from appstore api
			$asResponse = $osAppStore->getAppDetails(array('app_name'=> $params['name']));
			if(!$osAppStore->success)
			{
				$error = $osAppStore->getError();
				$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => $error['message']);
			}
			else
			{
				if(isset($asResponse['app']))
				{
					$appDetails = $this->buildAppDetails($asResponse['app']);
					
					$operationDetails = array();
					
					$osAppOps =  $OS->getAppOps();
					
					if($params['current_op'] == 'install')
					{
						$installResult = $osAppOps->installAppStoreApp($appDetails['name']);
						
						$responseData['actionStatus'] = $installResult['result'];
						$operationDetails = $installResult;
					}
					elseif($params['current_op'] == 'uninstall')
					{
						$uninstallResult = $osAppOps->uninstallApp($appDetails['name']);
						
						$responseData['actionStatus'] = $uninstallResult['result'];
						$operationDetails = $uninstallResult;
					}
					elseif($params['current_op'] == 'update')
					{
						$updateResult = $osAppOps->updateAppStoreApp($appDetails['name']);
						
						$responseData['actionStatus'] = $updateResult['result'];
						$operationDetails = $updateResult;
					}
					elseif($params['current_op'] == 'submit_review')
					{
						$writeReviewResult = $this->submitReview($appDetails,$params);
						
						$responseData['actionStatus'] = $writeReviewResult['result'];
						$operationDetails['writeReviewResult'] = $writeReviewResult;
					}
					
					//prepare data
					$excludeFields = array('tests', 'notifications');
					foreach($excludeFields as $field)
					{
						if(isset($operationDetails[$field]))
						{
							$responseData['actionData'][$field] = $operationDetails[$field];
							unset($operationDetails[$field]);
						}
					}
					
					$responseData['actionData']['modelDetails'] = array_merge($appDetails, $operationDetails);
				}
				else
				{
					$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("App not found in AppStore !"));
				}
			}		
		}
		else
		{
			$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Invalid Operaton !"));
		}
		
		return $responseData;
	}
	
	private function submitReview($appDetails, $params)
	{
		$result = false;
		$OS = getOS();
		$responseData = array('notifications'=> array());
		
		$params['user_review_stars'] = 5;
		
		//check if appstore account is set
		
		//check if app is installed by review_user
		
		//validate review fields
		if(empty($params['user_review_title'])) $responseData['notifications'][] = array('type' => 'error', 'message'=>_('Review title is missing'));
		elseif(strlen($params['user_review_title']) < 3) $responseData['notifications'][] = array('type' => 'error', 'message'=>sprintf(_('Review title is too short (min %s characters)'), 3));
		elseif(strlen($params['user_review_title']) > 50) $responseData['notifications'][] = array('type' => 'error', 'message'=>sprintf(_('Review title is too long (max %s characters)'), 50));
		
		if(empty($params['user_review_comment'])) $responseData['notifications'][] = array('type' => 'error', 'message'=>_('Review comment is missing'));
		elseif(strlen($params['user_review_comment']) < 3) $responseData['notifications'][] = array('type' => 'error', 'message'=>sprintf(_('Review comment is too short (min %s characters)'), 3));
		elseif(strlen($params['user_review_comment']) > 1200) $responseData['notifications'][] = array('type' => 'error', 'message'=>sprintf(_('Review comment is too long (max %s characters)'), 1200));

		if(empty($params['user_review_stars'])) $responseData['notifications'][] = array('type' => 'error', 'message'=>_('Review Stars Selection is missing'));
		elseif(strlen($params['user_review_stars']) <= 0) $responseData['notifications'][] = array('type' => 'error', 'message'=> _('Invalid Review Stars Selection'));
		elseif(strlen($params['user_review_stars']) > 5) $responseData['notifications'][] = array('type' => 'error', 'message'=> _('Invalid Review Stars Selection'));
		
		if(empty($responseData['notifications']))
		{
			//send appstore api call
			$osAppStore = $OS->getAppStoreApi();
			
			$oscResponse = $osAppStore->submitAppReview(array('app_name'=>$appDetails['name'], 'title'=>$params['user_review_title'] ,'message'=>$params['user_review_comment'], 'stars' => $params['user_review_stars']));
			if(!$osAppStore->success)
			{
				$error = $osAppStore->getError();
				$responseData['notifications'][] = array('type' => 'error', 'message'=> $error['message']);
			}
			else 
			{
				$result = true;
				if($oscResponse['action'] == 'new') $responseData['notifications'][] = array('type' => 'success', 'message'=> _("Review successfully created"));
				elseif($oscResponse['action'] == 'update') $responseData['notifications'][] = array('type' => 'success', 'message'=> _("Review successfully updated"));
			}
			
			$responseData['oscResponse'] = $oscResponse;	
		}
		
		$responseData['result'] = $result;
		
		return $responseData;
	}

	public function updateStoreItem($params)
	{
		$result=false;
		
		$actionData=false;
		
		$OS = getOS();
		
		$storeApps=$this->getAppstoreDetails(array());
		
		if ($storeApps['actionStatus'])
		{
			$storeApps=$storeApps['actionData']['featuredItems'];
			
			if (isset($storeApps[$params['id']]))
			{
				if ($storeApps[$params['id']]['is_installed'] AND !$params['is_installed'])
				{
					$project=$OS->getProject();
					$user=$OS->getUser();
					$appHandler=$OS->getAppHandler();
					
					$appHandler->app_id=$params['id'];
					
					if ($appHandler->loadByAppID())
					{
						if ($appHandler->remove($project->id,$user->id))
						{
							$result=true;
							$actionData=true;
						}
					}
				}
				elseif (!$storeApps[$params['id']]['is_installed'] AND $params['is_installed'])
				{
					$project=$OS->getProject();
					$user=$OS->getUser();
					$appHandler=$OS->getAppHandler();
					
					$appHandler->app_id=$params['id'];
					$appHandler->name=$storeApps[$params['id']]['name'];
					$appHandler->title=$storeApps[$params['id']]['title'];
					
					if ($appHandler->start($project->id,$user->id))
					{
						$result=true;
						$actionData=true;
					}
				}
				else
				{
					$result=true;
					$actionData=true;
				}
			}
		}
		
		$responseData =  array(
			'actionStatus' => $result,
			'actionData' => $actionData,
		);
		
		return $responseData;
	}
}

//set the ajax server
$OS = getOS();
$osAjax = $OS->getAjax();
$osAjax->setClass("osAjaxAdminAppStore");
$osAjax->handle();
?>