<?php
include "../../init.php";

class osAjaxAdminProxiesManager
{
	public function __construct()
	{
		$this->permissionsRequired = array('checkUserLogged', 'checkUserAdmin');
	}

	public function getAvailableProxies()
	{
		$OS = getOS();
		
		$result = false;
		
		$responseData = array('actionStatus' => false, 'actionData'=> array());
		
		//get available proxies
		$availableProxies = array();
		$osProxyOps = $OS->getProxyOps();
		$allProxies = $osProxyOps->getProxies();
		if(!empty($allProxies))
		{
			foreach($allProxies as $proxy_id => $oneProxy)
			{
				$availableProxies[] = array(
					'id' => $proxy_id,
					'proxy_ip' => $oneProxy->proxy_ip,
					'proxy_port' => $oneProxy->proxy_port,
					'status' => $oneProxy->status,
					'status_reason' => $oneProxy->status_reason,
					'request_time' => $oneProxy->request_time
					);
			}
		}
		
		$adminBoards = array();
		$parentItems = $OS->getMenu()->getParentItems('admin_apps_manager');
		if(!empty($parentItems))
		{
			foreach($parentItems as $item => $details)
			{
				$adminBoards[] = array('title' => $details['title'], 'name' => $item);
			}
		}
		
		$responseData['actionStatus'] = $result;
		$responseData['actionData']['modelDetails']['boards'] = $adminBoards;
		$responseData['actionData']['modelDetails']['availableProxies'] = $availableProxies;	
			
		return $responseData;
	}
	
	public function getProxyDetails($params)
	{
		$responseData = array('actionStatus' => false, 'actionData'=> array());
		
		return $responseData;
	} 
	
	public function updateProxyDetails($params)
	{
		$responseData = array('actionStatus' => false, 'actionData'=> array());
		$valid_op = false;
		
		if(isset($params['current_op']))
		{
			if($params['current_op']=='disable_proxy')
			{
				$valid_op = true;
				
				$operationResult = $this->handleDisableProxy($params);
				
				$responseData['actionStatus'] = $operationResult['result'];
				$responseData['actionData'] = array_merge($responseData['actionData'], $operationResult);
			}
			elseif($params['current_op']=='enable_proxy')
			{
				$valid_op = true;
				$operationResult = $this->handleEnableProxy($params);
				
				$responseData['actionStatus'] = $operationResult['result'];
				$responseData['actionData'] = array_merge($responseData['actionData'], $operationResult);
			}
			elseif($params['current_op']=='edit_proxy')
			{
				$valid_op = true;
				$operationResult = $this->handleEditProxy($params);
				
				$responseData['actionStatus'] = $operationResult['result'];
				$responseData['actionData'] = array_merge($responseData['actionData'], $operationResult);
			}			
			elseif($params['current_op']=='check_proxy')
			{
				$valid_op = true;
				$operationResult = $this->handleCheckProxy($params);

				$responseData['actionStatus'] = $operationResult['result'];
				$responseData['actionData'] = array_merge($responseData['actionData'], $operationResult);
			}
			elseif($params['current_op']=='delete_proxy')
			{
				$valid_op = true;
				$operationResult = $this->handleDeleteProxy($params);
				
				$responseData['actionStatus'] = $operationResult['result'];
				$responseData['actionData'] = array_merge($responseData['actionData'], $operationResult);
			}
		}
		
		if(!$valid_op)
		{
			$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Current action not defined"));
		}
		
		return $responseData;
	}
	
	private function handleEnableProxy($params)
	{
		$responseData = array('result'=> false);
		
		if(empty($params['id']))
		{
			$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Proxy ID not found"));
		}
		elseif(!is_numeric($params['id']))
		{
			$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Invalid Proxy ID"));
		}
		else
		{
			$osProxyOps = getOS()->getProxyOps();
			$oneProxy = $osProxyOps->getProxyByID($params['id']);
			
			if($oneProxy!== false)
			{
				$oneProxy->set(array('status' => "E"));
				$saveResult = $oneProxy->save();
				
				if($saveResult)
				{
					$responseData['result'] = true;
					$responseData['modelDetails']['status'] = "E";
					$responseData['notifications'][] = array('type'=> 'success', 'message' => _("Proxy activated"));
				}
				else
				{
					$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Unable to activate proxy"));
				}
			}
			else
			{
				$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Proxy not found"));
			}			
		}
		
		return $responseData;
	}
	
	
	private function handleDisableProxy($params)
	{
		$responseData = array('result'=> false);
		
		if(empty($params['id']))
		{
			$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Proxy ID not found"));
		}
		elseif(!is_numeric($params['id']))
		{
			$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Invalid Proxy ID"));
		}
		else
		{
			$osProxyOps = getOS()->getProxyOps();
			$oneProxy = $osProxyOps->getProxyByID($params['id']);
			
			if($oneProxy!== false)
			{
				$oneProxy->set(array('status' => "D"));
				$saveResult = $oneProxy->save();
				
				if($saveResult)
				{
					$responseData['result'] = true;
					$responseData['modelDetails']['status'] = "D";
					$responseData['notifications'][] = array('type'=> 'success', 'message' => _("Proxy deactivated"));
				}
				else
				{
					$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Unable to deactivate proxy"));
				}
			}
			else
			{
				$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Proxy not found"));
			}			
		}
		
		return $responseData;
	}

	private function handleEditProxy($params)
	{
		$responseData = array('result'=> false);
		
		if((!empty($params['proxy_ip'])) && (!empty($params['proxy_port'])))
		{
			$OS = getOS();
			$osValidator = $OS->getValidator();
			
			if(!$osValidator->isValidIP($params['proxy_ip']))
			{//validate proxy_ip
				$responseData['notifications'][] = array('type'=>'error', 'message'=> _("Proxy has an invalid IP Address"));
			}
			elseif(!$osValidator->isValidPortNumber($params['proxy_port']))
			{//validate proxy_port
				$responseData['notifications'][] = array('type'=>'error', 'message'=> _("Proxy has an invalid port number"));
			}
			else
			{
				$osProxyOps = $OS->getProxyOps();
				$oneProxy = $osProxyOps->getProxyByID($params['id']);
				
				if($oneProxy!== false)
				{
					$oneProxy->set(array('proxy_ip' => $params['proxy_ip'], 'proxy_port' => $params['proxy_port']));
					$saveResult = $oneProxy->save();
					
					if($saveResult)
					{
						$responseData['result'] = true;
						$responseData['notifications'][] = array('type'=> 'success', 'message' => _("Proxy details updated"));
					}
					else
					{
						$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Proxy detail could not be saved"));
					}
				}
				else
				{
					$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Proxy not found"));
				}
			}
		}
		else
		{
			$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Proxy IP and/or Proxy Port not completed"));
		}	
		
		return $responseData;
	}
	
	private function handleCheckProxy($params)
	{
		$responseData = array('result'=> false);
		
		$osProxyOps = getOS()->getProxyOps();
		$oneProxy = $osProxyOps->getProxyByID($params['id']);
		
		if($oneProxy !== false)
		{
			$proxyDetails = array('request_time' => 0);
			
			$checkResult = $oneProxy->checkProxy();
			
			if($checkResult['result'])
			{
				//take this url from SE manager
				$checkUrl = $oneProxy->checkUrl("http://google.com");
				
				if($checkUrl['result'])
				{
					$responseData['result'] = true;
					
					//log request time
					$proxyDetails['request_time'] = $checkUrl['request_time'];
					
					$oneProxy->addLabel('google_ready');	
					
					$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Proxy is available"));
				}
				else
				{
					$oneProxy->removeLabel('google_ready');
					
					$responseData['notifications'][] = array('type'=> 'error', 'message' => sprintf(_("Proxy not working on %s"),"Google"));	
				}
			}
			else
			{
				$proxyDetails['status'] = "D";
				$proxyDetails['status_reason'] =  "invalid_proxy";
				
				$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Invalid Proxy"));	
			}
			
			//update proxy details
			$oneProxy->set($proxyDetails);
			$oneProxy->save();
		}
		else
		{
			$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Proxy not found"));
		}
		
		return $responseData;
	}
	
	private function handleDeleteProxy($params)
	{
		$responseData = array('result'=> false);
		
		$osProxyOps = getOS()->getProxyOps();
		$oneProxy = $osProxyOps->getProxyByID($params['id']);
		
		if($oneProxy !== false)
		{
			$deleteResult = $oneProxy->delete();
			
			if($deleteResult)
			{
				$responseData['result'] = true;
				$responseData['notifications'][] = array('type'=> 'success', 'message' => _("Proxy has been deleted"));
			}
			else
			{
				$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Proxy could not be deleted"));
			}
		}
		else
		{
			$responseData['notifications'][] = array('type'=> 'error', 'message' => _("Proxy not found"));
		}
		
		return $responseData;
	}
	
	
	public function updateNewProxyDetails($params)
	{
		$responseData = array('actionStatus'=> false, 'actionData'=> array());
		$valid_step = false;
		
		//check operations
		if(isset($params['current_op']))
		{
			$OS = getOS();
			
			if($params['current_op'] == 'new_proxy')
			{
				$valid_step = true;
				
				if((!empty($params['proxy_ip_box'])) && (!empty($params['proxy_port_box'])))
				{
					$osValidator = $OS->getValidator();
					
					if(!$osValidator->isValidIP($params['proxy_ip_box']))
					{//validate proxy_ip
						$responseData['actionData']['notifications'][] = array('type'=>'error', 'message'=> _("Proxy has an invalid IP Address"));
					}
					elseif(!$osValidator->isValidPortNumber($params['proxy_port_box']))
					{//validate proxy_port
						$responseData['actionData']['notifications'][] = array('type'=>'error', 'message'=> _("Proxy has an invalid port number"));
					}
					else
					{
						$proxyDetails = array(
							'proxy_ip' => $params['proxy_ip_box'],
							'proxy_port' => $params['proxy_port_box'],
							'status' => "E" 
							);
							
						$oneProxy = new OS_Proxy($proxyDetails);
						$saveResult = $oneProxy->save();

						//throw a notification
						if($saveResult)
						{
							$responseData['actionStatus'] = $saveResult;
							$responseData['actionData']['notifications'][] = array('type'=>'success', 'message'=> _("Proxy has been added"));	
						}
						else
						{
							$responseData['actionData']['notifications'][] = array('type'=>'error', 'message'=> _("Proxy could not be added"));
						}
					}
				}
				else
				{
					$responseData['actionData']['notifications'][] = array('type'=>'info', 'message'=> _("Proxy IP and/or Proxy Port not completed"));
				}
			}
			elseif($params['current_op'] == 'bulk_proxy')
			{
				$valid_step = true;
				
				$osValidator = $OS->getValidator();
				
				if(empty($params['proxy_bulk_box']))
				{
					$responseData['actionData']['notifications'][] = array('type'=>'info', 'message'=> _("Bulk Proxies field not completed"));
				}
				else
				{
					//find separator
					$proxies_list = explode(",", $params['proxy_bulk_box']);
					
					if(count($proxies_list) < 2)
					{
						$responseData['actionData']['notifications'][] = array('type'=>'error', 'message'=> _("Proxies must be separated by a comma (,)"));
					}
					else
					{
						$bukProxiesDetails = array();
						foreach($proxies_list as $proxy_full_ip)
						{
							if(!empty($proxy_full_ip) && (strpos($proxy_full_ip, ":") !== false))
							{
								//get proxy port
								list($proxy_ip, $proxy_port) = explode(":", trim($proxy_full_ip));
								$bukProxiesDetails[trim($proxy_ip)][] = trim($proxy_port); 
							}
						}
						
						if(!empty($bukProxiesDetails))
						{
							foreach($bukProxiesDetails as $current_ip => $proxy_ports)
							{
								foreach($proxy_ports as $current_port)
								{
									//create proxy
									$proxyData = array(
										'proxy_ip' => $current_ip,
										'proxy_port' => $current_port,
										'status' => "E" 
										);
										
									$oneProxy = new OS_Proxy($proxyData);
									$saveResult = $oneProxy->save();
								}
							}
							
							$responseData['actionStatus'] = true;
						}
						
						
						
						//throw notification
						if($responseData['actionStatus'])
						{
							$responseData['actionData']['notifications'][] = array('type'=>'success', 'message'=> _("Proxies list added"));	
						}
						else
						{
							$responseData['actionData']['notifications'][] = array('type'=>'error', 'message'=> _("Proxies list could not be added"));
						}
					}
				}
			}
		}
		
		if(!$valid_step)
		{
			$responseData['actionData']['notifications'][] = array('type'=>'error', 'message'=> _("Invalid Action"));
		}
			
		return $responseData;
	}
}

//set the ajax server
$OS = getOS();
$osAjax = $OS->getAjax();
$osAjax->setClass("osAjaxAdminProxiesManager");
$osAjax->handle();
?>