<?php
include "../../init.php";

class osAjaxAdminEventsManager
{
	public function __construct()
	{
		$this->permissionsRequired = array('checkUserLogged', 'checkUserAdmin');
	}

	public function getSettingsDetails()
	{
		$OS = getOS();
		
		$responseData = array('actionStatus' => true);
		
		$osSettingsItems = $OS->getSettings()->load();
		
		$sectionsItems = array(
			array('title'=>"Basic", 'name'=>"basic"),
			array('title'=>"OpenS API", 'name'=>"opensapi"),
			array('title'=>"Mail Service", 'name'=>"mailservice"),
			);
			
		$responseData['actionData']['modelDetails']['sectionsItems'] = $sectionsItems;
		$responseData['actionData']['modelDetails']['adminSettings'] = (!empty($osSettingsItems) ? $osSettingsItems : array());	
		
		return $responseData;
	}
	
	public function updateSettingsDetails($params)
	{
		$responseData = array('actionStatus' => false, 'actionData'=> array());
		$validAction = false;
		
		if(isset($params['current_op']))
		{
			if($params['current_op'] == 'change_settings')
			{
				$OS = getOS();
				$osSettings = $OS->getSettings();
				
				$validAction = true;
				
				if(isset($params['adminSettings']))
				{
					//get settings from file ?
					$settingsParams = array();
					$settingsItems = $osSettings->getSettingsItems();
					
					if(!empty($params['adminSettings']))
					{
						foreach($settingsItems as $settings_item)
						{
							if(isset($params['adminSettings'][$settings_item]))
							{
								$settingsParams[$settings_item] = $params['adminSettings'][$settings_item]; 	
							}
						}
						
						if(!empty($settingsParams))
						{
							//$osSettings->flush();
							foreach($settingsParams as $key => $val)
							{
								$osSettings->setParam($key, $val);	
							}
							
							//save current settings to file 
							$saveResult = $osSettings->save();
							
							$responseData['actionStatus'] = $saveResult;
							$responseData['actionData']['modelDetails']['adminSetings'] = $params['adminSettings'];
						}
					}
				}
				
				if($responseData['actionStatus'])
				{
					$responseData['actionData']['notifications'][] = array('type'=> 'success', 'message' => _("Admin Settings updated"));
				}
				else
				{
					$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Admin Settings could not be saved"));
				}
			}
			elseif($params['current_op']=='change_api')
			{
				$OS = getOS();
				$osSettings = $OS->getSettings();
				
				$validAction = true;
				
				if(isset($params['adminSettings']))
				{
					if(!isset($params['adminSettings']['osc_user']))
					{
						$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Missing OpenS.com API user"));
					} 
					elseif(!isset($params['adminSettings']['osc_api_key']))
					{
						$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Missing OpenS.com API key"));
					}
					else
					{
						//validate api crendetials
						$osAppStore = $OS->getAppStoreApi();
						$asResponse = $osAppStore->checkUser(array('user'=> $params['adminSettings']['osc_user'], 'api_key'=> $params['adminSettings']['osc_api_key']));
						if(!$osAppStore->success)
						{
							$apiError = $osAppStore->getError();
							$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => $apiError['message']);
						}
						else
						{
							//add OpenS API credentials to settings file
							$osSettings = $OS->getSettings();
							
							$osSettings->setParam('osc_user', $params['adminSettings']['osc_user']);
							$osSettings->setParam('osc_api_key', $params['adminSettings']['osc_user']);

							//save current settings to file 
							$saveResult = $osSettings->save();
							$responseData['actionStatus'] = $saveResult;

							if($responseData['actionStatus'])
							{
								$responseData['actionData']['notifications'][] = array('type'=> 'success', 'message' => _("OpenS.com API credentials Updated"));
								
								$responseData['actionData']['modelDetails']['adminSetings'] = $params['adminSettings'];
							}
							else
							{
								$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("OpenS.com API credentials Not Validated"));
							}
						}
					}
				}
			}
			elseif($params['current_op']=='change_smtpmail')
			{
				$OS = getOS();
				$osSettings = $OS->getSettings();
				
				$validAction = true;

				if(isset($params['adminSettings']))
				{

					if(!isset($params['adminSettings']['os_mail_smtp_host']))
					{
						$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Missing SMTP host"));
					} 
					elseif(!isset($params['adminSettings']['os_mail_smtp_username']))
					{
						$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Missing SMTP username"));
					}
					elseif(!isset($params['adminSettings']['os_mail_smtp_password']))
					{
						$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Missing SMTP password"));
					}
					elseif(!isset($params['adminSettings']['os_mail_smtp_auth']))
					{
						$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Missing SMTP authentication"));
					}
					else
					{
						//add OpenS API credentials to settings file
						$osSettings = $OS->getSettings();
						
						$osSettings->setParam('os_mail_smtp_host', $params['adminSettings']['os_mail_smtp_host']);
						$osSettings->setParam('os_mail_smtp_username', $params['adminSettings']['os_mail_smtp_username']);
						$osSettings->setParam('os_mail_smtp_password', $params['adminSettings']['os_mail_smtp_password']);
						$osSettings->setParam('os_mail_smtp_auth', $params['adminSettings']['os_mail_smtp_auth']);

						//save current settings to file 
						$saveResult = $osSettings->save();
						$responseData['actionStatus'] = $saveResult;

						if($responseData['actionStatus'])
						{
							$responseData['actionData']['notifications'][] = array('type'=> 'success', 'message' => _("SMTP Settings updated"));
							
							$responseData['actionData']['modelDetails']['adminSetings'] = $params['adminSettings'];
						}
						else
						{
							$responseData['actionData']['notifications'][] = array('type'=> 'success', 'message' => _("SMTP Settings could not be saved"));
						}
					}
				}
			}
			elseif($params['current_op']=='change_sendmail')
			{
				$OS = getOS();
				$osSettings = $OS->getSettings();
				
				$validAction = true;

				if(isset($params['adminSettings']))
				{
					if(!isset($params['adminSettings']['os_mail_sendmail_path']))
					{
						$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Missing path to sendmail program"));
					} 
					else
					{
						//add OpenS API credentials to settings file
						$osSettings = $OS->getSettings();
						
						$osSettings->setParam('os_mail_sendmail_path', $params['adminSettings']['os_mail_sendmail_path']);

						//save current settings to file 
						$saveResult = $osSettings->save();
						$responseData['actionStatus'] = $saveResult;
						
						if($responseData['actionStatus'])
						{
							$responseData['actionData']['notifications'][] = array('type'=> 'success', 'message' => _("Sendmail Settings updated"));
							
							$responseData['actionData']['modelDetails']['adminSetings'] = $params['adminSettings'];
						}
						else
						{
							$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Sendmail could not be saved"));
						}
					}
				}
			}
			elseif($params['current_op']=='change_mail_type')
			{
				$OS = getOS();
				$osSettings = $OS->getSettings();
				
				$validAction = true;

				if(isset($params['adminSettings']))
				{
					if(!isset($params['adminSettings']['os_mail_type']))
					{
						$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Missing Mail Type"));
					} 
					else
					{
						$validChange = true;
						
						//add OpenS API credentials to settings file
						$osSettings = $OS->getSettings();
						
						if($params['adminSettings']['os_mail_type'] == 'smtp')
						{
							$smt_host = $osSettings->getParam('os_mail_smtp_host');
							if($smt_host == false)
							{
								$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("SMTP server settings are incomplete"));
								$validChange = false;
							}
						}
						
						if($validChange)
						{
							$osSettings->setParam('os_mail_type', $params['adminSettings']['os_mail_type']);
	
							//save current settings to file 
							$saveResult = $osSettings->save();
							$responseData['actionStatus'] = $saveResult;
							
							if($responseData['actionStatus'])
							{
								$responseData['actionData']['notifications'][] = array('type'=> 'success', 'message' => sprintf(_("Mail Type has been changed to %s"), ucfirst($params['adminSettings']['os_mail_type'])));
								
								$responseData['actionData']['modelDetails']['adminSetings'] = $params['adminSettings'];
							}
							else
							{
								$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Mail Type could not be changed"));
							}
						}
					}
				}
			}
		}
		
		if(!$validAction)
		{
			$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => _("Current action not defined"));	
		}

		return $responseData;
	}
}

//set the ajax server
$OS = getOS();
$osAjax = $OS->getAjax();
$osAjax->setClass("osAjaxAdminEventsManager");
$osAjax->handle();
?>