<?php
include "../../init.php";

class osAjaxAdminWidgetsManager
{
	public function __construct()
	{
		$this->permissionsRequired = array('checkUserLogged', 'checkUserAdmin', 'checkAppstore');
	}

	public function getWidgetboardDetails()
	{
		$responseData =  array('actionStatus' => false);
		
		$OS = getOS();

		//process installed widgets
		$installedWidgets = array();
		$installedDetails = $this->getInstalledWidgetsDetails();
		if($installedDetails['actionStatus'])
		{
			$responseData['actionStatus'] = true;
			$installedWidgets = $installedDetails['actionData']['collectionDetails'];
		} 
			
		//process uninstalled widgets
		$uninstalledWidgets = array();
		$uninstalledDetails = $this->getUninstalledWidgetsDetails();
		if($uninstalledDetails['actionStatus'])
		{
			$responseData['actionStatus'] = true;
			$uninstalledWidgets = $uninstalledDetails['actionData']['collectionDetails'];
		}
		
		
		//check widgets versions
		if($installedDetails['actionStatus'])
		{
			//get widgets names
			$installed_widgets_names = array();
			foreach($installedWidgets as $widgetData)
			{
				$installed_widgets_names[] = $widgetData['name'];
			}
			
			//get details about app versions from Appstore
			$osAppStore = $OS->getAppStoreApi();
			$asResponse = $osAppStore->getWidgetsVersions(array('widgets'=>$installed_widgets_names));
			if($osAppStore->success)
			{
				$widgetsVersions = $asResponse;
				
				foreach($installedWidgets as $index => $widgetData)
				{
					$install_type = "up2date";
					
					if(isset($widgetsVersions[$widgetData['name']]))
					{
						if($widgetData['version'] < $widgetsVersions[$widgetData['name']])
						{
							$install_type = "update";
						}
					}
					
					$installedWidgets[$index]['install_type'] = $install_type;
				}
			}
			else
			{
				$responseData['actionData']['notifications'][] = array('type' => 'error', 'message' => _("Could not connect to Appstore"));	
			}
		}
		

		//build Admin Boards
		$adminBoards = array();
		$parentItems = getOS()->getMenu()->getParentItems('admin_apps_manager');
		if(!empty($parentItems))
		{
			foreach($parentItems as $item => $details)
			{
				$adminBoards[] = array('title' => $details['title'], 'name' => $item);
			}
		}

		$responseData['actionData']['modelDetails'] = array('installedWidgets'=> $installedWidgets, 'uninstalledWidgets' => $uninstalledWidgets, 'boards' => $adminBoards);
			
		return $responseData;
	}

	public function getInstalledWidgetsDetails()
	{
		$OS = getOS();

		$result = false;

		//get widgets handler operations
		$osWidgetOps = $OS->getWidgetOps();

		$osAvailableWidgets = $osWidgetOps->getAvailableWidgets();

		$widgetboardData = array(); $counter = 0;

		if(!empty($osAvailableWidgets))
		{
			foreach($osAvailableWidgets as $widget_id => $oneWidgetHandler)
			{
				$counter++;

				$tmpDetails = array(
					'id' => $widget_id,
					'widget_icon_board' => $oneWidgetHandler->getWidgetUrl()."/resources/widget_icon_board.png",
					'widget_link' => $OS->getConfigVar('root_url')."/admin/widgets_manage.php?widget=".$oneWidgetHandler->name,
					'name' => $oneWidgetHandler->name,
					'description' => $oneWidgetHandler->description,
					'title' => $oneWidgetHandler->title,
					'status' => $oneWidgetHandler->status,
					'version' => $oneWidgetHandler->version,
					'position' => $counter,
				);
					
				$widgetboardData[] = $tmpDetails;
					
				$result = true;
			}
		}

		uasort($widgetboardData,array($this,'sortWidgetboard'));

		$responseData =  array(
			'actionStatus' => $result,
			'actionData' => array('collectionDetails' => $widgetboardData)
		);

		return $responseData;
	}

	public function getUninstalledWidgetsDetails()
	{
		$OS = getOS();

		$result = false;

		//get widgets handler operations
		$osWidgetOps = $OS->getWidgetOps();

		//get  uninstalled widgets info
		$uninstalledWidgets = $osWidgetOps->getUninstalledWidgets();

		$uninstalledWidgetsCollection = array(); $counter = 0;
		if($uninstalledWidgets !== false)
		{
			foreach ($uninstalledWidgets as $widgetName=>$widgetPath)
			{
				$counter++;

				$widgetIconPath = (file_exists("{$widgetPath}/widget/resources/widget_icon_board.png") ? $OS->getConfigVar('root_url')."/widgets/{$widgetName}_unistalled/widget/resources/widget_icon_board.png" : "#");

				$uninstalledWidgetsCollection[] = array(
					'widget_icon_board' => $widgetIconPath,
					'name' => $widgetName,
					'title' => $widgetName,
					'position' => $counter,
					'widget_link' => $OS->getConfigVar('root_url')."/admin/widgets_manage.php?widget=".$widgetName	
				);
			}
		}


		$responseData =  array(
			'actionStatus' => $result,
			'actionData' => array('collectionDetails' => $uninstalledWidgetsCollection)
		);

		return $responseData;
	}

	public function updateWidgetDetails($params)
	{
		$responseData = array('actionStatus' => false, 'actionData'=> array());

		$valid_op = false;

		//check operations
		if(isset($params['current_op'], $params['name']))
		{
			$OS = getOS();
				
			//get widgets handler operations
			$osAppStore = $OS->getAppStoreApi();
				
			//here should get info from appstore api
			$asResponse = $osAppStore->getWidgetDetails(array('widget_name'=>$params['name']));
			if(!$osAppStore->success)
			{
				$error = $osAppStore->getError();
				$responseData['actionData']['notifications'][] = array('type'=> 'error', 'message' => $error['message']);
			}
			else
			{
				if(isset($asResponse['widget']))
				{
					$widgetDetails = $asResponse['widget'];
						
					$responseData['actionData']['modelDetails'] = $widgetDetails;
						
					$osWidgetsOps =  $OS->getWidgetsOps();
						
					if($params['current_op'] == 'update')
					{
						$valid_op = true;
						$updateResult = $osWidgetsOps->updateAppStoreApp($widgetDetails['name']);

						$responseData['actionStatus'] = $updateResult['result'];
						$responseData['actionData'] = array_merge($responseData['actionData'], $updateResult);
					}
				}
			}
		}


		if(!$valid_op)
		{
			$responseData['actionData']['notifications'][] = array("type" => "error", "message" => _("Invalid Operation"));
		}

		return $responseData;
	}

	public function updateNewWidgetDetails($params)
	{
		$responseData = array('actionStatus'=> false, 'actionData'=> array());
		$valid_step = false;

		//check operations
		if(isset($params['current_step']))
		{
			$OS = getOS();
			$osWidgetOps = $OS->getWidgetOps();
				
			if($params['current_step'] == 'validate')
			{
				$valid_step = true;

				if(!empty($params['get_widget_url_box']))
				{
					$unpackResponse = $osWidgetOps->getWidgetFromURL($params['get_widget_url_box']);
						
					$responseData['actionStatus'] = $unpackResponse['result'];
					$responseData['actionData']['modelDetails'] = array(
						'unpackTests' => $unpackResponse['tests'], 
						'current_step'=> $params['current_step'],
						'widgetKitName' => $unpackResponse['widgetKitName']
					);
						
					//add widgetInfo if provided
					if(isset($unpackResponse['widgetInfo']))
					{
						$responseData['actionData']['modelDetails']['widgetInfo'] = $unpackResponse['widgetInfo'];
					}

					if(isset($unpackResponse['validationResult']))
					{
						$responseData['actionData']['modelDetails']['validationResult'] = $unpackResponse['validationResult'];
					}
						
						
					//throw notification
					if($unpackResponse['result'])
					{
						$responseData['actionData']['notifications'][] = array('type'=>'info', 'message'=> _("Widget Downloaded"));
					}
					else
					{
						$responseData['actionData']['notifications'][] = array('type'=>'error', 'message'=> _("Widget could not be downloaded"));
					}
				}
				else
				{
					$responseData['actionData']['notifications'][] = array('type'=>'info', 'message'=> _("Widget URL field is empty"));
				}
			}
			elseif($params['current_step'] == 'install')
			{
				$valid_step = true;

				$installResponse = $osWidgetOps->installWidgetFromPath($params['widgetKitName']);

				$responseData['actionStatus'] = $installResponse['result'];
				$responseData['actionData']['modelDetails'] = array('installTests' => $installResponse['tests'], 'current_step'=> $params['current_step']);

				//add widgetInfo if provided
				if(isset($installResponse['widgetInfo']))
				{
					$responseData['actionData']['modelDetails']['widgetInfo'] = $installResponse['widgetInfo'];
				}

				//throw notification
				if($installResponse['result'])
				{
					$responseData['actionData']['notifications'][] = array('type'=>'success', 'message'=> _("Widget Successfully Installed"));
				}
				else
				{
					$responseData['actionData']['notifications'][] = array('type'=>'error', 'message'=> _("Widget could not be installed"));
				}
			}
		}

		if(!$valid_step)
		{
			$responseData['actionData']['notifications'][] = array('type'=>'error', 'message'=> _("Invalid Action"));
		}
			
		return $responseData;
	}

	public function doWidgetUpload($params)
	{
		$responseData = array('actionStatus'=> false, 'actionData'=> array());

		if(empty($_FILES))
		{
			$responseData['actionData']['notifications'][] = array('type'=>'error', 'message' => _('There are no uploaded files'));
		}
		elseif(!isset($_FILES['get_widget_upload_box']))
		{
			$responseData['actionData']['notifications'][] = array('type'=>'error', 'message' => _('There are no uploaded files'));
		}
		else
		{
			$OS = getOS();
				
			$osWidgetOps = $OS->getWidgetOps();
				
			$unpackResponse = $osWidgetOps->getWidgetFromUpload($_FILES['get_widget_upload_box']);
				
			$responseData['actionStatus'] = $unpackResponse['result'];
			
			//handle app upload notifications
			if(!empty($unpackResponse['notifications']))
			{
				$responseData['actionData']['notifications'] = $unpackResponse['notifications'];
			}
			
			//handle app upload notifications
			if(!empty($unpackResponse['tests']))
			{
				$responseData['actionData']['tests'] = $unpackResponse['tests'];
			}
			
			$responseData['actionData']['modelDetails'] = array('current_step'=>'validate', 'unpackTests' => $unpackResponse['tests'], 'widgetKitName' => $unpackResponse['widgetKitName']);
			
				
			if(isset($unpackResponse['widgetInfo']))
			{
				$responseData['actionData']['modelDetails']['widgetInfo'] = $unpackResponse['widgetInfo'];
			}

			if(isset($unpackResponse['validationResult']))
			{
				$responseData['actionData']['modelDetails']['validationResult'] = $unpackResponse['validationResult'];
			}
				
				
			//throw notification
			if($responseData['actionStatus'])
			{
				$responseData['actionData']['notifications'][] = array('type'=>'info', 'message'=> _("Widget Downloaded"));
			}
		}

		return $responseData;
	}

	private function sortWidgetboard($widget1,$widget2)
	{
		if ($widget1['position']<$widget2['position']) return -1;
		else return 1;
	}
}
//set the ajax server
$OS = getOS();
$osAjax = $OS->getAjax();
$osAjax->setClass("osAjaxAdminWidgetsManager");
$osAjax->handle();
?>