<?php
include "../../init.php";

class osAjaxDashBoard
{
	private $osProject;
	
	private $osUser;
	
	public function __construct()
	{
		$OS = getOS();
		
		$this->osUser = $OS->getUser();
		
		$this->osProject = $OS->getProject();
		
		$this->permissionsRequired = array('checkUserLogged', 'checkUserProject');
	}
		
	public function getAppboardDetails($params)
	{
		$OS = getOS();
			
		$result = false;

		$osUser = $OS->getUser();
			
		$osProject = $OS->getProject();
			
		$osUserAvailableApps = $osUser->getAvailableApps($osProject->id);
			
		$osUserApps = $osUser->getApps($osProject->id);
			
		//get apps handler operations
		$osAppOps = $OS->getAppOps();
			
		$osAvailableApplications = $osAppOps->getAvailableApps();
	
		$appboardData=array(); $counter = 0;
			
		foreach($osAvailableApplications as $app_id=>$oneAppHandler)
		{
			if($osUserAvailableApps AND in_array($oneAppHandler->name,$osUserAvailableApps) AND isset($osUserApps[$app_id]))
			{
				$counter++;
				
				$manifest=json_decode($oneAppHandler->manifest,true);
				$has_settings=(!empty($manifest['features']['has_settings'])?($manifest['features']['has_settings']=='yes'?true:false):false);
				
				$tmpDetails = array(
					'id'=>$app_id,
					'app_icon_board' => $oneAppHandler->getAppUrl()."/resources/app_icon_board.png",
					'app_link' => $OS->getConfigVar('root_url')."/users/app.php?app=".$oneAppHandler->name,
					'settings_link' => $OS->getConfigVar('root_url')."/users/app.php?app=".$oneAppHandler->name."&view=settings",
					'name'=>$oneAppHandler->name,
					'description'=>$oneAppHandler->description,
					'title'=>$osUserApps[$app_id]['app_title'],
					'has_settings'=>$has_settings,
					'settings_title' => ($has_settings?"Settings for ".$oneAppHandler->title:false),
					'status'=>$osUserApps[$app_id]['status'],
					'position'=> $osUserApps[$app_id]['position'],
					'is_installed'=>true
					);
							
				$appboardData[$app_id] = $tmpDetails;
							
				$result=true;
			}
		}
			
		uasort($appboardData,array($this,'sortAppboard'));
			
		$responseData = array('actionStatus' => $result);
		$responseData['actionData']['modelDetails']['availableApps'] = $appboardData;
				
		return $responseData;
	}

	public function updateAppDetails($params)
	{
		$responseData = array('actionStatus' => false);
		
		$OS = getOS();
		
		$appboardApps = $this->getAppboardDetails(array());
		
		if ($appboardApps['actionStatus'])
		{
			$appboardApps = $appboardApps['actionData']['modelDetails']['availableApps'];
			
			if (isset($appboardApps[$params['id']]))
			{
				$appHandler=$OS->getAppHandler();
				
				$appHandler->app_id=$params['id'];
				
				if ($appboardApps[$params['id']]['is_installed'])
				{
					if ($appHandler->loadByAppID())
					{
						unset($params['id']);
						
						if ($appHandler->position != $params['position'])
						{
							$appHandlerOps = $OS->getAppHandlerOps();
							$appHandlerOps->moveUserApp($appHandler->position,$params['position']);
						}
						
						$appHandler->set($params);
						
						if ($appHandler->save())
						{
							$responseData['actionStatus'] = true;
							$responseData['actionData']['modelDetails'] = get_object_vars($appHandler);
							$responseData['actionData']['notifications'][] = array('type' => 'success', 'message' => _("Apps Board updated"));
						}
						else
						{
							$responseData['actionData']['notifications'][] = array('type' => 'error', 'message' => _("App position not saved !"));
						}
					}
					else
					{
						$responseData['actionData']['notifications'][] = array('type' => 'error', 'message' => _("App not found !"));
					}
				}
				else
				{
					$project = $OS->getProject();
					$user = $OS->getUser();
					$appHandler=$OS->getAppHandler();
					
					$appHandler->app_id=$params['id'];
					$appHandler->name=$appboardApps[$params['id']]['name'];
					$appHandler->title=$appboardApps[$params['id']]['title'];
					
					if ($appHandler->start($project->id,$user->id))
					{
						$responseData['actionStatus'] = true;
						$responseData['actionData']['modelDetails'] = get_object_vars($appHandler); 
					}
					else
					{
						$responseData['actionData']['notifications'][] = array('type' => 'error', 'message' => _("App could not be started !"));	
					}
				}
			}
			else
			{
				$responseData['actionData']['notifications'][] = array('type' => 'error', 'message' => _("App not found !"));
			}
		}
		else
		{
			$responseData['actionData']['notifications'][] = array('type' => 'error', 'message' => _("Available Apps not found !"));
		}
		
		return $responseData;
	}
	
	private function sortAppboard($app1,$app2)
	{
		if ($app1['position']<$app2['position']) return -1;
		else return 1;
	}
}

//set the ajax server
$OS = getOS();
$osAjax = $OS->getAjax();
$osAjax->setClass("osAjaxDashBoard");
$osAjax->handle();
?>