<?php
include "../../init.php";

class osAjaxAppStore
{
	private $osProject;
	
	private $osUser;
	
	public function __construct()
	{
		$OS = getOS();
		
		$this->osUser = $OS->getUser();
		
		$this->osProject = $OS->getProject();
		
		$this->permissionsRequired = array('checkUserLogged', 'checkUserProject');
	}

	public function getAppstoreDetails($params)
	{
		$OS = getOS();
		
		$responseData = array('actionStatus' => false);
		
		$result = false;

		$osAppStore = $OS->getAppStoreApi();
		
		$osAppOps = $OS->getAppOps();
		
		$appStoreData = array();
		$categoriesData = array();
		
		$oscResponse = $osAppStore->getCategories(array());
		if($osAppStore->success)
		{
			$responseData['actionStatus'] = true;
			
			$categoriesData = $oscResponse;
			$firstCategory = current($oscResponse);
			$first_category_name = $firstCategory['name'];
			
			if (!empty($params['category']))
			{
				$for_category=$params['category'];
			}
			else
			{
				$for_category=$first_category_name;
			}
			
			$appsData=$this->getCategoryDetails(array('categoryName'=>$for_category));
			if ($appsData['actionStatus'])
			{
				$appStoreData = $appsData['actionData']['collectionDetails'];
			}
		}
		
		$responseData['actionData']['modelDetails'] = array('featuredItems'=>$appStoreData, 'categoriesItems'=> $categoriesData);
			
		return $responseData;
	}
	
	public function getCategoryDetails($params)
	{
		$responseData = array('actionStatus' => false);
		
		$appStoreData = array();
		
		if (empty($params['categoryName']) AND !empty($params['category']))
		{
			$params['categoryName']=$params['category'];
		}
		
		if(isset($params['categoryName']))
		{
			$OS = getOS();
			
			$currentCategoryName = $params['categoryName'];
			
			$osAppOps=$OS->getAppOps();
			$osUser=$OS->getUser();
			$osProject=$OS->getProject();
			
			$availableApps=$osAppOps->getAvailableApps();
			$userAvailableApps=$osUser->getAvailableApps($osProject->id);
			
			foreach ($availableApps as $app_id=>$app)
			{
				if (isset($userAvailableApps[$app_id]) AND $app->category==$currentCategoryName)
				{
					$appURL=$app->getAppUrl();
					
					$appStoreData[$app_id]=array(
						'app_id'=>$app_id,
						'name'=>$app->name,
						'version'=>$app->version,
						'title'=>$app->title,
						'description'=>$app->description,
						'icon_bar'=>"{$appURL}/resources/app_icon_bar.png",
						'icon_board'=>"{$appURL}/resources/app_icon_board.png",
						'icon_manager'=>"{$appURL}/resources/app_icon_manager.png",
						'is_added'=>false,
						'app_action'=>'add',
						'category'=>$app->category
					);
				}
			}
			
			$userAddedApps=$osUser->getApps($osProject->id);

			foreach ($userAddedApps as $app_id=>$handler)
			{
				if (isset($appStoreData[$app_id]))
				{
					$appStoreData[$app_id]['handler_id']=$handler['id'];
					$appStoreData[$app_id]['is_added']=true;
					$appStoreData[$app_id]['app_action']='remove';
				}
			}				

			$responseData['actionStatus'] = true;
		}
		
		$responseData['actionData']['collectionDetails'] = $appStoreData; 
			
		return $responseData;
	}
	
	public function getAppDetails($params)
	{
		$responseData = array('actionStatus' => false);
		
		$appDetails = array();
		
		if(isset($params['app_id']))
		{
			$OS = getOS();
			
			$osAppOps=$OS->getAppOps();
			$osUser=$OS->getUser();
			$osProject=$OS->getProject();
			
			$osUserAvailableApps=$osUser->getAvailableApps();
			
			if (isset($osUserAvailableApps[$params['app_id']]))
			{
				if ($osApp=$osAppOps->getAvailableAppByID($params['app_id']))
				{
					$appURL=$osApp->getAppUrl();
					
					$appDetails=array(
						'app_id'=>$osApp->id,
						'name'=>$osApp->name,
						'version'=>$osApp->version,
						'description'=>$osApp->description,
						'title'=>$osApp->title,
						'category'=>$osApp->category,
						'icon_bar'=>"{$appURL}/resources/app_icon_bar.png",
						'icon_board'=>"{$appURL}/resources/app_icon_board.png",
						'icon_manager'=>"{$appURL}/resources/app_icon_manager.png",
						'is_added'=>false,
						'app_action'=>'add'
					);
					
					$osAppHandlerOps=$OS->getAppHandlerOps();
					
					if ($osAppHandler=$osAppHandlerOps->getAppHandlerByAppID($params['app_id']))
					{
						$appDetails['handler_id']=$osAppHandler->id;
						$appDetails['is_added']=true;
						$appDetails['app_action']='remove';
					}
					
					$responseData['actionStatus'] = true;
				}
			}				
		}
		
		$responseData['actionData']['modelDetails']['appDetails'] = $appDetails; 
			
		return $responseData;
	}
	
	public function updateStoreItem($params)
	{
		$responseData =  array('actionStatus' => false);
		
		$actionData=false;
		
		$OS = getOS();
		
		$storeApps=$this->getAppstoreDetails($params);
		
		if ($storeApps['actionStatus'])
		{
			$storeApps = $storeApps['actionData']['modelDetails']['featuredItems'];
			
			$responseData['actionData']['storeApps'] = $storeApps;
			
			if (isset($storeApps[$params['app_id']]))
			{
				if ($storeApps[$params['app_id']]['is_added'] AND !$params['is_added'])
				{
					$project=$OS->getProject();
					$user=$OS->getUser();
					$appHandler=$OS->getAppHandler();
					
					$appHandler->app_id=$params['app_id'];
					
					if ($appHandler->loadByAppID())
					{
						if ($appHandler->remove($project->id,$user->id))
						{
							$responseData['actionStatus'] = true;
							$responseData['actionData']['modelDetails'] = get_object_vars($appHandler);
							
							$responseData['actionData']['notifications'][] = array('type' => 'success', 'message'=> _("App removed"));
						}
						else
						{
							$responseData['actionData']['notifications'][] = array('type' => 'error', 'message'=> _("App could not be removed"));	
						}
					}
					else
					{
						$responseData['actionData']['notifications'][] = array('type' => 'error', 'message'=> _("App not found !"));
					}
				}
				elseif (!$storeApps[$params['app_id']]['is_added'] AND $params['is_added'])
				{
					$project=$OS->getProject();
					$user=$OS->getUser();
					$appHandler=$OS->getAppHandler();
					
					$appHandler->app_id=$params['app_id'];
					$appHandler->name=$storeApps[$params['app_id']]['name'];
					$appHandler->title=$storeApps[$params['app_id']]['title'];
					
					if ($appHandler->start($project->id,$user->id))
					{
						$responseData['actionStatus'] = true;
						$responseData['actionData']['modelDetails'] = get_object_vars($appHandler);
						
						$responseData['actionData']['notifications'][] = array('type' => 'success', 'message'=> _("App started"));
					}
					else
					{
						$responseData['actionData']['notifications'][] = array('type' => 'error', 'message'=> _("App could not be started"));			
					}
				}
				else
				{
					$responseData['actionStatus'] = true;
					$responseData['actionData']['notifications'][] = array('type' => 'success', 'message'=> _("App started"));			
				}
			}
			else
			{
				$responseData['actionData']['notifications'][] = array('type' => 'error', 'message'=> _("App not found !"));
			}
		}
		else
		{
			$responseData['actionData']['notifications'][] = array('type' => 'error', 'message'=> _("Invalid action !"));
		}
		
		return $responseData;
	}
	
	public function updateAppDetails($params)
	{
		$responseData =  array('actionStatus' => false);
		
		if (isset($params['appDetails']) AND isset($params['is_added']))
		{
			$transParams=$params['appDetails'];
			$transParams['is_added']=$params['is_added'];
			$transParams['app_action']=$params['app_action'];
			
			$transResponse=$this->updateStoreItem($transParams);
			if ($transResponse['actionStatus'])
			{
				$responseData['actionStatus'] = true;
				$responseData['actionData']['modelDetails']['appDetails'] = $transParams;
			}
		}
		
		return $responseData;
	}
}

//set the ajax server
$OS = getOS();
$osAjax = $OS->getAjax();
$osAjax->setClass("osAjaxAppStore");
$osAjax->handle();
?>