<?php
include "../../init.php";

class osAjaxDashBoard
{
	private $osProject;
	
	private $osUser;
	
	public function __construct()
	{
		$OS = getOS();
		
		$this->osUser = $OS->getUser();
		
		$this->osProject = $OS->getProject();
		
		$this->permissionsRequired = array('checkUserLogged', 'checkUserProject');		
	}

	public function getDashboardDetails($params)
	{
		$OS = getOS();
		
		$result = false;
		
		$os_root_url = $OS->getConfigVar('root_url');

		//cache these requests
		$dashboardData  =  array('sections'=>array(),'widgets'=>array());

		//get sections data
		$osSectionOps = $OS->getSectionOps();
		
		$osProjectSections = $osSectionOps->getSectionsByUserID($this->osUser->id);
		if(!empty($osProjectSections))
		{
			//filter sections by projectID
			foreach($osProjectSections as $sectionID => $sectionData)
			{
				if($sectionData->project_id == $this->osProject->id)
				{
					$dashboardData['sections'][$sectionID] = $sectionData;
					$result = true;	
				}
			}
		}
	
		//get available widgets data
		$dashboardData['availablewidgets'] = $this->getAvailableWidgets();
	
		//get widgets data
		$osWidgetHandlerOps = $OS->getWidgetHandlerOps();
		$osUserWidgets = $osWidgetHandlerOps->getWidgetsByUserID($this->osUser->id);
		
		$allProjectWidgets = array(); 
		if(!empty($osUserWidgets))
		{
			foreach($osUserWidgets as $widgetHandlerID => $widgetHandler)
			{
				//filter widgets by projectID
				if($widgetHandler->project_id ==  $this->osProject->id)
				{
					if (isset($dashboardData['availablewidgets'][$widgetHandler->main_widget_id]))
					{
						$mainWidgetDetails = $dashboardData['availablewidgets'][$widgetHandler->main_widget_id];
						
						$widgetDetails = get_object_vars($widgetHandler);
						$widgetDetails['widget_icon'] = $os_root_url.'/widgets/'.$widgetHandler->name."/resources/widget_icon_bar.png";
						$widgetDetails['apps'] = $mainWidgetDetails['apps'];
						$widgetDetails['dashboard_features'] = $mainWidgetDetails['dashboard_features'];
						$widgetDetails['tpl_cache_time'] = $mainWidgetDetails['tpl_cache_time'];
						
						$allProjectWidgets[$widgetHandler->id] = $widgetDetails;
						
						$result = true;
					}
				}
			}	
		}
	
		$dashboardData['allwidgets'] = $allProjectWidgets;
		
		$responseData = array('actionStatus' => $result);
			
		$responseData['actionData']['modelDetails'] = $dashboardData;
			
		return $responseData;
	}
	
	public function getAvailableWidgets()
	{
		$OS = getOS();
		
		//get widget operations
		$osWidgetOps = $OS->getWidgetOps();
		
		$osAvailableWidgets = $osWidgetOps->getAvailableWidgets();
		
		//get apps available for the current user in the current project :-)
		$osUser=$OS->getUser();
		$osProject=$OS->getProject();
		
		$osUserApps=$osUser->getApps($osProject->id);
		
		$osRunningApps=array();
		foreach ($osUserApps as $app_id=>$app_details)
		{
			if ($app_details['status']=='E')
			{
				$osRunningApps[$app_details['app_name']]=$app_id;
			}
		}
		
		$osProjectWidgets = array();
		foreach($osAvailableWidgets as $widget_id=>$oneWidget)
		{
			$manifest=json_decode($oneWidget->manifest,true);
			
			$dependencies_met=true;
			$widgetApps=false;
			
			$os_root_url = $OS->getConfigVar('root_url');
			
			if (!empty($manifest['dependencies']))
			{
				foreach ($manifest['dependencies'] as $app_name=>$app_version)
				{
					if (!isset($osRunningApps[$app_name]))
					{
						$dependencies_met = false;
						break;
					}
					
					$widgetApps[$app_name]=array(
						'icon'=> $os_root_url.'/apps/'.$app_name.'/resources/app_icon_bar.png',
						'url'=> $os_root_url.'/livedash/index.php#apps/'.$app_name,
						'title'=> $osUserApps[$osRunningApps[$app_name]]['app_title']
					);
				}
			}
			
			if ($dependencies_met)
			{
				//check template cache valid
				$widgetMaxCacheTime = false;
				if(isset($manifest['cache_time']))
				{
					$widgetMaxCacheTime = $manifest['cache_time'];		
				}
				 
				$osProjectWidgets[$widget_id] = array(
					'main_widget_id'=>$widget_id,
					'widget_icon_manager' => $oneWidget->getWidgetUrl()."/resources/widget_icon_manager.png",
					'status'=>$oneWidget->status,
					'name'=>$oneWidget->name,
					'title'=>$oneWidget->title,
					'description'=>$oneWidget->description,
					'dashboard_features'=>$manifest['dashboard_features'],
					'tpl_cache_time' => $widgetMaxCacheTime,
					'apps'=>$widgetApps
					);
			}
		}
		
		return $osProjectWidgets;
	}
	
	public function addSection($params)
	{
		$responseData = array('actionStatus' => false);
		
		//cache these requests
		
		if(isset($params['name']))
		{
			//get sections data
			$OS = getOS();
			$osSectionOps = $OS->getSectionOps();
			
			$osProjectSections = $osSectionOps->getSectionsByProjectID($this->osProject->id);
			$position = count($osProjectSections) + 1;
			
			//add new section
			$sectionDetails =  array(
				'project_id' => $this->osProject->id,
				'user_id' => $this->osUser->id,
				'name' => $params['name'],
				'position' => $position,
				'icon' => '',
				'layout' => 2,
				);
			
			$oneSection = new OS_Section();
			$oneSection->set($sectionDetails);
			$sectionResponse = $oneSection->save();
			
			if($sectionResponse === true)
			{
				$responseData['actionStatus'] = true;
				$responseData['actionData']['modelDetails'] = get_object_vars($oneSection);
			}	
		}
		
		
		if($responseData['actionStatus'])
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'success', 'message' => sprintf(_("Section `%s` created"),$params['name']));	
		}
		else
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'error', 'message' => sprintf(_("Section `%s` cannot be created"),$params['name']));
		}	
		
		return $responseData;
	}
	
	public function removeSection($params)
	{
		$responseData = array('actionStatus' => false);

		//cache these requests
		if(isset($params['id']))
		{
			$currentSectionID = $params['id'];
			
			//get sections data
			$oneSection = new OS_Section();
			$oneSection->id = $currentSectionID;
			$sectionResponse = $oneSection->delete();
			
			$responseData['notification'] =  array('type' => 'reror', 'message' => _("Section cannot be removed"));
			
			if($sectionResponse !== false)
			{
				$responseData['actionStatus'] = true;
				$responseData['actionData']['modelDetails'] =  array('sectionID' => $currentSectionID, 'sectionData' => $oneSection);
			}
		}

		if($responseData['actionStatus'])
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'success', 'message' => _("Section removed"));	
		}
		else
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'error', 'message' => _("Section could not be removed"));
		}
		
		return $responseData;
	}
	
	public function getSectionWidgets($params)
	{
		$responseData = array('actionStatus' => true);
		$responseData['actionData']['modelDetails'] = array('sectionID' => $params['section_id']);	
			
		return $responseData;	
	}
	
	public function hideWidgetContainer($params)
	{
		$responseData = array('actionStatus' => false);
		
		if(isset($params['widgetID']))
		{
			$widget_id = $params['widgetID'];
			
			$newWidgetHandler = new OS_WidgetHandler();
			$newWidgetHandler->id = $widget_id;
			$newWidgetHandler->load();
			$newWidgetHandler->collapsed = "Y";
			
			$toggleResponse = $newWidgetHandler->save();
			if($toggleResponse !== false)
			{
				$responseData['actionStatus'] = true;
				$responseData['actionData']['modelDetails'] = array('widgetID' => $widget_id);	
			}
		}
		
		if($responseData['actionStatus'])
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'success', 'message' => _("Widget collapsed"));	
		}
		else
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'error', 'message' => _("Widget could not be collapsed"));
		}
		
		return $responseData;
	}
	
	public function widgetEdit($params)
	{
		$OS = getOS();
		
		//set intial variables
		$responseData = array('actionStatus' => false);
		
		if(isset($params['id'], $params['column_id'], $params['position']))
		{
			//get widget data
			$sourceWidgetData = $params;
			
			$widget_id = $params['id'];
			
			$new_column_id = $params['column_id'];
	
			$new_position = $params['position'];
			
			$widget_changed = false;
			
			//get stored widget data
			$osWidgetandlerOps = $OS->getWidgetHandlerOps();
				
			$oneWidgetHandler = $osWidgetandlerOps->getWidgetHandlerByID($widget_id);
			if(!empty($oneWidgetHandler))
			{
				$osWidgetVars =  get_object_vars($oneWidgetHandler);
				
				if(!empty($osWidgetVars))
				{
					//move current widget  (if needed)
					if(($new_column_id != $osWidgetVars['column_id']) || ($new_position != $osWidgetVars['position']))
					{
						$moveResult = $osWidgetandlerOps->handleWidgetMove($oneWidgetHandler,$new_column_id,$new_position);
					}
					
					//change other properties
					foreach($osWidgetVars as $property => $value)
					{
						if(isset($sourceWidgetData[$property]))
						{
							$oneWidgetHandler->$property = $sourceWidgetData[$property];
							$widget_changed = true;
						}
					}
				}
			}
			
			if($widget_changed)
			{
				$saveResponse = $oneWidgetHandler->save();
					
				if($saveResponse !== false)
				{
					$responseData['actionStatus'] = true;
					$responseData['actionData']['modelDetails'] = get_object_vars($oneWidgetHandler);
				}
			}
		}
		
		if($responseData['actionStatus'])
		{
			$responseData['actionData']['notifications'][] = array('type' => 'success', 'message' => _("Widget Details Updated"));
		}
		else
		{
			$responseData['actionData']['notifications'][] = array('type' => 'error', 'message' => _("Widget details could not be updated"));
		}
		
		return $responseData;		
	}
	
	public function showWidgetContainer($params)
	{
		$responseData = array('actionStatus' => false);
		
		if(isset($params['widgetID']))
		{
			$widget_id = $params['widgetID'];
			
			$newWidgetHandler = new OS_WidgetHandler();
			$newWidgetHandler->id = $widget_id;
			$newWidgetHandler->load();
			$newWidgetHandler->collapsed = "";		
			
			$toggleResponse = $newWidgetHandler->save();
			if($toggleResponse !== false)
			{
				$responseData['actionStatus'] = true;
				$responseData['actionData']['modelDetails'] = array('widgetID'=>$widget_id);	
			}
		}
		
		if($responseData['actionStatus'])
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'success', 'message' => _("Widget uncollapsed"));	
		}
		else
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'error', 'message' => _("Widget cannot be uncollapsed"));	
		}
						
		return $responseData;
	}
	
	public function moveWidgetContainer($params)
	{
		$responseData = array('actionStatus' => false);
		
		if(isset($params['widgetID'], $params['newColumnID'], $params['newPosition']))
		{
			$OS = getOS();
			
			$widget_id = $params['widgetID'];
			
			//$section_id = $params['sectionID'];
			
			$new_column_id = $params['newColumnID'];
	
			$new_position = $params['newPosition'];
			
			$osWidgetandlerOps = $OS->getWidgetHandlerOps();
			
			//do some smart stuff here
			$oneWidget = $osWidgetandlerOps->getWidgetHandlerByID($widget_id);
			
			//move widget 
			$moveResult = $osWidgetandlerOps->handleWidgetMove($oneWidget, $new_column_id, $new_position);
			
			//send as response the new panel scheme
			if($moveResult)
			{
				$dashBoardData = $this->getDashboardDetails(array());
				
				$responseData['actionStatus'] = true;	
				$responseData['actionData']['modelDetails'] =  array('widgetID' => $widget_id, 'dashboardData' => $dashBoardData['actionData']['modelDetails']);
				$responseData['actionData']['dashboardData'] =  $dashBoardData['actionData'];
			}
		}
		
		if($responseData['actionStatus'])
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'success', 'message' => _("Widget moved"));	
		}
		else
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'error', 'message' => _("Widget canot be moved"));
		}
		
		return $responseData;
	}
	
	public function addWidget2Section($params)
	{
		$responseData = array('actionStatus' => true);
		
		if(isset($params['main_widget_id'], $params['section_id']))
		{
			$main_widget_id = $params['main_widget_id'];
			
			//get widget details
			$availableWidgets = $this->getAvailableWidgets();
			
			//check required if widget exists
			if(isset($availableWidgets[$main_widget_id]))
			{
				$OS = getOS();
				
				$os_root_url = $os_root_url = $OS->getConfigVar('root_url');; 
				
				//set ucrrent section
				$section_id = $params['section_id'];
		
				//set column_id
				if (!isset($params['column_id']))
				{
					$ops=$OS->getSectionOps();
					$column_id=$ops->getEmptiestColumn($section_id);
				}
				else
				{
					$column_id=$params['column_id'];
				}
				
				//set position
				$position = (isset($params['position']) ? $params['position'] : 0 );
				
				//set backgound color
				$bgcolor = (isset($params['background_color']) ? $params['background_color'] : 'white');
				
				$osWidget = $availableWidgets[$main_widget_id];
				
				if($osWidget !== false)
				{
					if(empty($position))
					{
						//calculate new widget position
						$osWidgetandlerOps = $OS->getWidgetHandlerOps();
						
						$position = 1;
						$sectionWidgets = $osWidgetandlerOps->getWidgetsBySectionID($section_id);
						if(!empty($sectionWidgets))
						{
							foreach($sectionWidgets as $cwidgetID => $widgetData)
							{
								if($widgetData->column_id == $column_id)
								{
									$position++;
								}	
							}
						}
					}
					
					//add new widgets
					$widgetDetails = array(
						"main_widget_id" => $main_widget_id,
						"project_id" => $this->osProject->id,
						"user_id" => $this->osUser->id,
						"section_id" => $section_id,
						"column_id" => $column_id,
						"position" => $position,
						"background_color" => $bgcolor,
						"collapsed" => "",
						"name" => $osWidget['name'],
						"title" => $osWidget['title']
						);
						
					$osWidgetHandler = new OS_WidgetHandler();
					$osWidgetHandler->set($widgetDetails);	 
					$addWidgetResponse = $osWidgetHandler->save();
					
					if($addWidgetResponse === true)
					{
						$responseData['actionStatus'] = true;
						
						$osWidgetHandler->load();
						$widgetData = get_object_vars($osWidgetHandler);
		
						$widgetData['widget_icon'] = $os_root_url.'/widgets/'.$osWidgetHandler->name."/resources/widget_icon_bar.png";
						$widgetData['dashboard_features'] = $osWidget['dashboard_features'];
						$widgetData['apps'] = $osWidget['apps'];
						 
						$responseData['actionData']['modelDetails'] = $widgetData;
					}
				}
			}
		}
		
		if($responseData['actionStatus'])
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'success', 'message' => _("Widget Created"));	
		}
		else
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'error', 'message' => _("Widget cannot be created"));
		}
		
		return $responseData;
	}
	
	public function removeWidget($params)
	{
		$responseData = array('actionStatus' => false);
		
		if(isset($params['id']))
		{
			$OS =  getOS();
			
			$widget_id = $params['id'];
			
			$newWidgetHandler = new OS_WidgetHandler();
			$newWidgetHandler->id = $widget_id;
			$newWidgetHandler->load();
			
			$deleteResponse = $newWidgetHandler->delete();
			if($deleteResponse === true)
			{
				//refresh widgets positions 
				$osWidgetandlerOps = $OS->getWidgetHandlerOps();
				
				$osWidgetandlerOps->refreshWidgetsPositions($newWidgetHandler);
				
				$responseData['actionStatus'] = true;
				$responseData['actionData']['modelDetails'] = array('widgetID' => $widget_id);
			}
		}
		
		if($responseData['actionStatus'])
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'success', 'message' => _("Widget removed"));
		}
		else
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'error', 'message' => _("Widget could not be removed"));
		}
		
		return $responseData;
	}
	
	public function sectionEdit($params)
	{
		$responseData = array('actionStatus' => false);
		
		
		if(isset($params['id']))
		{
			
			$section_changed = false;

			$OS = getOS();
			
			$section_id = $params['id'];
			$client_section_data = $params;
	
			//get sections data
			$osSectionOps = $OS->getSectionOps();
				
			$osSection = $osSectionOps->getSectionByID($section_id);
			if(!empty($osSection))
			{
				$osSectionVars =  get_object_vars($osSection);
				
				if(!empty($osSectionVars))
				{
					foreach($osSectionVars as $property => $value)
					{
						if(isset($client_section_data[$property]))
						{
							$osSection->$property = $client_section_data[$property];
							$section_changed = true;
						}
					}
				}
			}
			
			if($section_changed)
			{
				$saveResponse = $osSection->save();
					
				if($saveResponse !== false)
				{
					$responseData['actionStatus'] = true;
					$responseData['actionData']['modelDetails'] = get_object_vars($osSection);		
				}
			}
		}
		
		if($responseData['actionStatus'])
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'success', 'message' => _("Section Details Updated"));	
		}
		else
		{
			$responseData['actionData']['notifications'][] =  array('type' => 'error', 'message' => _("Section details could not be updated"));
		}
		
		return $responseData;
	}
}

//set the ajax server
$OS = getOS();
$osAjax = $OS->getAjax();
$osAjax->setClass("osAjaxDashBoard");
$osAjax->handle();
?>