<?php
class OS_DAEMON_SearchEngines_Fetcher
{
	private $nextSync;
	private $fileSignatures;
	private $proxies;
	private $availableAt;
	
	public function __construct()
	{
		getOS()->initTimezone('UTC');
		
		$this->nextSync=0;
		$this->fileSignatures=array();
		$this->proxies=array();
		$this->availableSE=array();
		$this->availableAt=array();
	}
	
	public function run()
	{
		$OS=getOS();
		$osSE=$OS->getSearchEngine();
		$osSEOps=$OS->getSearchEngineOps();
		$osHttp=$OS->getHttp();
		
		while (1==1)
		{
			$this->sync();
			
			if ($queriable=$this->getQueriableSearchEngines())
			{
				if (!array_diff($this->availableSE,$queriable))
				{
					$select_engines=false;
				}
				else
				{
					$select_engines=$queriable;
				}
				
				if ($queueItem=$osSEOps->getQueuedItem($select_engines))
				{
					$proxy_id=$this->getProxyID($queueItem['engine']);
					if ($proxy_id!==false)
					{
						if ($proxy_id==0)
						{
							$osHttp->useProxy=false;
						}
						else
						{
							$osHttp->useProxy=true;
							
							//TODO: get proxy details, $osHttp->setProxy();
						}
						
						$response=$osHttp->get($queueItem['url']);
						
						if ($osHttp->success() AND !empty($response))
						{
							$osSE->storeInCache($queueItem['url'],$response,$queueItem['engine'],$queueItem['locale']);
							sleep(1);
							
							$eventParams=array(
								'queue_id'=>$queueItem['id'],
								'status'=>'done',
								'data'=>array()
							);
							
							$queueItem['processing_methods']=json_decode($queueItem['processing_methods'],true);
							
							foreach ($queueItem['processing_methods'] as $method)
							{
								if ($method_result=$osSE->$method($queueItem['query'],$queueItem['engine'],$queueItem['locale']))
								{
									if (!isset($method_result['data']))
									{
										trigger_error("{$queueItem['url']} => {$method}");
										trigger_error(var_export($method_result,true));
									}
									$eventParams['data'][$method]=$method_result['data'];
								}
							}
							
							$osSEOps->deleteQueueItem($queueItem['id']);
							
							OS_Events::triggerEvent('searchEngineQueried',$eventParams);
							
							$OS->initTimezone('UTC');	
						}
						else
						{
							if ($queueItem['fails']>=3)
							{
								$eventParams=array(
									'queue_id'=>$queueItem['id'],
									'status'=>'failed',
									'data'=>false
								);
								
								$osSEOps->deleteQueueItem($queueItem['id']);
								
								OS_Events::triggerEvent('searchEngineQueried',$eventParams);
								
								$OS->initTimezone('UTC');
							}
							else	
							{
								$osSEOps->markQueueItemAsFailed($queueItem['id']);
							}
						}
						
						$this->computeAvailableAt($queueItem['engine'],$proxy_id,(int)$osHttp->responseCode);
						
						//TODO: sync availableAt to sqla
					}
					else
					{
						sleep(5);
					}
				}
				else
				{
					sleep(5);
				}
			}
			else
			{
				sleep(5);
			}
		}
	}
	
	public function sync()
	{
		if ($this->nextSync<=time())
		{
			$included_files=get_included_files();
			
			$currentSignatures=array();
			foreach ($included_files as $file)
			{
				$sig=md5_file($file);
				
				if (!isset($this->fileSignatures[$file]))
				{
					$this->fileSignatures[$file]=$sig;
				}
				elseif ($this->fileSignatures[$file]!=$sig)
				{
					exit;
				}
			}
			
			$OS=getOS();
			$osSEOps=$OS->getSearchEngineOps();
			if ($availableSE=$osSEOps->getAvailableSearchEngines())
			{
				$availableSE=array_keys($availableSE);
				$this->availableSE=$availableSE;
			}
			
			if ($expired_se=array_diff(array_keys($this->availableAt),$availableSE))
			{
				foreach ($expired_se as $se)
				{
					unset($availableSE[$se]);
				}
			}
			
			$old_proxy_ids=array_values($this->proxies);
			
			//TODO: get actual proxies
			$this->proxies=array();
			
			$proxy_ids=array_values($this->proxies);
			$proxy_ids[]=0;
			
			if ($expired_proxy_ids=array_diff($old_proxy_ids,$proxy_ids))
			{
				foreach ($this->availableAt as $se=>$proxies)
				{
					foreach ($proxies as $pid=>$dummy)
					{
						if (in_array($pid,$expired_proxy_ids))
						{
							unset($this->availableAt[$se][$pid]);
						}
					}
				}
			}
			
			$time=time();
			
			if ($new_proxy_ids=array_diff($proxy_ids,$old_proxy_ids))
			{
				foreach ($new_proxy_ids as $pid)
				{
					foreach ($this->availableAt as $se=>$dummy)
					{
						if (!isset($this->availableAt[$se][$pid]))
						{
							$this->availableAt[$se][$pid]=$time;
						}
					}
				}
			}
			
			if ($new_se=array_diff($availableSE,array_keys($this->availableAt)))
			{
				foreach ($new_se as $se)
				{
					foreach ($proxy_ids as $pid)
					{
						$this->availableAt[$se][$pid]=$time;
					}
				}
			}
			
			$this->sortAvailableAt();
			
			//TODO: sync availableAt to SQL
			
			$this->nextSync=time()+60;
		}
	}
	
	private function computeAvailableAt($engine,$proxy_id,$response_code)
	{
		if ($response_code==200)
		{
			$wait=rand(20,50);
		}
		elseif ($response_code==503)
		{
			$wait=rand(20,60)*60;
		}
		elseif ($response_code==403)
		{
			$wait=rand(2,5)*3600;
		}
		else
		{
			$wait=60;
		}
		
		$this->availableAt[$engine][$proxy_id]=time()+$wait;
		$this->sortAvailableAt();
		
		return $wait;
	}
	
	private function sortAvailableAt()
	{
		foreach ($this->availableAt as $se=>$dummy)
		{
			asort($this->availableAt[$se]);
		}
	}
	
	private function getQueriableSearchEngines()
	{
		$result=false;
		
		foreach ($this->availableAt as $se=>$dummy)
		{
			$firstAvailableAt=reset($dummy);
			
			if ($firstAvailableAt<=time())
			{
				$result[]=$se;
			}
		}
		
		return $result;
	}
	
	private function getProxyID($engine)
	{
		$result=false;
		
		$availableProxies=array();
		$time=time();
		foreach ($this->availableAt[$engine] as $proxy_id=>$availableAt)
		{
			if ($availableAt<=$time)
			{
				$availableProxies[]=$proxy_id;
			}
			else
			{
				break;
			}
		}
		
		if (!empty($availableProxies))
		{
			$result=$availableProxies[array_rand($availableProxies)];
		}
		
		return $result;
	}
}
?>