<?php
include('../init.php');

$OS = getOS();

$osUser = $OS->getUser();
$osUser->forceUserLogin();
$osUser->forcePerm('core','is_developer');

$webscopes=array(
	'project'=>"Current project only",
	'competitors'=>"Competitors only",
	'both'=>"Both the current project and competitors"
);

$appstore=$OS->getAppStoreApi();
$categories=$appstore->getCategories();

if ($_SERVER['REQUEST_METHOD']=='POST')
{
	if (empty($_POST['name_box']))
	{
		$OS->addFieldError("Name missing",'name');
	}
	elseif (strlen($_POST['name_box'])>32)
	{
		$OS->addFieldError("Name too long. Maximum length: 32 chars",'name');
	}
	elseif (!ctype_alnum($_POST['name_box']))
	{
		$OS->addFieldError("Invalid name. Names can only contain alphanumeric chars",'name');
	}
	elseif (is_numeric($_POST['name_box'][0]))
	{
		echo $_POST['name_box'][0];
		$OS->addFieldError("Invalid name. Names must start with a letter",'name');
	}
	else
	{
		$appDevOps=$OS->getAppDeveloperOps();
		
		if ($appDevOps->getAppByName($_POST['name_box']))
		{
			$OS->addFieldError("Name already used",'name');
		}
	}

	if (empty($_POST['title_box']))
	{
		$OS->addFieldError("Title missing",'title');
	}
	elseif (strlen($_POST['name_box'])>64)
	{
		$OS->addFieldError("Title too long. Maximum length: 64 chars",'title');
	}
	
	if (empty($_POST['description_box']))
	{
		$OS->addFieldError("Description missing",'description');
	}
	elseif (strlen($_POST['description_box'])<32)
	{
		$OS->addFieldError("Description too short. Minimum length: 32 chars",'description');
	}
	
	if (empty($_POST['version_box']))
	{
		$OS->addFieldError("Version missing",'version');
	}
	else
	{
		$version=explode('.',$_POST['version_box']);
		
		if (count($version)!=3)
		{
			$OS->addFieldError("Invalid version. Version must be in the format MAJOR.MINOR.BUILD. Example: 1.0.0",'version');
		}
		else
		{
			foreach ($version as $version_number)
			{
				if (!is_numeric($version_number))
				{
					$OS->addFieldError("Invalid version. Version must be in the format MAJOR.MINOR.BUILD. Example: 1.0.0",'version');
					
					break;
				}
			}
		}
	}
	
	if (empty($_POST['webscope_box']))
	{
		$OS->addFieldError("Webscope missing",'webscope');
	}
	elseif (!isset($webscopes[$_POST['webscope_box']]))
	{
		$OS->addFieldError("Invalid webscope",'webscope');
	}
	
	if (empty($_POST['category_box']))
	{
		$OS->addFieldError("Category missing",'category');
	}
	elseif (!isset($categories[$_POST['category_box']]))
	{
		$OS->addFieldError("Unknown category",'category');
	}

	if(!isset($OS->errorMessages))
	{
		$appstoreApi=getOS()->getAppStoreApi();
		
		$appstore_details=array(
			'name'=>$_POST['name_box'],
			'title'=>$_POST['title_box'],
			'description'=>$_POST['description_box'],
			'category'=>$categories[$_POST['category_box']]['name'],
			'version'=>$_POST['version_box'],
			'webscope'=>$_POST['webscope_box']
		);
		
		$appstoreApi->addApp($appstore_details);

		if (!$appstoreApi->success)
		{
			$OS->addBoxError($appstoreApi->errData['message']);
		}
		else
		{
			$app=$OS->getAppDeveloper();
			
			$app->name=$_POST['name_box'];
			$app->title=$_POST['title_box'];
			$app->description=$_POST['description_box'];
			$app->category=$categories[$_POST['category_box']]['name'];
			$app->version=$_POST['version_box'];
			$app->webscope=$_POST['webscope_box'];
			
			if (!$app->save())
			{
				$OS->addBoxError("Unable to add application");
			}
			else
			{
				$OS->redirectTO('/developers/?msg=add_ok');
			}
		}
	}
}
else
{
	$_POST['name_box']='';
	$_POST['title_box']='';
	$_POST['description_box']='';
	$_POST['version_box']='1.0.0';
	$_POST['category_box']='';
	$_POST['webscope_box']='';
}

$tpl = $OS->getTemplate();

$tpl->setTopSectionTitle("Developer Applications");

$tpl->setVar('errors',$OS->errorMessages);
$tpl->setVar('info',$OS->infoMessages);

$tpl->setVar('ptitle',"Add application");
$tpl->setVar('categories',$categories);
$tpl->setVar('webscopes',$webscopes);


$tpl->selectedMenuItem = "developers";

$tpl->bodyTemplateName = "developers_apps_add";

echo $tpl->mainTemplateRender();
?>