<?php
class OS_APP_AdjacentKws_ReportOperations
{
	private static $_instance;
	
	public function __construct()
	{
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_AdjacentKws_ReportOperations();
		}
		
		return self::$_instance;
	}
	
	public function getReportByID($report_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE id=?",array($report_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$row['result']=json_decode($row['result'],true);
			
			$result=new OS_APP_AdjacentKws_Report();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getReports($project_id=false,$offset=0,$count=10)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE project_id=? ORDER BY `insert_dt` DESC LIMIT {$offset},{$count}";
		
		$dbresult=$db->query($query,array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['result']=json_decode($row['result'],true);
			
			$oneReport=new OS_APP_AdjacentKws_Report();
			$oneReport->set($row);
			
			$result[$row['id']]=$oneReport;
		}
		
		return $result;
	}
	
	public function getReportsCount($project_id=false)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT COUNT(id) AS total_reports FROM ".$appHandler->dbPrefix()."reports WHERE project_id=?";
		
		$dbresult=$db->query($query,array($project_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row['total_reports'];
		}
		
		return $result;
	}
	
	public function getScheduledReports($project_id=false,$count=10)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE project_id=? AND frequency<>0";
		
		$dbresult=$db->query($query,array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$is_scheduled=(time()-strtotime($row['status_dt'])>=$row['frequency']*86400);
			
			if ($is_scheduled)
			{
				$row['result']=json_decode($row['result'],true);
				
				$oneReport=new OS_APP_AdjacentKws_Report();
				$oneReport->set($row);
				
				$result[$row['id']]=$oneReport;
			}
			
			if (count($result)==$count)
			{
				break;
			}
		}
		
		return $result;
	}
	
	public function getPendingReports($project_id=false,$count=10)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE project_id=? AND status=? ORDER BY status_dt ASC LIMIT {$count}";
		
		$dbresult=$db->query($query,array($project_id,'W'));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['result']=json_decode($row['result'],true);
			
			$oneReport=new OS_APP_AdjacentKws_Report();
			$oneReport->set($row);
			
			$result[$row['id']]=$oneReport;
		}
		
		return $result;
	}
	
	public function processReportCompetitors($report,$competitors)
	{
		$result=false;
		
		$OS=getOS();
		$osTextualizer=$OS->getTextualizer();
						
		if ($initialText=$osTextualizer->extractTextFromURL($report->url))
		{
			$competingUrls=array();
			
			$se=$OS->getSearchEngine();
			
			if (count($competitors)>5)
			{
				$competitors=array_slice($competitors,0,5,true);
			}
			
			foreach ($competitors as $competitor)
			{
				if ($competitor['url']!=$report->url)
				{
					if ($competitorText=$osTextualizer->extractTextFromURL($competitor['url']))
					{
						$competingUrls[]=$competitorText;
					}
				}
			}
			
			$reportPhrases=array();
			
			if ($report->stop_words_list)
			{
				$osStopWords=getOS()->getStopWords();
				
				$stop_words=$osStopWords->getWords($report->stop_words_list);
			}
			else
			{
				$stop_words=array();
			}

			for ($i=2;$i<=3;$i++)
			{
				if ($initialPhrases=$osTextualizer->extractPhrases($initialText,$i,3,false,$stop_words,false))
				{
					$allCompetingPhrases=array();
					
					foreach ($competingUrls as $competingUrl)
					{
						if ($competingPhrases=$osTextualizer->extractPhrases($competingUrl,$i,3,false,$stop_words,false))
						{
							foreach ($competingPhrases as $phrase=>$occurances)
							{
								if (!isset($initialPhrases[$phrase]))
								{
									if (empty($allCompetingPhrases[$phrase]))
									{
										$allCompetingPhrases[$phrase]=array(
											'urls'=>0,
											'occurances'=>0
										);
									}
									
									$allCompetingPhrases[$phrase]['urls']++;
									$allCompetingPhrases[$phrase]['occurances']+=$occurances;
								}
							}
						}
					}
					
					if (!empty($allCompetingPhrases))
					{
						$osSorter=$OS->getSorter();
						
						$osSorter->setSortOrder('desc');
						
						$osSorter->setSortBy('urls');
						$osSorter->sort($allCompetingPhrases);
						
						if (count($allCompetingPhrases)>5)
						{
							$allCompetingPhrases=array_slice($allCompetingPhrases,0,5,true);
						}
						
						$osSorter->setSortBy('occurances');
						$osSorter->sort($allCompetingPhrases);
						
						$reportPhrases[$i]=$allCompetingPhrases;
					}
				}
			}
			
			$result=array(
				'competitors'=>$competitors,
				'adjacent_keywords'=>$reportPhrases
			);
		}
		
		return $result;
	}
	
	public function eventSearchEngineQueried($params)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$report_ids=array();
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."queue WHERE queue_id=?",array($params['queue_id']));
		while ($row=$db->fetchRow($dbresult))
		{
			$report_ids[]=$row['report_id'];
		}
		
		if (!empty($report_ids))
		{
			$db->query("DELETE FROM ".$appHandler->dbPrefix()."queue WHERE queue_id=?",array($params['queue_id']));
			trigger_error('reports found => '.var_export($report_ids,true));
			foreach ($report_ids as $report_id)
			{
				if ($oneReport=$this->getReportByID($report_id))
				{
					trigger_error('report loaded');
					if ($params['status']=='done')
					{
						trigger_error(var_export($params['data']['getResults'],true));
						if ($oneReport->result=$this->processReportCompetitors($oneReport,$params['data']['getResults']))
						{
							trigger_error('done');
							$oneReport->status='D';
						}
						else
						{
							trigger_error('almost');
							$oneReport->status='F';
						}
					}
					elseif ($params['status']=='failed')
					{
						trigger_error('failed');
						$oneReport->status='F';
					}
					
					$oneReport->save();
				}
			}
			
			$result=true;
		}
		
		return $result;
	}
	
	public function isQueuedReport($report_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."queue WHERE report_id=?",array($report_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function queueReport($report_id,$queue_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$dbresult=$db->query("INSERT INTO ".$appHandler->dbPrefix()."queue (report_id,queue_id) VALUES (?,?)",array($report_id,$queue_id));
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function insertReport($report)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$json_result=json_encode($report->result);
		
		$query="INSERT INTO ".$appHandler->dbPrefix()."reports (project_id,url,keyword,se,se_locale,se_title,stop_words_list,frequency,insert_dt,insert_ip,status,status_dt,status_ip,result) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		$dbresult=$db->query($query,array($report->project_id,$report->url,$report->keyword,$report->se,$report->se_locale,$report->se_title,$report->stop_words_list,$report->frequency,$time,$ip,$report->status,$time,$ip,$json_result));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateReport($report)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$json_result=json_encode($report->result);
		
		$query="UPDATE ".$appHandler->dbPrefix()."reports SET status=?,status_dt=?,status_ip=?,result=? WHERE id=?";
		$dbresult=$db->query($query,array($report->status,$time,$ip,$json_result,$report->id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteReportByID($report_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."reports WHERE id=?";
		$dbresult=$db->query($query,array($report_id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteDataByProjectID($project_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$dbresult=$db->query("DELETE FROM ".$appHandler->dbPrefix()."reports WHERE project_id=?",array($project_id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
}
?>