<?php
class OS_APPVIEW_AdjacentKws_Analyze extends OS_AppViewBase
{
	public $regenerationFrequencies=array(0=>"Never",1=>"Every day",5=>"Every 5 days",10=>"Every 10 days",15=>"Every 15 days",30=>"Every 30 days");
	
	public function __construct()
	{
		parent::__construct();
	}
	
	public function processRequest()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		$osProject=$OS->getProject();
		
		$searchEngineOps=$OS->getSearchEngineOps();
		$stopWords=$OS->getStopWords();
		
		$searchEngines=$searchEngineOps->getAvailableSearchEnginesFull();
		$stopWordsLists=$stopWords->getAvailableLists();
		
		$requestParams=$appPlugin->getRequestParams();
		
		$requestParams['stop_words_lists']=$stopWordsLists;
		$requestParams['search_engines']=$searchEngines;
		
		if ($_SERVER['REQUEST_METHOD']=='POST')
		{
			$osValidator=$OS->getValidator();
			$osUtils=$OS->getUtils();
			
			if (empty($requestParams['url_box']))
			{
				$OS->addFieldError("URL missing",'url');
			}
			else
			{
				$requestParams['url_box']=$osUtils->prependHTTP($requestParams['url_box']);
				
				if (!$osValidator->is_url($requestParams['url_box']))
				{
					$OS->addFieldError(_("Invalid URL"),'url');
				}
			}
			
			if (empty($requestParams['keywords_box']))
			{
				$OS->addFieldError(_("Keyword missing"),'keyword');
			}
			else
			{
				$keywords=explode("\n",$requestParams['keywords_box']);
				$valid_keywords=array();
				
				foreach ($keywords as $keyword)
				{
					$keyword=trim($keyword);
					
					if (strlen($keyword)>=3)
					{
						$valid_keywords[]=$keyword;
					}
				}
				
				if (empty($valid_keywords))
				{
					$OS->addFieldError(_("No valid keywords provided. Minimum length: 3 chars"),'keywords');
				}
			}
			
			if (empty($requestParams['se_box']))
			{
				$OS->addFieldError(_("Search Engine missing"),'se');
			}
			elseif (!isset($searchEngines[$requestParams['se_box']]))
			{
				$OS->addFieldError(_("Unknown search engine"),'se');
			}
			else
			{
				$se_title=$searchEngines[$requestParams['se_box']]['title'];
				
				if (!empty($searchEngines[$requestParams['se_box']]['has_locales']))
				{
					if (empty($requestParams['se_locale_box']))
					{
						$OS->addFieldError(_("Search Engine locale missing"),'se_locale');
					}
					elseif (!isset($searchEngines[$requestParams['se_box']]['_locales'][$requestParams['se_locale_box']]))
					{
						$OS->addFieldError(_("Unknown search engine locale"),'se_locale');
					}
					else
					{
						$se_title.=' '.$searchEngines[$requestParams['se_box']]['_locales'][$requestParams['se_locale_box']]['title'];
					}
				}
				else
				{
					$requestParams['se_locale_box']='';
				}
			}

			$stop_words_list='';
			if (!empty($requestParams['stop_words_list_box']))
			{
				if (!isset($stopWordsLists[$requestParams['stop_words_list_box']]))
				{
					$OS->addFieldError(_("Invalid list"),'stop_words_list');
				}
				else
				{
					$stop_words_list=$requestParams['stop_words_list_box'];
				}
			}
			else
			{
				$requestParams['stop_words_list_box']='';
			}

			if (empty($requestParams['frequency_box']))
			{
				$requestParams['frequency_box']=0;
			}
			elseif (!isset($this->regenerationFrequencies[$requestParams['frequency_box']]))
			{
				$OS->addFieldError(_("Invalid frequency"),'frequency');
			}
			
			if (!isset($OS->errorMessages))
			{
				$fork_report=true;
				
				foreach ($valid_keywords as $keyword)
				{
					$report=new OS_APP_AdjacentKws_Report();
					
					$report->project_id=$osProject->id;
					$report->url=$requestParams['url_box'];
					$report->keyword=$keyword;
					$report->se=$requestParams['se_box'];
					$report->se_locale=$requestParams['se_locale_box'];
					$report->se_title=$se_title;
					$report->stop_words_list=$stop_words_list;
					$report->frequency=$requestParams['frequency_box'];
					$report->status='W';
					
					if ($report->save())
					{
						if ($fork_report)
						{
							$forked=OS_Fork::fork('app','adjacentkws','generate_report',array('project_id'=>$report->project_id,'report_id'=>$report->id));
							$fork_report=false;
						}
					}
				}
				
				$OS->redirectTO($appPlugin->getAppActionUrl('main'),true);
			}
		}
		else
		{
			$requestParams['url_box']='';
			$requestParams['keywords_box']='';
			$requestParams['se_box']='';
			$requestParams['se_locale_box']='';
			$requestParams['stop_words_list_box']='';
			$requestParams['frequency_box']=0;
		}
		
		return $requestParams;
	}
	
	public function render()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$tplVars=$this->processedRequest;
		$tplVars['appURL']=$appPlugin->getAppUrl();
		$tplVars['regenerationFrequencies']=$this->regenerationFrequencies;
		
		$locales=array();
		foreach ($tplVars['search_engines'] as $engine=>$engine_details)
		{
			if ($engine_details['has_locales'])
			{
				foreach ($engine_details['_locales'] as $locale=>$details)
				{
					$locales[$engine][$locale]=$details['title'];
				}
			}
		}
		
		$headContents="<script type='text/javascript'>
		var seLocales=".json_encode($locales).";
		function updateLocales(engine)
		{
			if (typeof seLocales[engine]=='undefined')
			{
				$('#locales_container').hide();
			}
			else
			{
				$('#se_locale_box').empty();
				$('#se_locale_box').append(\"<option value=''></option>\");
				for (var i in seLocales[engine])
				{
					$('#se_locale_box').append(\"<option value='\"+i+\"'>\"+seLocales[engine][i]+\"</option>\");
				}
		
				$('#locales_container').show();
			}
		}
		</script>";
		
		$tpl = $OS->getTemplate();
		
		$tpl->setHeadContents($headContents);
		
		return $tpl->fetchTemplate('analyze',$tplVars);
	}
}
?>