<?php
class OS_APP_backlinks extends OS_AppBase
{
	private static $_instance;
	
	public $linkLabels;
	
	protected function __construct()
	{
		parent::__construct();
		
		$user=getOS()->getUser();
		
		if ($user->checkPerm('backlinks','supervise'))
		{
			$this->addMenuItem('supervisor', array("name" => _("Supervisor"), 'routerOption'=> "handleSupervisorView"));
			$this->addMenuItem('labels',array("name" => _("Link Labels"), 'routerOption' => "handleLabelsView"));
		}
		
		$this->addMenuItem('linkbuilding', array("name" => _("Link Building"), 'before' => 'labels', 'routerOption'=> "handleLinkBuildingView"));
				
		$this->setRouterOption("view","handleMainView");
		$this->setRouterOption("linksmanage","handleLinksManageView");
		$this->setRouterOption("labelsmanage","handleLabelsManageView");
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_backlinks();
		}
		return self::$_instance;
	}
	
	public function handleMainView()
	{
		$user=getOS()->getUser();

		if ($user->checkPerm('backlinks','supervise'))
		{
			return $this->handleSupervisorView();
		}
		else
		{
			return $this->handleLinkBuildingView();
		}
	}
	
	public function handleSupervisorView()
	{
		getOS()->getUser()->forcePerm('backlinks','supervise');
		
		$viewData=new OS_APPVIEW_Backlinks_Supervisor();
		
		return $viewData->render();
	}
	
	public function handleLinkBuildingView()
	{
		$user=getOS()->getUser();
		
		if (!$user->checkPerm('backlinks','supervise'))
		{
			$user->forcePerm('backlinks','view');
		}
		
		$viewData=new OS_APPVIEW_Backlinks_LinkBuilding();
		
		return $viewData->render();
	}
	
	public function handleLinksManageView()
	{
		$user=getOS()->getUser();
		
		if (!$user->checkPerm('backlinks','supervise'))
		{
			$user->forcePerm('backlinks','view');
		}
		
		$viewData=new OS_APPVIEW_Backlinks_LinksManage();
		
		return $viewData->render();
	}
	
	public function handleLabelsView()
	{
		getOS()->getUser()->forcePerm('backlinks','supervise');
		
		$viewData=new OS_APPVIEW_Backlinks_Labels();
		
		return $viewData->render();
	}
	
	public function handleLabelsManageView()
	{
		getOS()->getUser()->forcePerm('backlinks','supervise');
		
		$viewData=new OS_APPVIEW_Backlinks_LabelsManage();
		
		return $viewData->render();
	}
	
	protected function defineAppPermissions()
	{
		$this->appPermissions=array(
			'backlinks'=>array(
				'view'=>array('name'=>_("Link building")),
				'supervise'=>array('name'=>_("Superviser"))
			)
		);
	}
	
	public function &getLink()
	{
		return OS_APP_backlinks_link::get_instance();
	}
	
	public function &getOperations()
	{
		return OS_APP_backlinks_linkoperations::get_instance();
	}
	
	public function &getLabel()
	{
		return OS_APP_backlinks_label::get_instance();
	}
	
	public function &getLabelOperations()
	{
		return OS_APP_backlinks_labeloperations::get_instance();
	}
	
	public function eventProjectDeleted($params)
	{
		$ops=OS_APP_Backlinks_LinkOperations::get_instance();
		
		return $ops->deleteDataByProjectID($params['project_id']);
	}
	
	public function eventAppAddedToProject($params)
	{
		$result=false;
		
		if ($params['app_name']=='backlinks')
		{
			$result=OS_Fork::fork('app','backlinks','import_links',array('project_id'=>$params['project_id']));
		}
		
		return $result;
	}
}
?>