<?php
class OS_APP_backlinks_link
{
	private static $_instance;
	public $id;
	public $source_url;
	public $target_url;
	public $anchor;
	
	public function __construct()
	{
		$this->id=false;
		$this->source_url='';
		$this->target_url='';
		$this->anchor='';
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_backlinks_link();
		}
		return self::$_instance;
	}
	
	public function extractHost($url)
	{
		return parse_url($url,PHP_URL_HOST);
	}
	
	public function exists()
	{
		$result=array('href'=>false,'anchor'=>false);
		
		if ($this->source_url AND $this->target_url AND $this->anchor)
		{
			$OS=getOS();
			$http=$OS->getHttp();
			
			if ($response=$http->get($this->source_url))
			{
				$utils=$OS->getUtils();
				
				$doc=new DOMDocument();
				libxml_use_internal_errors(true);
				$doc->loadHTML($response);
				libxml_use_internal_errors(false);
				$xpath=new DOMXPath($doc);
				
				$entries=$xpath->query("//a");
				$pattern="/^http\:\/\/(www.)?".str_replace('/','\/',preg_quote($utils->stripifyURL($this->target_url)))."\/?$/i";
				
				foreach ($entries as $entry)
				{
					if (preg_match($pattern,$entry->getAttribute('href')))
					{
						$result['href']=true;
						
						if (trim(strtolower((string)$entry->nodeValue))==trim(strtolower($this->anchor)))
						{
							$result['anchor']=true;
						}
					}
				}
			}
		}
		
		return $result;
	}
	
	public function markAsChecked()
	{
		$ops=getOS()->getAppHandler()->getAppPlugin()->getOperations();
		
		return $ops->markLinkAsChecked($this);
	}
	
	public function save()
	{
		$ops=getOS()->getAppHandler()->getAppPlugin()->getOperations();
		if (!$this->id)
			{
			if (!$this->id=$ops->insertLink($this)) return false;
			return true;
			}
		else return $ops->updateLink($this);
	}
	
	public function load()
	{
		if (!$this->id) return false;
		$ops=getOS()->getAppHandler()->getAppPlugin()->getOperations();
		if (!$link=$ops->getLinkByID($this->id)) return false;
		$this->project_id=$link->project_id;
		$this->label_id=$link->label_id;
		$this->user_id=$link->user_id;
		$this->source_host=$link->source_host;
		$this->source_url=$link->source_url;
		$this->source_pr=$link->source_pr;
		$this->target_host=$link->target_host;
		$this->target_url=$link->target_url;
		$this->anchor=$link->anchor;
		$this->status=$link->status;
		return true;
	}
	
	public function delete()
	{
		if (!$this->id) return false;
		
		$ops=getOS()->getAppHandler()->getAppPlugin()->getOperations();
		
		return $ops->deleteLinkByID($this->id);
	}
	
	public function approve()
	{
		if (!$this->id) return false;
		
		$ops=$OS->getAppHandler()->getAppPlugin()->getOperations();
		
		if ($ops->approveLinkByID($this->id))
		{
			$this->load();
			return true;
		}
		else
		{
			return false;
		}
	}
	
	public function reject()
	{
		if (!$this->id) return false;
		
		$ops=getOS()->getAppHandler()->getAppPlugin()->getOperations();
		
		if ($ops->rejectLinkByID($this->id))
		{
			$this->load();
			return true;
		}
		else
		{
			return false;
		}
	}
	
	public function toTemplate()
	{
		if (!$this->id) return false;
		
		$utils=getOS()->getUtils();
		
		$statusesHuman=array('W'=>_('Waiting'),'A'=>_('Approved'),'R'=>_('Rejected'));
		
		$user=getOS()->getUser();
		$app=getOS()->getAppHandler()->getAppPlugin();
		
		if (is_null($app->linkLabels))
		{
			$app->linkLabels=array();
			
			if ($labels=$app->getLabelOperations()->getLabels())
			{
				foreach ($labels as $label)
				{
					$app->linkLabels[$label->id]=$label->name;
				}
			}
		}

		$link_arr=array(
			'source_url_safe'=>$utils->getSafeURL($this->source_url),
			'source_host'=>$this->source_host,
			'target_url_safe'=>$utils->getSafeURL($this->target_url),
			'target_host'=>$this->target_host,
			'source_pr'=>$this->source_pr,
			'anchor'=>$this->anchor,
			'status_human'=>$statusesHuman[$this->status],
			'label_id'=>$this->label_id,
			'label_name'=>(empty($this->label_id)?'':(isset($app->linkLabels[$this->label_id])?$app->linkLabels[$this->label_id]:''))
		);
		
		if ($this->status=='W')
		{
			$link_arr['edit_url']=$app->getAppActionUrl('linkmanage',array('op'=>'edit','link_id'=>$this->id));
		}
		else
		{
			$link_arr['edit_url']=false;
		}
		
		if ($this->status=='W')
		{
			$link_arr['delete_url']=$app->getAppActionUrl('linkbuilding',array('op'=>'delete','link_id'=>$this->id));
		}
		else
		{
			$link_arr['delete_url']=false;
		}
		
		return $link_arr;
	}
}
?>