<?php
class OS_APP_ContentStrategy extends OS_AppBase
{
	private static $_instance;

	public function __construct()
	{
		parent::__construct();
		
		$this->addMenuItem('view', array("name" => _("Overview"), 'routerOption'=> "handleMainView"));
		$this->addMenuItem('inventory', array("name" => _("Inventory"), 'routerOption'=> "handleInventoryView"));
		$this->addMenuItem('research', array("name" => _("Research"), 'routerOption'=> "handleResearchView"));
		$this->addMenuItem('audience', array("name" => _("Audience"), 'routerOption'=> "handleAudienceView"));
		
		$this->setRouterOption("inventory_ae", "handleInventoryAEView");
		$this->setRouterOption("inventory_import", "handleInventoryImportView");
		$this->setRouterOption("inventory_import_crawl", "handleInventoryImportCrawlView");
		$this->setRouterOption("audience_persona_ae", "handleAudiencePersonaAEView");
		$this->setRouterOption("audience_funnelstage_ae", "handleAudienceFunnelStageAEView");
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_ContentStrategy();
		}
		
		return self::$_instance;
	}
	
	public function handleMainView()
	{
		$viewData=new OS_APPVIEW_ContentStrategy_Main();
		
		return $viewData->render();
	}
	
	public function handleInventoryView()
	{
		$viewData=new OS_APPVIEW_ContentStrategy_Inventory();
		
		return $viewData->render();
	}
	
	public function handleInventoryAEView()
	{
		$viewData=new OS_APPVIEW_ContentStrategy_Inventory_AE();
		
		return $viewData->render();
	}
	
	public function handleInventoryImportView()
	{
		$viewData=new OS_APPVIEW_ContentStrategy_Inventory_Import();
		
		return $viewData->render();
	}
	
	public function handleInventoryImportCrawlView()
	{
		$viewData=new OS_APPVIEW_ContentStrategy_Inventory_Import_Crawl();
		
		return $viewData->render();
	}
	
	public function handleResearchView()
	{
		$viewData=new OS_APPVIEW_ContentStrategy_Research();
		
		return $viewData->render();
	}
	
	public function handleAudienceView()
	{
		$viewData=new OS_APPVIEW_ContentStrategy_Audience();
		
		return $viewData->render();
	}
	
	public function handleAudiencePersonaAEView()
	{
		$viewData=new OS_APPVIEW_ContentStrategy_Audience_Persona_AE();
		
		return $viewData->render();
	}
	
	public function handleAudienceFunnelStageAEView()
	{
		$viewData=new OS_APPVIEW_ContentStrategy_Audience_FunnelStage_AE();
		
		return $viewData->render();
	}
	
	protected function defineAppPermissions()
	{
		$this->appPermissions=array(
			'contentstrategy'=>array(
				'view'=>array('name'=>"Access Content Strategy application"),
			)
		);
	}
	
	public function eventAppAddedToProject($params)
	{
		$result=false;
		
		if ($params['app_name']=='contentstrategy')
		{
			$personaOps=OS_APP_ContentStrategy_PersonaOperations::get_instance();
			if ($personaOps->createDefaultPersona($params['project_id']))
			{
				$funnelOps=OS_APP_ContentStrategy_FunnelStageOperations::get_instance();
				if ($funnelOps->createDefaultFunnelStages($params['project_id']))
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public function eventProjectDeleted($params)
	{
		$result=false;
		
		$funnelstageOps=OS_APP_ContentStrategy_FunnelStageOperations::get_instance();
		if ($funnelstageOps->deleteFunnelStagesByProjectID($params['project_id']))
		{
			$personaOps=OS_APP_ContentStrategy_PersonaOperations::get_instance();
			if ($personaOps->deletePersonasByProjectID($params['project_id']))
			{
				$contentOps=OS_APP_ContentStrategy_ContentOperations::get_instance();
				if ($contentOps->deleteContentsByProjectID($params['project_id']))
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
}
?>