<?php
class OS_APP_ContentStrategy_Content
{
	private static $_instance;
	
	public $id;
	public $project_id;
	public $title;
	public $author;
	public $url;
	public $host;
	public $type;
	public $keywords;
	public $persona_id;
	public $funnelstage_id;
	public $placement;
	public $due_date;
	public $status;
	public $goals;
	public $stats;
	public $performance;
	public $goal_completion;
	
	public function __construct()
	{
		$this->setInitialValues();
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_ContentStrategy_Content();
		}
		
		return self::$_instance;
	}
	
	public function setInitialValues()
	{
		$this->id=0;
		$this->project_id=0;
		$this->title='';
		$this->author='';
		$this->url='';
		$this->host='';
		$this->type='';
		$this->keywords=array();
		$this->persona_id=0;
		$this->funnelstage_id=0;
		$this->placement='';
		$this->due_date='';
		$this->status='';
		$this->goals=array();
		$this->stats=array();
		$this->performance=0;
		$this->goal_completion=0;
	}
	
	public function set($data)
	{
		$result = false;
		
		$objVars = get_object_vars($this);
		
		foreach($objVars as $key=>$val)
		{
			if(isset($data[$key]))
			{
				$this->$key = $data[$key];
				$result = true;
			}
		}
		
		return $result;
	}
	
	public function save()
	{
		$result=false;
		
		$ops=OS_APP_ContentStrategy_ContentOperations::get_instance();
		
		if (!$this->id)
		{
			if ($this->id=$ops->insertContent($this))
			{
				$result=true;
			}
		}
		else
		{
			$result=$ops->updateContent($this);
		}
		
		return $result;
	}
	
	public function load()
	{
		$result = false;
		
		if ($this->id)
		{
			$ops=OS_APP_ContentStrategy_ContentOperations::get_instance();
			
			if ($data=$ops->getContentByID($this->id))
			{
				$this->set(get_object_vars($data));
				
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function delete()
	{
		$result = false;
		
		if ($this->id)
		{
			$ops=OS_APP_ContentStrategy_ContentOperations::get_instance();
			
			$result=$ops->deleteContentByID($this->id);
		}
		
		return $result;
	}
	
	public function toTemplate()
	{
		if (!$this->id) return false;
		
		$osUtils=getOS()->getUtils();
		$app=getOS()->getAppHandler()->getAppPlugin();
		
		$contentOps=OS_APP_ContentStrategy_ContentOperations::get_instance();
		$types=$contentOps->getContentTypes();
		$statuses=$contentOps->getContentStatuses();
		$placements=$contentOps->getContentPlacements();
		$goal_types=$contentOps->getContentGoalTypes();
		
		$personaOps=OS_APP_ContentStrategy_PersonaOperations::get_instance();
		$personas=$personaOps->getPersonas();
		
		$funnelStageOps=OS_APP_ContentStrategy_FunnelStageOperations::get_instance();
		$funnelstages=$funnelStageOps->getFunnelStages();
		
		$goals_human='';
		foreach ($goal_types as $goal_type=>$goal_name)
		{
			if (!empty($this->goals[$goal_type]))
			{
				$goals_human.=(empty($goals_human)?'':', ').$this->goals[$goal_type].' '.$goal_name;
			}
		}
		
		$result=array(
			'id'=>$this->id,
			'project_id'=>$this->project_id,
			'title'=>$this->title,
			'author'=>$this->author,
			'url'=>$this->url,
			'url_safe'=>(empty($this->url)?false:$osUtils->getSafeURL($this->url)),
			'host'=>$this->host,
			'type'=>$this->type,
			'type_human'=>$types[$this->type]['name'],
			'keywords'=>implode(', ',$this->keywords),
			'persona_id'=>$this->persona_id,
			'persona'=>(isset($personas[$this->persona_id])?$personas[$this->persona_id]->name:false),
			'funnelstage_id'=>$this->funnelstage_id,
			'funnelstage'=>(isset($funnelstages[$this->funnelstage_id])?$funnelstages[$this->funnelstage_id]->name:false),
			'placement'=>$this->placement,
			'placement_human'=>$placements[$this->placement],
			'due_date'=>$osUtils->humanizeDate($this->due_date,'date'),
			'status'=>$this->status,
			'status_human'=>$statuses[$this->status],
			'goals_human'=>$goals_human,
			'stats'=>$this->stats,
			'performance'=>$this->performance,
			'_editURL'=>$app->getAppActionUrl('inventory_ae',array('op'=>'edit','content_id'=>$this->id)),
			'_deleteURL'=>$app->getAppActionUrl('inventory',array('op'=>'delete','content_id'=>$this->id)),
		);
		
		return $result;
	}
}
?>