<?php
class OS_APP_ContentStrategy_ContentOperations
{
	private static $_instance;
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_ContentStrategy_ContentOperations();
		}
		
		return self::$_instance;
	}
	
	public function getContents($project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."content WHERE project_id=?",array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['keywords']=json_decode($row['keywords'],true);
			$row['goals']=json_decode($row['goals'],true);
			$row['stats']=json_decode($row['stats'],true);
			
			$oneContent=new OS_APP_ContentStrategy_Content();
			$oneContent->set($row);
			
			$result[$row['id']]=$oneContent;
		}
		
		return $result;
	}
	
	public function getContentsByTimeframe($project_id=false,$start_dt=false,$end_dt=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		if (!$start_dt)
		{
			$start_dt=mktime(0,0,0,date('m'),1,date('Y'));
		}
		
		if (!$end_dt)
		{
			$end_dt=mktime(23,59,59,date('m'),date('t'),date('Y'));
		}
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."content WHERE project_id=? AND due_date>=? AND due_date<=? ORDER BY due_date ASC",array($project_id,$start_dt,$end_dt));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['keywords']=json_decode($row['keywords'],true);
			$row['goals']=json_decode($row['goals'],true);
			$row['stats']=json_decode($row['stats'],true);
			
			$oneContent=new OS_APP_ContentStrategy_Content();
			$oneContent->set($row);
			
			$result[$row['id']]=$oneContent;
		}
		
		return $result;
	}
	
	public function getContentQueue($project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."content WHERE project_id=? AND `status`<>? ORDER BY due_date ASC",array($project_id,'published'));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['keywords']=json_decode($row['keywords'],true);
			$row['goals']=json_decode($row['goals'],true);
			$row['stats']=json_decode($row['stats'],true);
			
			$oneContent=new OS_APP_ContentStrategy_Content();
			$oneContent->set($row);
			
			$result[$row['id']]=$oneContent;
		}
		
		return $result;
	}
	
	public function getPublishedContent($project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."content WHERE project_id=? AND `status`=? ORDER BY due_date DESC",array($project_id,'published'));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['keywords']=json_decode($row['keywords'],true);
			$row['goals']=json_decode($row['goals'],true);
			$row['stats']=json_decode($row['stats'],true);
			
			$oneContent=new OS_APP_ContentStrategy_Content();
			$oneContent->set($row);
			
			$result[$row['id']]=$oneContent;
		}
		
		return $result;
	}
	
	public function getContentByID($content_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."content WHERE id=?",array($content_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['keywords']=json_decode($row['keywords'],true);
			$row['goals']=json_decode($row['goals'],true);
			$row['stats']=json_decode($row['stats'],true);
			
			$result=new OS_APP_ContentStrategy_Content();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function insertContent($content)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$keywords=json_encode($content->keywords);
		$goals=json_encode($content->goals);
		$stats=json_encode($content->stats);
		
		$dbresult=$db->query("INSERT INTO ".$appHandler->dbPrefix()."content (project_id,title,author,url,host,`type`,keywords,persona_id,funnelstage_id,placement,due_date,status,goals,stats,performance,goal_completion) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)",array($content->project_id,$content->title,$content->author,$content->url,$content->host,$content->type,$keywords,$content->persona_id,$content->funnelstage_id,$content->placement,$content->due_date,$content->status,$goals,$stats,$content->performance,$content->goal_completion));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateContent($content)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$keywords=json_encode($content->keywords);
		$goals=json_encode($content->goals);
		$stats=json_encode($content->stats);
		
		$dbresult=$db->query("UPDATE ".$appHandler->dbPrefix()."content SET title=?,author=?,url=?,host=?,`type`=?,keywords=?,persona_id=?,funnelstage_id=?,placement=?,due_date=?,status=?,goals=?,stats=?,performance=?,goal_completion=? WHERE id=?",array($content->title,$content->author,$content->url,$content->host,$content->type,$keywords,$content->persona_id,$content->funnelstage_id,$content->placement,$content->due_date,$content->status,$goals,$stats,$content->performance,$content->goal_completion,$content->id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteContentByContentID($content_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."content WHERE id=?";
		$dbresult=$db->query($query,array($content_id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteContentsByProjectID($project_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."content WHERE project_id=?";
		$dbresult=$db->query($query,array($project_id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function computeContentGoalCompletion($content)
	{
		if (empty($content->goals))
		{
			$result=0;
		}
		else
		{
			$result=0;
			
			foreach ($content->goals as $type=>$target)
			{
				$actual=(isset($content->stats[$type])?$content->stats[$type]:0);
				
				$result+=min($actual*100/$target,100);
			}
			
			$result=round($result/count($content->goals),2);
		}
		
		return $result;
	}
	
	public function logContentStats($content)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$stats_d=date('Y-m-d',time());
		
		$hasHistory=$this->getContentStats($content,$stats_d);
		
		if ($hasHistory===false)
		{
			$dbresult=$db->query("INSERT INTO ".$appHandler->dbPrefix()."content_stats (project_id,content_id,stats,stats_d) VALUES (?,?,?,?)",array($content->project_id,$content->id,json_encode($content->stats),$stats_d));
		}
		else
		{
			$dbresult=$db->query("UPDATE ".$appHandler->dbPrefix()."content_stats SET stats=? WHERE content_id=? AND stats_d=?",array(json_encode($content->stats),$content->id,$stats_d));
		}
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function getContentStats($content,$stats_d=false)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."content_stats WHERE content_id=?".($stats_d?" AND stats_d=?":'');
		$dbresult=$db->query($query,($stats_d?array($content->id,$stats_d):array($content->id)));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=json_decode($row['signals'],true);
		}
		
		return $result;
	}
	
	public function getContentUrlsByPattern($pattern,$regex=false,$offset=0,$limit=false,$project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."projects_urls WHERE project_id=? AND url ".($regex?" REGEXP '?'":"LIKE ?");
		
		if (!$regex)
		{
			$pattern='%'.$pattern.'%';
		}
		
		$dbresult=$db->query($query,array($project_id,$pattern));
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['id']]=$row;
		}
		
		return $result;
	}
	
	public function getContentStatuses()
	{
		return array(
			'not_started'=>_("Not started"),
			'in_progress'=>_("In progress"),
			'completed'=>_("Completed"),
			'published'=>_("Published")
		);
	}
	
	public function getContentTypes()
	{
		return array(
			'news'=>array('name'=>_("News"),'description'=>_("News on recent niche events")),
			'awards'=>array('name'=>_("Awards"),'description'=>_("Top Lists: Anual, Segmented, Competitions, Products, Services")),
			'contest'=>array('name'=>_("Contest"),'description'=>_("User contests with prizes or benefits")),
			'curation'=>array('name'=>_("Curation"),'description'=>_("Selection of multiple content pieces of the same kind with added commentary")),
			'egobait'=>array('name'=>_("Egobait"),'description'=>_("Content designed around specific influencers")),
			'guide'=>array('name'=>_("Guide"),'description'=>_("Informational content (How-To, Tutorials)")),
			'infographic'=>array('name'=>_("Infographic"),'description'=>_("Data vizualization content, usually in the form of images")),
			'interview'=>array('name'=>_("Interview"),'description'=>_("Interview with influencial persons in the niche")),
			'opinion'=>array('name'=>_("Opinion"),'description'=>_("Author's subjective opinion on a given topic")),
			'research'=>array('name'=>_("Research"),'description'=>_("Analyzing a set of data")),
			'resource'=>array('name'=>_("Resource"),'description'=>_("Tools, Applications, Templates, Libraries")),
			'ugc'=>array('name'=>_("UGC"),'description'=>_("User Generated Content")),
			'video'=>array('name'=>_("Video"),'description'=>_("Presentations, Tutorials, Webinars, Reviews")),
			'generic'=>array('name'=>_("Generic"),'description'=>_("Generic content"))
		);
	}
	
	public function getContentPlacements()
	{
		return array(
			'local'=>_("Local"),
			'not_local'=>_("Not local")
		);
	}
	
	public function getContentGoalTypes()
	{
		return array(
			'lrds'=>_("Linking root domains"),
			'social'=>_("Social signals")
		);
	}
}
?>