<?php
class OS_APP_ContentStrategy_PersonaOperations
{
	private static $_instance;
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_ContentStrategy_PersonaOperations();
		}
		
		return self::$_instance;
	}
	
	public function getPersonaByID($persona_id)
	{
		$result=false;
		
		$OS=getOS();
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."personas WHERE id=?",array($persona_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['keywords']=json_decode($row['keywords'],true);
			
			$result=new OS_APP_ContentStrategy_Persona();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getPersonas($project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."personas WHERE project_id=?",array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['keywords']=json_decode($row['keywords'],true);
			
			$onePersona=new OS_APP_ContentStrategy_Persona();
			$onePersona->set($row);
			
			$result[$row['id']]=$onePersona;
		}
		
		return $result;
	}
	
	public function insertPersona($persona)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$keywords=json_encode($persona->keywords);
		
		$query="INSERT INTO ".$appHandler->dbPrefix()."personas (project_id,name,age_min,age_max,gender,location,device,information,keywords,outcome) VALUES (?,?,?,?,?,?,?,?,?,?)";
		$dbresult=$db->query($query,array($persona->project_id,$persona->name,$persona->age_min,$persona->age_max,$persona->gender,$persona->location,$persona->device,$persona->information,$keywords,$persona->outcome));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updatePersona($persona)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$keywords=json_encode($persona->keywords);
		
		$query="UPDATE ".$appHandler->dbPrefix()."personas SET name=?,age_min=?,age_max=?,gender=?,location=?,device=?,information=?,keywords=?,outcome=? WHERE id=?";
		$dbresult=$db->query($query,array($persona->name,$persona->age_min,$persona->age_max,$persona->gender,$persona->location,$persona->device,$persona->information,$keywords,$persona->outcome,$persona->id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deletePersonaByID($persona_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."personas WHERE id=?";
		$dbresult=$db->query($query,array($persona_id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deletePersonasByProjectID($project_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."personas WHERE project_id=?";
		$dbresult=$db->query($query,array($project_id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function getPersonaGenders()
	{
		return array(
			'X'=>_("Any"),
			'M'=>_("Male"),
			'F'=>_("Female")
		);
	}
	
	public function createDefaultPersona($project_id)
	{
		$result=false;
		
		$onePersona=new OS_APP_ContentStrategy_Persona();
		
		$onePersona->project_id=$project_id;
		$onePersona->name='Generic';
		$onePersona->age_min=18;
		$onePersona->age_max=65;
		$onePersona->gender='X';
		$onePersona->location='Any';
		$onePersona->device='Any';
		$onePersona->information='';
		$onePersona->keywords='Any';
		$onePersona->outcome='Visits, Conversions, Links, Shares';
		
		if ($onePersona->save())
		{
			$result=true;
		}
		
		return $result;
	}
}
?>