<?php

class OS_APP_copydetector_CopyOperations
{
	private static $_instance;

	private $contentTypes;
	
	
	public function __construct()
	{
		$this->contentTypes = array('content'=> 1, 'img' => 2, 'link'=> 3);
	}

	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_copydetector_CopyOperations();
		}
		return self::$_instance;
	}

	public function getCopyByID($copy_id)
	{
		if( $id < 1 ) return false;
		else return $this->getCopyByDetail(array('id'=>$copy_id));
	}
	
	public function getCopyByDetail($details)
	{
		$result = false;
		$query  = false;

 		$OS = getOS();

		$db = $OS->getDb();
		$appHandler = $OS->getAppHandler('getAppHandler');
		
		if(isset($details['id']))  $query = "SELECT * FROM ".$appHandler->dbPrefix()."copies WHERE `id` = ?";	
		
		if($query)
		{
			$dbresult = $db->query($query, array_values($details));
			
			if ($row = $db->fetchRow($dbresult))
			{
				$oneCopy = new OS_APP_copydetector_Copy();
				$oneCopy->set($row);
							
				$result = $oneCopy;
			}
				
		}
		return $result;
	}	
	
	public function insertCopy($oneCopy)
	{
		$result=false;
		
 		$OS = getOS();

		$db = $OS->getDb();
		$appHandler = $OS->getAppHandler('copydetector');
		
		$insert_dt = $db->DBTimeStamp(time());
		
		$copy_ts_utc = gmmktime();
		
		$requiredVals = array('content_text', 'content_url', 'content_alt', 'content_anchor');
		foreach($requiredVals as $val)
		{
			if(is_null($oneCopy->$val)) $oneCopy->$val = "";
		}

		$query = "INSERT INTO ".$appHandler->dbPrefix()."copies (`insert_dt`,`copy_dt`,`copy_ts_utc`,`project_id`,`content_text`,`content_type`,`content_length`, `content_words`, `content_url`,`content_alt` ,`content_anchor`, `visitor_ip`,`page_url`, `page_url_hash`, `page_title`, `location_continent_code`, `location_continent_name`, `location_country_code`, `location_country_name`) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		$dbresult = $db->query($query, array($insert_dt, $oneCopy->copy_dt, $copy_ts_utc, $oneCopy->project_id, $oneCopy->content_text, $oneCopy->content_type, $oneCopy->content_length, $oneCopy->content_words, $oneCopy->content_url, $oneCopy->content_alt, $oneCopy->content_anchor, $oneCopy->visitor_ip, $oneCopy->page_url, $oneCopy->page_url_hash, $oneCopy->page_title, $oneCopy->location_continent_code, $oneCopy->location_continent_name, $oneCopy->location_country_code, $oneCopy->location_country_name));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}

	public function updateCopy($oneCopy)
	{
		$result=false;
		
		return $result;
	}
	
	public function deleteCopyByID($copy_id)
	{
		if( $copy_id < 1 ) return false;

 		$result = false;
 		$OS = getOS();

		$db = $OS->getDb();
		$appHandler = $OS->getAppHandler('copydetector');
 		
		$query = "DELETE FROM ".$appHandler->dbPrefix()."copies WHERE `id` = ?";
		$dbresult = $db->query($query, array($copy_id));

		if ($dbresult !== false)
		{
			$result = true;
		}

		return $result;
	}

	
	public function getProjectCopiesTimeframe($project_id, $start_d, $end_d)
	{
		$result = array();
		
		if((!empty($start_d)) && (!empty($project_id)) && (!empty($end_d)))
		{
			$OS = getOS();
			$db = $OS->getDb();
			$appHandler = $OS->getAppHandler('copydetector');
			
			$datesRange = $this->createDateRangeArray($start_d, $end_d);
			foreach($datesRange as $cdate)
			{
				$result[$cdate] = 0;
			}
			
			$query = "SELECT stats_d,SUM(total_value) AS total_copies FROM ".$appHandler->dbPrefix()."stats_days WHERE `project_id`=? AND `metric_name1`=? AND `stats_d`>=? AND `stats_d`<=? GROUP BY stats_d";
			$dbresult = $db->query($query,array($project_id, 'copy_content_hash', $start_d, $end_d));
			
			while ($row = $db->fetchRow($dbresult))
			{
				$result[$row['stats_d']] = $row['total_copies'];
			}
		}
		
		return $result;
	}
	
	public function getPagesCopiesTimeframe($project_id, $start_d, $end_d, $page_url_hash)
	{
		$result = array();
		
		if((!empty($start_d)) && (!empty($project_id)))
		{
			$OS = getOS();
			$db = $OS->getDb();
			$appHandler = $OS->getAppHandler('copydetector');
			
			$datesRange = $this->createDateRangeArray($start_d, $end_d);
			
			foreach($datesRange as $cdate)
			{
				$result[$cdate] = 0;
			}
			
			$query = "SELECT stats_d,total_value FROM ".$appHandler->dbPrefix()."stats_days WHERE `project_id`=? AND `metric_name1`=? AND `metric_name2`=? AND `metric_value1`=? AND `stats_d`>=? AND `stats_d`<=?";
			$dbresult = $db->query($query,array($project_id, 'page_url_hash', 'content_type', $page_url_hash, $start_d, $end_d));
			while ($row = $db->fetchRow($dbresult))
			{
				$result[$row['stats_d']] = $row['total_value'];
			}
		}
		
		return $result;
	}	
	
	public function getCopiesTimeframeByType($project_id, $start_d, $end_d, $content_type)
	{
		$result = array();
		
		if((!empty($start_d)) && (!empty($project_id)) && (isset($this->contentTypes[$content_type])))
		{
			$OS = getOS();
			$db = $OS->getDb();
			$appHandler = $OS->getAppHandler('copydetector');
			
			$current_type = $this->contentTypes[$content_type];
			
			$datesRange = $this->createDateRangeArray($start_d, $end_d);
			
			foreach($datesRange as $cdate)
			{
				$result[$cdate] = 0;
			}
			
			$query = "SELECT stats_d,total_value FROM ".$appHandler->dbPrefix()."stats_days WHERE `project_id`=? AND `metric_name1`=? AND `metric_name2`=? AND `metric_value2`=? AND `stats_d`>=? AND `stats_d`<=?";
			$dbresult = $db->query($query,array($project_id, 'page_url_hash', 'content_type', $current_type, $start_d, $end_d));
			while ($row = $db->fetchRow($dbresult))
			{
				$result[$row['stats_d']] = $row['total_value'];
			}
		}
		
		return $result;
	}	
	
	public function getTopCopiesPages($project_id, $start_d, $end_d = false)
	{
		$result = array();
		
		if((!empty($start_d)) && (!empty($project_id)))
		{
			$OS = getOS();
			$db = $OS->getDb();
			$appHandler = $OS->getAppHandler('copydetector');
			
			if($end_d == false) $end_d = date("Y-m-d");
			
			
			//check with previous data
			$start_d_ts = strtotime($start_d);
			$end_d_prev_ts = ($start_d_ts - 86400);
			$end_d_prev = date("Y-m-d", $end_d_prev_ts);
			$start_d_prev = date("Y-m-d", ($end_d_prev_ts - (strtotime($end_d) - $start_d_ts)));
			
			$copiesData = array(
				'current'=> array('start_d' => $start_d,'end_d' => $end_d, 'counter' => 0),
				'prev'=> array('start_d' => $start_d_prev, 'end_d' => $end_d_prev, 'counter' => 0)
				);			
			
			$max_values = 10; $total_copies = 0; $cpData = array(); 
			foreach($copiesData as $type => $details)
			{
				$query = "SELECT metric_value1,extra_data,total_value FROM ".$appHandler->dbPrefix()."stats_days WHERE `project_id`=? AND metric_name1=? AND metric_name2=? AND stats_d>=? AND stats_d<=? GROUP BY metric_value1 ORDER BY total_value DESC";
				$dbresult = $db->query($query,array($project_id, 'page_url_hash', 'content_type', $details['start_d'], $details['end_d']));

				while ($row = $db->fetchRow($dbresult))
				{
				
					if($type == 'current')
					{
						$total_copies += $row['total_value'];
						
						$details['counter']++;

						if($details['counter'] <= $max_values)
						{
							$extraData = json_decode($row['extra_data'], true);
							
							$cpData[$row['metric_value1']] = array(
								'page_url_hash' => $row['metric_value1'],	
								'page_url' => $extraData['page_url'],
								'page_title' => $extraData['page_title'],
								'total_copies' => $row['total_value'],
								'current_position' => $details['counter'],
								'prev_position' => 0							
								);
						}
					}
					elseif($type == 'prev')
					{
						$details['counter']++;
						
						if(isset($cpData[$row['metric_value1']]))
						{
							$cpData[$row['metric_value1']]['prev_position'] = $details['counter'];
						}
					}
				}	
			}
			
			
			//add percentage and change to type copies
			foreach($cpData as $copy_hash => $details)
			{
				$cval = $details['current_position'];
				$lval = $details['prev_position'];
				
				if($cval == 0) $percentage = 0;
				else $percentage = ($cval < $lval? "-".round(100-($cval/$lval)*100,2) : round(100-($lval/$cval)*100,2)); 
					
				$cpData[$copy_hash]['compare_evolution'] = ($percentage == 0? "same" : ($cval < $lval ? "down" : "up"));
				$cpData[$copy_hash]['compare_percentage'] = $percentage;
				$cpData[$copy_hash]['percentage'] = ($total_copies == 0 ? 0 : round((($details['total_copies']/$total_copies)*100),2));
			}
			
			$result = $cpData;
		}
		
		return $result;
	}
	
	public function getTopCopiesByType($project_id, $start_d, $end_d, $content_type)
	{
		$result = array();
		
		if((!empty($start_d)) && (!empty($end_d)) && (!empty($project_id)) && (isset($this->contentTypes[$content_type])))
		{
			$OS = getOS();
			$db = $OS->getDb();
			$appHandler = $OS->getAppHandler('copydetector');
			
			$current_type = $this->contentTypes[$content_type];
			
			//check with previous data
			$start_d_ts = strtotime($start_d);
			$end_d_prev_ts = ($start_d_ts - 86400);
			$end_d_prev = date("Y-m-d", $end_d_prev_ts);
			$start_d_prev = date("Y-m-d", ($end_d_prev_ts - (strtotime($end_d) - $start_d_ts)));
			
			$copiesData = array(
				'current'=> array('start_d' => $start_d,'end_d' => $end_d, 'counter' => 0),
				'prev'=> array('start_d' => $start_d_prev, 'end_d' => $end_d_prev, 'counter' => 0)
				);			
			
			$max_values = 10; $total_copies = 0; $cpData = array(); 
			foreach($copiesData as $type => $details)
			{
				$query = "SELECT metric_value1,extra_data,total_value,total_value FROM ".$appHandler->dbPrefix()."stats_days WHERE `project_id`=? AND metric_name1=? AND metric_name2=? AND metric_value2=? AND stats_d>=? AND stats_d<=? GROUP BY metric_value1 ORDER BY total_value DESC";
				$dbresult = $db->query($query,array($project_id, 'copy_content_hash', 'content_type', $current_type, $details['start_d'], $details['end_d']));
				
				while ($row = $db->fetchRow($dbresult))
				{
					if($type == 'current')
					{
						$total_copies += $row['total_value'];
						
						$details['counter']++;

						if($details['counter'] <= $max_values)
						{
							$extraData = json_decode($row['extra_data'], true);
							
							$cpData[$row['metric_value1']] = array(
								'content_text' => $extraData['content_text'],
								'content_url' => $extraData['content_url'],
								'content_words' => $extraData['content_words'],
								'total_copies' => $row['total_value'],
								'current_position' => $details['counter'],
								'prev_position' => 0							
								);
						}
					}
					elseif($type == 'prev')
					{
						$details['counter']++;
						
						if(isset($cpData[$row['metric_value1']]))
						{
							$cpData[$row['metric_value1']]['prev_position'] = $details['counter'];
						}
					}
				}
			}
			
			//add percentage and change to type copies
			foreach($cpData as $copy_hash => $details)
			{
				$cval = $details['current_position'];
				$lval = $details['prev_position'];
				
				if($cval == 0) $percentage = 0;
				else $percentage = ($cval < $lval? "-".round(100-($cval/$lval)*100,2) : round(100-($lval/$cval)*100,2)); 
					
				$cpData[$copy_hash]['compare_evolution'] = ($percentage == 0? "same" : ($cval < $lval ? "down" : "up"));
				$cpData[$copy_hash]['compare_percentage'] = $percentage;
				$cpData[$copy_hash]['percentage'] = ($total_copies == 0 ? 0 : round((($details['total_copies']/$total_copies)*100),2));
			}
			$result = $cpData;
		}
		
		return $result;
	}	
	
	public function getTotalCopiesByType($project_id, $start_d, $end_d, $page_url_hash = false)
	{
		$result = array();
		
		if((!empty($start_d)) && (!empty($project_id)))
		{
			$OS = getOS();
			$db = $OS->getDb();
			$appHandler = $OS->getAppHandler('copydetector');
			
			$currentTypes = array('1' => 'content', '2' => 'img', '3' => 'link' ,'-1' => 'total');
			
			//check with previous data
			$start_d_ts = strtotime($start_d);
			$end_d_prev_ts = ($start_d_ts - 86400);
			$end_d_prev = date("Y-m-d", $end_d_prev_ts);
			$start_d_prev = date("Y-m-d", ($end_d_prev_ts - (strtotime($end_d) - $start_d_ts)));
			
			$copiesData = array(
				'current'=> array('start_d' => $start_d,'end_d' => $end_d),
				'prev'=> array('start_d' => $start_d_prev, 'end_d' => $end_d_prev)
				);			
			
			foreach($currentTypes as $type_name)
			{
				$copiesData['current']['data'][$type_name]['total_copies'] = 0;
				$copiesData['prev']['data'][$type_name]['total_copies'] = 0;	
			} 
			
			
			foreach($copiesData as $type => $details)
			{
				//get current timeframe stats
				if($page_url_hash !== false)
				{
					$query = "SELECT metric_value2,SUM(total_value) AS total_copies FROM ".$appHandler->dbPrefix()."stats_days WHERE `project_id`=? AND `metric_name1`=?  AND `metric_value1`=? AND `metric_name2`=? AND stats_d>=? AND stats_d<=? GROUP BY metric_value2";
					$dbresult = $db->query($query,array($project_id, 'page_url_hash', $page_url_hash, 'content_type', $details['start_d'], $details['end_d']));
				}
				else
				{
					$query = "SELECT metric_value2,SUM(total_value) AS total_copies FROM ".$appHandler->dbPrefix()."stats_days WHERE `project_id`=? AND metric_name1=? AND metric_name2=? AND stats_d>=? AND stats_d<=? GROUP BY metric_value2";
					$dbresult = $db->query($query,array($project_id, 'page_url_hash', 'content_type', $details['start_d'], $details['end_d']));
				}
			
				while ($row = $db->fetchRow($dbresult))
				{
					$copiesData[$type]['data'][$currentTypes[$row['metric_value2']]]['total_copies'] = $row['total_copies'];
					
					$copiesData[$type]['data']['total']['total_copies'] += $row['total_copies']; 
				}
			}
			
			$total_copies = $copiesData['current']['data']['total']['total_copies'];
			
			//compare details
			foreach($copiesData['current']['data'] as $index => $details)
			{
				$cval = $details['total_copies'];
				$lval = $copiesData['prev']['data'][$index]['total_copies'];
				
				if($cval == 0) $percentage = 0;
				else $percentage=($cval < $lval? "-".round(100-($cval/$lval)*100,2) : round(100-($lval/$cval)*100,2) ); 
					
				$copiesData['current']['data'][$index]['compare_evolution'] = ($percentage == 0? "same" : ($cval < $lval ? "down" : "up"));
				$copiesData['current']['data'][$index]['compare_percentage'] = $percentage;
				$copiesData['current']['data'][$index]['percentage'] = ($total_copies == 0 ? 0 : round((($cval/$total_copies)*100),2));
			}
			
			$result = $copiesData['current']['data'];
		}
		
		return $result;
	}
	
	
	public function getPageLatestCopiesByType($project_id, $start_d, $end_d, $page_url_hash, $content_type, $page = 0)
	{
		$result = array();
		
		if((!empty($project_id)) && (!empty($start_d)) && (!empty($end_d)) && (isset($this->contentTypes[$content_type])))
		{
			$OS = getOS();
			$db = $OS->getDb();
			$appHandler = $OS->getAppHandler('copydetector');
			
			$current_type = $this->contentTypes[$content_type];
			
			$limit = ($page * 10);
			$start_dt = date("Y-m-d H:i:s", strtotime($start_d));
			$end_dt = date("Y-m-d H:i:s", (strtotime($end_d) + 86400));
			
			$copiesData = array();
			
			$query = "SELECT * FROM ".$appHandler->dbPrefix()."copies WHERE `project_id`=? AND `copy_dt`>=? AND `copy_dt`<=? AND `page_url_hash`=? AND content_type=? AND `content_words`>? ORDER BY copy_dt DESC LIMIT 10";
			$dbresult = $db->query($query, array($project_id, $start_dt, $end_dt, $page_url_hash, $current_type, ($current_type == 1 ? 7 : -1)));
			while($row = $db->fetchRow($dbresult))
			{
				$copiesData[$row['id']] = $row;
			}
			
			$result = $copiesData;
		}
		
		return $result;
	}	
	
	public function getPageLatestSearchCopies($project_id, $start_d, $end_d, $page_url_hash, $page = 0)
	{
		$result = array();
		
		if((!empty($project_id)) && (!empty($start_d)) && (!empty($end_d)))
		{
			$OS = getOS();
			$db = $OS->getDb();
			$appHandler = $OS->getAppHandler('copydetector');
			
			$limit = ($page * 10);
			$start_dt = date("Y-m-d H:i:s", strtotime($start_d));
			$end_dt = date("Y-m-d H:i:s", (strtotime($end_d) + 86400));
			
			$copiesData = array();
			
			$query = "SELECT * FROM ".$appHandler->dbPrefix()."copies WHERE `project_id`=? AND `copy_dt`>=? AND `copy_dt`<=? AND `page_url_hash`=? AND `content_type`=? AND `content_words`<=? ORDER BY copy_dt DESC LIMIT 10";
			$dbresult = $db->query($query, array($project_id, $start_dt, $end_dt, $page_url_hash, 1, 7));
			while($row = $db->fetchRow($dbresult))
			{
				$copiesData[$row['id']] = $row;
			}
			
			$result = $copiesData;
		}
		
		return $result;
	}
	
	public function getLatestCopiesByType($project_id, $start_d, $end_d, $content_type, $page = 0)
	{
		$result = array();
		
		if((!empty($project_id)) && (!empty($start_d)) && (!empty($end_d)) && (isset($this->contentTypes[$content_type])))
		{
			$OS = getOS();
			$db = $OS->getDb();
			$appHandler = $OS->getAppHandler('copydetector');
			
			$current_type = $this->contentTypes[$content_type];
			
			$limit = ($page * 10);
			$start_dt = date("Y-m-d H:i:s", strtotime($start_d));
			$end_dt = date("Y-m-d H:i:s", (strtotime($end_d) + 86400));
			
			$copiesData = array();
			
			$query = "SELECT * FROM ".$appHandler->dbPrefix()."copies WHERE `project_id`=? AND `copy_dt`>=? AND `copy_dt`<=? AND content_type=? ORDER BY copy_dt DESC LIMIT 10";
			$dbresult = $db->query($query, array($project_id, $start_dt, $end_dt, $current_type));
			while($row = $db->fetchRow($dbresult))
			{
				$copiesData[$row['id']] = $row;
			}
			
			$result = $copiesData;
		}
		
		return $result;
	}
	
	public function addCopyStatsDay($oneCopy, $copiesNo = 1)
	{
		$result = false;
		
		$OS = getOS();
		$db = $OS->getDb();
		$appHandler = $OS->getAppHandler('copydetector');
		
		$stats_d = date("Y-m-d");

		$copy_content_hash = ($oneCopy->content_type == 1 ? md5($oneCopy->content_text) : md5($oneCopy->content_url));

		$query="SELECT * FROM ".$appHandler->dbPrefix()."stats_days WHERE `project_id`=? AND `metric_name1`=? AND `metric_value1`=? AND `metric_name2`=? AND `metric_value2`=? AND `stats_d`=?";
		$dbresult = $db->query($query, array($oneCopy->project_id, 'copy_content_hash', $copy_content_hash, 'content_type', $oneCopy->content_type, $stats_d));
		if($row = $db->fetchRow($dbresult))
		{
			$query="UPDATE ".$appHandler->dbPrefix()."stats_days SET `total_value`=? WHERE id=?";
			$db->query($query, array(($row['total_value'] + $copiesNo), $row['id']));
			$result = true;
		}
		else
		{
			$content_text = str_replace(array("\r\n","\n"),array("\n"," "), $oneCopy->content_text);
			$extraDataJson = json_encode(array('content_text'=> $content_text, 'content_url' => $oneCopy->content_url, 'content_words' => $oneCopy->content_words));
			
			$query="INSERT INTO ".$appHandler->dbPrefix()."stats_days (`project_id`, `metric_name1`,`metric_value1`,`metric_name2`,`metric_value2`,`stats_d`,`total_value`, `extra_data`) VALUES (?,?,?,?,?,?,?,?)";
			$db->query($query, array($oneCopy->project_id, 'copy_content_hash', $copy_content_hash, 'content_type', $oneCopy->content_type, $stats_d, $copiesNo, $extraDataJson));
			$result = true;
		}
				
		return $result;
	}

	
	public function addTypeStatsDay($oneCopy, $copiesNo=1)
	{
		$result = false;
		
		$OS = getOS();
		$db = $OS->getDb();
		$appHandler = $OS->getAppHandler('copydetector');
		
		$stats_d = date("Y-m-d");
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."stats_days WHERE `project_id`=? AND `metric_name1`=? AND `metric_value1`=? AND `metric_name2`=? AND `metric_value2`=? AND `stats_d`=?";
		$dbresult = $db->query($query, array($oneCopy->project_id, 'page_url_hash' ,$oneCopy->page_url_hash, 'content_type', $oneCopy->content_type, $stats_d));
		if($row = $db->fetchRow($dbresult))
		{
			$query="UPDATE ".$appHandler->dbPrefix()."stats_days SET `total_value`=? WHERE id=?";
			$db->query($query, array(($row['total_value'] + $copiesNo), $row['id']));
			$result = true;
		}
		else
		{
			$extraDataJson = json_encode(array('page_url'=> $oneCopy->page_url,'page_title'=> $oneCopy->page_title));
			
			$query="INSERT INTO ".$appHandler->dbPrefix()."stats_days (`project_id`, `metric_name1`,`metric_value1`,`metric_name2`,`metric_value2`,`stats_d`,`total_value`, `extra_data`) VALUES (?,?,?,?,?,?,?,?)";
			$db->query($query, array($oneCopy->project_id, 'page_url_hash' ,$oneCopy->page_url_hash, 'content_type', $oneCopy->content_type, $stats_d, $copiesNo, $extraDataJson));
			$result = true;
		}
		

		return $result;
	}
	
	
	public function createDateRangeArray($strDateFrom, $strDateTo)
	{
	    $aryRange = array();
	
	    $iDateFrom = mktime(1,0,0,substr($strDateFrom,5,2), substr($strDateFrom,8,2),substr($strDateFrom,0,4));
	    $iDateTo = mktime(1,0,0,substr($strDateTo,5,2), substr($strDateTo,8,2),substr($strDateTo,0,4));
	
	    if ($iDateTo >= $iDateFrom)
	    {
	        $aryRange[] = date('Y-m-d',$iDateFrom);
	        while ($iDateFrom<$iDateTo)
	        {
	            $iDateFrom += 86400;
	            $aryRange[] = date('Y-m-d',$iDateFrom);
	        }
	    }
	    return $aryRange;
	}

	
	public function timeAgo($date, $granularity=2)
	{
		if(!is_numeric($date)) $date = strtotime($date);
		
		$ts_default = time();
		
		$difference = $ts_default - $date;
		$periods = array(
			'decade' => 315360000,
		    'year' => 31536000,
		    'month' => 2628000,
		    'week' => 604800, 
		    'day' => 86400,
		    'hour' => 3600,
		    'minute' => 60,
		    'second' => 1
		    );
		                                 
		if($difference>10*60) unset($periods['second']);
		if($difference>3*60*60) unset($periods['minute']);
		
		$retval='';
		foreach ($periods as $key => $value)
		{
		    if ($difference >= $value)
		   	{
		        $time = floor($difference/$value);
		        $difference %= $value;
		        $retval.=($retval ? ' ' : '').$time.' ';
		        $retval.=(($time > 1) ? "{$key}s":$key);
		        $granularity--;
		   	}
		    if ($granularity == '0') { break; }
		}
		
		if($retval!='') return "{$retval} ago";
		else return "less than a minute ago";      
	}
	
	public function timeAgoMin($date, $granularity=2)
	{
		if(!is_numeric($date)) $date = strtotime($date);
		
		$ts_default = time();
		
		$difference = $ts_default - $date;
		$periods = array(
			'dec' => 315360000,
		    'y' => 31536000,
		    'mo' => 2628000,
		    'w' => 604800, 
		    'd' => 86400,
		    'h' => 3600,
		    'm' => 60,
		    's' => 1
		    );
		                                 
		if($difference>10*60) unset($periods['second']);
		if($difference>3*60*60) unset($periods['minute']);
		
		$retval='';
		foreach ($periods as $key => $value)
		{
		    if ($difference >= $value)
		   	{
		        $time = floor($difference/$value);
		        $difference %= $value;
		        $retval.=($retval ? ' ' : '').$time.' ';
		        $retval.= $key;
		        $granularity--;
		   	}
		    if ($granularity == '0') { break; }
		}
		
		if($retval!='') return "{$retval}";
		else return "<1m";     
	}

	public function textTruncate($text, $length, $forced=false) 
	{
		if (strlen($text) > $length)
		{
			$text = substr($text, 0, $length);
			if(!$forced)
			{
				$text = substr($text,0,strrpos($text," "));
				if ((substr($text, -1)) == ".") $text = substr($text,0,(strrpos($text,".")));
			}
			$text.=" ...";
		}
		return $text;
	}
}
?>