<?php

interface OS_APP_copydetector_Tracker_Actions_Interface
{
	function setRequest($requestArray);
	function handle();
}

class OS_APP_copydetector_Tracker_Actions implements OS_APP_copydetector_Tracker_Actions_Interface
{
	private $request;
	
	private $visitorInfo;
	
	private $project_id;
	
	private $extraData;
	
	private $typeRefererAnalyzed;
	
	private $nameRefererAnalyzed;
	
	private $keywordRefererAnalyzed;
	
	private $refererHost;
	
	private $refererUrl;
	
	private $refererUrlParse;
	
	private $currentUrlParse;
	
	private $currentTimeUTC;
	
	private $rootPath;
	
	private $availableEvents;
	
	private $contentTypes;
	
	private $refererTypes;
	
	private $appHandler;
	
	public function __construct($requestArray = array())
	{
		$OS = getOS();
		
		if(!empty($requestArray))
		{
			$this->setRequest($requestArray);
		}
		
		$this->appHandler = $OS->getAppHandler('copydetector');
		
		$this->currentTimeUTC = gmdate("Y-m-d H:i:s");
		
		$this->rootPath = $OS->getConfigVar('root_path');
		
		$this->availableEvents = array('copiesTrackerContent', 'copiesTrackerImages', 'copiesTrackerLinks');
		
		$this->contentTypes = array('txt' => 1, 'img'=>2, 'lnk'=> 3);
		
		$this->refererTypes = array('direct'=>1, 'search'=>2, 'website'=>3);
	}
	
	public function setRequest($requestArray)
	{
		if(isset($requestArray['project_id'], $requestArray['events']))
		{
			if(empty($requestArray['project_id'])) $this->error('102','General_ExceptionInvalidProjectAccount');
			else
			{
				$this->project_id = $requestArray['project_id'];
				
				$this->extraData = (isset($requestArray['extra']) ? $requestArray['extra'] : array());
				
				$availableEvents = array_flip($this->availableEvents);
				
				foreach($requestArray['events'] as $eventName => $values)
				{
					if(isset($availableEvents[$eventName]))
					{
						$this->request[$eventName] = $requestArray['events'][$eventName]['handlerResult'];	
					}
				}
			}
		}
	}
	
	public function handle()
	{
		$OS = getOS();
		
		/*
		$refererInfo = $this->getRefererInformation();
		
		$pageInfo = $this->getPageInformation();

		$userInfo = $this->getUserSettingsInformation();
		*/
		
		$page_url = $this->getPageUrl();
		
		$visior_ua = $this->getUserAgent();
		
		$visior_ip = $this->getVisitorIp();
		
		$osGeoIP = $OS->getGeoIP();
		
		$locationDetails = $osGeoIP->getLocation($visior_ip);
		
		$referer_keyword = ""; //for now
		
		$this->visitorInfo = array(
			'project_id' => $this->project_id,
			'copy_dt' => date("Y-m-d H:i:s"),
			'visitor_ip' => $visior_ip,
			'referer_keyword' => $referer_keyword,
			'page_url' => $page_url,
			'page_url_hash' => md5($page_url),
			'page_title' =>  $this->getPageTitle(),
			'location_continent_code' => ($locationDetails['continent_code'] !== false ? $locationDetails['continent_code'] : ''),
			'location_continent_name' => ($locationDetails['continent_name'] !== false ? $locationDetails['continent_name'] : ''),
			'location_country_code' => ($locationDetails['country_code'] !== false ? $locationDetails['country_code'] : ''),
			'location_country_name' => ($locationDetails['country_name'] !== false ? $locationDetails['country_name'] : ''),
		);		
		
		if(isset($this->request['copiesTrackerContent']))
		{
			$this->handleContentCopy($this->request['copiesTrackerContent']);
		}
		
		if(isset($this->request['copiesTrackerImages']))
		{
			$this->handleImageCopy($this->request['copiesTrackerImages']);
		}
		
		if(isset($this->request['copiesTrackerLinks']))
		{
			$this->handleLinkCopy($this->request['copiesTrackerLinks']);
		}
	}
	
	private function handleContentCopy($request)
	{
		$handler_info = $this->visitorInfo;
		
		$content_text = $this->sanitizeText($request['ct']);
		
		$handler_info['content_text'] = $content_text;
		$handler_info['content_type'] = $this->contentTypes[$request['tp']];
		$handler_info['content_length'] = strlen($content_text);
		$handler_info['content_words'] = str_word_count($content_text);
		
		$this->saveHandlerInformation($handler_info);	
	}
	
	private function handleImageCopy($request)
	{
		$handler_info = $this->visitorInfo; 
		
		$content_text = $this->sanitizeText($request['ct']);
		
		$handler_info['content_url'] = $request['cu'];
		$handler_info['content_alt'] = (isset($request['ca']) ? $this->sanitizeText($request['ca']): '');
		$handler_info['content_text'] = (isset($request['ct']) ? $this->sanitizeText($request['ct']): '');
		$handler_info['content_type'] = $this->contentTypes[$request['tp']];
		$handler_info['content_length'] = strlen($content_text);
		$handler_info['content_words'] = str_word_count($content_text);
		
		$this->saveHandlerInformation($handler_info);
	}
	
	private function handleLinkCopy($request)
	{
		$handler_info = $this->visitorInfo;
		
		$content_text = $this->sanitizeText($request['ct']);
		
		$handler_info['content_url'] = $request['cu'];
		$handler_info['content_anchor'] = (isset($request['ca']) ? $this->sanitizeText($request['ca']): '');
		$handler_info['content_text'] = (isset($request['ct']) ? $this->sanitizeText($request['ct']): '');
		$handler_info['content_type'] =  $this->contentTypes[$request['tp']];
		$handler_info['content_length'] = strlen($content_text);
		$handler_info['content_words'] = str_word_count($content_text);
		
		$this->saveHandlerInformation($handler_info);
	}
	
	private function saveHandlerInformation($handler_info)
	{
		if($this->project_id <= 0) return (false);
		
		//build sql query and save it to file
		
		//save query to file for later insertion into mysql database
		
		/*
		$oneCopy = new OS_APP_copydetector_Copy();
		$oneCopy->set($handler_info);
		$oneCopy->save();
		*/
		
		//buffer result to parse it later
		$log_file_path = $this->getLogFile();
		$dirname = dirname($log_file_path);
		if (!file_exists($dirname)) mkdir($dirname, 0755, true);
		
		if ($file = fopen($log_file_path, 'a+'))
		{
			$buffer = json_encode($handler_info);
			
			fwrite($file, $buffer."\n");
			fclose($file);
		}
	}
	
	private function getLogFile()
	{
		return os_join_path($this->appHandler->getAppStoragePath(),'buffer',floor(time()/3600).'.log');
	}	
	

	private function getRemoteAddr(){return (isset($_SERVER['REMOTE_ADDR']) ? $_SERVER['REMOTE_ADDR'] : '0.0.0.0');}
	
	private function getUserAgent() {return ( isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : '' );}
	
	private function getVisitorIp() {return $this->getRemoteAddr();}
	
	private function getPageUrl() {return (isset($this->extraData['url']) ? urldecode($this->extraData['url']) : '');}
	
	private function getPageTitle() {return (isset($this->extraData['pt']) ? $this->extraData['pt'] : '' );} 
	
	private function getCurrentTimestamp() {return time();}
	
	private function getCurrentDate( $format = "Y-m-d") {return date($format, $this->getCurrentTimestamp());}
	
	private function getBrowserLanguage() {return $this->extraData['lg'];}

	public function getRefererInformation()
	{
		// default values for the referer_* fields
		$this->typeRefererAnalyzed = $this->refererTypes['direct'];
		$this->nameRefererAnalyzed = '';
		$this->keywordRefererAnalyzed = '';
		$this->refererHost = '';
		
		// get the urls and parse them
		$refererUrl	= $this->extraData['rf'];
		$currentUrl	= $this->extraData['lc'];

		$this->refererUrl = $refererUrl;
		$this->refererUrlParse = parse_url($this->unsanitizeInputValue($refererUrl));
		$this->currentUrlParse = parse_url($this->unsanitizeInputValue($currentUrl));

		if(isset($this->refererUrlParse['host'])) $this->refererHost = $this->refererUrlParse['host'];

		$refererDetected = false;
		//if(!$refererDetected) if( $this->detectRefererDirectEntry() || $this->detectRefererSearchEngine() ) $refererDetected = true;

		if(!empty($this->refererHost)&& !$refererDetected)
		{
			$this->typeRefererAnalyzed = $this->refererTypes['website'];
			
			$this->nameRefererAnalyzed = $this->refererHost;
		}

		return  array(
			'referer_type'    => $this->typeRefererAnalyzed,
			'referer_name'    => $this->nameRefererAnalyzed,
			'referer_keyword' => $this->keywordRefererAnalyzed,
			'referer_url'     => $refererUrl,
			);
	}
		
	private function getPageInformation()
	{
		$this->currentUrlParse = parse_url($this->extraData['url']);
		$page_title = $this->sanitizeText($this->extraData['pt']);
		
		return array(
			'page_title' => $page_title,
			'page_host' => (isset($this->currentUrlParse['host'])?$this->currentUrlParse['host']:''),
			'page_path' => (isset($this->currentUrlParse['path'])?$this->currentUrlParse['path']:''),
			'page_query' => (isset($this->currentUrlParse['query'])?$this->currentUrlParse['query']:''),
			'page_hash' => (isset($this->currentUrlParse['fragment'])?$this->currentUrlParse['fragment']:'')
			);
	}
	
	private function sanitizeInputValue($value) 
	{
		if(is_numeric($value)) return $value;
		elseif(is_string($value)) return $value;
		elseif (is_array($value))
		{
			$p=array_keys($value);
			foreach ($p as $key)
			{
				$newKey = $key;
				$newKey = $this->sanitizeInputValue($newKey);
				
				if ($key != $newKey)
				{
					$value[$newKey] = $value[$key];
					unset($value[$key]);
				}
				$value[$newKey] = $this->sanitizeInputValue($value[$newKey]);
			}
		}
		elseif( !is_null($value)&& !is_bool($value)) $this->error('105',"The value to escape has not a supported type. Value = ".var_export($value, true));
		return $value;	
	}	

	private function detectRefererDirectEntry()
	{
		if(!empty($this->refererHost))
		{
			// is the referer host the current host?
			if(isset($this->currentUrlParse['host']))
			{
				if($this->currentUrlParse['host'] == $this->refererHost)
				{
					$this->typeRefererAnalyzed = $this->refererTypes['direct'];
					
					return (true);
				}
			}
				
			if($this->isHostKnownAliasHost($this->refererHost))
			{
				$this->typeRefererAnalyzed = $this->refererTypes['direct'];
				return (true);
			}
		}
		return (false);
	}	
	
	static function getParameterFromQueryString($urlQuery, $parameter)
	{
		$nameToValue = array();
		parse_str($urlQuery, $nameToValue);
		if(isset($nameToValue[$parameter])) return $nameToValue[$parameter];
		return false;
	}
	
	private function isHostKnownAliasHost($urlHost){return (false);}
	
	private function split_string($string)
	{
		$tmp='';
		if(isset($string[0])) $tmp.="/{$string[0]}";	
		if(isset($string[1])) $tmp.="/{$string[1]}";
		if(isset($string[2])) $tmp.="/{$string[2]}";
		$tmp.="/{$string}";
		return $tmp; 
	}

	private function sanitizeText($text)
	{
		if(function_exists('iconv'))
		{
			$charset = 'iso-8859-2';
			$text = @iconv($charset, 'utf-8//IGNORE', $text);	
		}
		
		return $text;
	}

	private function error($error,$error_code,$header="HTTP/1.0 400 Bad Request")
	{
		//trigger_error("copyDetector :: {$error_code} | {$error} | {$this->jsonString}", E_WARNING);	
	}
}	