<?php 
class OS_APP_CopyDetector_mainView
{
	private $appPlugin;
	
	public function __construct()
	{
		$this->appPlugin = getOS()->getAppHandler()->getAppPlugin();
	}
	
	public function processRequest()
	{
		//handle get & post requests
	
	}
	
	
	public function buildViewData()
	{
		$OS = getOS();
		
		$osProject = $OS->getProject();
		
		$copyDetectorOps = OS_APP_copydetector_CopyOperations::get_instance();
		
		$project_id = $osProject->id;

		//get gobal timeframe
		$osTimeframe = $OS->getTimeframe();
		$timeframe = $osTimeframe->getTimeframe();
		$start_d = $timeframe['first'];
		$end_d = $timeframe['last'];
		
		//cache results
		$cache_key = md5('copydetector'.$project_id.$start_d.$end_d.'mainpage'); 
		$osCache = $OS->getCache();
		
		$viewDataVars = $osCache->get($cache_key);
		if($viewDataVars === false)
		{
			$viewDataVars = array();
			
			$timeFrameResult = $copyDetectorOps->getProjectCopiesTimeframe($project_id, $start_d, $end_d);
			
			$viewDataVars['timeFrameResult'] = $timeFrameResult;
			
			//get top copies pages (by url)
			$topCopiesPages = $copyDetectorOps->getTopCopiesPages($project_id, $start_d, $end_d);
			$viewDataVars['topCopiesPages'] = $topCopiesPages;
			
			//get total copies by copy type
			$totalCopiesByType = $copyDetectorOps->getTotalCopiesByType($project_id, $start_d, $end_d);
			$viewDataVars['totalCopiesByType'] = $totalCopiesByType;
			
			$osCache->set($cache_key, $viewDataVars);
		}
		
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS = getOS();
		
		$tplVars = array();
		
		$viewData = $this->buildViewData();
		
		$chartValues = array(); $chartTooltips = array(); $chartLabels = array(); $headContents = array();
		
		if(!empty($viewData['timeFrameResult']))
		{
			foreach ($viewData['timeFrameResult'] as $day => $copies)
			{
				$chartValues[] = $copies;
				if (date('N',strtotime($day)) == 6)
				{
					$chartLabels[] = date('d M', strtotime($day));
				}
				else
				{
					$chartLabels[] = false;
				}
				$chartTooltips[] = date('d M', strtotime($day))."\n{$copies} copies";
			}
			
			$charts = $OS->getCharts();
			
			$chartOptions = array(
				'values' => array_values($chartValues),
				'labels' => $chartLabels,
				'tooltips' => $chartTooltips,
				'fill' => true,
				'normalize' => true
			);
			
			$chartData = $charts->getLineChart($chartOptions);
			
			$tplVars['chart_html'] = $chartData['html'];
			
			foreach ($chartData['js'] as $key=>$val)
			{
				$headContents['chart_'.$key]=$val;
			}
		}
		
		if(!empty($viewData['totalCopiesByType']))
		{
			$copyTypesTitles = array(
				'total' => array('type_title'=> _("Total Copies"), 'type_box_color'=> 'blue'),
				'content' =>  array('type_title'=> _("Text Copies"), 'type_box_color'=> 'red', 'view_link' => $this->appPlugin->getAppActionUrl("type-content")),
				'img' =>  array('type_title'=> _("Image Copies"), 'type_box_color'=> 'yellow', 'view_link' => $this->appPlugin->getAppActionUrl("type-img")),
				'link' =>  array('type_title'=> _("URL Copies"), 'type_box_color'=> 'green', 'view_link' => $this->appPlugin->getAppActionUrl("type-link"))
				);
				
			foreach($copyTypesTitles as $type => $details)
			{
				if(isset($viewData['totalCopiesByType'][$type]))
				{
					$tplVars['totalCopiesByType'][$type] = array_merge($viewData['totalCopiesByType'][$type], $details);
				}
			}	
		}

		
		if(!empty($viewData['topCopiesPages']))
		{
			foreach($viewData['topCopiesPages'] as $index => $values)
			{
				if($values['percentage']<20) $percentage_bar_color = 'red';
				elseif($values['percentage']<70) $percentage_bar_color = 'yellow';
				else $percentage_bar_color = 'green';
				
				$tplVars['topCopiesPages'][$index] = array(
					'page_url' => $values['page_url'],
					'page_title' => $values['page_title'],
					'total_copies' => $values['total_copies'],
					'percentage' => $values['percentage'],
					'compare_evolution' => $values['compare_evolution'],
					'compare_percentage' => $values['compare_percentage'],
					'percentage_bar_color' => $percentage_bar_color,
					'view_link' => $this->appPlugin->getAppActionUrl("pagecopiesview", array('page_hash'=> $values["page_url_hash"])),
					); 
			}
		}
		
		$tpl = $OS->getTemplate();
		
		$tpl->setHeadContents($headContents);
		
		return $tpl->fetchTemplate('mainview', $tplVars);
	}
}
?>