<?php
class OS_APP_CopyDetector_pageCopiesView
{
	private $appPlugin;
	
	public function __construct()
	{
		$this->appPlugin = getOS()->getAppHandler()->getAppPlugin();
	}
		
	public function processRequest()
	{
		//handle get & post requests
	
	}
	
	public function buildViewData()
	{
		$OS = getOS();
		
		$requestParams = $this->appPlugin->getRequestParams();
		
		$osProject = $OS->getProject();
		
		$copyDetectorOps = OS_APP_copydetector_CopyOperations::get_instance();
		
		$project_id = $osProject->id;
		
		$page_url_hash = $requestParams['page_hash'];
		
		//get copies by type

		//get gobal timeframe
		$osTimeframe = $OS->getTimeframe();
		$timeframe = $osTimeframe->getTimeframe();
		$start_d = $timeframe['first'];
		$end_d = $timeframe['last'];
		
		//cache results
		$cache_key = md5('copydetector'.$project_id.$page_url_hash.$start_d.$end_d.'pagecopiesview'); 
		$osCache = $OS->getCache();
		
		$viewDataVars = $osCache->get($cache_key);
		if($viewDataVars === false)
		{
			$viewDataVars = array();
			
			$timeFrameResult = $copyDetectorOps->getPagesCopiesTimeframe($project_id, $start_d, $end_d, $page_url_hash);
			$viewDataVars['timeFrameResult'] = $timeFrameResult;
			
			$totalCopiesByType = $copyDetectorOps->getTotalCopiesByType($project_id, $start_d, $end_d, $page_url_hash);
			if(isset($totalCopiesByType['content']))
			{
				$viewDataVars['totalCopiesByType'] = $totalCopiesByType;
			}
			
			$contentPageCopiesByTime = $copyDetectorOps->getPageLatestCopiesByType($project_id, $start_d, $end_d, $page_url_hash, 'content');
			if(!empty($contentPageCopiesByTime))
			{
				$viewDataVars['contentPageCopiesByTime'] = $contentPageCopiesByTime;
			}
			
			$pageLatestSearchCopies = $copyDetectorOps->getPageLatestSearchCopies($project_id, $start_d, $end_d, $page_url_hash);
			if(!empty($pageLatestSearchCopies))
			{
				$viewDataVars['pageLatestSearchCopies'] = $pageLatestSearchCopies;
			}
			
			$imagePageCopiesByTime = $copyDetectorOps->getPageLatestCopiesByType($project_id, $start_d, $end_d, $page_url_hash, 'img');
			if(!empty($imagePageCopiesByTime))
			{
				$viewDataVars['imagePageCopiesByTime'] = $imagePageCopiesByTime;
			}
			
			$linkPageCopiesByTime = $copyDetectorOps->getPageLatestCopiesByType($project_id, $start_d, $end_d, $page_url_hash, 'link');
			if(!empty($linkPageCopiesByTime))
			{
				$viewDataVars['linkPageCopiesByTime'] = $linkPageCopiesByTime;
			}
			
			$osCache->set($cache_key, $viewDataVars);
		}	
		
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS = getOS();
		
		$tplVars = array();
		
		$headContents = array();
		
		$viewData = $this->buildViewData();
		
		$osCharts = $OS->getCharts();
		
		$copyDetectorOps = OS_APP_copydetector_CopyOperations::get_instance();
		
		if(!empty($viewData['timeFrameResult']))
		{
			foreach ($viewData['timeFrameResult'] as $day => $copies)
			{
				$chartValues[] = $copies;
				if (date('N',strtotime($day)) == 6)
				{
					$chartLabels[] = date('d M', strtotime($day));
				}
				else
				{
					$chartLabels[] = false;
				}
				$chartTooltips[] = date('d M', strtotime($day))."\n{$copies} "._("copies");
			}
			
			$chartOptions = array(
				'values' => array_values($chartValues),
				'labels' => $chartLabels,
				'tooltips' => $chartTooltips,
				'fill' => true,
				'normalize' => true
			);
			
			$chartData = $osCharts->getLineChart($chartOptions);
			
			$tplVars['timeframe_chart_html'] = $chartData['html'];
			
			$headContents = array_merge($headContents, $chartData['js']);
		}		
		
		
		if(!empty($viewData['totalCopiesByType']))
		{
			$totalContentData = $viewData['totalCopiesByType']['total'];
			$pieData = $viewData['totalCopiesByType']; 
			
			$chartOptions = array(
				'radius' => 50,
				'values' => array($pieData['content']['percentage'], $pieData['img']['percentage'], $pieData['link']['percentage']),
				'colors' => array('#C13A32', '#F3D645'. '#A1C132')
				);
			
			$tplVars['pie_chart_values'] = array(
				'content_copies' => array(
					'title' =>  _("Content Copies"),
					'legend_custom_color' => '#C13A32',
					'percentage' => $pieData['content']['percentage'],
					'total' => $pieData['content']['total_copies'],
					'compare_percentage' => $pieData['content']['compare_percentage'],
					'compare_evolution' => $pieData['content']['compare_evolution'],
				),
				'image_copies' => array(
					'title' => _("Image Copies"),
					'legend_custom_color' => '#F3D645',
					'percentage' =>  $pieData['img']['percentage'],
					'total' => $pieData['img']['total_copies'],
					'compare_percentage' => $pieData['img']['compare_percentage'],
					'compare_evolution' => $pieData['img']['compare_evolution'],
				),
				'link_copies' => array(
					'title' => _("Link Copies"),
					'legend_custom_color' => '#A1C132',
					'percentage' =>  $pieData['link']['percentage'],
					'total' => $pieData['link']['total_copies'],
					'compare_percentage' => $pieData['link']['compare_percentage'],
					'compare_evolution' => $pieData['link']['compare_evolution'],
				)
			);
			
			$chartData = $osCharts->getPieChart($chartOptions);

			$tplVars['pie_chart_html'] = $chartData['html'];
			
			$headContents = array_merge($headContents, $chartData['js']);
		}
		
		if(!empty($viewData['contentPageCopiesByTime']))
		{
			foreach($viewData['contentPageCopiesByTime'] as $index => $details)
			{
				$copy_ts = strtotime($details['copy_dt']);
				
				$truncated_text = $copyDetectorOps->textTruncate($details['content_text'], 120);
				
				$tplVars['contentPageCopiesByTime'][$index] = array(
					'page_url' => $details['page_url'],
					'page_title' => $details['page_title'],
					'content_text' => $details['content_text'],
					'content_text_truncated' => $truncated_text,
					'copy_dt' => date("d F Y H:i", $copy_ts),
					'copy_dt_human' => date("h:i A \- d M y", $copy_ts),
					'timeago_dt' =>	$copyDetectorOps->timeAgoMin($copy_ts),
					'copy_words' =>  $details['content_words'],
					'country_code_lower' =>  strtolower($details['location_country_code']),
					'country_name' =>  $details['location_country_name']
					);	
			}
		}
		
		if(!empty($viewData['pageLatestSearchCopies']))
		{
			foreach($viewData['pageLatestSearchCopies'] as $index => $details)
			{
				$copy_ts = strtotime($details['copy_dt']);
				
				$tplVars['pageLatestSearchCopies'][$index] = array(
					'page_url' => $details['page_url'],
					'page_title' => $details['page_title'],
					'content_text' => $details['content_text'],
					'copy_dt' => date("d F Y H:i", $copy_ts),
					'copy_dt_human' => date("h:i A \- d M y", $copy_ts),
					'timeago_dt' =>	$copyDetectorOps->timeAgoMin($copy_ts),
					'copy_words' =>  $details['content_words'],
					'country_code_lower' =>  strtolower($details['location_country_code']),
					'country_name' =>  $details['location_country_name']
					);	
			}
		}
		
		if(!empty($viewData['imagePageCopiesByTime']))
		{
			foreach($viewData['imagePageCopiesByTime'] as $index => $details)
			{
				$copy_ts = strtotime($details['copy_dt']);
				
				$tplVars['imagePageCopiesByTime'][$index] = array(
					'page_url' => $details['page_url'],
					'page_title' => $details['page_title'],
					'img_src' => $details['content_url'],
					'img_title' => $details['content_text'],
					'copy_dt' => date("d F Y H:i", $copy_ts),
					'copy_dt_human' => date("h:i A \- d M y", $copy_ts),
					'timeago_dt' =>	$copyDetectorOps->timeAgoMin($copy_ts),
					'country_code_lower' =>  strtolower($details['location_country_code']),
					'country_name' =>  $details['location_country_name']
					);	
			}
		}
		
		if(!empty($viewData['linkPageCopiesByTime']))
		{
			foreach($viewData['linkPageCopiesByTime'] as $index => $details)
			{
				$tplVars['linkPageCopiesByTime'][$index] = array(
					'page_url' => $details['page_url'],
					'page_title' => $details['page_title'],
					'link_url' => $details['content_url'],
					'link_title' => $details['content_text'],
					'copy_dt' => date("d F Y H:i", $copy_ts),
					'copy_dt_human' => date("h:i A \- d M y", $copy_ts),
					'timeago_dt' =>	$copyDetectorOps->timeAgoMin($copy_ts),
					'country_code_lower' =>  strtolower($details['location_country_code']),
					'country_name' =>  $details['location_country_name']
					);	
			}
		}
		
		
		$headContents['flags.css'] ="<link href='".$OS->getConfigVar('root_url')."/lib/css/flags.css' rel='stylesheet' type='text/css' />";
		$headContents['jquery-table-expand'] ="<script src='".$OS->getConfigVar('root_url')."/lib/javascript/jquery/jquery.table-expand.js' type='text/javascript'></script>";
		
		$headContents['activate-table-expand'] ="<script type='text/javascript'>
        	\$(document).ready(function(){\$('.striped.stats').jExpand();});
		</script>";
		
		$this->appPlugin->setMenuBackLink(array('back_view'=> 'view'));
		
		$tpl = $OS->getTemplate();
		
		$tpl->setHeadContents($headContents);
		
		return $tpl->fetchTemplate('pagecopiesview', $tplVars);
	}
}
?>