<?php
class OS_APP_DuplContent extends OS_AppBase
{
	private static $_instance;
	
	private $contentAttributes=array(
		'a'=>array('title'),
		'img'=>array('title','alt')
	);
	
	private $ignoredTags=array('script','style');
	
	private $similarUrls=10;
	
	protected function __construct()
	{
		parent::__construct();
		
		$this->addMenuItem('view', array("name" => "Main", 'routerOption'=> "handleMainView"));
				
		$this->setRouterOption("url", "handleUrlView");
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_DuplContent();
		}
		return self::$_instance;
	}
	
	public function handleMainView()
	{
		getOS()->getUser()->forcePerm('duplcontent','view');
		
		$viewData=new OS_APPVIEW_DuplContent_Main();
		
		return $viewData->render();
	}
	
	public function handleUrlView()
	{
		getOS()->getUser()->forcePerm('duplcontent','view');
		
		$viewData=new OS_APPVIEW_DuplContent_Url();
		
		return $viewData->render();
	}
	
	protected function defineAppPermissions()
	{
		$this->appPermissions=array(
			'duplcontent'=>array(
				'view'=>array('name'=>"View duplicate content report")
			)
		);
	}
	
	public function eventProjectCrawlStart($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();

		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
			$db=$OS->getDb();
			
			$db->query("DELETE FROM ".$this->dbPrefix()."trigrams WHERE project_id=?",array($params['project_id']));
			$db->query("DELETE FROM ".$this->dbPrefix()."url_trigrams WHERE project_id=?",array($params['project_id']));
		}
		
		return $result;
	}
	
	public function eventProjectPageCrawled($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();

		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
			$params['http_code']=(string)$params['http_code'];
			$ok_http_code=in_array($params['http_code'][0],array(1,2));
			
			$allowedContentType=(in_array($params['content_type'],array('text/html','text/plain')));
			
			if ($allowedContentType AND !empty($params['content']) AND $ok_http_code)
			{
				if (!$canonicalURL=$this->getCanonicalUrl($params['final_url'],$params['dom']))
				{
					$canonicalURL='';
				}
				
				if (!$title=$this->getTitle($params['dom']))
				{
					$title='';
				}
				
				$osTextualizer=$OS->getTextualizer();
				
				if ($text=$osTextualizer->extractTextFromDOM($params['dom']))
				{
					if ($trigrams=$osTextualizer->extractPhrases($text,3,3))
					{
						$db=$OS->getDb();
						
						$url_id=false;
						$time=$db->DBTimeStamp(time());
						
						$dbresult=$db->query("SELECT * FROM ".$this->dbPrefix()."urls WHERE project_id=? AND url=?",array($params['project_id'],$params['final_url']));
						if ($url_row=$db->fetchRow($dbresult))
						{
							$url_row['canonical_url']=$canonicalURL;
							$url_row['seen_dt']=$time;
							$url_row['title']=$title;
							
							$db->query("UPDATE ".$this->dbPrefix()."urls SET canonical_url=?,seen_dt=?,url_title=? WHERE id=?",array($canonicalURL,$time,$title,$url_row['id']));
							
							$url_id=$url_row['id'];
						}
						else
						{
							$dbresult=$db->query("INSERT INTO ".$this->dbPrefix()."urls (project_id,url,url_title,canonical_url,seen_dt) VALUES (?,?,?,?,?)",array($params['project_id'],$params['final_url'],$title,$canonicalURL,$time));
							
							if ($dbresult!==false)
							{
								$url_id=$db->getInsertId();
							}
						}
						
						if ($url_id)
						{
							foreach ($trigrams as $trigram)
							{
								$trigram_id=false;
								
								$dbresult=$db->query("SELECT * FROM ".$this->dbPrefix()."trigrams WHERE project_id=? AND trigram=?",array($params['project_id'],$trigram));
								if ($trigram_row=$db->fetchRow($dbresult))
								{
									$trigram_id=$trigram_row['id'];
								}
								else
								{
									$dbresult=$db->query("INSERT INTO ".$this->dbPrefix()."trigrams (project_id,trigram) VALUES (?,?)",array($params['project_id'],$trigram));
									
									if ($dbresult!==false)
									{
										$trigram_id=$db->getInsertId();
									}
								}
								
								if ($trigram_id)
								{
									$dbresult=$db->query("SELECT * FROM ".$this->dbPrefix()."url_trigrams WHERE trigram_id=? AND url_id=?",array($trigram_id,$url_id));
									if (!$link_row=$db->fetchRow($dbresult))
									{
										$dbresult=$db->query("INSERT INTO ".$this->dbPrefix()."url_trigrams (project_id,trigram_id,url_id) VALUES (?,?,?)",array($params['project_id'],$trigram_id,$url_id));
									}
								}
							}
							
							$result=true;
						}
					}
				}
			}
		}
		
		return $result;
	}
	
	public function eventProjectCrawlEnd($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();

		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
			$db=$OS->getDb();
			
			$dbresult=$db->query("DELETE FROM ".$this->dbPrefix()."urls WHERE project_id=? AND seen_dt<?",array($params['project_id'],$params['start_dt']));
			
			if ($dbresult!==false)
			{
				$result=OS_Fork::fork('app','duplcontent','generate_report',array('project_id'=>$params['project_id'],'similarUrls'=>$this->similarUrls));
			}
		}
		
		return $result;
	}
	
	public function getCanonicalUrl($url,$dom)
	{
		$result=false;
		
		$xpath=new DOMXPath($dom);
		
		$entries=$xpath->query("//link[@rel='canonical']");
		
		if (!empty($entries))
		{
			$entries=$entries->item(0);
			
			if (!empty($entries))
			{
				if ($href=$entries->getAttribute('href'))
				{
					$result=getOS()->getUtils()->makeAbsoluteUrl($url,$href);
				}
			}
		}
		
		return $result;
	}
	
	public function getTitle($dom)
	{
		$result=false;
		
		$xpath=new DOMXPath($dom);
		
		$entries=$xpath->query("//title");
		
		if (!empty($entries))
		{
			$entries=$entries->item(0);
			
			if (!empty($entries))
			{
				$result=$entries->nodeValue;
			}
		}
		
		return $result;
	}
	
	public function &getUrl()
	{
		return OS_APP_DuplContent_Url::get_instance();
	}
	
	public function &getUrlOps()
	{
		return OS_APP_DuplContent_UrlOperations::get_instance();
	}
	
	public function &getReport()
	{
		return OS_APP_DuplContent_Report::get_instance();
	}
	
	public function &getReportOps()
	{
		return OS_APP_DuplContent_ReportOperations::get_instance();
	}
}
?>