<?php
class OS_APPVIEW_DuplContent_Main extends OS_AppViewBase
{
	public function __construct()
	{
		parent::__construct();
	}
	
	public function buildViewData()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		$ops=OS_APP_DuplContent_UrlOperations::get_instance();
		
		$requestParams=$appPlugin->getRequestParams();
		$viewDataVars=array();
		
		if ($viewDataVars['urlsCounts']=$ops->getUrlsCounts())
		{
			$urls_per_page=10;
			$page=1;
			$similarity_group=false;
			
			if (!empty($requestParams['similarity_group']) AND isset($viewDataVars['urlsCounts'][$requestParams['similarity_group']]))
			{
				$similarity_group=$requestParams['similarity_group'];
			}
			
			if ($similarity_group==false)
			{
				$group_count=array_sum($viewDataVars['urlsCounts']);
			}
			else
			{
				$group_count=$viewDataVars['urlsCounts'][$similarity_group];
			}
			
			if (!empty($requestParams['page']) AND ($requestParams['page']>0) AND (($requestParams['page']-1)*$urls_per_page<$group_count))
			{
				$page=$requestParams['page'];
			}
			
			$viewDataVars['page']=$page;
			$viewDataVars['similarity_group']=$similarity_group;
			$viewDataVars['previous_urls']=($page-1)*$urls_per_page;
			
			$actual_urls=false;
			
			if ($group_count>0)
			{
				$actual_urls=$ops->getUrls(($page-1)*$urls_per_page,$urls_per_page,$similarity_group);
				
				if ($page*$urls_per_page<$group_count)
				{
					if ($similarity_group)
					{
						$next_page_url=$appPlugin->getAppActionUrl('view',array('similarity_group'=>$similarity_group,'page'=>$page+1));
					}
					else
					{
						$next_page_url=$appPlugin->getAppActionUrl('view',array('page'=>$page+1));
					}
				}
				else
				{
					$next_page_url=false;
				}
				
				if ($page>1)
				{
					if ($similarity_group)
					{
						$prev_page_url=$appPlugin->getAppActionUrl('view',array('similarity_group'=>$similarity_group,'page'=>$page-1));
					}
					else
					{
						$prev_page_url=$appPlugin->getAppActionUrl('view',array('page'=>$page-1));
					}
				}
				else
				{
					$prev_page_url=false;
				}
				
				$viewDataVars['next_page_url']=$next_page_url;
				$viewDataVars['prev_page_url']=$prev_page_url;
			}
			
			$viewDataVars['actual_urls']=$actual_urls;
		}
		
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$headContents=array();
		$headContents['css']['duplcontent']=$appPlugin->getAppHomeUrl()."/resources/style.css";
		
		$viewData=$this->buildViewData();
		
		if ($viewData['urlsCounts'])
		{
			$tplUrlsCounts=array();
			$totalUrls=array_sum($viewData['urlsCounts']);
			
			foreach ($viewData['urlsCounts'] as $group=>$urls)
			{
				$tplUrlsCounts[$group]=array(
					'urls'=>$urls,
					'percentage'=>round($urls*100/$totalUrls,1)
				);
			}
			
			$tplVars=array('urlsCounts'=>$tplUrlsCounts,'actualUrls'=>false,'similarity_group'=>$viewData['similarity_group'],'current_page'=>$viewData['page'],'previous_urls'=>$viewData['previous_urls']);
			
			if ($viewData['actual_urls'])
			{
				$tplUrls=array();
				
				$currentViewSettings=array('page'=>$viewData['page']);
				
				if ($viewData['similarity_group'])
				{
					$currentViewSettings['similarity_group']=$viewData['similarity_group'];
				}
				
				foreach ($viewData['actual_urls'] as $url_id=>$url)
				{
					$tplUrls[$url_id]=$url->toTemplate();
					
					$tplUrls[$url_id]['details_url']=$appPlugin->getAppActionUrl('url',array_merge($currentViewSettings,array('url_id'=>$url_id)));
				}
				
				$tplVars['actualUrls']=$tplUrls;
				$tplVars['prev_page_url']=$viewData['prev_page_url'];
				$tplVars['next_page_url']=$viewData['next_page_url'];
			}
			
			$tplVars['similarityGroups']=array(
				1=>array(
					'color'=>'green',
					'title'=>"Low duplication (<25%)",
					'description'=>"Project URLs with less than 25% duplicate content",
					'view_url'=>$appPlugin->getAppActionUrl('view',array('similarity_group'=>1,'page'=>1))
				),
				2=>array(
					'color'=>'yellow',
					'title'=>"Medium duplication (25-50%)",
					'description'=>"Project URLs with between 25% and 50% duplicate content",
					'view_url'=>$appPlugin->getAppActionUrl('view',array('similarity_group'=>2,'page'=>1))
				),
				3=>array(
					'color'=>'orange',
					'title'=>"High duplication (50-75%)",
					'description'=>"Project URLs with between 50% and 75% duplicate content",
					'view_url'=>$appPlugin->getAppActionUrl('view',array('similarity_group'=>3,'page'=>1))
				),
				4=>array(
					'color'=>'red',
					'title'=>"Extreme duplication (>75%)",
					'description'=>"Project URLs with more than 75% duplicate content",
					'view_url'=>$appPlugin->getAppActionUrl('view',array('similarity_group'=>4,'page'=>1))
				),
			);
			
			$tplVars['showAllGroupsUrl']=($viewData['similarity_group']?$appPlugin->getAppActionUrl('view'):false);
		}
		
		$tpl=$OS->getTemplate();
		
		$tpl->setHeadContents($headContents);
		
		return $tpl->fetchTemplate('view',$tplVars);
	}
}
?>