<?php
class OS_APP_DuplContent2 extends OS_AppBase
{
	private static $_instance;
	
	private $similarUrls=10;
	
	private $simhashLength=32;
	
	protected function __construct()
	{
		parent::__construct();
		
		$this->addMenuItem('view', array("name" => "Main", 'routerOption'=> "handleMainView"));
				
		$this->setRouterOption("url", "handleUrlView");
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_DuplContent2();
		}
		return self::$_instance;
	}
	
	public function handleMainView()
	{
		getOS()->getUser()->forcePerm('duplcontent2','view');
		
		$viewData=new OS_APPVIEW_DuplContent2_Main();
		
		return $viewData->render();
	}
	
	public function handleUrlView()
	{
		getOS()->getUser()->forcePerm('duplcontent2','view');
		
		$viewData=new OS_APPVIEW_DuplContent2_Url();
		
		return $viewData->render();
	}
	
	protected function defineAppPermissions()
	{
		$this->appPermissions=array(
			'duplcontent2'=>array(
				'view'=>array('name'=>"View duplicate content report")
			)
		);
	}
	
	public function eventProjectPageCrawled($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();

		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
			$params['http_code']=(string)$params['http_code'];
			$ok_http_code=in_array($params['http_code'][0],array(1,2));
			
			$allowedContentType=(in_array($params['content_type'],array('text/html','text/plain')));
			
			if ($allowedContentType AND !empty($params['content']) AND $ok_http_code)
			{
				$osTextualizer=$OS->getTextualizer();
				
				if ($text=$osTextualizer->extractTextFromDOM($params['dom']))
				{
					$simhash_bin=$this->simhash($text,$this->simhashLength);
					$simhash_dec=bindec($simhash_bin);
					
					$db=$OS->getDb();
					
					$dbresult=$db->query("SELECT * FROM ".$this->dbPrefix()."hashes WHERE project_id=? AND url_id=?",array($params['project_id'],$params['url_id']));
					if ($row=$db->fetchRow($dbresult))
					{
						if ($row['simhash_bin']!=$simhash_bin)
						{
							$db->query("UPDATE ".$this->dbPrefix()."hashes SET simhash_bin=?,simhash_dec=?,similars='' WHERE project_id=? AND url_id=?",array($simhash_bin,$simhash_dec,$params['project_id'],$params['url_id']));
						}
					}
					else
					{
						$db->query("INSERT INTO ".$this->dbPrefix()."hashes (project_id,url_id,simhash_bin,simhash_dec) VALUES (?,?,?,?)",array($params['project_id'],$params['url_id'],$simhash_bin,$simhash_dec));
					}
				}
			}
		}
		
		return $result;
	}
	
	public function eventProjectCrawlEnd($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();

		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
			$result=OS_Fork::fork('app','duplcontent2','generate_report',array('project_id'=>$params['project_id'],'similarUrls'=>$this->similarUrls));
		}
		
		return $result;
	}
	
	public function simhash($text,$bits)
	{
		$result=false;
		
		if ($words=str_split($text,2))
		{
			$hash=array();
			
			foreach ($words as $word)
			{
				$subhash=str_pad(decbin(hexdec(substr(md5($word),0,$bits/4))),$bits,'0',STR_PAD_LEFT);
				
				for ($i=0;$i<$bits;$i++)
				{
					if (!isset($hash[$i]))
					{
						$hash[$i]=0;
					}
					
					if ($subhash[$i]==1)
					{
						$hash[$i]++;
					}
					else
					{
						$hash[$i]--;
					}
				}
			}
			
			if ($hash)
			{
				foreach ($hash as $pos=>$val)
				{
					$hash[$pos]=($val>0?1:0);
				}
				
				$result=implode('',$hash);
			}
		}
		
		return $result;
	}
	
	public function hammingDistance($hash1,$hash2)
	{
		$result=0;
		
		$bits=max(strlen($hash1),strlen($hash2));
		
		if (strlen($hash1)<$bits)
		{
			$hash1=str_pad($hash1,$bits,'0',STR_PAD_LEFT);
		}
		
		if (strlen($hash2)<$bits)
		{
			$hash2=str_pad($hash2,$bits,'0',STR_PAD_LEFT);
		}
		
		for ($i=0;$i<$bits;$i++)
		{
			if ($hash1[$i]!=$hash2[$i])
			{
				$result++;
			}
		}
		
		return $result;
	}
	
	public function &getUrl()
	{
		return OS_APP_DuplContent2_Url::get_instance();
	}
	
	public function &getUrlOps()
	{
		return OS_APP_DuplContent2_UrlOperations::get_instance();
	}
	
	public function &getReport()
	{
		return OS_APP_DuplContent2_Report::get_instance();
	}
	
	public function &getReportOps()
	{
		return OS_APP_DuplContent2_ReportOperations::get_instance();
	}
}
?>