<?php
class OS_APP_DuplPages extends OS_AppBase
{
	private static $_instance;
	
	private $originals;
	private $report;
	
	public function __construct()
	{
		parent::__construct();
		
		$this->addMenuItem('view', array("name" => _("Main"), 'routerOption'=> "handleMainView"));
		$this->addMenuItem('reports', array("name" => _("Reports"), 'routerOption'=> "handleReportsView"));
		
		$this->setRouterOption("cluster", "handleClusterView");
		$this->setRouterOption("report", "handleReportView");
		$this->setRouterOption("reportevolution", "handleReportEvolutionView");
		$this->setRouterOption("inlinks", "handleInlinksView");
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_DuplPages();
		}
		
		return self::$_instance;
	}
	
	public function handleMainView()
	{
		getOS()->getUser()->forcePerm('duplpages','view');
		
		$viewData=new OS_APPVIEW_DuplPages_Main();
		
		return $viewData->render();
	}
	
	public function handleClusterView()
	{
		getOS()->getUser()->forcePerm('duplpages','view');
		
		$viewData=new OS_APPVIEW_DuplPages_Cluster();
		
		return $viewData->render();
	}
	
	public function handleReportsView()
	{
		getOS()->getUser()->forcePerm('duplpages','view');
		
		$viewData=new OS_APPVIEW_DuplPages_Reports();
		
		return $viewData->render();
	}
	
	public function handleReportView()
	{
		getOS()->getUser()->forcePerm('duplpages','view');
		
		$viewData=new OS_APPVIEW_DuplPages_Report();
		
		return $viewData->render();
	}
	
	public function handleReportEvolutionView()
	{
		getOS()->getUser()->forcePerm('duplpages','view');
		
		$viewData=new OS_APPVIEW_DuplPages_ReportEvolution();
		
		return $viewData->render();
	}
	
	public function handleInlinksView()
	{
		getOS()->getUser()->forcePerm('duplpages','view');
		
		$viewData=new OS_APPVIEW_DuplPages_Inlinks();
		
		return $viewData->render();
	}
	
	protected function defineAppPermissions()
	{
		$this->appPermissions=array(
			'duplpages'=>array(
				'view'=>array('name'=>_("View duplicate pages"))
			)
		);
	}
	
	public function getReportingData($type='overview')
	{
		$result=false;
		
		getOS()->getUser()->forcePerm('duplpages','view');
		
		$availableTypes=$this->getReportingTypes();
		
		if (isset($availableTypes[$type]))
		{
			if ($type=='overview')
			{
				$viewData=new OS_APPVIEW_DuplPages_Report();
			}
			elseif ($type=='evolution')
			{
				$viewData=new OS_APPVIEW_DuplPages_ReportEvolution();
			}
			
			$reportData=$viewData->buildViewData();
			
			if ($reportData['report'])
			{
				$result=$reportData['report'];
			}
		}
		
		return $result;
	}
	
	public function getReportingTypes()
	{
		return array(
			'overview'=>_("Overview report"),
			'evolution'=>_("Evolution report")
		);
	}
	
	public function eventProjectCrawlStart($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();

		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
			$clusterOps=OS_APP_DuplPages_ClusterOperations::get_instance();
			$urlOps=OS_APP_DuplPages_UrlOperations::get_instance();
			
			$clusterOps->deleteClustersByProjectID($params['project_id']);
			$urlOps->resetClustering($params['project_id']);
			
			$this->originals=array();
			
			$this->report=new OS_APP_DuplPages_Report();
			
			$this->report->project_id=$params['project_id'];
		}
		
		return $result;
	}
	
	public function eventProjectPageCrawled($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();

		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
			$params['http_code']=(string)$params['http_code'];
			$ok_http_code=in_array($params['http_code'][0],array(1,2));
			
			$allowedContentType=(in_array($params['content_type'],array('text/html','text/plain')));
			
			if ($allowedContentType AND !empty($params['content']) AND $ok_http_code)
			{
				$xpath=new DOMXPath($params['dom']);
				
				$analyze=true;
				$canonical=$xpath->query("//link[@rel='canonical']");
				if ($canonical->item(0))
				{
					$canonical=$canonical->item(0);
					if ($canonical=$canonical->getAttribute('href'))
					{
						$osUtils=$OS->getUtils();
						
						$canonical=$osUtils->makeAbsoluteUrl($params['url'],$canonical);
						if ($canonical!=$params['url'])
						{
							$analyze=false;
						}
					}
				}
				
				$robots=$xpath->query("//meta[@name='robots']");
				if ($robots->item(0))
				{
					$robots=$robots->item(0);
					if ($robots=$robots->getAttribute('content'))
					{
						if (false!==strpos(strtolower($robots),'noindex'))
						{
							$analyze=false;
						}
					}
				}
				
				unset($xpath);
				
				if ($analyze)
				{
					$osTextualizer=$OS->getTextualizer();
					
					$osTextualizer->setEngine('fullbody');
					$osTextualizer->setEngineOption('contentAttributes',false);
					
					if ($text=$osTextualizer->extractTextFromDOM($params['dom']))
					{
						$urlOps=OS_APP_DuplPages_UrlOperations::get_instance();
						
						if (!$simhash=$urlOps->generateSimhash($text))
						{
							$urlOps->deleteUrlByUrlHash($params['url_hash'],$params['project_id']);
						}
						else
						{
							$this->report->urls++;
							
							if (!$url=$urlOps->getUrlByUrlHash($params['url_hash'],$params['project_id']))
							{
								$url=new OS_APP_DuplPages_Url();
								
								$url->project_id=$params['project_id'];
								$url->url=$params['url'];
								$url->url_hash=$params['url_hash'];
							}
							
							$url->simhash=$simhash;
							
							$duplicate_of=false;
							foreach ($this->originals as $url_hash=>$url_details)
							{
								if ($urlOps->hammingDistance($url_details['simhash'],$simhash)<5)
								{
									$duplicate_of=$url_hash;
									break;
								}
							}
							if ($duplicate_of)
							{
								if (empty($this->originals[$duplicate_of]['cluster_id']))
								{
									$oneCluster=new OS_APP_DuplPages_Cluster();
									
									$oneCluster->project_id=$params['project_id'];
									$oneCluster->main_url=$this->originals[$duplicate_of]['url'];
									$oneCluster->main_url_hash=$duplicate_of;
									
									if ($oneCluster->save())
									{
										$this->report->duplication_clusters++;
										$this->report->unique_urls--;
										
										$this->originals[$duplicate_of]['status']='O';
										$this->originals[$duplicate_of]['cluster_id']=$oneCluster->id;
										
										if ($originalUrl=$urlOps->getUrlByUrlHash($duplicate_of,$params['project_id']))
										{
											$originalUrl->status='O';
											$originalUrl->cluster_id=$oneCluster->id;
											
											$originalUrl->save();
										}
									}
								}
								
								$url->status='C';
								$url->cluster_id=$this->originals[$duplicate_of]['cluster_id'];
							}
							else
							{
								$this->report->unique_urls++;
								
								$this->originals[$params['url_hash']]=array(
									'url'=>$params['url'],
									'simhash'=>$simhash,
									'status'=>'U',
									'cluster_id'=>0
								);
							}
							
							$url->save();
						}
						
						$result=true;
					}
				}
			}
		}
		
		return $result;
	}
	
	public function eventProjectCrawlEnd($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();

		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
			$this->report->save();
			
			$result=OS_Fork::fork('app','duplpages','update_clusters',array('project_id'=>$params['project_id']));
		}
		
		return $result;
	}
	
	public function eventProjectUrlsObsolete($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();
		
		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
			$ops=OS_APP_DuplPages_UrlOperations::get_instance();
			
			foreach ($params['urls'] as $url_id=>$url_details)
			{
				$ops->deleteUrlByUrlHash($url_details['url_hash'],$params['project_id']);
			}
		}
		
		return $result;
	}
	
	public function eventProjectDeleted($params)
	{
		$ops=OS_APP_DuplPages_ReportOperations::get_instance();
		
		return $ops->deleteDataByProjectID($params['project_id']);
	}
}
?>