<?php
class OS_APP_DuplPages_UrlOperations
{
	private static $_instance;
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_DuplPages_UrlOperations();
		}
		
		return self::$_instance;
	}
	
	public function getUrlByID($url_id,$project_id=false)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."urls WHERE id=? AND project_id=?",array($url_id,$project_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_APP_DuplPages_Url();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getUrlByUrlHash($url_hash,$project_id=false)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."urls WHERE project_id=? AND url_hash=?",array($project_id,$url_hash));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_APP_DuplPages_Url();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getUrlsByClusterID($cluster_id,$offset=0,$limit=10)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."urls WHERE cluster_id=? LIMIT {$offset},{$limit}",array($cluster_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneUrl=new OS_APP_DuplPages_Url();
			$oneUrl->set($row);
			
			$result[$row['id']]=$oneUrl;
		}
		
		return $result;
	}
	
	public function getUrlsCountByClusterID($cluster_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT COUNT(*) AS cluster_urls FROM ".$appHandler->dbPrefix()."urls WHERE cluster_id=?",array($cluster_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row['cluster_urls'];
		}
		
		return $result;
	}
	
	public function insertUrl($url)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="INSERT INTO ".$appHandler->dbPrefix()."urls (project_id,url,url_hash,simhash,simhash_dec,status,cluster_id) VALUES (?,?,?,?,CONV(?,2,10),?,?)";
		$dbresult=$db->query($query,array($url->project_id,$url->url,$url->url_hash,$url->simhash,$url->simhash,$url->status,$url->cluster_id));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateUrl($url)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="UPDATE ".$appHandler->dbPrefix()."urls SET simhash=?,simhash_dec=CONV(?,2,10),status=?,cluster_id=? WHERE id=?";
		$dbresult=$db->query($query,array($url->simhash,$url->simhash,$url->status,$url->cluster_id,$url->id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteUrlByID($url_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."urls WHERE id=?";
		$dbresult=$db->query($query,array($url_id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteUrlByUrlHash($url_hash,$project_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."urls WHERE project_id=? AND url_hash=?";
		$dbresult=$db->query($query,array($project_id,$url_hash));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function resetClustering($project_id=false)
	{
		$result=false;
		
		if (!$project_id)
		{
			$osProject=getOS()->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("UPDATE ".$appHandler->dbPrefix()."urls SET status=?,cluster_id=? WHERE project_id=?",array('U','0',$project_id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function generateSimhash($text,$bits=64)
	{
		$result=false;
		
		if ($words=explode(' ',$text))
		{
			$hash=array();
			
			foreach ($words as $word)
			{
				$word=trim($word);
				
				if (!empty($word))
				{
					$subhash='';
					
					$md5=md5($word);
					$step=128/$bits;
					for ($i=0;$i<32;$i+=$step)
					{
						$subhash.=str_pad(base_convert($md5[$i],16,2),4,'0',STR_PAD_LEFT);
					}
					
					for ($i=0;$i<$bits;$i++)
					{
						if (!isset($hash[$i]))
						{
							$hash[$i]=0;
						}
						
						if ($subhash[$i]==1)
						{
							$hash[$i]++;
						}
						else
						{
							$hash[$i]--;
						}
					}
				}
			}
			
			if ($hash)
			{
				foreach ($hash as $pos=>$val)
				{
					$hash[$pos]=($val>0?1:0);
				}
				
				$result=str_pad(implode('',$hash),$bits,'0',STR_PAD_LEFT);
			}
		}
		
		return $result;
	}
	
	public function hammingDistance($hash1,$hash2)
	{
		$result=0;
		
		$bits=max(strlen($hash1),strlen($hash2));
		
		if (strlen($hash1)<$bits)
		{
			$hash1=str_pad($hash1,$bits,'0',STR_PAD_LEFT);
		}
		
		if (strlen($hash2)<$bits)
		{
			$hash2=str_pad($hash2,$bits,'0',STR_PAD_LEFT);
		}
		
		for ($i=0;$i<$bits;$i++)
		{
			if ($hash1[$i]!=$hash2[$i])
			{
				$result++;
			}
		}
		
		return $result;
	}
}
?>