<?php
class OS_APPVIEW_DuplPages_Main extends OS_AppViewBase
{
	public $clustersPerPage=10;
	
	private $chartTypes;
	
	public function __construct()
	{
		parent::__construct();
		
		$this->chartTypes=array(
			'uniqueness'=>array('name'=>_("Uniqueness"),'metric_name'=>false,'value_append'=>'%'),
			'unique_urls'=>array('name'=>_("Unique URLs"),'metric_name'=>'URLs'),
			'duplication_clusters'=>array('name'=>_("Duplication clusters"),'metric_name'=>_('clusters')),
			'duplicate_urls'=>array('name'=>_("Duplicate URLs"),'metric_name'=>_('URLs'))
		);
	}
	
	public function processRequest()
	{
		$OS=getOS();
		
		$osProject=$OS->getProject();
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		$reportOps=OS_APP_DuplPages_ReportOperations::get_instance();
		
		$requestParams=$appPlugin->getRequestParams();
		
		if ($processedRequest['reports']=$reportOps->getReports())
		{
			$clusterOps=OS_APP_DuplPages_ClusterOperations::get_instance();
			
			$processedRequest['clustersCount']=$clusterOps->getClustersCount();
			$processedRequest['page']=1;
			
			if (!empty($requestParams['page']) AND ($requestParams['page']>0) AND (($requestParams['page']-1)*$this->clustersPerPage<$processedRequest['clustersCount']))
			{
				$processedRequest['page']=$requestParams['page'];
			}
		}
		
		return $processedRequest;
	}
	
	public function buildViewData()
	{
		$OS=getOS();
		
		$osProject=$OS->getProject();
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$viewDataVars=array();
		
		if ($this->processedRequest['reports'])
		{
			$viewDataVars['reports']=$this->processedRequest['reports'];
			
			if ($this->processedRequest['clustersCount'])
			{
				$clusterOps=OS_APP_DuplPages_ClusterOperations::get_instance();
				
				$viewDataVars['clustersCount']=$this->processedRequest['clustersCount'];
				
				$viewDataVars['clusters']=$clusterOps->getClusters($osProject->id,($this->processedRequest['page']-1)*$this->clustersPerPage,$this->clustersPerPage);
			}
		}
		
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$viewData=$this->buildViewData();
		$tplVars=array();
		$headContents=array();
		
		if (!empty($viewData['reports']))
		{
			$latestReport=reset($viewData['reports']);
			
			$tplVars['overview']=array(
				'uniqueness'=>round($latestReport->unique_urls*100/$latestReport->urls,2),
				'unique_urls'=>$latestReport->unique_urls,
				'duplication_clusters'=>$latestReport->duplication_clusters,
				'duplicate_urls'=>$latestReport->urls-$latestReport->unique_urls
			);
			
			if ($tplVars['overview']['uniqueness']<=20)
			{
				$tplVars['overview']['uniqueness_color']='red';
			}
			elseif ($tplVars['overview']['uniqueness']<=40)
			{
				$tplVars['overview']['uniqueness_color']='orange';
			}
			elseif ($tplVars['overview']['uniqueness']<=60)
			{
				$tplVars['overview']['uniqueness_color']='yellow';
			}
			elseif ($tplVars['overview']['uniqueness']<=80)
			{
				$tplVars['overview']['uniqueness_color']='blue';
			}
			else
			{
				$tplVars['overview']['uniqueness_color']='green';
			}
			
			if (count($viewData['reports'])>=2)
			{
				$tplVars['chartTypes']=$this->chartTypes;
				
				$stats=array();
				$viewData['reports']=array_reverse($viewData['reports'],true);
				foreach ($viewData['reports'] as $report)
				{
					$day=date('Y-m-d',strtotime($report->report_dt));
					
					$stats[$day]=array(
						'uniqueness'=>round($report->unique_urls*100/$report->urls,2),
						'unique_urls'=>$report->unique_urls,
						'duplication_clusters'=>$report->duplication_clusters,
						'duplicate_urls'=>$report->urls-$report->unique_urls
					);
				}
				
				if (count($stats)>=2)
				{
					$charts = $OS->getCharts();
					
					$chartValues=array();$chartTooltips=array();$chartLabels=array();
					$day_index=0;
					
					foreach ($stats as $day=>$day_stats)
					{
						if ($day_index%3==0)
						{
							$chartLabels[]=date('d M',strtotime($day));
						}
						else
						{
							$chartLabels[]=false;
						}
						
						foreach ($this->chartTypes as $type=>$details)
						{
							if ($type!='overall')
							{
								$chartValues[$type][]=$day_stats[$type];
								$chartTooltips[$type][]=date('d M',strtotime($day))."\n".($details['metric_name']?$details['metric_name'].': ':'')."{$day_stats[$type]}".(!empty($details['value_append'])?$details['value_append']:'');
							}
						}
					}
					
					foreach ($this->chartTypes as $type=>$details)
					{
						$chartOptions=array(
							'values'=>array_values($chartValues[$type]),
							'labels'=>$chartLabels,
							'tooltips'=>array_values($chartTooltips[$type]),
							'fill'=>true,
							'normalize'=>true,
							'height'=>174
						);
						$chartData = $charts->getLineChart($chartOptions);
						
						$tplVars['evolution'][$type]=$chartData['html'];
					}
				}
				else
				{
					$tplVars['evolution']=false;
				}
			}
			else
			{
				$tplVars['evolution']=false;
			}
			
			if ($viewData['clustersCount'])
			{
				foreach ($viewData['clusters'] as $url_id=>$url)
				{
					$tplVars['clusters'][$url_id]=$url->toTemplate();
				}
			}
			else
			{
				$tplVars['clusters']=false;
			} 
			
			if ($this->processedRequest['page']>1)
			{
				$tplVars['prev_page_url']=$appPlugin->getAppActionUrl('main',array('page'=>$this->processedRequest['page']-1));
			}
			else
			{
				$tplVars['prev_page_url']=false;
			}
			
			if (($this->processedRequest['page']*$this->clustersPerPage)<$viewData['clustersCount'])
			{
				$tplVars['next_page_url']=$appPlugin->getAppActionUrl('main',array('page'=>$this->processedRequest['page']+1));
			}
			else
			{
				$tplVars['next_page_url']=false;
			}
		}
		else
		{
			$tplVars['overview']=false;
		}
		
		$tpl=$OS->getTemplate();
		
		if (!empty($tplVars['evolution']))
		{
			$headContents['chartJS']=implode("\n",$chartData['js']);
			$headContents['css']['duplpages']=$appPlugin->getAppHomeUrl()."/resources/style.css";
			
			$headContents['duplpages']="<script type='text/javascript'>
				var currentType='all';

				function duplPagesChartChangeType(selectedIndex)
				{
					$('#chartsContainer').css('margin-top',(-selectedIndex*174)+'px')
				}
			</script>";
			
			$tpl->setHeadContents($headContents);
		}
		
		return $tpl->fetchTemplate('view',$tplVars);
	}
}
?>