<?php
class OS_APPVIEW_DuplPages_ReportEvolution extends OS_AppViewBase
{
	private $chartTypes;
	
	public function __construct()
	{
		parent::__construct();
		
		$this->chartTypes=array(
			'uniqueness'=>array('name'=>_("Uniqueness"),'metric_name'=>_('Unique').' %','value_append'=>'%'),
			'unique_urls'=>array('name'=>_("Unique URLs"),'metric_name'=>_('URLs')),
			'duplication_clusters'=>array('name'=>_("Duplication clusters"),'metric_name'=>_('Clusters')),
			'duplicate_urls'=>array('name'=>_("Duplicate URLs"),'metric_name'=>_('URLs'))
		);
	}
	
	public function buildViewData()
	{
		$OS=getOS();
		
		$project=$OS->getProject();
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		$ops=OS_APP_DuplPages_ReportOperations::get_instance();
		
		$viewDataVars=array('report'=>false);
		
		if ($reports=$ops->getReports())
		{
			if (count($reports)>=2)
			{
				$stats=array();
				
				$reports=array_reverse($reports);
				foreach ($reports as $report)
				{
					$day=date('d M',strtotime($report->report_dt));
					
					$stats['uniqueness'][$day]=round($report->unique_urls*100/$report->urls,2);
					$stats['unique_urls'][$day]=$report->unique_urls;
					$stats['duplication_clusters'][$day]=$report->duplication_clusters;
					$stats['duplicate_urls'][$day]=$report->urls-$report->unique_urls;
				}
				
				$osChartsImage=$OS->getChartsImage();
				$appHomeUrl=$appPlugin->getAppHomeUrl();
				
				$reportData=array(
					'filename'=>'duplication_evolution.pdf',
					'title'=>_('Duplication Evolution'),
					'sections'=>array()
				);
				
				foreach ($this->chartTypes as $type=>$details)
				{
					$chartData=array(
						'y_name'=>$details['metric_name'],
						'labels'=>array_keys($stats[$type]),
						'lines'=>array(
							array(
								'name'=>$details['metric_name'],
								'values'=>array_values($stats[$type]),
								'color'=>'#a1c132'
							)
						)
					);
					
					$reportData['sections'][$type]=array(
						'title'=>$details['name'],
						'icon'=>false,
						'type'=>'image',
						'image_url'=>$osChartsImage->getChartUrl('line',$chartData)
					);
				}
				
				$viewDataVars['report']=$reportData;
			}
		}
		
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS=getOS();
		
		$viewData=$this->buildViewData();
		
		if ($viewData['report'])
		{
			$osReport=$OS->getReport();
			
			$osReport->generateReport($viewData['report']);
		}
		else
		{
			return $OS->getTemplate()->fetchTemplate('report');
		}
	}
}
?>