<?php
class OS_APP_incomingkws extends OS_AppBase
{
	private static $_instance;
	
	public $SERules;
	
	protected function __construct()
	{
		parent::__construct();
		
		$this->setDefaultSERules();
		
		$this->addMenuItem('view', array("name" => _("Main"), 'routerOption'=> "handleMainView"));
				
		$this->setRouterOption("keyword", "handleKeywordView");
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_incomingkws();
		}
		return self::$_instance;
	}
	
	public function handleMainView()
	{
		getOS()->getUser()->forcePerm('incomingkws','view');
		
		$viewData=new OS_APPVIEW_IncomingKws_Main();
		
		return $viewData->render();
	}
	
	public function handleKeywordView()
	{
		getOS()->getUser()->forcePerm('incomingkws','view_keyword');
		
		$viewData=new OS_APPVIEW_IncomingKws_Keyword();
		
		return $viewData->render();
	}
	
	protected function defineAppPermissions()
	{
		$this->appPermissions=array(
			'incomingkws'=>array(
				'view'=>array('name'=>_("View incoming keywords")),
				'view_keyword'=>array('name'=>_("View keyword visits"))
			)
		);
	}
	
	public function trackEvent($eventDetails)
	{
		$tracker=new OS_APP_IncomingKws_Tracker();
		
		$tracker->setRequest($eventDetails);
		
		return $tracker->handle();
	}
	
	private function setDefaultSERules()
	{
		$this->SERules=array(
			'google.'=>array('engine'=>'Google','separator'=>'#'),
			'search.yahoo'=>array('engine'=>'Yahoo','q'=>'p'),
			'bing.com'=>array('engine'=>'Bing','q'=>'q'),
			'ask.com'=>array('engine'=>'Ask'),
			'hotbot.com'=>array('engine'=>'HotBot','q'=>'query'),
			'goo.ne.jp'=>array('engine'=>'Goo','q'=>'MT'),
			'search.icq.com'=>array('engine'=>'ICQ'),
			'search.ke.voila.fr'=>array('engine'=>'Voila.fr','q'=>'rdata'),
			'lemoteur.fr'=>array('engine'=>'LeMoteur.fr','q'=>'rdata'),
			'search.yippy.com'=>array('engine'=>'Yippy','q'=>'query'),
			'search.com'=>array('engine'=>'Search.com'),
			'surfy.com'=>array('engine'=>'Surfy','q'=>'key'),
			'websearch.cs.com'=>array('engine'=>'CompuServe','q'=>'query'),
			'search.aol.com'=>array('engine'=>'AOL'),
			'mamma.com'=>array('engine'=>'Mamma'),
			'dmoz.org'=>array('engine'=>'DMOZ'),
			'yandex.ru'=>array('engine'=>'Yandex.ru','q'=>'text'),
			'baidu.com'=>array('engine'=>'Baidu','q'=>'wd'),
			'wolframalpha.com'=>array('engine'=>'Wolfram Alpha','q'=>'i'),
			'search.lycos.com'=>array('engine'=>'Lycos','q'=>'query'),
			'gigablast.com'=>array('engine'=>'GigaBlast'),
			'galaxy.com'=>array('engine'=>'Galaxy'),
			'alexa.com'=>array('engine'=>'Alexa'),
			'nova.rambler.ru'=>array('engine'=>'Rambler.ru','q'=>'query'),
			'rediff.com'=>array('engine'=>'Rediff','q'=>'MT'),
			'najdi.si'=>array('engine'=>'Najdi.si'),
			'search.naver.com'=>array('engine'=>'Naver','q'=>'query'),
			'szukaj.onet.pl'=>array('engine'=>'Onet.pl','q'=>'qt'),
			'pesquisa.sapo.pt'=>array('engine'=>'Sapo.pt'),
			'search.walla.co.il'=>array('engine'=>'Walla.co.il'),
			'search.ch'=>array('engine'=>'Search.ch'),
			'alleba.com'=>array('engine'=>'Alleba'),
			'ansearch.com.au'=>array('engine'=>'Ansearch'),
			'search.daum.net'=>array('engine'=>'Daum'),
			'guruji.com'=>array('engine'=>'Guruji'),
			'blogscope.net'=>array('engine'=>'BlogScope'),
			'icerocket.com'=>array('engine'=>'IceRocket'),
			'surphace.com'=>array('engine'=>'Surphace'),
			'technorati.com'=>array('engine'=>'Technorati'),
			'info.com'=>array('engine'=>'Info.com','q'=>'qkw')
		);
	}
	
	public function addSERule($url_sampler,$engine,$keyword_variable=false,$separator=false)
	{
		$rule=array('engine'=>$engine);
		
		if ($keyword_variable)
		{
			$rule['q']=$keyword_variable;
		}
		
		if ($separator)
		{
			$rule['separator']=$separator;
		}
		
		$this->SERules[$url_sampler]=$rule;
		
		return true;
	}
	
	public function removeSERule($url_sampler)
	{
		$result=false;
		
		if (isset($this->SERules[$url_sampler]))
		{
			unset($this->SERules[$url_sampler]);
			
			$result=true;
		}
		
		return $result;
	}
	
	public function removeSERuleByEngine($engine)
	{
		$result=false;
		
		$engine=strtolower($engine);
		
		foreach ($this->SERules as $url_sampler=>$details)
		{
			if (strtolower($details['engine'])==$engine)
			{
				unset($this->SERules[$url_sampler]);
				
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function parseSEReferral($url)
	{
		$parsed=parse_url($url);
		
		foreach ($this->SERules as $url_sampler=>$details)
		{
			if (false!==strpos($parsed['host'],$url_sampler))
			{
				if (isset($details['separator']) AND $details['separator']=='#')
				{
					$query_keys=array('fragment','query');
				}
				else
				{
					$query_keys=array('query');
				}
				
				if (empty($details['q']))
				{
					$details['q']='q';
				}
				
				foreach ($query_keys as $query_key)
				{
					if (!empty($parsed[$query_key]))
					{
						parse_str($parsed[$query_key],$query_vars);
						
						if (!empty($query_vars[$details['q']]))
						{
							return array('keyword'=>$query_vars[$details['q']],'engine'=>$details['engine']);
						}
					}
				}
			}
		}
		
		return false;
	}
	
	public function keywordStoragePath($project_id,$keyword)
	{
		$keyword_filename=$this->keywordFileName($keyword);
		
		return array('dir'=>os_join_path($this->getAppStoragePath(),'keywords',$project_id,$keyword_filename[0],$keyword_filename[1],$keyword_filename[2]),'file'=>$keyword_filename.'.php');
	}
	
	public function keywordFileName($keyword)
	{
//		$filename='';
//		
//		for ($i=0;$i<strlen($keyword);$i++)
//		{
//			$filename.=ord($keyword[$i]);
//		}
//		
//		$filename=base_convert($filename,10,36);
//
//		return $filename;
		
		//return str_replace(array('=','/'),array('','-'),base64_encode($keyword));
		
		return md5($keyword);
	}
	
	public function getMedianValue($values)
	{
		$result=false;
		
		sort($values);
		
		$count=count($values);
		$middlevar=floor(($count-1)/2);
		
		if ($count%2)
		{
			$result=$values[$middlevar];
		}
		else
		{
			$result=(($values[$middlevar]+$values[$middlevar+1])/2);
		}
		
		return $result;
	}
	
	public function eventProjectDeleted($params)
	{
		$ops=OS_APP_IncomingKws_KeywordOperations::get_instance();
		
		return $ops->deleteDataByProjectID($params['project_id']);
	}
	
	public function &getKeyword()
	{
		return OS_APP_incomingkws_keyword::get_instance();
	}
	
	public function &getOperations()
	{
		return OS_APP_incomingkws_keywordoperations::get_instance();
	}
}
?>