<?php
class OS_APP_incomingkws_keywordoperations
{
	private static $_instance;
	
	public function __construct()
	{
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_incomingkws_keywordoperations();
		}
		return self::$_instance;
	}
	
	public function getKeywords()
	{
		$project=getOS()->getProject();
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$keywords=array();
		$query="SELECT * FROM ".$appHandler->dbPrefix()."keywords WHERE project_id=? ORDER BY last_dt DESC";
		$result=$db->query($query,array($project->id));
		while ($row=$db->fetchRow($result))
		{
			$row=$this->resetExpiredKeywordStats($row);
			
			$keyword=new OS_APP_incomingkws_keyword();
			$keyword->set($row);
			
			$keywords[$keyword->id]=$keyword;
		}
		
		return $keywords;
	}
	
	public function getKeywordsCountByTimeframe($params)
	{
		$result=false;
		
		$project=getOS()->getProject();
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$from_dt = $params['from_dt'];  
		$to_dt =  $params['to_dt'];
		
		$keyword_visits=array();
		
		$query="SELECT keyword_id,SUM(visits) AS keyword_visits FROM ".$appHandler->dbPrefix()."stats_keyword WHERE project_id=? AND stats_d>=?".($to_dt?" AND stats_d<=?":'')." GROUP BY keyword_id ORDER BY keyword_visits DESC";
		$dbresult=$db->query($query, array($project->id,$from_dt, $to_dt));
		while ($row=$db->fetchRow($dbresult))
		{
			$keyword_visits[$row['keyword_id']]=$row['keyword_visits'];
		}
		
		return count($keyword_visits);
	}
	
	public function getKeywordsByTimeframe($params)
	{
		$result=false;
		
		$project=getOS()->getProject();
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$from_dt = $params['from_dt'];  
		$to_dt =  $params['to_dt'];
		
		//use operations function here
		$current_set =  $params['set'];
		$max_rows = $params['max_rows'];
		
		$limit = (($current_set * $max_rows) - $max_rows);
		
		$keyword_visits=array();
		
		$query="SELECT keyword_id,SUM(visits) AS keyword_visits FROM ".$appHandler->dbPrefix()."stats_keyword WHERE project_id=? AND stats_d>=?".($to_dt?" AND stats_d<=?":'')." GROUP BY keyword_id ORDER BY keyword_visits DESC";
		$dbresult=$db->query($query, array($project->id,$from_dt, $to_dt));
		while ($row=$db->fetchRow($dbresult))
		{
			$keyword_visits[$row['keyword_id']]=$row['keyword_visits'];
		}
		
		$temp=array();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."keywords WHERE project_id=? AND last_dt>=? AND last_dt<=?";
		$dbresult=$db->query($query, array($project->id, $from_dt, $to_dt));
		while ($row=$db->fetchRow($dbresult))
		{
			$row=$this->resetExpiredKeywordStats($row);
			if (isset($keyword_visits[$row['id']]))
			{
				$row['visits_timeframe']=$keyword_visits[$row['id']];
			}
			else
			{
				$row['visits_timeframe']=false;
			}
			
			$oneKeyword=new OS_APP_IncomingKws_Keyword();
			$oneKeyword->set($row);
			
			$temp[$oneKeyword->id]=$oneKeyword;
		}
		
		foreach ($keyword_visits as $keyword_id=>$dummy)
		{
			if (isset($temp[$keyword_id]))
			{
				$result[$keyword_id]=$temp[$keyword_id];
			}
		}
		
		if (!$result)
		{
			$result=array();
		}
		else
		{
			$result=array_slice($result,$limit,$max_rows,true);
		}
		
		return $result;
	}
	
	public function getKeywordByID($keyword_id)
	{
		$project=getOS()->getProject();
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."keywords WHERE id=? AND project_id=?";
		$result=$db->query($query,array($keyword_id,$project->id));
		if (!$row=$db->fetchRow($result)) return false;
		
		$row=$this->resetExpiredKeywordStats($row);
		
		$keyword=new OS_APP_incomingkws_keyword();
		$keyword->set($row);
		
		return $keyword;
	}
	
	public function getKeywordByKeyword($keyword)
	{
		$project=getOS()->getProject();
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."keywords WHERE keyword=? AND project_id=?";
		$result=$db->query($query,array($keyword,$project->id));
		if (!$row=$db->fetchRow($result)) return false;
		
		$row=$this->resetExpiredKeywordStats($row);
		
		$keyword=new OS_APP_incomingkws_keyword();
		$keyword->set($row);
		
		return $keyword;
	}
	
	public function resetExpiredKeywordStats($keyword_row)
	{
		$ctime=time();
		$cyear=date('Y',$ctime);$cmonth=date('m',$ctime);
		$cweek=date('W',$ctime);$cday=date('Y-m-d',$ctime);
		
		if ($cyear<>$keyword_row['year'])
		{
			$keyword_row['year']=$cyear;
			$keyword_row['visits_year']=0;
			$keyword_row['month']=$cmonth;
			$keyword_row['visits_month']=0;
			$keyword_row['week']=$cweek;
			$keyword_row['visits_week']=0;
			$keyword_row['day']=$cday;
			$keyword_row['visits_day']=0;
		}
		elseif ($cmonth<>$keyword_row['month'])
		{
			$keyword_row['month']=$cmonth;
			$keyword_row['visits_month']=0;
			$keyword_row['week']=$cweek;
			$keyword_row['visits_week']=0;
			$keyword_row['day']=$cday;
			$keyword_row['visits_day']=0;
		}
		elseif ($cweek<>$keyword_row['week'])
		{
			$keyword_row['week']=$cweek;
			$keyword_row['visits_week']=0;
			$keyword_row['day']=$cday;
			$keyword_row['visits_day']=0;
		}
		elseif ($cday<>$keyword_row['day'])
		{
			$keyword_row['day']=$cday;
			$keyword_row['visits_day']=0;
		}
		
		return $keyword_row;
	}
	
	public function getKeywordVisits($keyword)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."visits WHERE keyword_id=? ORDER BY visit_dt DESC";
		$dbresult=$db->query($query,array($keyword->id));
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['id']]=$row;
		}
		
		return $result;
	}
	
	public function getKeywordVisitsByTimeframe($keyword,$from_dt,$to_dt=false)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."visits WHERE keyword_id=? AND visit_dt>=?".($to_dt?" AND visit_dt<=?":'')." ORDER BY visit_dt DESC";
		$query_params=array($keyword->id,$from_dt);
		if ($to_dt)
		{
			$query_params[]=$to_dt;
		}
		$dbresult=$db->query($query,$query_params);
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['id']]=$row;
		}
		
		return $result;
	}
	
	public function deleteDataByProjectID($project_id)
	{
		$result=true;
		
		$tables=array('visits','stats_keyword','stats_project','keywords');
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		foreach ($tables as $table)
		{
			$dbresult=$db->query("DELETE FROM ".$appHandler->dbPrefix().$table." WHERE project_id=?",array($project_id));
			
			if ($dbresult===false)
			{
				$result=false;
				break;
			}
		}
		
		return $result;
	}
}
?>