<?php
class OS_APP_IncomingKws_Tracker
{
	private $request;
	
	private $visitorInfo;
	
	private $project_id;
	
	private $extraData;
	
	private $appHandler;
	
	public function __construct($requestArray = array())
	{
		$OS = getOS();
		
		if(!empty($requestArray))
		{
			$this->setRequest($requestArray);
		}
		
		$this->appHandler = $OS->getAppHandler('incomingkws');
		
		$this->currentTimeUTC = gmdate("Y-m-d H:i:s");
		
		$this->rootPath = $OS->getConfigVar('root_path');
		
		$this->availableEvents = array('kwsTracker');
	}

	public function setRequest($requestArray)
	{
		if(isset($requestArray['project_id'], $requestArray['events']))
		{
			if(empty($requestArray['project_id'])) $this->error('102','General_ExceptionInvalidProjectAccount');
			else
			{
				$this->project_id = $requestArray['project_id'];
				
				$this->extraData = (isset($requestArray['extra']) ? $requestArray['extra'] : array());
				
				$availableEvents = array_flip($this->availableEvents);
				
				foreach($requestArray['events'] as $eventName => $values)
				{
					if(isset($availableEvents[$eventName]))
					{
						$this->request[$eventName] = $requestArray['events'][$eventName]['handlerResult'];	
					}
				}
			}
		}
	}
	
	public function handle()
	{
		$OS = getOS();
		
		$page_url = $this->getPageUrl();
		
		$visior_ua = $this->getUserAgent();
		
		$visior_ip = $this->getVisitorIp();
		
		$osGeoIP = $OS->getGeoIP();
		
		$locationDetails = $osGeoIP->getLocation($visior_ip);
		
		$this->visitorInfo = array(
			'project_id' => $this->project_id,
			'visitor_dt' => date("Y-m-d H:i:s"),
			'visitor_ip' => $visior_ip,
			'page_url' => $page_url,
			'page_url_hash' => md5($page_url),
			'page_title' =>  $this->getPageTitle(),
			'location_continent_code' => ($locationDetails['continent_code'] !== false ? $locationDetails['continent_code'] : ''),
			'location_continent_name' => ($locationDetails['continent_name'] !== false ? $locationDetails['continent_name'] : ''),
			'location_country_code' => ($locationDetails['country_code'] !== false ? $locationDetails['country_code'] : ''),
			'location_country_name' => ($locationDetails['country_name'] !== false ? $locationDetails['country_name'] : ''),
		);		
		
		if(isset($this->request['kwsTracker']))
		{
			$this->handleNewKWs($this->request['kwsTracker']);
		}
	}
	
	private function handleNewKWs($request)
	{
		$kwsData = array(
			$this->project_id,
			base64_encode($request['keyword']),
			time(),
			$this->visitorInfo['visitor_ip'],
			base64_encode($request['referral']),
			base64_encode($this->visitorInfo['page_url'])
		);
		
		$this->saveHandlerInformation($kwsData);	
	}
	
	private function saveHandlerInformation($handler_info)
	{
		if($this->project_id <= 0) return (false);
		
		//save data to file for later insertion into mysql database
		
		$path = $this->getLogFile();
		if (!file_exists($path['dir'])) mkdir($path['dir'],0755,true);
		$logFile = os_join_path($path['dir'],$path['file']);
		
		if ($file = fopen($logFile, 'a+'))
		{
			$buffer = implode("|",$handler_info);
			
			fwrite($file, $buffer."\n");
			fclose($file);
		}
	}
	
	public function getLogFile()
	{
		return array('dir'=> os_join_path($this->appHandler->getAppStoragePath(),'buffer'), 'file'=> floor(time()/3600).'.log');
	}	
	
	private function getRemoteAddr(){return (isset($_SERVER['REMOTE_ADDR']) ? $_SERVER['REMOTE_ADDR'] : '0.0.0.0');}
	
	private function getUserAgent() {return ( isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : '' );}
	
	private function getVisitorIp() {return $this->getRemoteAddr();}
	
	private function getPageUrl() {return (isset($this->extraData['url']) ? urldecode($this->extraData['url']) : '');}
	
	private function getPageTitle() {return (isset($this->extraData['pt']) ? $this->extraData['pt'] : '' );} 
	
	private function getCurrentTimestamp() {return time();}
	
	private function getCurrentDate( $format = "Y-m-d") {return date($format, $this->getCurrentTimestamp());}
	
	private function getBrowserLanguage() {return $this->extraData['lg'];}
}
?>