<?php
class OS_APPVIEW_IncomingKws_Keyword extends OS_AppViewBase
{
	public function __construct()
	{
		parent::__construct();
	}
	
	public function buildViewData()
	{
		$OS=getOS();
		
		$db=$OS->getDb();
		$ops=OS_APP_IncomingKws_KeywordOperations::get_instance();
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$viewDataVars=array();
		
		$requestParams=$appPlugin->getRequestParams();
		
		if ($viewDataVars['keyword']=$ops->getKeywordByID($requestParams['keyword_id']))
		{
//			$osTimeframe=$OS->getTimeframe();
//			
//			$timeframe=$osTimeframe->getTimeframe();
//			$previous_timeframe=$osTimeframe->getPreviousTimeframe();
			$timeframe=array(
				'from_dt'=>date("Y-m-d H:i:s",time()-30*86400),
				'to_dt'=>date("Y-m-d H:i:s")
			);
			$previous_timeframe=array(
				'from_dt'=>date("Y-m-d H:i:s",time()-61*86400),
				'to_dt'=>date("Y-m-d H:i:s",time()-31*86400)
			);
			
			if ($viewDataVars['keywordVisits']=$viewDataVars['keyword']->getVisitsByTimeframe($timeframe['first'],$timeframe['last']))
			{
				$viewDataVars['keywordVisitsPrev']=$viewDataVars['keyword']->getVisitsByTimeframe($previous_timeframe['first'],$previous_timeframe['last']);
				
				$viewDataVars['stats']=array();
				
				$from=strtotime($timeframe['first']);
				$current=$from;
				$to=strtotime($timeframe['last']);
				
				while ($current<=$to)
				{
					$viewDataVars['stats'][date('Y-m-d',$current)]=0;
					$current+=86400;
				}
				
				$viewDataVars['actual_stats']=false;
				
				$dbresult=$db->query("SELECT * FROM ".$appPlugin->dbPrefix()."stats_keyword WHERE keyword_id=? AND stats_d>=? AND stats_d<=? ORDER BY stats_d DESC LIMIT 10",array($viewDataVars['keyword']->id,$timeframe['first'],$timeframe['last']));
				while ($row=$db->fetchRow($dbresult))
				{
					$viewDataVars['stats'][$row['stats_d']]=$row['visits'];
					$viewDataVars['actual_stats']=true;
				}
			}
		}
		
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$requestParams=$appPlugin->getRequestParams();
		
		if (empty($requestParams['keyword_id']))
		{
			$OS->redirectTO($appPlugin->getAppActionUrl('view'),true);
		}
		
		$viewData=$this->buildViewData();
		
		if (!$viewData['keyword'] OR !$viewData['keywordVisits'])
		{
			$OS->redirectTO($appPlugin->getAppActionUrl('view'),true);
		}
		
		$osUtils=$OS->getUtils();
		$osGeoIP=$OS->getGeoIP();
		
		$headContents=array(
			'css'=>array('flags'=>$OS->getConfigVar('root_url')."/lib/css/flags.css")
		);
		
		$visits=array();
		$enginesSummary=array();
		foreach ($viewData['keywordVisits'] as $visit_id=>$visit_details)
		{
			if (empty($enginesSummary[$visit_details['engine']]))
			{
				$enginesSummary[$visit_details['engine']]=array(
					'visits'=>0,
					'last_dt'=>$osUtils->humanizeDate($visit_details['visit_dt'])
				);
			}
			
			$enginesSummary[$visit_details['engine']]['visits']++;
			
			if ($geolocation=$osGeoIP->getLocation($visit_details['visit_ip']))
			{
				$geolocation['country_code_lower']=strtolower($geolocation['country_code']);
			}
			
			$visits[$visit_id]=array(
				'engine'=>$visit_details['engine'],
				'landing_page'=>$visit_details['landing_page'],
				'landing_page_safe'=>$osUtils->getSafeURL($visit_details['landing_page']),
				'serp_url'=>$visit_details['referral'],
				'serp_url_safe'=>$osUtils->getSafeURL($visit_details['referral']),
				'date'=>$osUtils->humanizeDate($visit_details['visit_dt']),
				'ip'=>$visit_details['visit_ip'],
				'geolocation'=>$geolocation
			);
		}
		
		$enginesPrev=array();
		if ($viewData['keywordVisitsPrev'])
		{
			foreach ($viewData['keywordVisitsPrev'] as $visit_id=>$visit_details)
			{
				if (empty($enginesPrev[$visit_details['engine']]))
				{
					$enginesPrev[$visit_details['engine']]=0;
				}
				
				$enginesPrev[$visit_details['engine']]++;
			}
		}
		
		foreach ($enginesSummary as $engine=>&$details)
		{
			if (!isset($enginesPrev[$engine]))
			{
				$details['trend']='asc';
			}
			elseif ($enginesPrev[$engine]<$details['visits'])
			{
				$details['trend']='asc';
			}
			elseif ($enginesPrev[$engine]>$details['visits'])
			{
				$details['trend']='desc';
			}
			else
			{
				$details['trend']='static';
			}
		}

		$tplVars=array('visits'=>$visits,'actualKeyword'=>$viewData['keyword']->keyword,'enginesSummary'=>$enginesSummary,'back_url'=>$appPlugin->getAppUrl());
		
		if ($viewData['actual_stats'])
		{
			$chartValues=array();$chartTooltips=array();$chartLabels=array();
			foreach ($viewData['stats'] as $day=>$visits)
			{
				$chartValues[]=$visits;
				if (date('N',strtotime($day))==6)
				{
					$chartLabels[]=date('d M',strtotime($day));
				}
				else
				{
					$chartLabels[]=false;
				}
				$chartTooltips[]=date('d M',strtotime($day))."\n{$visits} "._("visits");
			}
			
			$charts = $OS->getCharts();
			
			$chartOptions=array(
				'values'=>$chartValues,
				'labels'=>$chartLabels,
				'tooltips'=>$chartTooltips,
				'fill'=>true,
			);
			
			$chartData = $charts->getLineChart($chartOptions);
			
			$tplVars['chart']=$chartData['html'];
			
			foreach ($chartData['js'] as $key=>$val)
			{
				$headContents[$key]=$val;
			}
		}
		
		$tpl=$OS->getTemplate();
		
		$tpl->setHeadContents($headContents);
		
		return $tpl->fetchTemplate('view_keyword',$tplVars);
	}
}
?>