<?php
class OS_APPVIEW_IncomingKws_Main extends OS_AppViewBase
{
	private $currentSet;
	
	private $maxRows;
	
	private $availableTotalRows;
	
	private $startCounter;
	
	
	public function __construct()
	{
		$OS = getOS();
		
		$this->projectId = $OS->getProject()->id;
		
		$this->appPlugin = $OS->getAppHandler()->getAppPlugin();
		
		$this->availableTotalRows = array(10,25,50,100);
		
		$this->startCounter = 0;
		
		parent::__construct();
	}
	
	public function processRequest()
	{
		$requestParams = $this->appPlugin->getRequestParams();
		
		$this->maxRows = 10;
		if(isset($requestParams['rows']))
		{
			if(in_array($requestParams['rows'], $this->availableTotalRows))
			{
				$this->maxRows = $requestParams['rows'];			
			}
		}
		
		$this->currentSet = 1;
		if(isset($requestParams['page']))
		{
			if(is_numeric($requestParams['page']))
			{
				if($requestParams['page'] > 0)
				{
					$this->currentSet = $requestParams['page'];
					$this->startCounter = (($requestParams['page'] * $this->maxRows) - $this->maxRows);			
				}
			}
		}
	}
	
	public function buildViewData()
	{
		$OS=getOS();
		
		$user=$OS->getUser();
		$db=$OS->getDb();
		$ops=OS_APP_IncomingKws_KeywordOperations::get_instance();
		
		$viewDataVars=array();
		
//		$osTimeframe=$OS->getTimeframe();
//		$timeframe=$osTimeframe->getTimeframe();
		
		$timeframe=array(
			'from_dt'=>date("Y-m-d H:i:s",time()-30*86400),
			'to_dt'=>date("Y-m-d H:i:s")
		);
		
		$viewDataVars['keywords']=$ops->getKeywordsByTimeframe(array('to_dt'=> $timeframe['first'], 'from_dt'=>$timeframe['last'],'set'=> $this->currentSet, 'max_rows'=> $this->maxRows));
		$viewDataVars['keywords_count']=$ops->getKeywordsCountByTimeframe(array('to_dt'=> $timeframe['first'], 'from_dt'=>$timeframe['last']));
		$viewDataVars['stats']=array();
		
		$from=strtotime($timeframe['first']);
		$current=$from;
		$to=strtotime($timeframe['last']);
		
		while ($current<=$to)
		{
			$viewDataVars['stats'][date('Y-m-d',$current)]=0;
			$current+=86400;
		}
		$viewDataVars['actual_stats']=false;
		
		//use operations function here
		$query = "SELECT * FROM ".$this->appPlugin->dbPrefix()."stats_project WHERE project_id=? AND stats_d>=? AND stats_d<=? ORDER BY stats_d";
		$dbresult = $db->query($query, array($this->projectId, $timeframe['first'], $timeframe['last']));
		while ($row=$db->fetchRow($dbresult))
		{
			$viewDataVars['stats'][$row['stats_d']]=$row['visits'];
			$viewDataVars['actual_stats']=true;
		}
		
		$viewDataVars['view_keyword']=$user->checkPerm('incomingkws','view_keyword');
		
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS=getOS();

		$viewData=$this->buildViewData();
		
		$keywords_processed=array();
		foreach ($viewData['keywords'] as $keyword)
		{
			$keywords_processed[$keyword->id]=$keyword->toTemplate();
		}
		
		$tplVars=array('keywords'=>$keywords_processed,'view_keyword'=>$viewData['view_keyword']);
		
		$headContents=array('css'=>array('incomingkws'=>$this->appPlugin->getAppHomeUrl()."/resources/style.css"));
		
		if ($viewData['actual_stats'])
		{
			$total_visits=array_sum($viewData['stats']);
			
			if ($viewData['keywords_count']>0)
			{
				$average_visits=$total_visits/count($keywords_processed);
			}
			else
			{
				$average_visits=0;
			}
			
			$keywords_performance=array();
			foreach ($keywords_processed as $keyword_id=>$keyword_details)
			{
				$visits=$keyword_details['visits_timeframe'];
				$diff=abs($visits-$average_visits);
				$diff_percent=round($diff*100/$average_visits);
				
				if ($visits>$average_visits)
				{
					$diff_type='+';
				}
				elseif ($visits<$average_visits)
				{
					$diff_type='-';
				}
				else
				{
					$diff_type=false;
				}
				
				$bar_width_percent=($diff_percent>100?100:$diff_percent);
				
				$keywords_performance[$keyword_id]=array(
					'diff_percent'=>$diff_percent,
					'diff_type'=>$diff_type,
					'bar_width'=>($bar_width_percent*55/100)
				);
			}
			
			$tplVars['keywordsPerformance']=$keywords_performance;
			
			$chartValues=array();$chartTooltips=array();$chartLabels=array();
			foreach ($viewData['stats'] as $day=>$visits)
			{
				$chartValues[]=$visits;
				if (date('N',strtotime($day))==6)
				{
					$chartLabels[]=date('d M',strtotime($day));
				}
				else
				{
					$chartLabels[]=false;
				}
				$chartTooltips[]=date('d M',strtotime($day))."\n{$visits} "._("visits");
			}
			
			$charts = $OS->getCharts();
			
			$chartOptions=array(
				'values'=>array_values($chartValues),
				'labels'=>$chartLabels,
				'tooltips'=>$chartTooltips,
				'fill'=>true,
				'normalize'=>true
			);
			
			$chartData = $charts->getLineChart($chartOptions);
			
			$tplVars['chart']=$chartData['html'];
			
			foreach ($chartData['js'] as $key=>$val)
			{
				$headContents['chart_'.$key]=$val;
			}
		}
		
		
		//smart table pagination
		$prev_page = ($this->currentSet > 1 ? ($this->currentSet - 1): 1);
		$next_page = $this->currentSet +1;
		
		$linkParams = array('rows' => $this->maxRows);
		$tplVars['prev_link'] = $this->appPlugin->getAppActionUrl("main", array_merge($linkParams, array('page' => $prev_page)));
		$tplVars['next_link'] = $this->appPlugin->getAppActionUrl("main", array_merge($linkParams, array('page' => $next_page)));
		
		$tplVars['availableTotalRows'] = $this->availableTotalRows;
		$tplVars['maxRows'] = $this->maxRows;
		$tplVars['startCounter'] = $this->startCounter;
		$tplVars['linkParams'] = array_merge($linkParams, array('app' => 'incomingkws', 'view' => 'main'));
		
		$tpl=$OS->getTemplate();
		
		$tpl->setHeadContents($headContents);
		
		return $tpl->fetchTemplate('view',$tplVars);
	}
}
?>