<?php
class OS_APPVIEW_IndexedUrls_Main extends OS_AppViewBase
{
	private $currentSet;
	
	private $maxRows;
	
	private $availableTotalRows;
	
	private $startCounter;
	
	public function __construct()
	{
		$OS = getOS();
		
		$this->projectId = $OS->getProject()->id;
		
		$this->appPlugin = $OS->getAppHandler()->getAppPlugin();
		
		$this->availableTotalRows = array(10,25,50,100);
		
		$this->startCounter = 0;
		
		parent::__construct();
	}
	
	public function processRequest()
	{
		$requestParams = $this->appPlugin->getRequestParams();
		
		$this->maxRows = 10;
		if(isset($requestParams['rows']))
		{
			if(in_array($requestParams['rows'], $this->availableTotalRows))
			{
				$this->maxRows = $requestParams['rows'];			
			}
		}
		
		$this->currentSet = 1;
		if(isset($requestParams['page']))
		{
			if(is_numeric($requestParams['page']))
			{
				if($requestParams['page'] > 0)
				{
					$this->currentSet = $requestParams['page'];
					$this->startCounter = (($requestParams['page'] * $this->maxRows) - $this->maxRows);			
				}
			}
		}
	}
	
	public function buildViewData()
	{
		$OS=getOS();
		
		$ops=OS_APP_IndexedUrls_DayOperations::get_instance();
		
		$viewDataVars['days'] = $ops->getDays(array('set' => $this->currentSet, 'max_rows' => $this->maxRows));
		
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS = getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$tplVars=array();
		$headContents=array();
		
		$viewData=$this->buildViewData();
		
		$days_processed=array();
		$days_chart=array();
		foreach ($viewData['days'] as $day)
		{
			$days_processed[$day->id]=$day->toTemplate();
			$days_chart[strtotime($day->date)]=$day->urls;
		}
		$days_chart=array_reverse(array_slice($days_chart,0,10,true),true);
		
		$tplVars['days']=$days_processed;
		
		if (!empty($days_chart))
		{
			$chartValues=array();$chartTooltips=array();$chartLabels=array();
			foreach ($days_chart as $ts=>$urls)
			{
				$chartValues[]=$urls;
				$chartLabels[]=date('d M',$ts);
				$chartTooltips[]="{$urls} "._("indexed URLs");
			}
				
			$charts = $OS->getCharts();
			
			$chartOptions=array(
				'values'=>$chartValues,
				'labels'=>$chartLabels,
				'tooltips'=>$chartTooltips,
				'fill'=>true,
				'normalize'=>true
			);
			
			$chartData = $charts->getLineChart($chartOptions);

			$tplVars['chart']=$chartData['html'];
			$headContents=$chartData['js'];
		}
		
		//smart table pagination
		$prev_page = ($this->currentSet > 1 ? ($this->currentSet - 1): 1);
		$next_page = $this->currentSet +1;
		
		$linkParams = array('rows' => $this->maxRows);
		$tplVars['prev_link'] = $this->appPlugin->getAppActionUrl("main", array_merge($linkParams, array('page' => $prev_page)));
		$tplVars['next_link'] = $this->appPlugin->getAppActionUrl("main", array_merge($linkParams, array('page' => $next_page)));
		
		$tplVars['availableTotalRows'] = $this->availableTotalRows;
		$tplVars['maxRows'] = $this->maxRows;
		$tplVars['startCounter'] = $this->startCounter;
		$tplVars['linkParams'] = array_merge($linkParams, array('app' => 'indexedurls', 'view' => 'main'));
		
		$tpl = $OS->getTemplate();
		
		$tpl->setHeadContents($headContents);
		
		return $tpl->fetchTemplate('view',$tplVars);
	}
}
?>