<?php
class OS_APP_InternalLinks_Operations
{
	private static $_instance;
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_InternalLinks_Operations();
		}
		
		return self::$_instance;
	}
	
	public function hasWordsFromList($text,$wordlist)
	{
		$result=false;
		
		$text=explode(' ',strtolower($text));
		
		foreach ($text as $word)
		{
			if (in_array($word,$wordlist))
			{
				$result=true;
				break;
			}
		}
		
		return $result;
	}
	
	public function getInternalLinksDistribution($project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		if (!$project_id)
		{
			$project_id=$OS->getProject()->id;
		}
		
		$dbresult=$db->query("SELECT to_depth,COUNT(DISTINCT to_url) AS total_urls FROM ".$db->dbPrefix()."projects_urls_links WHERE project_id=? GROUP BY to_depth",array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['to_depth']]['urls']=$row['total_urls'];
		}
		
		$dbresult=$db->query("SELECT from_depth,SUM(occurances) AS total_links FROM ".$db->dbPrefix()."projects_urls_links WHERE project_id=? GROUP BY from_depth",array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['from_depth']]['outgoing']=$row['total_links'];
			$result[$row['from_depth']]['outgoing_avg']=round($row['total_links']/$result[$row['from_depth']]['urls']);
		}
		
		$dbresult=$db->query("SELECT to_depth,SUM(occurances) AS total_links FROM ".$db->dbPrefix()."projects_urls_links WHERE project_id=? AND to_depth>0 GROUP BY to_depth",array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['to_depth']]['incoming']=$row['total_links'];
			$result[$row['to_depth']]['incoming_avg']=round($row['total_links']/$result[$row['to_depth']]['urls']);
		}
		
		return $result;
	}
	
	public function getDepthUrlsInlinks($depth,$project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		if (!$project_id)
		{
			$project_id=$OS->getProject()->id;
		}
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."projects_urls_links WHERE project_id=? AND to_depth=?",array($project_id,$depth));
		while ($row=$db->fetchRow($dbresult))
		{
			if (!isset($result[$row['to_url_hash']]))
			{
				$result[$row['to_url_hash']]=array(
					'url'=>$row['to_url'],
					'incoming_links'=>0,
					'anchors_count'=>0,
					'anchors'=>array()
				);
			}
			
			if (!isset($result[$row['to_url_hash']]['anchors'][$row['anchor']]))
			{
				$result[$row['to_url_hash']]['anchors_count']++;
				$result[$row['to_url_hash']]['anchors'][$row['anchor']]=0;
			}
			
			$result[$row['to_url_hash']]['incoming_links']+=$row['occurances'];
			$result[$row['to_url_hash']]['anchors'][$row['anchor']]+=$row['occurances'];
		}
		
		return $result;
	}
	
	public function getUrlInlinksDistribution($url_hash,$project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		if (!$project_id)
		{
			$project_id=$OS->getProject()->id;
		}
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."projects_urls_links WHERE project_id=? AND to_url_hash=?",array($project_id,$url_hash));
		while ($row=$db->fetchRow($dbresult))
		{
			if (!$result)
			{
				$result=array(
					'incoming_links'=>0,
					'anchors'=>array()
				);
			}
			
			if (!isset($result['anchors'][$row['anchor']]))
			{
				$result['anchors'][$row['anchor']]=array(
					'incoming_links'=>0,
					'urls_linking'=>array(),
					'urls_linked_with_anchor'=>0
				);
				
				$dbresult2=$db->query("SELECT * FROM ".$db->dbPrefix()."projects_urls_links WHERE project_id=? AND anchor=? AND to_url_hash<>? GROUP BY to_url_hash",array($project_id,$row['anchor'],$url_hash));
				while ($row2=$db->fetchRow($dbresult2))
				{
					$result['anchors'][$row['anchor']]['urls_linked_with_anchor']++;
				}
			}
			
			if (!isset($result['anchors'][$row['anchor']]['urls_linking'][$row['from_url_hash']]))
			{
				$result['anchors'][$row['anchor']]['urls_linking'][$row['from_url_hash']]=0;
			}
			
			$result['incoming_links']+=$row['occurances'];
			$result['anchors'][$row['anchor']]['incoming_links']+=$row['occurances'];
			$result['anchors'][$row['anchor']]['urls_linking'][$row['from_url_hash']]+=$row['occurances'];
		}
		
		if ($result)
		{
			foreach ($result['anchors'] as $anchor=>$details)
			{
				$result['anchors'][$anchor]['urls_linking']=count($result['anchors'][$anchor]['urls_linking']);
				$result['anchors'][$anchor]['percent_of_links']=round($details['incoming_links']/$result['incoming_links']*100);
			}
		}
		
		return $result;
	}
	
	public function getAnchorLinkedUrls($anchor,$project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		if (!$project_id)
		{
			$project_id=$OS->getProject()->id;
		}
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."projects_urls_links WHERE project_id=? AND anchor=?",array($project_id,$anchor));
		while ($row=$db->fetchRow($dbresult))
		{
			if (!isset($result[$row['to_url_hash']]))
			{
				$result[$row['to_url_hash']]=array(
					'url'=>$row['to_url'],
					'links'=>0
				);
			}
			
			$result[$row['to_url_hash']]['links']+=$row['occurances'];
		}
		
		return $result;
	}
	
	public function getAnchorLinkingUrls($anchor,$linked_url_hash,$project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		if (!$project_id)
		{
			$project_id=$OS->getProject()->id;
		}
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."projects_urls_links WHERE project_id=? AND to_url_hash=? AND anchor=?",array($project_id,$linked_url_hash,$anchor));
		while ($row=$db->fetchRow($dbresult))
		{
			if (!isset($result[$row['from_url_hash']]))
			{
				$result[$row['from_url_hash']]=array(
					'url'=>$row['from_url'],
					'links'=>0
				);
			}
			
			$result[$row['from_url_hash']]['links']+=$row['occurances'];
		}
		
		return $result;
	}
}
?>