<?php
class OS_APPVIEW_KwAnalysis_Keywords extends OS_AppViewBase
{
	public function __construct()
	{
		parent::__construct();
	}
	
	public function processRequest()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$searchEngineOps=$OS->getSearchEngineOps();
		
		$searchEngines=$searchEngineOps->getAvailableSearchEnginesFull();
		
		$allowedSearchEngines=array('google');
		
		foreach ($searchEngines as $engine=>$details)
		{
			if (!in_array($engine,$allowedSearchEngines))
			{
				unset($searchEngines[$engine]);
			}
		}
		
		$requestParams=$appPlugin->getRequestParams();
		$requestParams['search_engines']=$searchEngines;
		
		if ($_SERVER['REQUEST_METHOD']=='POST')
		{
			if (empty($requestParams['keywords_box']))
			{
				$OS->addFieldError(_("Keywords missing"),'keywords');
			}
			else
			{
				$keywords=explode("\n",$requestParams['keywords_box']);
				$valid_keywords=array();
				
				foreach ($keywords as $keyword)
				{
					$keyword=trim($keyword);
					
					if (strlen($keyword)>=3)
					{
						$valid_keywords[]=$keyword;
					}
				}
				
				if (empty($valid_keywords))
				{
					$OS->addFieldError(_("No valid keywords provided. Minimum length: 3 chars"),'keywords');
				}
			}
			
			if (empty($requestParams['se_box']))
			{
				$OS->addFieldError(_("Search Engine missing"),'se');
			}
			elseif (!isset($searchEngines[$requestParams['se_box']]))
			{
				$OS->addFieldError(_("Unknown search engine"),'se');
			}
			else
			{
				$se_title=$searchEngines[$requestParams['se_box']]['title'];
				
				if (!empty($searchEngines[$requestParams['se_box']]['has_locales']))
				{
					if (empty($requestParams['se_locale_box']))
					{
						$OS->addFieldError(_("Search Engine locale missing"),'se_locale');
					}
					elseif (!isset($searchEngines[$requestParams['se_box']]['_locales'][$requestParams['se_locale_box']]))
					{
						$OS->addFieldError(_("Unknown search engine locale"),'se_locale');
					}
					else
					{
						$se_title.=' '.$searchEngines[$requestParams['se_box']]['_locales'][$requestParams['se_locale_box']]['title'];
					}
				}
				else
				{
					$requestParams['se_locale_box']='';
				}
			}
			
			if (!isset($OS->errorMessages))
			{
				foreach ($valid_keywords as $keyword)
				{
					$oneKeyword=new OS_APP_KwAnalysis_Keyword();
					
					$oneKeyword->project_id=$OS->getProject()->id;
					$oneKeyword->keyword=$keyword;
					$oneKeyword->se=$requestParams['se_box'];
					$oneKeyword->se_locale=$requestParams['se_locale_box'];
					$oneKeyword->se_title=$se_title;
					
					$oneKeyword->save();
				}
				
				$OS->redirectTO($appPlugin->getAppActionUrl('main',array('msg'=>'keywords_ok')),true);
			}
		}
		else
		{
			$requestParams['keywords_box']='';
			$requestParams['se_box']='';
			$requestParams['se_locale_box']='';
		}
		
		return $requestParams;
	}
	
	public function render()
	{
		$OS=getOS();

		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$tplVars=$this->processedRequest;
		$tplVars['appURL']=$appPlugin->getAppUrl();
		
		$locales=array();
		foreach ($tplVars['search_engines'] as $engine=>$engine_details)
		{
			if ($engine_details['has_locales'])
			{
				foreach ($engine_details['_locales'] as $locale=>$details)
				{
					$locales[$engine][$locale]=$details['title'];
				}
			}
		}
		
		$headContents="<script type='text/javascript'>
		var seLocales=".json_encode($locales).";
		function updateLocales(engine)
		{
			if (typeof seLocales[engine]=='undefined')
			{
				$('#locales_container').hide();
			}
			else
			{
				$('#se_locale_box').empty();
				$('#se_locale_box').append(\"<option value=''></option>\");
				for (var i in seLocales[engine])
				{
					$('#se_locale_box').append(\"<option value='\"+i+\"'>\"+seLocales[engine][i]+\"</option>\");
				}
		
				$('#locales_container').show();
			}
		}
		</script>";
		
		$tpl = $OS->getTemplate();
		
		$tpl->setHeadContents($headContents);
		
		return $tpl->fetchTemplate('keywords',$tplVars);
	}
}
?>