<?php
class OS_APP_KwExtractor extends OS_AppBase
{
	private static $_instance;
	
	public function __construct()
	{
		parent::__construct();
		
		$this->addMenuItem('view', array("name" => _("Main"), 'routerOption'=> "handleMainView"));
		$this->addMenuItem('addedit', array("name" => _("Analyze URL"), 'routerOption'=> "handleAddEditView"));
		
		$this->setRouterOption("report", "handleReportView");
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_KwExtractor();
		}
		
		return self::$_instance;
	}
	
	public function handleMainView()
	{
		getOS()->getUser()->forcePerm('kwextractor','view');
		
		$viewData=new OS_APPVIEW_KwExtractor_Main();
		
		return $viewData->render();
	}
	
	public function handleAddEditView()
	{
		getOS()->getUser()->forcePerm('kwextractor','view');
		
		$viewData=new OS_APPVIEW_KwExtractor_AddEdit();
		
		return $viewData->render();
	}
	
	public function handleReportView()
	{
		getOS()->getUser()->forcePerm('kwextractor','view');
		
		$viewData=new OS_APPVIEW_KwExtractor_Report();
		
		return $viewData->render();
	}
	
	protected function defineAppPermissions()
	{
		$this->appPermissions=array(
			'kwextractor'=>array(
				'view'=>array('name'=>_("View and perform keyword extraction"))
			)
		);
	}
	
	public function eventProjectDeleted($params)
	{
		$ops=OS_APP_KwExtractor_ReportOperations::get_instance();
		
		return $ops->deleteDataByProjectID($params['project_id']);
	}
	
	public function interactionWorkerExtractKeywordsUrl($params)
	{
		$result=false;
		
		if (!empty($params['url']))
		{
			$extractor=OS_APP_KwExtractor_Extractor::get_instance();
			
			$extractionParams=array(
				'url'=>$params['url'],
				'min_word_length'=>(isset($params['min_word_length'])?$params['min_word_length']:3),
				'words_min'=>(isset($params['words_min'])?$params['words_min']:2),
				'words_max'=>(isset($params['words_max'])?$params['words_max']:4),
				'stop_words_list'=>(isset($params['stop_words_list'])?$params['stop_words_list']:''),
				'stop_words'=>(isset($params['stop_words'])?$params['stop_words']:array()),
				'conditionValue'=>(isset($params['conditionValue'])?$params['conditionValue']:10),
				'conditionType'=>(isset($params['conditionType'])?$params['conditionType']:'count'),
			);

			$result=$extractor->extractKeywords($extractionParams['url'],$extractionParams['min_word_length'],$extractionParams['words_min'],$extractionParams['words_max'],$extractionParams['stop_words_list'],$extractionParams['stop_words'],$extractionParams['conditionValue'],$extractionParams['conditionType']);
		}
		
		return $result;
	}
	
	public function interactionWorkerExtractKeywordsHtml($params)
	{
		$result=false;
		
		if (!empty($params['url']) AND !empty($params['html']))
		{
			$extractor=OS_APP_KwExtractor_Extractor::get_instance();
			
			$extractionParams=array(
				'min_word_length'=>(isset($params['min_word_length'])?$params['min_word_length']:3),
				'words_min'=>(isset($params['words_min'])?$params['words_min']:2),
				'words_max'=>(isset($params['words_max'])?$params['words_max']:4),
				'stop_words_list'=>(isset($params['stop_words_list'])?$params['stop_words_list']:''),
				'stop_words'=>(isset($params['stop_words'])?$params['stop_words']:array()),
				'conditionValue'=>(isset($params['conditionValue'])?$params['conditionValue']:10),
				'conditionType'=>(isset($params['conditionType'])?$params['conditionType']:'count'),
			);
					
			$result=$extractor->extractKeywordsFromContent($params['url'],$params['html'],$extractionParams['min_word_length'],$extractionParams['words_min'],$extractionParams['words_max'],$extractionParams['stop_words_list'],$extractionParams['stop_words'],$extractionParams['conditionValue'],$extractionParams['conditionType']);
		}
		
		return $result;
	}
}
?>