<?php
class OS_APP_KwExtractor_Extractor
{
	private static $_instance;
	
	public function __constructor()
	{
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_KwExtractor_Extractor();
		}
		
		return self::$_instance;
	}
	
	public function extractKeywords($url,$min_word_length=3,$words_min=1,$words_max=3,$stop_words_list=false,$stop_words=array(),$conditionValue=10,$conditionType='count')
	{
		$result=false;
		
		$http=getOS()->getHttp();
		$response=$http->get($url);
		
		if (!empty($response) AND $http->success())
		{
			$result=$this->extractKeywordsFromContent($url,$response,$min_word_length,$words_min,$words_max,$stop_words_list,$stop_words,$conditionValue,$conditionType);
		}
		
		return $result;
	}
	
	public function extractKeywordsFromContent($url,$html,$min_word_length=3,$words_min=1,$words_max=3,$stop_words_list=false,$stop_words=array(),$conditionValue=10,$conditionType='count')
	{
		set_time_limit(0);
		$result=false;
		
		$dom=new DOMDocument();
					
		libxml_use_internal_errors(true);
		$domLoaded=$dom->loadHTML($html);
		libxml_use_internal_errors(false);
		
		if ($domLoaded)
		{
			unset($html);
		
			$osTextualizer=getOS()->getTextualizer();
			$osSorter=getOS()->getSorter();
			
			$osTextualizer->setEngine('fullhtml');
			$osTextualizer->setEngineOption('contentAttributes',false);
			
			if ($textualContent=$osTextualizer->extractTextFromDOM($dom))
			{
				$xpath=new DOMXPath($dom);
				$keywords=array();
				
				if ($stop_words_list)
				{
					$osStopWords=getOS()->getStopWords();
					
					if ($osStopWords->loadList($stop_words_list))
					{
						$stop_words=array_merge($stop_words,$osStopWords->getWords($stop_words_list));
					}
				}
				
				for ($i=$words_min;$i<=$words_max;$i++)
				{
					if ($phrases=$osTextualizer->extractPhrases($textualContent,$i,$min_word_length,false,$stop_words,false))
					{
						//textual content
						$first=true;
						foreach ($phrases as $phrase=>$occurances)
						{
							if ($occurances>4)
							{
								$keywords[$i][$phrase]['text']=3;
							}
							else
							{
								$keywords[$i][$phrase]['text']=1;
							}
							
							if ($first)
							{
								$keywords[$i][$phrase]['text']+=2;
							}
							
							if ($this->broadMatch($phrase,$url))
							{
								$keywords[$i][$phrase]['url']=25;
							}
							
							$first=false;
						}
						
						//emphasised intext
						$emphasis_tags=array('b','strong','em','i');
						foreach ($emphasis_tags as $tag)
						{
							$already=array();
							
							$entries=$xpath->query("//{$tag}");
							
							foreach ($entries as $entry)
							{
								if ($em_text=$entry->nodeValue)
								{
									foreach ($keywords[$i] as $phrase=>$details)
									{
										if (!isset($already[$phrase]))
										{
											if ($this->broadMatch($phrase,$em_text))
											{
												$keywords[$i][$phrase]['text']+=1;
											}
										}
									}
								}
							}
						}
						
						//title
						$entries=$xpath->query("//title");
						
						if ($entries->item(0))
						{
							if ($title=$entries->item(0)->nodeValue)
							{
								$title=strtolower($title);
								
								foreach ($keywords[$i] as $phrase=>$details)
								{
									$exact_pos=strpos($title,$phrase);
									
									if (0===$exact_pos)
									{
										$keywords[$i][$phrase]['title']=25;
									}
									elseif ($exact_pos!==false)
									{
										$keywords[$i][$phrase]['title']=20;
									}
									elseif ($this->broadMatch($phrase,$title))
									{
										$keywords[$i][$phrase]['title']=15;
									}
								}
							}
						}
						
						//h1
						$entries=$xpath->query("//h1");
						
						foreach ($entries as $entry)
						{
							if ($h1=$entry->nodeValue)
							{
								$h1=strtolower($h1);
								
								foreach ($keywords[$i] as $phrase=>$details)
								{
									$exact_pos=strpos($h1,$phrase);
									
									if (0===$exact_pos)
									{
										if (!isset($keywords[$i][$phrase]['h1']))
										{
											$keywords[$i][$phrase]['h1']=20;
										}
										elseif ($keywords[$i][$phrase]['h1']<20)
										{
											$keywords[$i][$phrase]['h1']=20;
										}
									}
									elseif ($exact_pos!==false)
									{
										if (!isset($keywords[$i][$phrase]['h1']))
										{
											$keywords[$i][$phrase]['h1']=18;
										}
										elseif ($keywords[$i][$phrase]['h1']<18)
										{
											$keywords[$i][$phrase]['h1']=18;
										}
									}
									elseif ($this->broadMatch($phrase,$h1))
									{
										if (!isset($keywords[$i][$phrase]['h1']))
										{
											$keywords[$i][$phrase]['h1']=15;
										}
										elseif ($keywords[$i][$phrase]['h1']<15)
										{
											$keywords[$i][$phrase]['h1']=15;
										}
									}
								}
							}
						}
						
						//h2
						$entries=$xpath->query("//h2");
						
						foreach ($entries as $entry)
						{
							if ($h2=$entry->nodeValue)
							{
								$h2=strtolower($h2);
								
								foreach ($keywords[$i] as $phrase=>$details)
								{
									$exact_pos=strpos($h2,$phrase);
									
									if (0===$exact_pos)
									{
										if (!isset($keywords[$i][$phrase]['h2']))
										{
											$keywords[$i][$phrase]['h2']=5;
										}
										elseif ($keywords[$i][$phrase]['h2']<5)
										{
											$keywords[$i][$phrase]['h2']=5;
										}
									}
									elseif ($exact_pos!==false)
									{
										if (!isset($keywords[$i][$phrase]['h2']))
										{
											$keywords[$i][$phrase]['h2']=4;
										}
										elseif ($keywords[$i][$phrase]['h2']<4)
										{
											$keywords[$i][$phrase]['h2']=4;
										}
									}
									elseif ($this->broadMatch($phrase,$h2))
									{
										if (!isset($keywords[$i][$phrase]['h2']))
										{
											$keywords[$i][$phrase]['h2']=3;
										}
										elseif ($keywords[$i][$phrase]['h2']<3)
										{
											$keywords[$i][$phrase]['h2']=3;
										}
									}
								}
							}
						}
						
						//anchors
						$entries=$xpath->query("//a");
						
						foreach ($entries as $entry)
						{
							if ($anchor=$entry->nodeValue)
							{
								$anchor=strtolower($anchor);
								
								foreach ($keywords[$i] as $phrase=>$details)
								{
									$exact_pos=strpos($anchor,$phrase);
									
									if ($exact_pos!==false)
									{
										if (!isset($keywords[$i][$phrase]['anchors']))
										{
											$keywords[$i][$phrase]['anchors']=5;
										}
										elseif ($keywords[$i][$phrase]['anchors']<5)
										{
											$keywords[$i][$phrase]['anchors']=5;
										}
									}
									elseif ($this->broadMatch($phrase,$anchor))
									{
										if (!isset($keywords[$i][$phrase]['anchors']))
										{
											$keywords[$i][$phrase]['anchors']=3;
										}
										elseif ($keywords[$i][$phrase]['anchors']<3)
										{
											$keywords[$i][$phrase]['anchors']=3;
										}
									}
								}
							}
						}						
						
						//images
						$already_imgs=array();
						
						$entries=$xpath->query("//img");
						$img_attrs=array('alt'=>2,'title'=>2,'src'=>2);
						
						foreach ($entries as $entry)
						{
							foreach ($keywords[$i] as $phrase=>$details)
							{
								foreach ($img_attrs as $attr=>$attr_score)
								{
									if (!isset($already_imgs[$phrase][$attr]))
									{
										if ($attr_text=$entry->getAttribute($attr))
										{
											if ($this->broadMatch($phrase,$attr_text))
											{
												if (!isset($keywords[$i][$phrase]['images']))
												{
													$keywords[$i][$phrase]['images']=0;
												}
												
												$keywords[$i][$phrase]['images']+=$attr_score;
												
												$already_imgs[$phrase][$attr]=true;
											}
										}
									}
								}
							}
						}
						
						//meta_desc
						$entries=$xpath->query("//meta[@name='description']");
						
						if ($entries->item(0))
						{
							if ($desc=$entries->item(0)->getAttribute('content'))
							{
								foreach ($keywords[$i] as $phrase=>$details)
								{
									if ($this->broadMatch($phrase,$title))
									{
										$keywords[$i][$phrase]['desc']=5;
									}
								}
							}
						}
						
						//meta_kws
						$entries=$xpath->query("//meta[@name='keywords']");
						
						if ($entries->item(0))
						{
							if ($kws=$entries->item(0)->getAttribute('content'))
							{
								$kws=explode(',',$kws);
								
								foreach ($kws as $kw)
								{
									foreach ($keywords[$i] as $phrase=>$details)
									{
										if ($phrase==$kw)
										{
											$keywords[$i][$phrase]['kws']=1;
										}
									}
								}
							}
						}

						foreach ($keywords[$i] as $phrase=>$details)
						{
							$keywords[$i][$phrase]['score']=array_sum($details);
						}
						
						if ($conditionType=='count')
						{
							$osSorter->setSortBy('score');
							$osSorter->setSortType('NUMERIC');
							$osSorter->setSortOrder('DESC');
		
							$osSorter->sort($keywords[$i]);
							
							if (count($keywords[$i])>$conditionValue)
							{
								$keywords[$i]=array_slice($keywords[$i],0,$conditionValue,true);
							}
						}
						elseif ($conditionType=='score')
						{
							foreach ($keywords[$i] as $kw=>$details)
							{
								if ($details['score']<$conditionValue)
								{
									unset($keywords[$i][$kw]);
								}
							}
							
							if (empty($keywords[$i]))
							{
								unset($keywords[$i]);
							}
						}
					}
				}
				
				if (!empty($keywords))
				{
					foreach ($keywords as $length=>$len_kws)
					{
						foreach ($len_kws as $kw=>$details)
						{
							$result[$length][$kw]=$details['score'];
						}
					}
				}
				
				unset($keywords);
			}
		}

		return $result;
	}
	
	private function broadMatch($needle,$haystack)
	{
		$result=true;
		
		$needle=strtolower($needle);
		$haystack=strtolower($haystack);
		
		$needle=explode(' ',$needle);
		
		foreach ($needle as $word)
		{
			if (false===strpos($haystack,$word))
			{
				$result=false;
				
				break;
			}
		}
		
		return $result;
	}
}
?>