<?php
class OS_APPVIEW_KwExtractor_AddEdit extends OS_AppViewBase
{
	public function __construct()
	{
		parent::__construct();
	}
	
	public function processRequest()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		$project=$OS->getProject();
		
		$stopWords=$OS->getStopWords();
		
		$stopWordsLists=$stopWords->getAvailableLists();
		
		$requestParams=$appPlugin->getRequestParams();
		
		$requestParams['stop_words_lists']=$stopWordsLists;
		
		if (empty($requestParams['op']))
		{
			$requestParams['op']='add';
		}
		elseif ($requestParams['op']=='edit')
		{
			$valid=false;
			
			if (!empty($requestParams['report_id']))
			{
				$ops=OS_APP_KwExtractor_ReportOperations::get_instance();
				
				if ($report=$ops->getReportByID($requestParams['report_id'],$project->id))
				{
					$valid=true;
				}
			}
			
			if (!$valid)
			{
				$OS->redirectTO($appPlugin->getAppActionUrl('main'),true);
			}
		}
		
		if ($_SERVER['REQUEST_METHOD']=='POST')
		{
			$validator=$OS->getValidator();
			
			if (empty($requestParams['url_box']))
			{
				$OS->addFieldError("URL missing",'url');
			}
			elseif (!$validator->is_url($requestParams['url_box']))
			{
				$OS->addFieldError("Invalid URL",'url');
			}
			
			if (empty($requestParams['min_word_length_box']))
			{
				$OS->addFieldError("Minimum word length missing",'min_word_length');
			}
			elseif (!is_numeric($requestParams['min_word_length_box']))
			{
				$OS->addFieldError("Invalid minimum word length. Expecting an integer equal to or greater than 2",'min_word_length');
			}
			elseif ($requestParams['min_word_length_box']!=floor($requestParams['min_word_length_box']))
			{
				$OS->addFieldError("Invalid minimum word length. Expecting an integer equal to or greater than 2",'min_word_length');
			}
			elseif ($requestParams['min_word_length_box']<2)
			{
				$OS->addFieldError("Invalid minimum word length. Expecting an integer equal to or greater than 2",'min_word_length');
			}
			
			$words_min_ok=false;
			if (empty($requestParams['words_min_box']))
			{
				$OS->addFieldError("Minimum words in phrase missing",'words_min');
			}
			elseif (!is_numeric($requestParams['words_min_box']))
			{
				$OS->addFieldError("Invalid minimum words in phrase. Expecting an integer between 1 and 5",'words_min');
			}
			elseif ($requestParams['words_min_box']!=floor($requestParams['words_min_box']))
			{
				$OS->addFieldError("Invalid minimum words in phrase. Expecting an integer between 1 and 5",'words_min');
			}
			elseif ($requestParams['words_min_box']<1)
			{
				$OS->addFieldError("Invalid minimum words in phrase. Expecting an integer between 1 and 5",'words_min');
			}
			elseif ($requestParams['words_min_box']>5)
			{
				$OS->addFieldError("Invalid minimum words in phrase. Expecting an integer between 1 and 5",'words_min');
			}
			else
			{
				$words_min_ok=true;
			}
			
			$words_max_ok=false;
			if (empty($requestParams['words_max_box']))
			{
				$OS->addFieldError("Maximum words in phrase missing",'words_max');
			}
			elseif (!is_numeric($requestParams['words_max_box']))
			{
				$OS->addFieldError("Invalid maximum words in phrase. Expecting an integer between 1 and 5",'words_max');
			}
			elseif ($requestParams['words_max_box']!=floor($requestParams['words_max_box']))
			{
				$OS->addFieldError("Invalid maximum words in phrase. Expecting an integer between 1 and 5",'words_max');
			}
			elseif ($requestParams['words_max_box']<1)
			{
				$OS->addFieldError("Invalid maximum words in phrase. Expecting an integer between 1 and 5",'words_max');
			}
			elseif ($requestParams['words_max_box']>5)
			{
				$OS->addFieldError("Invalid maximum words in phrase. Expecting an integer between 1 and 5",'words_max');
			}
			else
			{
				$words_max_ok=true;
			}
			
			if ($words_min_ok AND $words_max_ok)
			{
				if ($requestParams['words_max_box']<$requestParams['words_min_box'])
				{
					$OS->addFieldError("The maximum number of words in a phrase must be greater than or equal to the minimum",'words_max');
				}
			}
			
			$stop_words=array();
			if (!empty($requestParams['stop_words_box']))
			{
				$temp=explode("\n",$requestParams['stop_words_box']);
				
				foreach ($temp as $stop_word)
				{
					$stop_word=trim($stop_word);
					
					if (!empty($stop_word))
					{
						$stop_words[]=$stop_word;
					}
				}
			}
			
			$stop_words_list='';
			if (!empty($requestParams['stop_words_list_box']))
			{
				if (!isset($stopWordsLists[$requestParams['stop_words_list_box']]))
				{
					$OS->addFieldError("Invalid list",'stop_words_list');
				}
				else
				{
					$stop_words_list=$requestParams['stop_words_list_box'];
				}
			}
			else
			{
				$requestParams['stop_words_list_box']='';
			}
			
			if (!isset($OS->errorMessages))
			{
				$extractor=OS_APP_KwExtractor_Extractor::get_instance();
				
				if (!$result=$extractor->extractKeywords($requestParams['url_box'],$requestParams['min_word_length_box'],$requestParams['words_min_box'],$requestParams['words_max_box'],$stop_words_list,$stop_words))
				{
					$OS->addFieldError("Unable to extract keywords from URL",'url');
				}
				else
				{
					if ($requestParams['op']=='add')
					{
						$report=OS_APP_KwExtractor_Report::get_instance();
						
						$report->project_id=$project->id;
					}
					
					$report->url=$requestParams['url_box'];
					$report->min_word_length=$requestParams['min_word_length_box'];
					$report->words_min=$requestParams['words_min_box'];
					$report->words_max=$requestParams['words_max_box'];
					$report->stop_words_list=$stop_words_list;
					$report->stop_words=$stop_words;
					$report->status='D';
					$report->result=$result;
					
					$report->save();
					
					$OS->redirectTO($appPlugin->getAppActionUrl('main',array('msg'=>'report_ok')),true);
				}
			}
		}
		elseif ($requestParams['op']=='edit')
		{
			$requestParams['url_box']=$report->url;
			$requestParams['min_word_length_box']=$report->min_word_length;
			$requestParams['words_min_box']=$report->words_min;
			$requestParams['words_max_box']=$report->words_max;
			$requestParams['stop_words_list_box']=$report->stop_words_list;
			$requestParams['stop_words_box']=implode("\n",$report->stop_words);
		}
		else
		{
			$requestParams['url_box']='';
			$requestParams['min_word_length_box']='3';
			$requestParams['words_min_box']='2';
			$requestParams['words_max_box']='4';
			$requestParams['stop_words_list_box']='';
			$requestParams['stop_words_box']='';
		}
		
		return $requestParams;
	}
	
	public function render()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$tplVars=$this->processedRequest;
		
		$tpl=$OS->getTemplate();
		
		return $tpl->fetchTemplate('addedit',$tplVars);
	}
}
?>