<?php
class OS_APP_KwLab extends OS_AppBase
{
	private static $_instance;
	
	protected function __construct()
	{
		parent::__construct();
		
		$this->addMenuItem('view', array("name" => _("Topics"), 'routerOption'=> "handleMainView"));
		$this->addMenuItem('nicheanalysis', array("name" => _("New Topic Analysis"), 'routerOption'=> "handleNicheAnalysisView"));
		$this->addMenuItem('other', array("name" => _("Other Reports"), 'routerOption'=> "handleOtherView"));

		$this->setRouterOption("keywords", "handleKeywordsView");
		$this->setRouterOption("competitors", "handleCompetitorsView");
		$this->setRouterOption("reportcompetitorssimple", "handleReportCompetitorsSimpleView");
		$this->setRouterOption("reportcompetitors", "handleReportCompetitorsView");
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_KwLab();
		}
		return self::$_instance;
	}
	
	public function handleMainView()
	{
		getOS()->getUser()->forcePerm('kwlab','view');
		
		$viewData=new OS_APPVIEW_KwLab_Main();
		
		return $viewData->render();
	}
	
	public function handleOtherView()
	{
		getOS()->getUser()->forcePerm('kwlab','view');
		
		$viewData=new OS_APPVIEW_KwLab_Other();
		
		return $viewData->render();
	}
	
	public function handleNicheAnalysisView()
	{
		getOS()->getUser()->forcePerm('kwlab','view');
		
		$viewData=new OS_APPVIEW_KwLab_NicheAnalysis();
		
		return $viewData->render();
	}
	
	public function handleKeywordsView()
	{
		getOS()->getUser()->forcePerm('kwlab','view');
		
		$viewData=new OS_APPVIEW_KwLab_Keywords();
		
		return $viewData->render();
	}
	
	public function handleCompetitorsView()
	{
		getOS()->getUser()->forcePerm('kwlab','view');
		
		$viewData=new OS_APPVIEW_KwLab_Competitors();
		
		return $viewData->render();
	}
	
	public function handleReportCompetitorsSimpleView()
	{
		getOS()->getUser()->forcePerm('kwlab','view');
		
		$viewData=new OS_APPVIEW_KwLab_ReportCompetitorsSimple();
		
		return $viewData->render();
	}
	
	public function handleReportCompetitorsView()
	{
		getOS()->getUser()->forcePerm('kwlab','view');
		
		$viewData=new OS_APPVIEW_KwLab_ReportCompetitors();
		
		return $viewData->render();
	}
	
	protected function defineAppPermissions()
	{
		$this->appPermissions=array(
			'kwlab'=>array(
				'view'=>array('name'=>_("Access Keywords Lab")),
			)
		);
	}
	
	public function eventProjectDeleted($params)
	{
		$ops=OS_APP_KwLab_ReportOperations::get_instance();
		
		return $ops->deleteDataByProjectID($params['project_id']);
	}
	
	public function eventProjectTopicAdded($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();
		
		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
			$projectOps=$OS->getProjectOps();
			
			if ($project=$projectOps->getProjectByID($params['project_id']) AND $project->isActive())
			{
				$oneReport=new OS_APP_KwLab_Report();
				
				$oneReport->project_id=$project->id;
				$oneReport->name=$params['topic'];
				$oneReport->self_host=parse_url($project->url,PHP_URL_HOST);
				$oneReport->locale=$params['search_engine']['locale'];
				$oneReport->discover='';
				$oneReport->language='';
				$oneReport->keywords=count($params['keywords']);
				$oneReport->blacklist_domains=array();
				
				if ($oneReport->save())
				{
					$report_id=$oneReport->id;
					
					$keywords=array();
					foreach ($params['keywords'] as $keyword)
					{
						$keyword=strtolower(trim($keyword));
					
						if (strlen($keyword)>=3)
						{
							$keywords[$keyword]=$keyword;
						}
					}
					
					foreach ($keywords as $keyword)
					{
						$oneKeyword=new OS_APP_KwLab_Keyword();
						
						$oneKeyword->project_id=$project->id;
						$oneKeyword->report_id=$report_id;
						$oneKeyword->keyword=$keyword;
						$oneKeyword->source='O';
						$oneKeyword->should_discover='';
						
						$oneKeyword->save();
					}
					
					$reportOps=OS_APP_KwLab_ReportOperations::get_instance();
					$reportOps->generateReport($oneReport);
				}
			}
		}
		
		return $result;
	}
	
	public function eventSearchEngineQueried($params)
	{
		$result=false;
		
		$kwOps=OS_APP_KwLab_KeywordOperations::get_instance();
		$result=$kwOps->eventSearchEngineQueried($params);
		
		return $result;
	}
	
	public function eventRelatedKeywordsReportFinished($params)
	{
		$result=false;
		
		$kwOps=OS_APP_KwLab_KeywordOperations::get_instance();
		$result=$kwOps->eventRelatedKeywordsReportFinished($params);
		
		return $result;
	}
}
?>