<?php
class OS_APP_KwLab_CompetitorOperations
{
	private static $_instance;
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_KwLab_CompetitorOperations();
		}
		
		return self::$_instance;
	}
	
	public function getCompetitorsByReportID($report_id,$project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."competitors WHERE report_id=? AND project_id=?",array($report_id,$project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneCompetitor=new OS_APP_KwLab_Competitor();
			$oneCompetitor->set($row);
			
			$result[$row['id']]=$oneCompetitor;
		}
		
		return $result;
	}
	
	public function getCompetitorsByKeywordID($keyword_id,$project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."competitors WHERE keyword_id=? AND project_id=?",array($keyword_id,$project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneCompetitor=new OS_APP_KwLab_Competitor();
			$oneCompetitor->set($row);
			
			$result[$row['id']]=$oneCompetitor;
		}
		
		return $result;
	}
	
	public function getCompetitorByID($competitor_id,$project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."competitors WHERE id=? AND project_id=?",array($competitor_id,$project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_APP_KwLab_Competitor();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getReportCompetitorsByHost($host,$report_id,$project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."competitors WHERE report_id=? AND host=? AND project_id=?",array($report_id,$host,$project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneCompetitor=new OS_APP_KwLab_Competitor();
			$oneCompetitor->set($row);
			
			$result[$row['id']]=$oneCompetitor;
		}
		
		return $result;
	}
	
	public function orderCompetitors()
	{
		$args = func_get_args();
		$data = array_shift($args);
		
	    foreach ($args as $n => $field)
		{
			if (is_string($field))
			{
				$tmp = array();
				
				foreach ($data as $key => $row)
				{
					$tmp[$key] = $row[$field];
				}
				
				$args[$n] = $tmp;
			}
		}
		
		$args[] = &$data;
		call_user_func_array('array_multisort', $args);
		
	    return array_pop($args);
	}
	
	public function insertCompetitor($competitor)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$query="INSERT INTO ".$appHandler->dbPrefix()."competitors (project_id,report_id,keyword_id,position,host,host_moz_da,host_moz_pa,host_majestic_cf,host_majestic_tf,host_majestic_backlinks,host_majestic_rootdomains,url,title,social_facebook,social_gplus,social_twitter,moz_da,moz_pa,majestic_cf,majestic_tf,majestic_backlinks,majestic_rootdomains) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		$dbresult=$db->query($query,array($competitor->project_id,$competitor->report_id,$competitor->keyword_id,$competitor->position,$competitor->host,$competitor->host_moz_da,$competitor->host_moz_pa,$competitor->host_majestic_cf,$competitor->host_majestic_tf,$competitor->host_majestic_backlinks,$competitor->host_majestic_rootdomains,$competitor->url,$competitor->title,$competitor->social_facebook,$competitor->social_gplus,$competitor->social_twitter,$competitor->moz_da,$competitor->moz_pa,$competitor->majestic_cf,$competitor->majestic_tf,$competitor->majestic_backlinks,$competitor->majestic_rootdomains));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateCompetitor($competitor)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$query="UPDATE ".$appHandler->dbPrefix()."competitors SET position=?,host=?,url=? WHERE id=?";
		$dbresult=$db->query($query,array($competitor->position,$competitor->host,$competitor->url,$competitor->id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteCompetitorByID($competitor_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."competitors WHERE id=?";
		$dbresult=$db->query($query,array($competitor_id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
}
?>