<?php
class OS_APP_KwLab_KeywordOperations
{
	private static $_instance;
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_KwLab_KeywordOperations();
		}
		
		return self::$_instance;
	}
	
	public function getKeywordsByReportID($report_id,$project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."keywords WHERE report_id=? AND project_id=? ORDER BY original_id ASC,difficulty DESC",array($report_id,$project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneKeyword=new OS_APP_KwLab_Keyword();
			$oneKeyword->set($row);
			
			$result[$row['id']]=$oneKeyword;
		}
		
		return $result;
	}
	
	public function getKeywordByID($keyword_id)
	{
		$result=false;
		
		$OS=getOS();
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."keywords WHERE id=?",array($keyword_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_APP_KwLab_Keyword();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getReportKeywordByKeyword($keyword,$report_id)
	{
		$result=false;
		
		$OS=getOS();
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."keywords WHERE report_id=? AND keyword=?",array($report_id,$keyword));
		while ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_APP_KwLab_Keyword();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getKeywordsPendingDiscovery($offset,$limit)
	{
		$result=false;
		
		$OS=getOS();
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."keywords WHERE should_discover=? AND (related=? OR autosuggest=?) LIMIT {$offset},{$limit}",array('Y','',''));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneKeyword=new OS_APP_KwLab_Keyword();
			$oneKeyword->set($row);
			
			$result[$row['id']]=$oneKeyword;
		}
		
		return $result;
	}
	
	public function getKeywordsPendingCompetitorExtraction($offset,$limit)
	{
		$result=false;
		
		$OS=getOS();
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."keywords WHERE competitors=? LIMIT {$offset},{$limit}",array(''));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneKeyword=new OS_APP_KwLab_Keyword();
			$oneKeyword->set($row);
			
			$result[$row['id']]=$oneKeyword;
		}
		
		return $result;
	}
	
	public function fetchRelated($keyword)
	{
		$result=false;
		
		$reportOps=OS_APP_KwLab_ReportOperations::get_instance();
		
		if ($report=$reportOps->getReportByID($keyword->report_id))
		{
			if ($worker=OS_Interactions::getInteractions('worker','get_related_keywords'))
			{
				$worker=reset($worker);
				
				if ($related=OS_Interactions::performInteraction($worker['id'],array('project_id'=>$keyword->project_id,'keyword'=>$keyword->keyword,'options'=>array('google'=>array('locale'=>$report->locale),'google_suggest'=>array('language'=>$report->language)))))
				{
					if ($related['status']=='done')
					{
						$result=$this->saveRelated($keyword,$related['related_keywords']);
					}
					elseif ($related['status']=='queued')
					{
						$result=$this->queueKeyword($keyword->id,$related['queue_id'],'related');
					}
				}
			}
		}
		
		return $result;
	}
	
	public function saveRelated($keyword,$related_keywords)
	{
		$result=false;
		
		$reportOps=OS_APP_KwLab_ReportOperations::get_instance();
		
		if ($report=$reportOps->getReportByID($keyword->report_id))
		{
			foreach ($related_keywords as $type=>$keywords)
			{
				if ($type=='google_suggest')
				{
					$keywords=$keywords['web'];
				}
				
				foreach ($keywords as $new_keyword)
				{
					if (!$oneKeyword=$this->getReportKeywordByKeyword($new_keyword,$keyword->report_id))
					{
						$oneKeyword=new OS_APP_KwLab_Keyword();
						
						$oneKeyword->project_id=$keyword->project_id;
						$oneKeyword->report_id=$keyword->report_id;
						$oneKeyword->keyword=$new_keyword;
						$oneKeyword->source=($type=='google'?'R':'A');
						$oneKeyword->original_id=$keyword->id;
						
						if ($oneKeyword->save())
						{
							$this->fetchCompetitors($oneKeyword,'google',$report->locale);
						}
					}										
				}
			}
			
			$keyword->related='Y';
			$keyword->autosuggest='Y';
			
			if ($keyword->save())
			{
				$reportOps->updateReportKeywordsCount($report);
				$reportOps->updateReportStatus($report);
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function eventRelatedKeywordsReportFinished($params)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$keyword_ids=array();
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."queue WHERE queue_id=? AND queue_type=?",array($params['report_id'],'related'));
		while ($row=$db->fetchRow($dbresult))
		{
			$keyword_ids[]=$row['keyword_id'];
		}
		
		if (!empty($keyword_ids))
		{
			$db->query("DELETE FROM ".$appHandler->dbPrefix()."queue WHERE queue_id=? AND queue_type=?",array($params['report_id'],'related'));
			
			foreach ($keyword_ids as $keyword_id)
			{
				if ($oneKeyword=$this->getKeywordByID($keyword_id))
				{
					if ($params['status']=='done')
					{
						$this->saveRelated($oneKeyword,$params['related_keywords']);
					}
					elseif ($params['status']=='failed')
					{
						$this->fetchRelated($oneKeyword);
					}
				}
			}
			
			$result=true;
		}
		
		return $result;
	}
	
	public function fetchCompetitors($keyword,$engine=false,$locale=false)
	{
		$result=false;
		
		$result=false;
		
		$OS=getOS();
		
		if (!$engine)
		{
			//TODO: get from report
		}
		
		if ($engine)
		{
			$osSearchEngine=$OS->getSearchEngine();
			
			if ($competitors=$osSearchEngine->getResults($keyword->keyword,$engine,$locale))
			{
				if ($competitors['status']=='done')
				{
					$result=$this->saveCompetitors($keyword,$competitors['data']);
				}
				elseif ($competitors['status']=='queued')
				{
					$result=$this->queueKeyword($keyword->id,$competitors['queue_id'],'competitors');
				}
			}
		}
		
		return $result;
	}
	
	public function saveCompetitors($keyword,$competitors)
	{
		$result=false;
		
		$reportOps=OS_APP_KwLab_ReportOperations::get_instance();
		
		if ($report=$reportOps->getReportByID($keyword->report_id,$keyword->project_id))
		{
			$OS=getOS();
			$osBacklinks=$OS->getBacklinks();
			$osUtils=$OS->getUtils();
			
			$competitorsUrls=array();
			$competitorsHosts=array();
			$competitorsHostsMoz=array();
			foreach ($competitors as $competitor)
			{
				$competitorsUrls[]=$osUtils->prependHTTP($competitor['url']);
				
				if ($host=parse_url($competitor['url'],PHP_URL_HOST))
				{
					$competitorsHosts[]=$host;
					$competitorsHostsMoz[]='http://'.$host.'/';
				}
			}
			
			$backlinksData=array(
				'moz'=>array(
					'hosts'=>false,
					'urls'=>false
				),
				'majesticsimple'=>array(
					'hosts'=>false,
					'urls'=>false
				)
			);
			
			if ($backlinksData['moz']['hosts']=$osBacklinks->getUrlsMetrics($competitorsHostsMoz,'moz'))
			{
				$backlinksData['moz']['urls']=$osBacklinks->getUrlsMetrics($competitorsUrls,'moz');
			}
			
			if ($backlinksData['majesticsimple']['hosts']=$osBacklinks->getUrlsMetrics($competitorsHosts,'majesticsimple'))
			{
				$backlinksData['majesticsimple']['urls']=$osBacklinks->getUrlsMetrics($competitorsUrls,'majesticsimple');
			}
			
			$osSocialSignals=$OS->getSocialSignals();
			$osSocialSignals->setSocialNetwork('sharedcount');
			
			$keyword_difficulty_metrics=array('url_metrics'=>array(),'domain_metrics'=>array());
			
			foreach ($competitors as $position=>$competitor)
			{
				if ($host=parse_url($competitor['url'],PHP_URL_HOST))
				{
					$position++;
					
					$oneCompetitor=new OS_APP_KwLab_Competitor();
					
					$oneCompetitor->project_id=$keyword->project_id;
					$oneCompetitor->report_id=$keyword->report_id;
					$oneCompetitor->keyword_id=$keyword->id;
					$oneCompetitor->position=$position;
					$oneCompetitor->host=$host;
					$oneCompetitor->url=$competitor['url'];
					$oneCompetitor->title=$competitor['title'];
					$oneCompetitor->host_moz_da=1;
					$oneCompetitor->host_moz_pa=1;
					$oneCompetitor->moz_da=1;
					$oneCompetitor->moz_pa=1;
					
					if ($signals=$osSocialSignals->getSocialSignals($competitor['url']))
					{
						$oneCompetitor->social_facebook=$signals['facebook']['total'];
						$oneCompetitor->social_gplus=$signals['gplus'];
						$oneCompetitor->social_twitter=$signals['twitter'];
					}
					
					$httpUrl=$osUtils->prependHTTP($competitor['url']);
					
					$keyword_difficulty_metrics['domain_metrics'][$position]=0;
					$keyword_difficulty_metrics['url_metrics'][$position]=0;
					$hasMoz=false;
					
					if ($backlinksData['moz']['hosts'])
					{
						$hasMoz=true;
						
						if ($backlinksData['moz']['hosts']['http://'.$host.'/'])
						{
							$oneCompetitor->host_moz_da=floor($backlinksData['moz']['hosts']['http://'.$host.'/']['domain_authority']);
							$oneCompetitor->host_moz_pa=floor($backlinksData['moz']['hosts']['http://'.$host.'/']['domain_authority']);
							
							$oneCompetitor->moz_da=$oneCompetitor->host_moz_da;
						}
						
						if ($backlinksData['moz']['urls'])
						{
							if ($backlinksData['moz']['urls'][$httpUrl])
							{
								$oneCompetitor->moz_da=floor($backlinksData['moz']['urls'][$httpUrl]['domain_authority']);
								$oneCompetitor->moz_pa=floor($backlinksData['moz']['urls'][$httpUrl]['page_authority']);
							}
						}
					}
					
					if ($backlinksData['majesticsimple']['hosts'])
					{
						if ($backlinksData['majesticsimple']['hosts'][$host])
						{
							$oneCompetitor->host_majestic_cf=$backlinksData['majesticsimple']['hosts'][$host]['citation_flow'];
							$oneCompetitor->host_majestic_tf=$backlinksData['majesticsimple']['hosts'][$host]['trust_flow'];
							$oneCompetitor->host_majestic_backlinks=$backlinksData['majesticsimple']['hosts'][$host]['backlinks'];
							$oneCompetitor->host_majestic_rootdomains=$backlinksData['majesticsimple']['hosts'][$host]['rootdomains'];
						}
						
						if ($backlinksData['majesticsimple']['urls'])
						{
							if (!empty($backlinksData['majesticsimple']['urls'][$httpUrl]))
							{
								$oneCompetitor->majestic_cf=$backlinksData['majesticsimple']['urls'][$httpUrl]['citation_flow'];
								$oneCompetitor->majestic_tf=$backlinksData['majesticsimple']['urls'][$httpUrl]['trust_flow'];
								$oneCompetitor->majestic_backlinks=$backlinksData['majesticsimple']['urls'][$httpUrl]['backlinks'];
								$oneCompetitor->majestic_rootdomains=$backlinksData['majesticsimple']['urls'][$httpUrl]['rootdomains'];
							}
						}
					}
					
					if ($hasMoz)
					{
						$keyword_difficulty_metrics['domain_metrics'][$position]=$oneCompetitor->host_moz_da;
						$keyword_difficulty_metrics['url_metrics'][$position]=$oneCompetitor->moz_pa;
					}
					else
					{
						$keyword_difficulty_metrics['domain_metrics'][$position]=$oneCompetitor->host_majestic_cf;
						$keyword_difficulty_metrics['url_metrics'][$position]=$oneCompetitor->majestic_cf;
					}
					
					if (!$reportOps->isBlacklistedHost($report,$host))
					{
						$oneCompetitor->save();
					}
				}
			}
			
			if (!empty($keyword_difficulty_metrics))
			{
				if ($worker=OS_Interactions::getInteractions('worker','compute_keyword_difficulty'))
				{
					$worker=reset($worker);
					
					if ($difficulty=OS_Interactions::performInteraction($worker['id'],$keyword_difficulty_metrics))
					{
						$keyword->difficulty=$difficulty;
					}
				}
			}
			
			$keyword->competitors='Y';
			
			if ($keyword->save())
			{
				$result=true;
				
				$reportOps->updateReportDifficulty($report);
				$reportOps->updateReportStatus($report);
			}
		}
		
		return $result;
	}
	
	public function eventSearchEngineQueried($params)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$keyword_ids=array();
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."queue WHERE queue_id=? AND queue_type=?",array($params['queue_id'],'competitors'));
		while ($row=$db->fetchRow($dbresult))
		{
			$keyword_ids[]=$row['keyword_id'];
		}
		
		if (!empty($keyword_ids))
		{
			$db->query("DELETE FROM ".$appHandler->dbPrefix()."queue WHERE queue_id=? AND queue_type=?",array($params['queue_id'],'competitors'));
			
			foreach ($keyword_ids as $keyword_id)
			{
				if ($oneKeyword=$this->getKeywordByID($keyword_id))
				{
					if ($params['status']=='done')
					{
						$this->saveCompetitors($oneKeyword,$params['data']['getResults']);
					}
					elseif ($params['status']=='failed')
					{
						$this->fetchCompetitors($oneKeyword);
					}
				}
			}
			
			$result=true;
		}
		
		return $result;
	}
	
	public function isQueuedKeyword($keyword_id,$queue_type)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."queue WHERE keyword_id=? AND queue_type=?",array($keyword_id,$queue_type));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function queueKeyword($keyword_id,$queue_id,$queue_type)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$dbresult=$db->query("INSERT INTO ".$appHandler->dbPrefix()."queue (keyword_id,queue_id,queue_type) VALUES (?,?,?)",array($keyword_id,$queue_id,$queue_type));
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function insertKeyword($keyword)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$query="INSERT INTO ".$appHandler->dbPrefix()."keywords (project_id,report_id,keyword,source,original_id,should_discover) VALUES (?,?,?,?,?,?)";
		$dbresult=$db->query($query,array($keyword->project_id,$keyword->report_id,$keyword->keyword,$keyword->source,$keyword->original_id,$keyword->should_discover));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateKeyword($keyword)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$query="UPDATE ".$appHandler->dbPrefix()."keywords SET should_discover=?,source=?,related=?,autosuggest=?,analyzed=?,competitors=?,difficulty=? WHERE id=?";
		$dbresult=$db->query($query,array($keyword->should_discover,$keyword->source,$keyword->related,$keyword->autosuggest,$keyword->analyzed,$keyword->competitors,$keyword->difficulty,$keyword->id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteKeywordByID($keyword_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$can_delete=true;
		
		$compOps=OS_APP_KwLab_CompetitorOperations::get_instance();
		if ($competitors=$compOps->getCompetitorsByKeywordID($keyword_id))
		{
			foreach ($competitors as $competitor)
			{
				if (!$competitor->delete())
				{
					$can_delete=false;
					break;
				}
			}
		}
		
		if ($can_delete)
		{
			$query="DELETE FROM ".$appHandler->dbPrefix()."keywords WHERE id=?";
			$dbresult=$db->query($query,array($keyword_id));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
}
?>