<?php
class OS_APP_KwLab_Report
{
	private static $_instance;
	
	public $id;
	public $project_id;
	public $name;
	public $self_host;
	public $locale;
	public $discover;
	public $language;
	public $blacklist_domains;
	public $keywords;
	public $difficulty;
	public $insert_dt;
	public $insert_ip;
	public $status;
	public $status_dt;
	public $status_ip;
	
	public function __construct()
	{
		$this->setInitialValues();
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_KwLab_Report();
		}
		
		return self::$_instance;
	}
	
	public function setInitialValues()
	{
		$this->id=0;
		$this->project_id=0;
		$this->name='';
		$this->self_host='';
		$this->locale='';
		$this->discover='';
		$this->language='';
		$this->blacklist_domains=array();
		$this->keywords=0;
		$this->difficulty=0;
		$this->insert_dt='';
		$this->insert_ip='';
		$this->status='';
		$this->status_dt='';
		$this->status_ip='';
	}
	
	public function set($data)
	{
		$result = false;
		
		$objVars = get_object_vars($this);
		
		foreach($objVars as $key=>$val)
		{
			if(isset($data[$key]))
			{
				$this->$key = $data[$key];
				$result = true;
			}
		}
		
		return $result;
	}
	
	public function save()
	{
		$result=false;
		
		$ops=OS_APP_KwLab_ReportOperations::get_instance();
		
		if (!$this->id)
		{
			if ($this->id=$ops->insertReport($this))
			{
				$result=true;
			}
		}
		else
		{
			$result=$ops->updateReport($this);
		}
		
		return $result;
	}
	
	public function load()
	{
		$result = false;
		
		if ($this->id)
		{
			$ops=OS_APP_KwLab_ReportOperations::get_instance();
			
			if ($data=$ops->getReportByID($this->id))
			{
				$this->set(get_object_vars($data));
				
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function delete()
	{
		$result = false;
		
		if ($this->id)
		{
			$ops=OS_APP_KwLab_ReportOperations::get_instance();
			
			$result=$ops->deleteReportByID($this->id);
		}
		
		return $result;
	}
	
	public function toTemplate()
	{
		if (!$this->id) return false;
		
		$utils=getOS()->getUtils();
		$app=getOS()->getAppHandler()->getAppPlugin();
		
		$statuses=array('W'=>_('Processing...'),'K'=>_('Finding keywords...'),'C'=>_('Getting competition...'),'F'=>_('Failed'),'D'=>_('Done'));
		
		$result=array(
			'id'=>$this->id,
			'name'=>$this->name,
			'discover'=>$this->discover,
			'keywords'=>$this->keywords,
			'difficulty'=>$this->difficulty,
			'insert_dt_human'=>$utils->humanizeDate($this->insert_dt),
			'status'=>$this->status,
			'status_human'=>$statuses[$this->status],
			'status_dt_human'=>$utils->humanizeDate($this->status_dt),
			'keywords_url'=>$app->getAppActionUrl('keywords',array('report_id'=>$this->id)),
			'competitors_url'=>($this->status=='D'?$app->getAppActionUrl('reportcompetitorssimple',array('report_id'=>$this->id)):false),
			'delete_url'=>$app->getAppActionUrl('view',array('op'=>'delete','report_id'=>$this->id))
		);
		
		return $result;
	}
}
?>