<?php
class OS_APP_KwLab_ReportOperations
{
	private static $_instance;
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_KwLab_ReportOperations();
		}
		
		return self::$_instance;
	}
	
	public function getReports($project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE project_id=?",array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['blacklist_domains']=json_decode($row['blacklist_domains'],true);
			
			$oneReport=new OS_APP_KwLab_Report();
			$oneReport->set($row);
			
			$result[$row['id']]=$oneReport;
		}
		
		return $result;
	}
	
	public function getReportByID($report_id)
	{
		$result=false;
		
		$OS=getOS();
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE id=?",array($report_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['blacklist_domains']=json_decode($row['blacklist_domains'],true);
			
			$result=new OS_APP_KwLab_Report();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getUnfinishedReports($offset,$limit)
	{
		$result=false;
		
		$OS=getOS();
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE status=? OR status=? LIMIT {$offset},{$limit}",array('C','K'));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['blacklist_domains']=json_decode($row['blacklist_domains'],true);
			
			$oneReport=new OS_APP_KwLab_Report();
			$oneReport->set($row);
			
			$result[$row['id']]=$oneReport;
		}
		
		return $result;
	}
	
	public function insertReport($report)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		if (empty($report->status))
		{
			$report->status=($report->discover=='Y'?'K':'C');
		}
		
		$blacklist_domains=json_encode($report->blacklist_domains);
		
		$query="INSERT INTO ".$appHandler->dbPrefix()."reports (project_id,name,self_host,locale,discover,language,blacklist_domains,keywords,difficulty,insert_dt,insert_ip,status,status_dt,status_ip) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		$dbresult=$db->query($query,array($report->project_id,$report->name,$report->self_host,$report->locale,$report->discover,$report->language,$blacklist_domains,$report->keywords,$report->difficulty,$time,$ip,$report->status,$time,$ip));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateReport($report)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$query="UPDATE ".$appHandler->dbPrefix()."reports SET keywords=?,difficulty=?,status=?,status_dt=?,status_ip=? WHERE id=?";
		$dbresult=$db->query($query,array($report->keywords,$report->difficulty,$report->status,$time,$ip,$report->id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteReportByID($report_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$can_delete=true;
		
		$kwOps=OS_APP_KwLab_KeywordOperations::get_instance();
		if ($keywords=$kwOps->getKeywordsByReportID($report_id))
		{
			foreach ($keywords as $keyword)
			{
				if (!$keyword->delete())
				{
					$can_delete=false;
					break;
				}
			}
		}
		
		if ($can_delete)
		{
			$query="DELETE FROM ".$appHandler->dbPrefix()."reports WHERE id=?";
			$dbresult=$db->query($query,array($report_id));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function generateReport($report)
	{
		return OS_Fork::fork('app','kwlab','analyze',array('project_id'=>$report->project_id,'report_id'=>$report->id));
	}
	
	public function computeReportStatus($report)
	{
		$result='K';
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		if ($report->discover=='Y')
		{
			$query="SELECT COUNT(*) AS pending_keywords FROM ".$appHandler->dbPrefix()."keywords WHERE report_id=? AND should_discover=? AND (related=? OR autosuggest=?)";
			$dbresult=$db->query($query,array($report->id,'Y','',''));
			$row=$db->fetchRow($dbresult);
			if ($row['pending_keywords']==0)
			{
				$result='C';
			}
		}
		else
		{
			$result='C';
		}
		
		if ($result=='C')
		{
			$query="SELECT COUNT(*) AS pending_keywords FROM ".$appHandler->dbPrefix()."keywords WHERE report_id=? AND competitors=?";
			$dbresult=$db->query($query,array($report->id,''));
			$row=$db->fetchRow($dbresult);
			if ($row['pending_keywords']==0)
			{
				$result='D';
			}
		}
		
		return $result;
	}
	
	public function updateReportStatus($report)
	{
		$result=false;
		
		if ($current_status=$this->computeReportStatus($report))
		{
			if ($report->status!=$current_status)
			{
				$report->status=$current_status;
				
				$result=$report->save();
			}
		}
		
		return $result;
	}
	
	public function updateReportDifficulty($report)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$difficulties=array();
		$dbresult=$db->query("SELECT difficulty FROM ".$appHandler->dbPrefix()."keywords WHERE report_id=?",array($report->id));
		while ($row=$db->fetchRow($dbresult))
		{
			$difficulties[]=$row['difficulty'];
		}
		
		if ($difficulties)
		{
			$osUtils=$OS->getUtils();
			
			$report->difficulty=$osUtils->getMedianValue($difficulties);
			
			$result=$report->save();
		}
		else
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function updateReportKeywordsCount($report)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="SELECT COUNT(*) AS report_keywords FROM ".$appHandler->dbPrefix()."keywords WHERE report_id=?";
		$dbresult=$db->query($query,array($report->id));
		$row=$db->fetchRow($dbresult);
		
		if ($report->keywords!=$row['report_keywords'])
		{
			$report->keywords=$row['report_keywords'];
			
			if ($report->save())
			{
				$result=$report->keywords;
			}
		}
		
		return $result;
	}
	
	public function isBlacklistedHost($report,$host)
	{
		$result=false;
		
		foreach ($report->blacklist_domains as $domain)
		{
			$pattern='/'.str_replace(array('.','*'),array('\.','(.*)'),$domain).'/i';
			
			if (preg_match($pattern,$host))
			{
				$result=true;
				break;
			}
		}
		
		return $result;
	}
	
	public function deleteDataByProjectID($project_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."competitors WHERE project_id=?";
		$dbresult=$db->query($query,array($project_id));
		
		if ($dbresult!==false)
		{
			$query="DELETE FROM ".$appHandler->dbPrefix()."keywords WHERE project_id=?";
			$dbresult=$db->query($query,array($project_id));
			
			if ($dbresult!==false)
			{
				$query="DELETE FROM ".$appHandler->dbPrefix()."reports WHERE project_id=?";
				$dbresult=$db->query($query,array($project_id));
				
				if ($dbresult!==false)
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
}
?>