<?php
class OS_APPVIEW_KwLab_Keywords extends OS_AppViewBase
{
	public function __construct()
	{
		parent::__construct();
	}
	
	public function processRequest()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		$project=$OS->getProject();
		
		$requestParams=$appPlugin->getRequestParams();
		$export=false;
		
		$valid=false;
		if (!empty($requestParams['report_id']))
		{
			$ops=OS_APP_KwLab_ReportOperations::get_instance();

			if ($report=$ops->getReportByID($requestParams['report_id'],$project->id))
			{
				$kwOps=OS_APP_KwLab_KeywordOperations::get_instance();
				
				if ($keywords=$kwOps->getKeywordsByReportID($requestParams['report_id'],$project->id))
				{
					$valid=true;
				}
			}
		}
		
		if (isset($requestParams['export']))
		{
			$export=true;
		}
		
		if (!$valid)
		{
			$OS->redirectTO($appPlugin->getAppActionUrl('main'),true);
		}
		
		$bulkActions=array('delete');
		
		if ($_SERVER['REQUEST_METHOD']=='POST')
		{
			if (!empty($requestParams['keywords_bulk_action_box']) AND in_array($requestParams['keywords_bulk_action_box'],$bulkActions))
			{
				$affectedKeywords=array();
				
				foreach ($keywords as $keyword_id=>$keyword)
				{
					if (!empty($requestParams["keyword_{$keyword_id}_box"]))
					{
						$affectedKeywords[]=$keyword_id;
					}
				}
				
				if (!empty($affectedKeywords))
				{
					if ($requestParams['keywords_bulk_action_box']=='delete')
					{
						$shouldUpdate=false;
						
						foreach ($affectedKeywords as $keyword_id)
						{
							if ($keywords[$keyword_id]->delete())
							{
								$shouldUpdate=true;
								unset($keywords[$keyword_id]);
							}
						}
						
						if ($shouldUpdate)
						{
							$keywordsCount=$ops->updateReportKeywordsCount($report);
							
							if ($keywordsCount==0 AND $keywordsCount!==false)
							{
								if ($report->delete())
								{
									$OS->redirectTO($appPlugin->getAppActionUrl('main',array('msg'=>'delete_ok')),true);
								}
							}
							else
							{
								$ops->updateReportDifficulty($report);
							}
						}
					}
				}
			}
		}		
		elseif (isset($requestParams['op']))
		{
			if ($requestParams['op']=='delete')
			{
				if (!empty($requestParams['keyword_id']) AND isset($keywords[$requestParams['keyword_id']]))
				{
					if ($keywords[$requestParams['keyword_id']]->delete())
					{
						unset($keywords[$requestParams['keyword_id']]);
						$OS->addInfo(_("Keyword deleted successfully"));
						
						$ops->updateReportKeywordsCount($report);
						$ops->updateReportDifficulty($report);
					}
					else
					{
						$OS->addBoxError(_("Unable to delete keyword"));
					}
				}
			}
			elseif ($requestParams['op']=='discover')
			{
				if (!empty($requestParams['keyword_id']) AND isset($keywords[$requestParams['keyword_id']]) AND $keywords[$requestParams['keyword_id']]->should_discover=='')
				{
					$canDiscover=true;
					if ($report->discover!='Y')
					{
						//TODO: language for autosuggest?!
						$report->discover='Y';
						
						if (!$report->save())
						{
							$canDiscover=false;
						}
					}
					
					if ($canDiscover)
					{
						$keywords[$requestParams['keyword_id']]->should_discover='Y';
						
						if ($keywords[$requestParams['keyword_id']]->save())
						{
							$OS->addInfo(_("Keyword marked for discovery"));
							
							if ($report->status!='K')
							{
								$report->status='K';
								$report->save();
							}
							
							$kwOps->fetchRelated($keywords[$requestParams['keyword_id']]);
						}
						else
						{
							$OS->addBoxError(_("Unable to mark keyword for discovery"));
						}
					}
					else
					{
						$OS->addBoxError(_("Unable to mark keyword for discovery"));
					}
				}
			}
		}
		
		return array('report'=>$report,'keywords'=>$keywords,'export'=>$export);
	}
	
	public function render()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
			
		$tplVars['report']=$this->processedRequest['report']->toTemplate();
		$tplVars['keywords']=array();
		$spread=array('easy'=>0,'average'=>0,'challenging'=>0,'hard'=>0,'extreme'=>0,'pending'=>0);
		foreach ($this->processedRequest['keywords'] as $keyword_id=>$keyword)
		{
			$tplVars['keywords'][$keyword_id]=$keyword->toTemplate();
			
			if ($keyword->competitors=='Y')
			{
				if ($keyword->difficulty>90)
				{
					$spread['extreme']++;
					$diff='extreme';
				}
				elseif ($keyword->difficulty>75)
				{
					$spread['hard']++;
					$diff='hard';
				}
				elseif ($keyword->difficulty>50)
				{
					$spread['challenging']++;
					$diff='challenging';
				}
				elseif ($keyword->difficulty>25)
				{
					$spread['average']++;
					$diff='average';
				}
				else
				{
					$spread['easy']++;
					$diff='easy';
				}
			}
			else
			{
				$spread['pending']++;
				$diff='pending';
			}
			
			$tplVars['keywords'][$keyword_id]['difficulty_group']=$diff;
			if ($diff=='pending')
			{
				$tplVars['keywords'][$keyword_id]['difficulty_color']='gray';
			}
			else
			{
				$tplVars['keywords'][$keyword_id]['difficulty_color']=($diff=='easy'?'blue':($diff=='average'?'green':($diff=='challenging'?'yellow':($diff=='hard'?'orange':'red'))));
			}
		}
		
		$tplVars['overview']['spread']=$spread;
		if ($this->processedRequest['report']->status=='D')
		{
			$diff=$this->processedRequest['report']->difficulty;
			
			$tplVars['overview']['difficulty']=array('difficulty'=>round($diff,2),'difficulty_text'=>($diff>90?_("Extreme"):($diff>75?_("Hard"):($diff>50?_("Challenging"):($diff>25?_("Average"):_("Easy"))))),'color'=>($diff>90?'red':($diff>75?'orange':($diff>50?'yellow':($diff>25?'green':'blue')))));
		}
		else
		{
			$tplVars['overview']['difficulty']=false;
		}
		
		if ($this->processedRequest['export'])
		{
			$export="Topic,Difficulty,Easy Keywords,Average Keywords,Challenging Keywords,Hard Keywords,Extreme Keywords\n{$this->processedRequest['report']->name},".($this->processedRequest['report']->status=='D'?round($this->processedRequest['report']->difficulty,2):'-').",{$spread['easy']},{$spread['average']},{$spread['challenging']},{$spread['hard']},{$spread['extreme']}\n\nKeyword,Difficulty,Source";
			
			foreach ($tplVars['keywords'] as $keyword)
			{
				$export.="\n".$keyword['keyword'].','.$keyword['difficulty'].','.$keyword['source_human'];
			}
			
			header('Content-Type: text/csv');
			header('Content-Disposition: attachment; filename="'.str_replace(' ','-',$this->processedRequest['report']->name).'_keywords.csv"');
			
			echo $export;
			
			exit;
		}
		else
		{
			$appPlugin->setMenuBackLink(array('back_view'=>'view'));			
			$tplVars['exportURL']=$appPlugin->getAppActionUrl('keywords',array('report_id'=>$this->processedRequest['report']->id,'export'=>'yes'));
			$tplVars['appURL']=$appPlugin->getAppUrl();
			
			$tpl=$OS->getTemplate();
			
			$headContents="<script type='text/javascript'>
				function toggleDifficultyGroup(group)
				{
					var areVisible=\$('#difficulty_toggle_'+group).hasClass('fill');

					\$('#difficulty_toggle_'+group).toggleClass('fill');

					\$('.difficulty_'+group).css('display',(areVisible?'none':'table-row'));
				}
				function toggleAllCheckboxes(el)
				{
					$('.keyword_check').prop('checked',$(el).is(':checked'));
					toggleBulkAction();
				}
				function toggleBulkAction()
				{
					if ($('.keyword_check:checked').length>0)
					{
						$('#keywords_bulk_action_top').show();
					}
					else
					{
						$('#keywords_bulk_action_top').hide();
					}
				}
			</script>";
			
			$tpl->setHeadContents($headContents);
			
			return $tpl->fetchTemplate('keywords',$tplVars);
		}
	}
}
?>