<?php
class OS_APPVIEW_KwLab_NicheAnalysis extends OS_AppViewBase
{
	public function __construct()
	{
		parent::__construct();
	}
	
	public function processRequest()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$searchEngineOps=$OS->getSearchEngineOps();
		
		$relatedOps=OS_APP_RelatedKws_ReportOperations::get_instance();
		
		$requestParams=$appPlugin->getRequestParams();
		$requestParams['locales']=$searchEngineOps->getAvailableSearchEngineLocales('google');
		$requestParams['languages']=$relatedOps->googleSuggestLanguages;
		
		if ($_SERVER['REQUEST_METHOD']=='POST')
		{
			if (empty($requestParams['name_box']))
			{
				$requestParams['name_box']='';
			}
			else
			{
				$requestParams['name_box']=trim($requestParams['name_box']);
			}
			
			if (empty($requestParams['keywords_box']))
			{
				$OS->addFieldError(_("Provide at least one keyword"),'keywords');
			}
			else
			{
				$keywords=array();
				
				$requestParams['keywords_box']=explode("\n",$requestParams['keywords_box']);
				
				foreach ($requestParams['keywords_box'] as $keyword)
				{
					$keyword=strtolower(trim($keyword));
					
					if (strlen($keyword)>=3)
					{
						$keywords[$keyword]=$keyword;
					}
				}
				
				if (empty($keywords))
				{
					$OS->addFieldError(_("Provide at least one keyword. Minimum length: 3 chars"),'keywords');
				}
				else
				{
					if (empty($requestParams['name_box']))
					{
						$requestParams['name_box']=reset($keywords);
					}
				}
				
				$requestParams['keywords_box']=implode("\n",$keywords);
			}
			
			if (empty($requestParams['self_host_box']))
			{
				$requestParams['self_host_box']='';
			}
			else
			{
				$osValidator=$OS->getValidator();
				
				if (!$osValidator->is_hostname($requestParams['self_host_box']))
				{
					$OS->addFieldError(_("Invalid domain name"),'self_host');
				}
			}
			
			if (empty($requestParams['locale_box']))
			{
				$OS->addFieldError(_("Google country missing"),'locale');
			}
			elseif (!isset($requestParams['locales'][$requestParams['locale_box']]))
			{
				$OS->addFieldError(_("Invalid Google country"),'locale');
			}
			
			if (!empty($requestParams['discover_box']))
			{
				$requestParams['discover_box']='Y';
				
				if (empty($requestParams['language_box']))
				{
					$OS->addFieldError(_("Language missing"),'language');
				}
				elseif (!isset($requestParams['languages'][$requestParams['language_box']]))
				{
					$OS->addFieldError(_("Unknown language"),'language');
				}
			}
			else
			{
				$requestParams['discover_box']='';
				$requestParams['language_box']='';
			}
			
			if (!empty($requestParams['blacklist_domains_box']))
			{
				$domains=explode("\n",$requestParams['blacklist_domains_box']);
				
				foreach ($domains as $key=>$domain)
				{
					$domains[$key]=trim($domain);
				}
			}
			else
			{
				$domains=array();
			}
			
			if (!isset($OS->errorMessages))
			{
				$project_id=$OS->getProject()->id;
				
				$oneReport=OS_APP_KwLab_Report::get_instance();
				$oneReport->project_id=$project_id;
				$oneReport->name=$requestParams['name_box'];
				$oneReport->self_host=$requestParams['self_host_box'];
				$oneReport->locale=$requestParams['locale_box'];
				$oneReport->discover=$requestParams['discover_box'];
				$oneReport->language=$requestParams['language_box'];
				$oneReport->keywords=count($keywords);
				$oneReport->blacklist_domains=$domains;
				
				if ($oneReport->save())
				{
					$report_id=$oneReport->id;
					
					foreach ($keywords as $keyword)
					{
						$oneKeyword=new OS_APP_KwLab_Keyword();
						
						$oneKeyword->project_id=$project_id;
						$oneKeyword->report_id=$report_id;
						$oneKeyword->keyword=$keyword;
						$oneKeyword->source='O';
						$oneKeyword->should_discover=($oneReport->discover=='Y'?'Y':'');
						
						$oneKeyword->save();
					}
					
					$reportOps=OS_APP_KwLab_ReportOperations::get_instance();
					$reportOps->generateReport($oneReport);
				}
				
				$OS->redirectTO($appPlugin->getAppActionUrl('main',array('msg'=>'analyze_ok')),true);
			}
		}
		else
		{
			$requestParams['name_box']='';
			$requestParams['keywords_box']='';
			$requestParams['self_host_box']=parse_url($OS->getProject()->url,PHP_URL_HOST);
			$requestParams['locale_box']='com';
			$requestParams['discover_box']='Y';
			$requestParams['language_box']='en-US';
			$requestParams['blacklist_domains_box']="*.about.me
*.linkedin.com
*.dailymotion.com
*.tripadvisor.com
*.submitanarticle.info
*.wikipedia.org
*.amazon.com
*.amazon.co.uk
*.facebook.com
*.articlesnatch.com
*.twitter.com
*.squidoo.com
*.youtube.com
*.article-heaven.us
*.about.com
*.ezinearticles.com
*.flickr.com
*.hubpages.com
itunes.apple.com
play.google.com
plus.google.com";
		}
		
		return $requestParams;
	}
	
	public function render()
	{
		$OS=getOS();

		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$tplVars=$this->processedRequest;
		$tplVars['appURL']=$appPlugin->getAppUrl();
		
		$tpl = $OS->getTemplate();
		
		return $tpl->fetchTemplate('nicheanalysis',$tplVars);
	}
}
?>