<?php
class OS_APPVIEW_KwLab_ReportCompetitors extends OS_AppViewBase
{
	public function __construct()
	{
		parent::__construct();
	}
	
	public function processRequest()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		$project=$OS->getProject();
		
		$requestParams=$appPlugin->getRequestParams();
		$export=false;
		
		$valid=false;
		if (!empty($requestParams['report_id']))
		{
			$ops=OS_APP_KwLab_ReportOperations::get_instance();

			if ($report=$ops->getReportByID($requestParams['report_id'],$project->id))
			{
				if ($report->status=='D')
				{
					$kwOps=OS_APP_KwLab_KeywordOperations::get_instance();
					
					if ($keywords=$kwOps->getKeywordsByReportID($requestParams['report_id'],$project->id))
					{
						$compOps=OS_APP_KwLab_CompetitorOperations::get_instance();
						
						if ($competitors=$compOps->getCompetitorsByReportID($requestParams['report_id'],$project->id))
						{
							$valid=true;
						}
					}
				}
			}
		}
		
		if (isset($requestParams['export']))
		{
			$export=true;
		}
		
		if (!$valid)
		{
			$OS->redirectTO($appPlugin->getAppActionUrl('main'),true);
		}
		
		return array('report'=>$report,'keywords'=>$keywords,'competitors'=>$competitors,'export'=>$export);
	}
	
	public function render()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$tplVars['report']=$this->processedRequest['report']->toTemplate();
		
		$keywords=array();
		foreach ($this->processedRequest['keywords'] as $keyword_id=>$keyword)
		{
			$keywords[$keyword_id]=$keyword->keyword;
		}
		
		$competitors=array();
		foreach ($this->processedRequest['competitors'] as $competitor_id=>$competitor)
		{
			if (empty($competitors[$competitor->host]))
			{
				$competitors[$competitor->host]=array(
					'total_keywords'=>0,
					'positions_sum'=>0,
					'first_keyword'=>array(),
					'other_keywords'=>array()
				);
			}
			
			$competitors[$competitor->host]['total_keywords']++;
			$competitors[$competitor->host]['positions_sum']+=$competitor->position;
			
			$comp=$competitor->toTemplate();
			$comp['competitor_id']=$competitor->id;
			$comp['keyword_id']=$competitor->keyword_id;
			$comp['keyword_human']=$keywords[$competitor->keyword_id];
			
			if (empty($competitors[$competitor->host]['first_keyword']))
			{
				$competitors[$competitor->host]['first_keyword']=$comp;
			}
			else
			{
				$competitors[$competitor->host]['other_keywords'][]=$comp;
			}
		}
		
		foreach ($competitors as $host=>$details)
		{
			$competitors[$host]['avg_position']=round($details['positions_sum']/$details['total_keywords'],1);
		}
		
		$compOps=OS_APP_KwLab_CompetitorOperations::get_instance();
		
		$competitors=$compOps->orderCompetitors($competitors,'total_keywords',SORT_DESC,'avg_position',SORT_ASC);
		
		if ($this->processedRequest['export'])
		{
			$csv="Host,Host keywords,Host average position,Keyword,Position,URL,Title,Facebook,Google+,Twitter,Moz DA,Moz PA";
			
			foreach ($competitors as $host=>$details)
			{
				$csv.="\n{$host},{$details['total_keywords']},{$details['avg_position']},\"{$details['first_keyword']['keyword_human']}\",{$details['first_keyword']['position']},{$details['first_keyword']['url']},\"{$details['first_keyword']['title']}\",{$details['first_keyword']['social_facebook']},{$details['first_keyword']['social_gplus']},{$details['first_keyword']['social_twitter']},{$details['first_keyword']['moz_da']},{$details['first_keyword']['moz_pa']}";
				
				if (!empty($details['other_keywords']))
				{
					foreach ($details['other_keywords'] as $kw)
					{
						$csv.="\n{$host},{$details['total_keywords']},{$details['avg_position']},\"{$kw['keyword_human']}\",{$kw['position']},{$kw['url']},\"{$kw['title']}\",{$kw['social_facebook']},{$kw['social_gplus']},{$kw['social_twitter']},{$kw['moz_da']},{$kw['moz_pa']}";
					}
				}
			}
			
			header('Content-Type: text/csv');
			header('Content-Disposition: attachment; filename="'.str_replace(' ','-',$this->processedRequest['report']->name).'_competitors_detailed.csv"');
			
			echo $csv;
			
			exit;
		}
		else
		{
			$tplVars['competitors']=$competitors;
			
			$appPlugin->setMenuBackLink(array('back_view'=>'reportcompetitorssimple','report_id'=>$this->processedRequest['report']->id));
			
			$tplVars['exportURL']=$appPlugin->getAppActionUrl('reportcompetitors',array('report_id'=>$this->processedRequest['report']->id,'export'=>'yes'));
			$tplVars['imagesURL']=$appPlugin->getAppHomeUrl().'/resources/images';
			
			$tpl=$OS->getTemplate();
			
			return $tpl->fetchTemplate('reportcompetitors',$tplVars);
		}
	}
}
?>