<?php
class OS_APPVIEW_KwLab_ReportCompetitorsSimple extends OS_AppViewBase
{
	public function __construct()
	{
		parent::__construct();
	}
	
	public function processRequest()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		$project=$OS->getProject();
		
		$requestParams=$appPlugin->getRequestParams();
		$export=false;
		
		$valid=false;
		if (!empty($requestParams['report_id']))
		{
			$ops=OS_APP_KwLab_ReportOperations::get_instance();

			if ($report=$ops->getReportByID($requestParams['report_id'],$project->id))
			{
				if ($report->status=='D')
				{
					$kwOps=OS_APP_KwLab_KeywordOperations::get_instance();
					
					if ($keywords=$kwOps->getKeywordsByReportID($requestParams['report_id'],$project->id))
					{
						$compOps=OS_APP_KwLab_CompetitorOperations::get_instance();
						
						if ($competitors=$compOps->getCompetitorsByReportID($requestParams['report_id'],$project->id))
						{
							$valid=true;
						}
					}
				}
			}
		}
		
		if (isset($requestParams['export']))
		{
			$export=true;
		}
		
		if (!$valid)
		{
			$OS->redirectTO($appPlugin->getAppActionUrl('main'),true);
		}
		
		return array('report'=>$report,'keywords'=>$keywords,'competitors'=>$competitors,'export'=>$export);
	}
	
	public function render()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$tplVars['report']=$this->processedRequest['report']->toTemplate();
		
		$keywords=array();
		foreach ($this->processedRequest['keywords'] as $keyword_id=>$keyword)
		{
			$keywords[$keyword_id]=$keyword->keyword;
		}
		
		$charts=array(
			'da'=>array('easy'=>0,'average'=>0,'challenging'=>0,'hard'=>0,'extreme'=>0),
			'cf'=>array('easy'=>0,'average'=>0,'challenging'=>0,'hard'=>0,'extreme'=>0),
			'tf'=>array('easy'=>0,'average'=>0,'challenging'=>0,'hard'=>0,'extreme'=>0),
		);
		$chartable_fields=array('host_moz_da'=>'da','host_majestic_cf'=>'cf','host_majestic_tf'=>'tf');
		$competitors=array();
		foreach ($this->processedRequest['competitors'] as $competitor_id=>$competitor)
		{
			if (empty($competitors[$competitor->host]))
			{
				$competitors[$competitor->host]=array(
					'total_keywords'=>0,
					'positions_sum'=>0,
					'host_moz_da'=>$competitor->host_moz_da,
					'host_moz_pa'=>$competitor->host_moz_pa,
					'host_majestic_cf'=>$competitor->host_majestic_cf,
					'host_majestic_tf'=>$competitor->host_majestic_tf,
					'host_majestic_backlinks'=>$competitor->host_majestic_backlinks,
					'host_majestic_rootdomains'=>$competitor->host_majestic_rootdomains
				);
			}
			
			$competitors[$competitor->host]['total_keywords']++;
			$competitors[$competitor->host]['positions_sum']+=$competitor->position;
		}
		
		
		foreach ($competitors as $host=>$details)
		{
			$competitors[$host]['avg_position']=round($details['positions_sum']/$details['total_keywords'],1);
			
			if (!$this->processedRequest['export'])
			{
				foreach ($chartable_fields as $field=>$chart)
				{
					if ($details[$field]>90)
					{
						$chart_zone='extreme';
					}
					elseif ($details[$field]>75)
					{
						$chart_zone='hard';
					}
					elseif ($details[$field]>50)
					{
						$chart_zone='challenging';
					}
					elseif ($details[$field]>25)
					{
						$chart_zone='average';
					}
					else
					{
						$chart_zone='easy';
					}
					
					$charts[$chart][$chart_zone]+=$details['total_keywords'];
				}
			}
		}
		
		$compOps=OS_APP_KwLab_CompetitorOperations::get_instance();
		
		$competitors=$compOps->orderCompetitors($competitors,'total_keywords',SORT_DESC,'avg_position',SORT_ASC);
		
		if ($this->processedRequest['export'])
		{
			$csv="Competitor,Keywords,Average position,Moz DA,Majestic CitationFlow,Majestic TrustFlow,Backlinks,Rootdomains";
			
			foreach ($competitors as $host=>$details)
			{
				$csv.="\n{$host},{$details['total_keywords']},{$details['avg_position']},{$details['host_moz_da']},{$details['host_majestic_cf']},{$details['host_majestic_tf']},{$details['host_majestic_backlinks']},{$details['host_majestic_rootdomains']}";
			}
			
			header('Content-Type: text/csv');
			header('Content-Disposition: attachment; filename="'.str_replace(' ','-',$this->processedRequest['report']->name).'_competitors.csv"');
			
			echo $csv;
			
			exit;
		}
		else
		{
			$headContents=array();
			$osCharts=$OS->getCharts();
			$tplVars['charts']=array();
			
			foreach ($charts as $chart_type=>$chart_values)
			{
				$chartOptions=array(
					'values'=>array_values($chart_values),
					'legend'=>array(),
					'legend_position'=>'none',
					'colors'=>array('#3498db','#27ae60','#f1c40f','#d35400','#c13a32')
				);
				
				if ($chart=$osCharts->getPieChart($chartOptions))
				{
					$headContents=array_merge($headContents,$chart['js']);
					
					$tplVars['charts'][$chart_type]=$chart['html'];
				}
			}
			
			$tplVars['competitors']=$competitors;
			
			$appPlugin->setMenuBackLink(array('back_view'=>'main'));
			$tplVars['exportURL']=$appPlugin->getAppActionUrl('reportcompetitorssimple',array('report_id'=>$this->processedRequest['report']->id,'export'=>'yes'));
			$tplVars['detailedReportURL']=$appPlugin->getAppActionUrl('reportcompetitors',array('report_id'=>$this->processedRequest['report']->id));
			$tplVars['imagesURL']=$appPlugin->getAppHomeUrl().'/resources/images';
			
			$tpl=$OS->getTemplate();
			
			if ($headContents)
			{
				$tpl->setHeadContents($headContents);
			}
			
			return $tpl->fetchTemplate('reportcompetitorssimple',$tplVars);
		}
	}
}
?>