<?php
class OS_APP_KwTracker_ReportOperations
{
	private static $_instance;
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_KwTracker_ReportOperations();
		}
		
		return self::$_instance;
	}
	
	public function getReportByID($report_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE id=?",array($report_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_APP_KwTracker_Report();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getReports($project_id,$only_done=true,$offset=0,$count=10,$order_by='report_dt')
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE project_id=? ".($only_done?"AND `status`=?":'')." ORDER BY `{$order_by}` DESC".($offset!==false?" LIMIT {$offset},{$count}":''),($only_done?array($project_id,'D'):array($project_id)));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneReport=new OS_APP_KwTracker_Report();
			$oneReport->set($row);
			
			$result[$row['id']]=$oneReport;
		}
		
		return $result;
	}
	
	public function insertReport($report)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		
		$query="INSERT INTO ".$appHandler->dbPrefix()."reports (project_id,pos_p1,pos_t10,pos_t30,pos_others,report_dt,status) VALUES (?,?,?,?,?,?,?)";
		$dbresult=$db->query($query,array($report->project_id,$report->pos_p1,$report->pos_t10,$report->pos_t30,$report->pos_others,$time,'W'));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateReport($report)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="UPDATE ".$appHandler->dbPrefix()."reports SET pos_p1=?,pos_t10=?,pos_t30=?,pos_others=?,status=? WHERE id=?";
		$dbresult=$db->query($query,array($report->pos_p1,$report->pos_t10,$report->pos_t30,$report->pos_others,$report->status,$report->id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteReportByID($report_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		if ($report=$this->getReportByID($report_id))
		{
			if ($report->status=='W')
			{
				$db->query("DELETE FROM ".$appHandler->dbPrefix()."queue WHERE report_id=?",array($report_id));
			}
			else
			{
				$db->query("DELETE FROM ".$appHandler->dbPrefix()."topics WHERE report_id=?",array($report_id));
			}
			
			$db->query("DELETE FROM ".$appHandler->dbPrefix()."keywords WHERE report_id=?",array($report_id));
			
			$query="DELETE FROM ".$appHandler->dbPrefix()."reports WHERE id=?";
			$dbresult=$db->query($query,array($report_id));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function getReportTopics($report_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."topics WHERE report_id=?",array($report_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['project_pos']=json_decode($row['project_pos'],true);
			$row['competitors_pos']=json_decode($row['competitors_pos'],true);
			
			$result[$row['topic_id']]=$row;
		}
		
		return $result;
	}
	
	public function getReportTopic($report_id,$topic_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."topics WHERE report_id=? AND topic_id=?",array($report_id,$topic_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['project_pos']=json_decode($row['project_pos'],true);
			$row['competitors_pos']=json_decode($row['competitors_pos'],true);
			
			$result=$row;
		}
		
		return $result;
	}
	
	public function getReportKeyword($report_id,$keyword_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."keywords WHERE report_id=? AND keyword_id=?",array($report_id,$keyword_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['project_pos']=$row['project_pos'];
			$row['competitors_pos']=json_decode($row['competitors_pos'],true);
			
			$result=$row;
		}
		
		return $result;
	}
	
	public function getReportKeywordsByTopicID($report_id,$topic_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."keywords WHERE report_id=? AND topic_id=?",array($report_id,$topic_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['competitors_pos']=json_decode($row['competitors_pos'],true);
			
			$result[$row['id']]=$row;
		}
		
		return $result;
	}
	
	public function shouldTrackProject($project_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		if ($report=$this->getReports($project_id,false,0,1))
		{
			$report=reset($report);
			
			if ($report->status=='D')
			{
				if (time()-strtotime($report->report_dt)>604800)
				{
					$result=true;
				}
			}
		}
		else
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function trackKeywords($report_id,$keywords)
	{
		$OS=getOS();
		$osSearchEngine=$OS->getSearchEngine();
		
		if ($report=$this->getReportByID($report_id))
		{
			foreach ($keywords as $topic_id=>$details)
			{
				if ($osSearchEngine->loadEngine($details['se']['engine'],$details['se']['locale']))
				{
					$db=$OS->getDb();
					$appHandler=$OS->getAppHandler();
					
					foreach ($details['keywords'] as $keyword_id=>$keyword)
					{
						$db->query("INSERT INTO ".$appHandler->dbPrefix()."keywords (project_id,report_id,topic_id,keyword_id,project_pos,competitors_pos,status) VALUES (?,?,?,?,?,?,?)",array($report->project_id,$report_id,$topic_id,$keyword_id,'0',json_encode(array()),'W'));
					}
					
					foreach ($details['keywords'] as $keyword_id=>$keyword)
					{
						$this->trackKeyword($report_id,$details['se']['engine'],$details['se']['locale'],$topic_id,$keyword_id,$keyword);
					}
				}
			}
		}
	}
	
	public function trackKeyword($report_id,$engine,$locale,$topic_id,$keyword_id,$keyword,$offset=0)
	{
		$OS=getOS();
		$osSearchEngine=$OS->getSearchEngine();
		
		$allFound=false;$queued=false;$failed=false;
					
		while (!$failed AND !$queued AND !$allFound AND $offset<=20)
		{
			$osSearchEngine->setOffset($offset,$engine,$locale);
			
			if ($results=$osSearchEngine->getResults($keyword,$engine,$locale))
			{
				if ($results['status']=='done')
				{
					$allFound=$this->processKeyword($report_id,$topic_id,$keyword_id,$offset,$results['data']);
				}
				elseif ($results['status']=='queued')
				{
					$this->enqueueKeyword($report_id,$engine,$locale,$topic_id,$keyword_id,$keyword,$offset,$results['queue_id']);
					
					$queued=true;
				}
			}
			else
			{
				$failed=true;
			}
			
			$offset+=10;
		}
	}
	
	public function processKeyword($report_id,$topic_id,$keyword_id,$offset,$results)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		if ($report=$this->getReportByID($report_id))
		{
			$osProjectOps=$OS->getProjectOps();
			
			if ($project=$osProjectOps->getProjectByID($report->project_id))
			{
				$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."keywords WHERE report_id=? AND keyword_id=?",array($report_id,$keyword_id));
				if (!$current=$db->fetchRow($dbresult))
				{
					$current=array(
						'report_id'=>$report_id,
						'topic_id'=>$topic_id,
						'keyword_id'=>$keyword_id,
						'project_pos'=>0,
						'competitors_pos'=>array()
					);
				}
				else
				{
					$current['competitors_pos']=json_decode($current['competitors_pos'],true);
				}
				
				$osCompetitorOps=$OS->getCompetitorOps();
				if ($competitors=$osCompetitorOps->getCompetitorsByTopicID($topic_id))
				{
					foreach ($competitors as $competitor_id=>$details)
					{
						if (!isset($current['competitors_pos'][$competitor_id]))
						{
							$current['competitors_pos'][$competitor_id]=0;
						}
						elseif (!empty($current['competitors_pos'][$competitor_id]))
						{
							unset($competitors[$competitor_id]);
						}
					}
				}
				
				if (!empty($competitors) OR empty($current['project_pos']))
				{
					if (empty($current['project_pos']))
					{
						$project_host=parse_url($project->url,PHP_URL_HOST);
						
						if ($pos=$this->getPositionInResults($project_host,$results))
						{
							$current['project_pos']=$offset+$pos;
						}
					}
					
					if (!empty($competitors))
					{
						foreach ($competitors as $competitor_id=>$details)
						{
							if ($pos=$this->getPositionInResults($details->host,$results))
							{
								$current['competitors_pos'][$competitor_id]=$offset+$pos;
								unset($competitors[$competitor_id]);
							}
						}
					}
				}
				
				$result=(empty($competitors) AND !empty($current['project_pos']));
				
				$status=(($result OR $offset==20)?'D':'W');
				
				$current['competitors_pos']=json_encode($current['competitors_pos']);
				if (empty($current['id']))
				{
					$db->query("INSERT INTO ".$appHandler->dbPrefix()."keywords (project_id,report_id,topic_id,keyword_id,project_pos,competitors_pos,status) VALUES (?,?,?,?,?,?,?)",array($project->id,$report_id,$topic_id,$keyword_id,$current['project_pos'],$current['competitors_pos'],$status));
				}
				else
				{
					$db->query("UPDATE ".$appHandler->dbPrefix()."keywords SET project_pos=?,competitors_pos=?,status=? WHERE id=?",array($current['project_pos'],$current['competitors_pos'],$status,$current['id']));
				}
				
				if ($status=='D')
				{
					$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."keywords WHERE report_id=? AND status=? LIMIT 1",array($report_id,'W'));
					if (!$row=$db->fetchRow($dbresult))
					{
						OS_Fork::fork('app','kwtracker','complete_report',array('project_id'=>$project->id,'report_id'=>$report_id));
					}
				}
			}
		}
		
		return $result;
	}
	
	public function getPositionInResults($host,$results)
	{
		$result=false;
		
		$OS=getOS();
		$osUtils=$OS->getUtils();
		
		$host=$osUtils->stripWWW($host);
		$position=0;
		foreach ($results as $se_result)
		{
			$position++;
			
			if ($se_result_host=parse_url($se_result['url'],PHP_URL_HOST))
			{
				$se_result_host=$osUtils->stripWWW($se_result_host);
				
				if ($host==$se_result_host)
				{
					$result=$position;
					break;
				}
			}
		}
		
		return $result;
	}
	
	public function enqueueKeyword($report_id,$engine,$locale,$topic_id,$keyword_id,$keyword,$offset,$queue_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$dbresult=$db->query("INSERT INTO ".$appHandler->dbPrefix()."queue (report_id,`engine`,`locale`,topic_id,keyword_id,`keyword`,`offset`,queue_id) VALUES (?,?,?,?,?,?,?,?)",array($report_id,$engine,$locale,$topic_id,$keyword_id,$keyword,$offset,$queue_id));
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function eventProjectDeleted($params)
	{
		$result=true;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		if ($reports=$this->getReports($params['project_id'],false))
		{
			foreach ($reports as $report_id=>$report)
			{
				$result=($result AND $report->delete()); 
			}
		}
		
		return $result;
	}
	
	public function eventSearchEngineQueried($params)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$keywords=array();
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."queue WHERE queue_id=?",array($params['queue_id']));
		while ($row=$db->fetchRow($dbresult))
		{
			if (empty($keywords[$row['report_id']][$row['topic_id']]))
			{
				$keywords[$row['report_id']][$row['topic_id']]=array(
					'se'=>array('engine'=>$row['engine'],'locale'=>$row['locale']),
					'keywords'=>array()
				);
			}
			
			$keywords[$row['report_id']][$row['topic_id']]['keywords'][$row['keyword_id']]=array('keyword'=>$row['keyword'],'current_offset'=>$row['offset']);
		}
		
		$db->query("DELETE FROM ".$appHandler->dbPrefix()."queue WHERE queue_id=?",array($params['queue_id']));
		
		if ($keywords)
		{
			foreach ($keywords as $report_id=>$topics)
			{
				foreach ($topics as $topic_id=>$topic_details)
				{
					foreach ($topic_details['keywords'] as $keyword_id=>$keyword_details)
					{
						if ($params['status']=='done')
						{
							$allFound=$this->processKeyword($report_id,$topic_id,$keyword_id,$keyword_details['current_offset'],$params['data']['getResults']);
							
							if (!$allFound AND $keyword_details['current_offset']<=10)
							{
								$offset=$keyword_details['current_offset']+10;
								
								$this->trackKeyword($report_id,$topic_details['se']['engine'],$topic_details['se']['locale'],$topic_id,$keyword_id,$keyword_details['keyword'],$offset);
							}
						}
						elseif ($params['status']=='failed')
						{
							$this->trackKeyword($report_id,$topic_details['se']['engine'],$topic_details['se']['locale'],$topic_id,$keyword_id,$keyword_details['keyword'],$keyword_details['current_offset']);
						}
					}
				}
			}
			
			$result=true;
		}
		
		return $result;
	}
}
?>