<?php
class OS_APPVIEW_KwTracker_Main extends OS_AppViewBase
{
	public function __construct()
	{
		parent::__construct();
	}
	
	public function processRequest()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		$project=$OS->getProject();
		
		$requestParams=$appPlugin->getRequestParams();
		$processedRequest=array('view_type'=>'general','se_id'=>false,'topic_id'=>false,'se_topics'=>array());
		
		$osProjectSearchEngineOps=$OS->getProjectSearchEngineOps();
		
		if ($search_engines=$osProjectSearchEngineOps->getProjectSearchEngines($project->id))
		{
			$osProjectTopicOps=$OS->getProjectTopicOps();
			
			if ($topics=$osProjectTopicOps->getProjectTopics($project->id))
			{
				foreach ($topics as $topic_id=>$topic)
				{
					if (isset($search_engines[$topic->se_id]))
					{
						if (!isset($processedRequest['se_topics'][$topic->se_id]))
						{
							$processedRequest['se_topics'][$topic->se_id]=array(
								'se_details'=>array(
									'engine'=>$search_engines[$topic->se_id]->engine,
									'locale'=>$search_engines[$topic->se_id]->locale,
									'title'=>ucfirst($search_engines[$topic->se_id]->engine).' '.strtoupper($search_engines[$topic->se_id]->locale)
								),
								'topics'=>array()
							);
						}
						
						$processedRequest['se_topics'][$topic->se_id]['topics'][$topic_id]=array(
							'topic'=>$topic->topic,
							'link'=>$appPlugin->getAppActionUrl('competitors',array('se_id'=>$topic->se_id,'topic_id'=>$topic->id))
						);
					}
				}
			}
		}
		
		if (!empty($requestParams['view_type']))
		{
			if ($requestParams['view_type']=='se')
			{
				if (!empty($requestParams['se_id']) AND isset($processedRequest['se_topics'][$requestParams['se_id']]))
				{
					$processedRequest['view_type']='se';
					$processedRequest['se_id']=$requestParams['se_id'];
				}
			}
			elseif ($requestParams['view_type']=='topic')
			{
				if (!empty($requestParams['se_id']) AND isset($processedRequest['se_topics'][$requestParams['se_id']]))
				{
					if (!empty($requestParams['topic_id']) AND isset($processedRequest['se_topics'][$requestParams['se_id']]['topics'][$requestParams['topic_id']]))
					{
						$processedRequest['view_type']='topic';
						$processedRequest['se_id']=$requestParams['se_id'];
						$processedRequest['topic_id']=$requestParams['topic_id'];
					}
				}
			}
		}
		
		if ($processedRequest['view_type']=='general' AND count($processedRequest['se_topics'])==1)
		{
			$processedRequest['view_type']='se';
			$processedRequest['se_id']=key($processedRequest['se_topics']);
		}
		
		if ($processedRequest['view_type']=='se' AND count($processedRequest['se_topics'][$processedRequest['se_id']]['topics'])==1)
		{
			$processedRequest['view_type']='topic';
			$processedRequest['topic_id']=key($processedRequest['se_topics'][$processedRequest['se_id']]['topics']);
		}
		
		return $processedRequest;
	}
	
	public function buildViewData()
	{
		$OS=getOS();
		
		$project=$OS->getProject();
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		$ops=OS_APP_KwTracker_ReportOperations::get_instance();
		
		$viewDataVars=array();

		$reports=$ops->getReports($project->id);
		
		$latest_stats=array();
		$prev_stats=array();
		$topics_stats=array();
		$ses_stats=array();
		$reports_stats=array();
		$dates=array();
		
		if ($reports)
		{
			reset($reports);
			$latest_report_id=key($reports);
			
			foreach ($reports as $report_id=>$report)
			{
				if ($topics=$ops->getReportTopics($report_id))
				{
					foreach ($topics as $topic_id=>$topic_details)
					{
						$topics_stats[$topic_id][$report_id]=$topic_details['project_pos'];
						
						if (!isset($ses_stats[$topic_details['se_id']][$report_id]))
						{
							$ses_stats[$topic_details['se_id']][$report_id]=array('p1'=>0,'t10'=>0,'t30'=>0,'others'=>0);
						}
						
						foreach ($topic_details['project_pos'] as $pos=>$kws)
						{
							$ses_stats[$topic_details['se_id']][$report_id][$pos]+=$kws;
						}
					}
					
					if (empty($latest_stats))
					{
						foreach ($topics as $topic_id=>$topic_details)
						{
							$latest_stats[$topic_id]=$topic_details['project_pos'];
						}
					}
					elseif (empty($prev_stats))
					{
						foreach ($topics as $topic_id=>$topic_details)
						{
							$prev_stats[$topic_id]=$topic_details['project_pos'];
						}
					}
				}
				
				$reports_stats[$report_id]=array('p1'=>$report->pos_p1,'t10'=>$report->pos_t10,'t30'=>$report->pos_t30,'others'=>$report->pos_others);
				$dates[$report_id]=date("d M",strtotime($report->report_dt));
			}
		}
		
		foreach ($latest_stats as $topic_id=>$positions)
		{
			if (isset($prev_stats[$topic_id]))
			{
				foreach ($positions as $type=>$value)
				{
					$latest_stats[$topic_id][$type]=array('keywords'=>$value,'change'=>$value-$prev_stats[$topic_id][$type]);
				}
			}
			else
			{
				foreach ($positions as $type=>$value)
				{
					$latest_stats[$topic_id][$type]=array('keywords'=>$value,'change'=>0);
				}
			}
		}
		
		$viewDataVars['reports']=$reports;
		$viewDataVars['stats']=array(
			'latest'=>$latest_stats,
			'dates'=>$dates,
			'general'=>$reports_stats,
			'ses'=>$ses_stats,
			'topics'=>$topics_stats
		);
		
		return $viewDataVars;
	}
	
	private function computeIndexesWithLabels($total_values)
	{
		$result=array(1,$total_values);

		$total_values-=($total_values%3);
		if ($total_values>2)
		{
			for ($i=2;$i<=$total_values;$i++)
			{
				if ($i%3==1)
				{
					$result[]=$i;
				}
			}
		}
		
		sort($result);
		
		return $result;
	}
	
	public function render()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$viewData=$this->buildViewData();
		$tplVars=array();
		
		if ($this->processedRequest['view_type']=='general')
		{
			$stats=$viewData['stats']['general'];
		}
		elseif ($this->processedRequest['view_type']=='se')
		{
			$stats=(isset($viewData['stats']['ses'][$this->processedRequest['se_id']])?$viewData['stats']['ses'][$this->processedRequest['se_id']]:array());
		}
		elseif ($this->processedRequest['view_type']=='topic')
		{
			$stats=(isset($viewData['stats']['topics'][$this->processedRequest['topic_id']])?$viewData['stats']['topics'][$this->processedRequest['topic_id']]:array());
		}
		$dates=$viewData['stats']['dates'];
		foreach ($dates as $report_id=>$date)
		{
			if (!isset($stats[$report_id]))
			{
				unset($dates[$report_id]);
			}
		}
		
		$tplVars['latestStats']=$viewData['stats']['latest'];
		
		$stats=array_reverse($stats,true);
		$dates=array_reverse($dates,true);
		$headContents = array();
		
		if (!empty($stats))
		{
			$tplVars['hasData']=true;
			
			if (count($stats)==1)
			{
				$tplVars['graph']=false;
				$tplVars['stats']=reset($stats);
			}
			else
			{
				$chartValues=array('others'=>array(),'t30'=>array(),'t10'=>array(),'p1'=>array());
				$chartTooltips=array('others'=>array(),'t30'=>array(),'t10'=>array(),'p1'=>array());
				$chartColors=array('others'=>'#C13A32','t30'=>'#D35400','t10'=>'#F1C40F','p1'=>'#27AE60');
				$check_sums=array('p1'=>0,'t10'=>0,'t30'=>0,'others'=>0);
				
				$day_index=1;
				$displayed_day_indexes=$this->computeIndexesWithLabels(count($dates));
				
				foreach ($stats as $report_id=>$day_stats)
				{
					$chartValues['p1'][]=$day_stats['p1'];
					$chartTooltips['p1'][]=$dates[$report_id]."\n {$day_stats['p1']} "._("keywords");
					$check_sums['p1']+=$day_stats['p1'];
					
					$chartValues['t10'][]=$day_stats['p1']+$day_stats['t10'];
					$chartTooltips['t10'][]=$dates[$report_id]."\n {$day_stats['t10']} "._("keywords");
					$check_sums['t10']+=$day_stats['t10'];
					
					$chartValues['t30'][]=$day_stats['p1']+$day_stats['t10']+$day_stats['t30'];
					$chartTooltips['t30'][]=$dates[$report_id]."\n {$day_stats['t30']} "._("keywords");
					$check_sums['t30']+=$day_stats['t30'];
					
					$chartValues['others'][]=$day_stats['p1']+$day_stats['t10']+$day_stats['t30']+$day_stats['others'];
					$chartTooltips['others'][]=$dates[$report_id]."\n {$day_stats['others']} "._("keywords");
					$check_sums['others']+=$day_stats['others'];
					
					if (in_array($day_index,$displayed_day_indexes))
					{
						$chartLabels[]=$dates[$report_id];
					}
					else
					{
						$chartLabels[]=false;
					}
					$day_index++;
				}
				
				foreach ($check_sums as $type=>$sum)
				{
					if ($sum==0)
					{
						unset($chartValues[$type]);
						unset($chartTooltips[$type]);
						unset($chartColors[$type]);
					}
				}
				
				$osCharts = $OS->getCharts();
				
				$chartOptions=array(
					'values'=>array_values($chartValues),
					'labels'=>$chartLabels,
					'tooltips'=>array_values($chartTooltips),
					'fill'=>true,
					'fill_opacity'=>1,
					'color'=>array_values($chartColors)
				);
				
				$chartData = $osCharts->getLineChart($chartOptions);
				
				$tplVars['graph'] = $chartData['html'];
				
				$headContents = $chartData['js'];
			}
		}
		else
		{
			$tplVars['hasData']=false;
		}
		
		$tplVars['view_details']=$this->processedRequest;
		
		$headContents['kwtracker']="<script type='text/javascript'>
			var kwtrackerBaseURL='".$appPlugin->getAppActionUrl('view')."';
			function kwtrackerUpdateView(changedElement)
			{
				var searchEngineID=$('#se_box').val();
				
				if (!searchEngineID)
				{
					window.location=kwtrackerBaseURL;
				}
				else
				{
					if (changedElement=='search_engine')
					{
						window.location=kwtrackerBaseURL+'&view_type=se&se_id='+searchEngineID;
					}
					else
					{
						var topicID=$('#topic_box').val();

						if (!topicID)
						{
							window.location=kwtrackerBaseURL+'&view_type=se&se_id='+searchEngineID;
						}
						else
						{
							window.location=kwtrackerBaseURL+'&view_type=topic&se_id='+searchEngineID+'&topic_id='+topicID;
						}
					}
				}
			}
		</script>";
		
		$tpl=$OS->getTemplate();
		
		if (!empty($headContents))
		{
			$tpl->setHeadContents($headContents);
		}
		
		return $tpl->fetchTemplate('view',$tplVars);
	}
}
?>