<?php 
class OS_APP_LinkRequest_Analyzer
{
	private static $_instance;
	
	private $appHandler;
	
	private $projectId;
	
	private $osUtils;
	
	private $requiredPageRank;
	
	private $emailsContents;
	
	public function __construct() 
	{
		$OS = getOS();
		
		$this->appHandler = $OS->getAppHandler('linkrequest');
		
		$this->osUtils = $OS->getUtils();
		
		$this->requiredPageRank = 1;
		
		$this->emailsContents = array();
		
		$this->checkedUrls = array();
	}

	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_LinkRequest_Analyzer();
		}
		return self::$_instance;
	}
	
	//parse Google SERP by one kewyword 
	public function examineSEByKeyword($keyword, $se_name = false, $se_location = false)
	{
		$result = array();
		
		if(!$se_name) $se_name = 'google';

		$se_name = strtolower($se_name);
		if($se_location) $se_location = strtolower($se_location);
		
		$OS = getOS();
		$osSearchEngine = $OS->getSearchEngine();
		$osSearchEngineOps = $OS->getSearchEngineOps();
		$allSearchEngines = $osSearchEngineOps->getAvailableSearchEnginesFull();
		
		$performSearch = false;
		if(isset($allSearchEngines[$se_name]))
		{
			if(!$se_location)
			{
				$performSearch = true;
			}
			elseif(!empty($allSearchEngines[$se_name]['_locales']))
			{
				if(isset($allSearchEngines[$se_name]['_locales'][$se_location]))
				{
					$performSearch = true;	
				}
			}
		}
		
		if($performSearch)
		{
			$serpResult = $osSearchEngine->getResults($keyword,'google','com');
			if(!empty($serpResult))
			{
				$partnerDomains = array();
				foreach($serpResult as $details)
				{
					//group by domain name
					$domain_name = parse_url($details['url'],PHP_URL_HOST);
					
					if($domain_name)
					{
						$partnerDomains[$domain_name] = $details;	
					}
				}
				
				$result = $partnerDomains;
			}
		} 
		
		return $result;
	}
	
	public function handleSerpPartners($partnerDomains)
	{
		$OS = getOS();
		$osUtils = $OS->getUtils();
		
		$appPartnerOperations = OS_APP_LinkRequest_Partners_Operations::get_instance();
		
		foreach($partnerDomains as $domainName => $domainData)
		{
			$partnerResult = $appPartnerOperations->getPartnerByUrl($domainName);
			if($partnerResult === false)
			{
				$stripped_url = $osUtils->stripHTTP($domainName);
				
				$partnerData = array(
					'url' => $domainName,  
					'name' => ucfirst($stripped_url),
					'status' => "W"
					);
					
				$onePartner = new OS_APP_LinkRequest_Partners();
				$onePartner->set($partnerData);
				$onePartner->save();
			}
		}
	}
	
	
	public function checkPartnersPageRank()
	{
		$appPartnerOperations = OS_APP_LinkRequest_Partners_Operations::get_instance();
		
		$max_items = 10; $definedPageRank = 5;
		$appPartnersList = $appPartnerOperations->getPartnersByDetail(array('status' => 'W', 'limit' => $max_items));
		if(!empty($appPartnersList))
		{
			foreach($appPartnersList as $onePartner)
			{
				$validPartner = false;
				$pageRankResult = $this->getPartnerPageRank($onePartner->url);
				if($pageRankResult)
				{
					if($pageRankResult >= $definedPageRank)
					{
						$validPartner = true;
					}
				}
				
				if($validPartner)
				{
					$onePartner->status = "V";
					$onePartner->save();
				}
				else
				{
					$onePartner->delete();
				}
			}	
		}
	}
	
	public function getPartnerPageRank($partnerDomain)
	{
		$result = false;
		
		if(!empty($partnerDomain))
		{
			$OS = getOS();
			$osRankings = $OS->getRankings();
			$osRankings->setRanking('pagerank');
			
			$pageRankResult = $osRankings->getRank($partnerDomain);
			if($pageRankResult !== false)
			{
				if($pageRankResult >= $this->requiredPageRank)
				{
					$result = $pageRankResult;
				}	
			}
		}
		
		return $result;
	}
	
	public function checkPartnerContactInfo($partnerUrl)
	{
		$result = false;
		
		$partnerDomain = parse_url($partnerUrl, PHP_URL_HOST);
		
		if(!empty($partnerDomain))
		{
			$OS = getOS();
			$osHttp = $OS->getHttp();
			
			$fullDomainUrl = "http://".$partnerDomain;
			$response = $osHttp->get($partnerUrl);
			
			if (!empty($response) && $osHttp->success())
			{
				$dom = new DOMDocument();
				
				libxml_use_internal_errors(true);
				$domLoaded = $dom->loadHTML($response);
				libxml_use_internal_errors(false);
				
				if ($domLoaded)
				{
					$this->checkedUrls[md5($partnerUrl)] = true;
					
					//find email addresses on current page
					$this->findContentEmails($dom, $response);
					
					//find contact links on current page
					$this->findContentLinks($dom, $fullDomainUrl);
					
					//change this
					$result = true;
				}
			}
		}
		
		return $result;
	}

	private function findContentEmails($pageDOM, $pageContent)
	{
		var_dump("findContentEmails");
		
		//apply all sorts of regex stuff to detect email addresses
		$xxx = $this->extractEmailsFrom($pageContent);
		var_dump($xxx);
		
		
		//$this->emailsContents push
	}
	
	private function extractEmailsFrom($string)
	{
  		$result = false;
		preg_match_all("/[\._a-zA-Z0-9-]+@[\._a-zA-Z0-9-]+/i", $string, $matches);
		if(isset($matches[0]))
		{
			$result = $matches[0];
		}
		
  		return false;
	}
	
	
	private function findContentLinks($pageDOM, $partnerDomain)
	{
		$result = false;
		
		if(!empty($pageDOM))
		{
			$OS = getOS();
			
			$xpath = new DOMXPath($pageDOM);
			$entries = $xpath->query("//a");
			
			$osValidator = $OS->getValidator();
			$osUtils = $OS->getUtils();
			
			$pageLinks = array(); $contactWords = array('contact','kontakt');
			foreach($entries as $entry)
			{
				$hrefAttr = $entry->getAttribute('href');
				
				if(!empty($hrefAttr))
				{
					$anchor = (string)$entry->nodeValue;
					$linkAnchor = (empty($anchor) ? "" : trim(strtolower($anchor)));
					
					$tmpData = array(
						'url' => $osUtils->makeAbsoluteUrl($partnerDomain, $hrefAttr),
						'title' => $entry->getAttribute('title'),
						'anchor' => $linkAnchor,
						);
						
					$isValidContactLink = false;
					foreach($tmpData as $item)
					{
						foreach($contactWords as $contactWord)
						{
							if(strpos($item, $contactWord) !== false)
							{
								$isValidContactLink = true;
							}
						}
					}

					//get url and go forward
					if($isValidContactLink)
					{
						//if($osValidator->is_url($tmpData['url']))
						
						if(!isset($this->checkedUrls[md5($tmpData['url'])]))
						{
							$this->checkPartnerContactInfo($tmpData['url']);
						}
					}
				}
			}
		}
		
		return $result;
	}
	
	public function findPartnerContactInfo($partner_url)
	{
		$result = array();
		
		//crawl partner website for more info
		
		return $result;
	}
}
?>