<?php

class OS_APP_LinkRequest_Partners_Operations
{
	private static $_instance;

	private $appHandler;
	
	
	public function __construct()
	{
		$this->appHandler = getOS()->getAppHandler('linkrequest');
	}

	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_LinkRequest_Partners_Operations();
		}
		return self::$_instance;
	}

	public function getPartnerByID($partner_id)
	{
		if( $partner_id < 1 ) return false;
		else return $this->getPartnerByDetail(array('id'=>$partner_id));
	}
	
	public function getPartnerByUrl($partner_url)
	{
		if(empty($partner_url)) return false;
		else return $this->getPartnerByDetail(array('url'=>$partner_url));
	}
	
	
	public function getPartnersByDetail($details)
	{
		$result = array();
		$query  = false;

 		$OS = getOS();
		$db = $OS->getDb();
		
		$limitValues = (!empty($details['limit']) ?  " LIMIT {$details['limit']}" : "");
		
		if(isset($details['id']))  $query = "SELECT * FROM ".$this->appHandler->dbPrefix()."partners WHERE `id` = ?".$limitValues;	
		elseif(isset($details['url']))  $query = "SELECT * FROM ".$this->appHandler->dbPrefix()."partners WHERE `url` = ?".$limitValues;
		elseif(isset($details['status']))  $query = "SELECT * FROM ".$this->appHandler->dbPrefix()."partners WHERE `status` = ?".$limitValues;
		
		if($query)
		{
			if(isset($details['limit'])) unset($details['limit']);
			
			$dbresult = $db->query($query, array_values($details));
			while ($row = $db->fetchRow($dbresult))
			{
				$onePartner = new OS_APP_LinkRequest_Partners();
				$onePartner->set($row);
				$result[$row['id']] = $onePartner;
			}
		}
		
		return $result;
	}
	
	public function getPartnerByDetail($details)
	{
		$result = false;
		$query  = false;

 		$OS = getOS();
		$db = $OS->getDb();
		
		if(isset($details['id']))  $query = "SELECT * FROM ".$this->appHandler->dbPrefix()."partners WHERE `id` = ?";	
		elseif(isset($details['url']))  $query = "SELECT * FROM ".$this->appHandler->dbPrefix()."partners WHERE `url` = ?";
		
		if($query)
		{
			$dbresult = $db->query($query, array_values($details));
			
			if ($row = $db->fetchRow($dbresult))
			{
				$onePartner = new OS_APP_LinkRequest_Partners();
				$onePartner->set($row);
							
				$result = $onePartner;
			}
				
		}
		return $result;
	}	
	
	public function insertPartner($onePartner)
	{
		$result=false;
		
 		$OS = getOS();
 		
 		$oneProject = $OS->getProject();

		$db = $OS->getDb();
		
		$sql_time = $db->DBTimeStamp(time());
		
		$status_by = "-1";//set by system
		
		if(!empty($onePartner->status))
		{
			$onePartner->status_dt = $sql_time;
			$onePartner->status_ip = $_SERVER['REMOTE_ADDR'];
		}
		
		$insertData = array(
			'insert_dt' => $sql_time,
			'project_id' => $oneProject->id,
			'url' => $onePartner->url,
			'name' => $onePartner->name,
			'status' => $onePartner->status,
			'status_dt' => $onePartner->status_dt,
			'status_ip' => $onePartner->status_ip,
			'status_by' => $status_by			
			);
		
		$query = "INSERT INTO ".$this->appHandler->dbPrefix()."partners (`".implode("`,`", array_keys($insertData))."`) VALUES (?,?,?,?,?,?,?,?)";
		$dbresult = $db->query($query, array_values($insertData));
		
		return $result;
	}

	public function updatePartner($onePartner)
	{
		$result = false;
		
		$OS =  getOS(); 
		$db = $OS->getDb();
		
		//check for partners conflict
		$query = "SELECT id FROM ".$this->appHandler->dbPrefix()."partners WHERE `url` = ? AND `id` != ?";
		$results =  $db->query($query,array($onePartner->url,$onePartner->id));
		if( $db->fetchRow($results) !== false) return $result;
		
		//get user data from database
		$time = $db->DBTimeStamp(time());
		$currentPartner = $this->getPartnerByID($onePartner->id);
		
		if($currentPartner !== false)
		{
			$userDetails = array();
			
			if($onePartner->status != $currentPartner->status)
			{
				//get current user's data (needed for status_by)
				$user_id = $OS->getUser()->id;
				if(is_null($user_id)) $user_id = -1;
				
				$userDetails['status'] = $onePartner->status;
				$userDetails['status_dt'] = $time;
				$userDetails['status_ip'] = $_SERVER['REMOTE_ADDR'];  
				$userDetails['status_by'] = $user_id;
			}	
			
			$currentPartner->set($userDetails);

			//execute the update query
			$query = "UPDATE ".$this->appHandler->dbPrefix()."partners SET `status` = ?,`status_dt` = ?,`status_ip` = ?,`status_by` = ?,`update_dt` = ? WHERE `id` = ?";
			$dbresult = $db->query($query, array($currentPartner->status, $currentPartner->status_dt, $currentPartner->status_ip, $currentPartner->status_by, $time, $currentPartner->id));
			if ($dbresult !== false)
			{
				$result = true;
			}
		}  
				
		return $result;
	}
	
	public function deletePartnerByID($partner_id)
	{
		if( $partner_id < 1 ) return false;

 		$result = false;
 		$OS = getOS();
		$db = $OS->getDb();
		
		$query = "DELETE FROM ".$this->appHandler->dbPrefix()."partners WHERE `id` = ?";
		$dbresult = $db->query($query, array($partner_id));

		if ($dbresult !== false)
		{
			$result = true;
		}

		return $result;
	}
}
?>