<?php
class OS_APP_OnPage extends OS_AppBase
{
	private static $_instance;
	
	public function __construct()
	{
		parent::__construct();
		
		$this->addMenuItem('view', array("name" => _("Main"), 'routerOption'=> "handleMainView"));
		$this->addMenuItem('urls', array("name" => _("Browse URLs"), 'routerOption'=> "handleUrlsView"));
		$this->addMenuItem('reports', array("name" => _("Reports"), 'routerOption'=> "handleReportsView"));
		$this->addMenuItem('crawl_now', array("name" => _("Analyze now"), 'routerOption'=> "handleCrawlNowView"));
		
		$this->setRouterOption("report", "handleReportView");
		$this->setRouterOption("reporturls", "handleReportUrlsView");
		$this->setRouterOption("reportevolution", "handleReportEvolutionView");
		$this->setRouterOption("pagelist", "handlePagelistView");
		$this->setRouterOption("page", "handlePageView");
		$this->setRouterOption("kwanalysis", "handleKwAnalysisView");
		$this->setRouterOption("pagedetailed", "handlePageDetailedView");
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_onpage();
		}
		
		return self::$_instance;
	}
	
	public function handleMainView()
	{
		getOS()->getUser()->forcePerm('onpage','view');
		
		$viewData=new OS_APPVIEW_OnPage_Main();
		
		return $viewData->render();
	}
	
	public function handleUrlsView()
	{
		getOS()->getUser()->forcePerm('onpage','view');
		
		$viewData=new OS_APPVIEW_OnPage_Urls();
		
		return $viewData->render();
	}
	
	public function handleCrawlNowView()
	{
		getOS()->getUser()->forcePerm('onpage','view');
		
		$viewData=new OS_APPVIEW_OnPage_CrawlNow();
		
		return $viewData->render();
	}
	
	public function handleReportsView()
	{
		getOS()->getUser()->forcePerm('onpage','view');
		
		$viewData=new OS_APPVIEW_OnPage_Reports();
		
		return $viewData->render();
	}
	
	public function handleReportView()
	{
		getOS()->getUser()->forcePerm('onpage','view');
		
		$viewData=new OS_APPVIEW_OnPage_Report();
		
		return $viewData->render();
	}
	
	public function handleReportUrlsView()
	{
		getOS()->getUser()->forcePerm('onpage','view');
		
		$viewData=new OS_APPVIEW_OnPage_ReportUrls();
		
		return $viewData->render();
	}
	
	public function handleReportEvolutionView()
	{
		getOS()->getUser()->forcePerm('onpage','view');
		
		$viewData=new OS_APPVIEW_OnPage_ReportEvolution();
		
		return $viewData->render();
	}
	
	public function handlePagelistView()
	{
		getOS()->getUser()->forcePerm('onpage','view');
		
		$viewData=new OS_APPVIEW_OnPage_Pagelist();
		
		return $viewData->render();
	}
	
	public function handlePageView()
	{
		getOS()->getUser()->forcePerm('onpage','view');
		
		$viewData=new OS_APPVIEW_OnPage_Page();
		
		return $viewData->render();
	}
	
	public function handleKwAnalysisView()
	{
		getOS()->getUser()->forcePerm('onpage','view');
		
		$viewData=new OS_APPVIEW_OnPage_KwAnalysis();
		
		return $viewData->render();
	}
	
	public function handlePageDetailedView()
	{
		getOS()->getUser()->forcePerm('onpage','view');
		
		$viewData=new OS_APPVIEW_OnPage_PageDetailed();
		
		return $viewData->render();
	}
	
	protected function defineAppPermissions()
	{
		$this->appPermissions=array(
			'onpage'=>array(
				'view'=>array('name'=>_("View OnPage SEO reports")),
			)
		);
	}
	
	public function getReportingData($type='overview')
	{
		$result=false;
		
		getOS()->getUser()->forcePerm('onpage','view');
		
		$availableTypes=$this->getReportingTypes();
		
		if (isset($availableTypes[$type]))
		{
			if ($type=='overview')
			{
				$viewData=new OS_APPVIEW_OnPage_Report();
			}
			elseif ($type=='urls')
			{
				$viewData=new OS_APPVIEW_OnPage_ReportUrls();
			}
			elseif ($type=='evolution')
			{
				$viewData=new OS_APPVIEW_OnPage_ReportEvolution();
			}
			
			$reportData=$viewData->buildViewData();
			
			if ($reportData['report'])
			{
				$result=$reportData['report'];
			}
		}
		
		return $result;
	}
	
	public function getReportingTypes()
	{
		return array(
			'overview'=>_("Overview report"),
			'urls'=>_("Problematic URLs"),
			'evolution'=>_("Evolution report")
		);
	}
	
	public function eventProjectCrawlStart($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();
		
		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
			$this->report=OS_APP_OnPage_Report::get_instance();
			
			$this->report->project_id=$params['project_id'];
		}
		
		return $result;
	}
	
	public function eventProjectPageCrawled($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();
		
		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
			$params['http_code']=(string)$params['http_code'];
			$ok_http_code=in_array($params['http_code'][0],array(1,2));
			
			$allowedContentType=(in_array($params['content_type'],array('text/html','text/plain')));
			
			if ($allowedContentType AND !empty($params['content']) AND $ok_http_code)
			{
				$analyzer=OS_APP_OnPage_Analyzer::get_instance();
				$db=$OS->getDb();
				$ops=OS_APP_OnPage_ReportOperations::get_instance();
				
				$osProject=$OS->getProjectOps()->getProjectByID($params['project_id']);
				
				$other=array(
					'size'=>$params['size'],
					'load_time'=>$params['load_time']
				);
				
				$error_profile=array();
				
				$analysis=$analyzer->analyze($params['url'],$params['dom'],$params['content'],$other);
				
				$score=$analysis['score'];
				$messages=$analysis['failed_tests'];
				
				$this->report->urls++;

				if ($messages)
				{
					foreach ($messages as $element=>$test_types)
					{
						if (isset($test_types['overall']))
						{
							foreach ($test_types['overall'] as $test_name=>$test)
							{
								$error_profile[$element]['overall'][$test_name]=true;
								
								$var=$test['level'].'s';
								
								$this->report->$var++;
								
								if (!isset($this->report->failed_tests[$element]['overall'][$test_name]))
								{
									$this->report->failed_tests[$element]['overall'][$test_name]=array('pages'=>0,'occurances'=>0);
								}
								
								$this->report->failed_tests[$element]['overall'][$test_name]['pages']++;
								
								$this->report->failed_tests[$element]['overall'][$test_name]['occurances']++;
							}
						}
						
						$knownPageTests=array();
						
						if (isset($test_types['element']))
						{
							foreach ($test_types['element'] as $elem_id=>$tests)
							{
								foreach ($tests as $test_name=>$test)
								{
									$error_profile[$element]['element'][$test_name]=true;
									
									$var=$test['level'].'s';
								
									$this->report->$var++;
									
									if (!isset($this->report->failed_tests[$element]['element'][$test_name]))
									{
										$this->report->failed_tests[$element]['element'][$test_name]=array('pages'=>0,'occurances'=>0);
									}
									
									if (!isset($knownPagesTests[$element][$test_name]))
									{
										$knownPagesTests[$element][$test_name]=true;
										
										$this->report->failed_tests[$element]['element'][$test_name]['pages']++;
									}
									
									$this->report->failed_tests[$element]['element'][$test_name]['occurances']++;
								}
							}
						}
					}
				}
				$rules=$analyzer->getRules();
				
				$xpath=new DOMXPath($params['dom']);
				
				$has_gplus_authorship=false;
				$entries=$xpath->query("//link[@rel='author']");
				if ($entries->item(0))
				{
					$has_gplus_authorship=true;
				}
				if (!$has_gplus_authorship)
				{
					$entries=$xpath->query("//a");
					
					foreach ($entries as $entry)
					{
						$href=$entry->getAttribute('href');
						
						if (0===strpos($href,'https://plus.google.com/') AND false!==strpos($href,'rel=author'))
						{
							$rel=$entry->getAttribute('rel');
							
							if ($rel=='author')
							{
								$has_gplus_authorship=true;
								break;
							}
						}
					}
					
					if (!$has_gplus_authorship)
					{
						$entries=$xpath->query("//plus[@rel='author']");
						
						foreach ($entries as $entry)
						{
							if ($entries->item(0))
							{
								$has_gplus_authorship=true;
								break;
							}
						}
						
						if (!$has_gplus_authorship)
						{
							$entries=$xpath->query("//div[@class='g-plus']");
							
							foreach ($entries as $entry)
							{
								$href=$entry->getAttribute('data-href');
						
								if (0===strpos($href,'https://plus.google.com/'))
								{
									if ($rel=$entry->getAttribute('rel'))
									{
										if ($rel=='author')
										{
											$has_gplus_authorship=true;
											break;
										}
									}
									elseif ($rel=$entry->getAttribute('data-rel'))
									{
										if ($rel=='author')
										{
											$has_gplus_authorship=true;
											break;
										}
									}
								}
							}
						}
					}
				}
				
				if (!$has_gplus_authorship)
				{
					$entries=$xpath->query("//link[@rel='publisher']");
					if ($entries->item(0))
					{
						$has_gplus_authorship=true;
					}
					if (!$has_gplus_authorship)
					{
						$entries=$xpath->query("//a[@rel='publisher']");
						
						foreach ($entries as $entry)
						{
							$href=$entry->getAttribute('href');
							
							if (0===strpos($href,'https://plus.google.com/'))
							{
								$has_gplus_authorship=true;
								break;
							}
						}
						
						if (!$has_gplus_authorship)
						{
							$entries=$xpath->query("//plus");
							
							if ($entries->item(0))
							{
								$has_gplus_authorship=true;
							}
							
							if (!$has_gplus_authorship)
							{
								$entries=$xpath->query("//div[@class='g-plus']");
								
								foreach ($entries as $entry)
								{
									$href=$entry->getAttribute('data-href');
							
									if (0===strpos($href,'https://plus.google.com/'))
									{
										$has_gplus_authorship=true;
										break;
									}
								}
							}
						}
					}
				}
				
				if (!$has_gplus_authorship)
				{
					$error_profile['gplus_authorship']['overall']['not_found']=true;
						
					if (!isset($this->report->failed_tests['gplus_authorship']['overall']['not_found']))
					{
						$this->report->failed_tests['gplus_authorship']['overall']['not_found']=array('pages'=>0,'occurances'=>0);
					}
					
					$this->report->failed_tests['gplus_authorship']['overall']['not_found']['pages']++;
					$this->report->failed_tests['gplus_authorship']['overall']['not_found']['occurances']++;
					
					$var=$rules['gplus_authorship']['not_found']['level'].'s';
					$this->report->$var++;
					
					if (isset($rules['gplus_authorship']['not_found']['score_decrease']))
					{
						$score-=$rules['gplus_authorship']['not_found']['score_decrease'];
					}
				}
				$osTextualizer=$OS->getTextualizer();
				
				$keyword_density=array();
				
				if ($textualContent=$osTextualizer->extractTextFromDOM($params['dom']))
				{
//					if ($worker=OS_Interactions::getInteractions('worker','extract_keywords_html'))
//					{
//						$worker=reset($worker);
//						
//						$keyword_density=OS_Interactions::performInteraction($worker['id'],array('url'=>$params['url'],'html'=>$params['content'],'words_min'=>1,'words_max'=>3,'stop_words_list'=>$osProject->language,'conditionValue'=>40,'conditionType'=>'score'));
//					}
					
					$text2html=round(strlen($textualContent)*100/strlen($params['content']),2);
					
					$failed_test=false;
					$failed_test_level=false;
					
					if ($text2html<5)
					{
						$failed_test='extremely_low';
						$failed_test_level='error';
					}
					elseif ($text2html<10)
					{
						$failed_test='low';
						$failed_test_level='warning';
					}
					
					if ($failed_test)
					{
						$error_profile['text2html']['element'][$failed_test]=true;
						
						if (!isset($this->report->failed_tests['text2html']['element'][$failed_test]))
						{
							$this->report->failed_tests['text2html']['element'][$failed_test]=array('pages'=>0,'occurances'=>0);
						}
						
						$this->report->failed_tests['text2html']['element'][$failed_test]['pages']++;
						$this->report->failed_tests['text2html']['element'][$failed_test]['occurances']++;
						
						$var=$failed_test_level.'s';
						$this->report->$var++;
						
						if (isset($rules['text2html']['tests_element'][$failed_test]['score_decrease']))
						{
							$score-=$rules['text2html']['tests_element'][$failed_test]['score_decrease'];
						}
					}
				}
				
				$osTextualizer->setEngine('fullbody');
				if ($bodyTextualContent=$osTextualizer->extractTextFromDOM($params['dom']))
				{
					$wordCount=$osTextualizer->wordCount($bodyTextualContent);
					
					if ($wordCount<200)
					{
						$error_profile['thin_content']['element']['thin_content']=true;
						
						if (!isset($this->report->failed_tests['thin_content']['element']['thin_content']))
						{
							$this->report->failed_tests['thin_content']['element']['thin_content']=array('pages'=>0,'occurances'=>0);
						}
						
						$this->report->failed_tests['thin_content']['element']['thin_content']['pages']++;
						$this->report->failed_tests['thin_content']['element']['thin_content']['occurances']++;
						
						$this->report->errors++;
						
						if (isset($rules['thin_content']['tests_element']['thin_content']['score_decrease']))
						{
							$score-=$rules['thin_content']['tests_element']['thin_content']['score_decrease'];
						}
					}
				}
				if ($score<0)
				{
					$score=0;
				}
				
				$error_profile_hash='';
				
				foreach ($error_profile as $element=>$test_types)
				{
					$error_profile_hash.=$element;
					
					foreach ($test_types as $test_type=>$tests)
					{
						$error_profile_hash.=$test_type;
						
						foreach ($tests as $test_name=>$dummy)
						{
							$error_profile_hash.=$test_name;
						}
					}
				}
				
				$error_profile_hash=md5($error_profile_hash);
				
				$dbresult=$db->query("SELECT * FROM ".$this->dbPrefix()."error_profiles WHERE error_profile_hash=? LIMIT 1",array($error_profile_hash));
				if (!$row=$db->fetchRow($dbresult))
				{
					foreach ($error_profile as $element=>$test_types)
					{
						foreach ($test_types as $test_type=>$tests)
						{
							foreach ($tests as $test_name=>$dummy)
							{
								$db->query("INSERT INTO ".$this->dbPrefix()."error_profiles (error_profile_hash,element,test_type,test_name) VALUES (?,?,?,?)",array($error_profile_hash,$element,$test_type,$test_name));
							}
						}
					}
				}
				
				$dbresult=$db->query("SELECT * FROM ".$this->dbPrefix()."pages_error_profiles WHERE project_id=? AND url_hash=?",array($params['project_id'],$params['url_hash']));
				if (!$row=$db->fetchRow($dbresult))
				{
					$db->query("INSERT INTO ".$this->dbPrefix()."pages_error_profiles (project_id,url_hash,error_profile_hash,score) VALUES (?,?,?,?)",array($params['project_id'],$params['url_hash'],$error_profile_hash,$score));
				}
				elseif ($row['error_profile_hash']!=$error_profile_hash OR $row['score']!=$score)
				{
					$db->query("UPDATE ".$this->dbPrefix()."pages_error_profiles SET error_profile_hash=?,score=? WHERE url_hash=?",array($error_profile_hash,$score,$params['url_hash']));
				}
				
				$old_density=$ops->getPageKeywords($params['url_hash'],$this->report->project_id);
				
				if (!empty($keyword_density))
				{
					foreach ($keyword_density as $length=>$kws)
					{
						if ($kws)
						{
							foreach ($kws as $keyword=>$score)
							{
								if (!isset($old_density[$length][$keyword]))
								{
									$dbresult=$db->query("INSERT INTO ".$this->dbPrefix()."pages_keywords (project_id,url_hash,length,keyword,score) VALUES (?,?,?,?,?)",array($params['project_id'],$params['url_hash'],$length,$keyword,$score));
								}
								else
								{
									$old_kwdensity=$old_density[$length][$keyword];
									
									if ($old_kwdensity['score']!=$score)
									{
										$dbresult=$db->query("UPDATE ".$this->dbPrefix()."pages_keywords SET score=? WHERE id=?",array($score,$old_kwdensity['id']));
									}
									
									unset($old_density[$length][$keyword]);
								}
							}
						}
					}
				}
				
				if (!empty($old_density))
				{
					$ops->deletePageOldKeywordDensity($old_density);
				}
				unset($keyword_density,$old_density);
				$result=true;
			}
			
		}
		
		return $result;
	}
	
	public function eventProjectCrawlEnd($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();
		
		
		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
//			//external tests (duplicate title, duplicate meta desc)
//			$tests=array(
//				'title'=>array(),
//				'description'=>array()
//			);
//			
//			$db=$OS->getDb();
//			
//			$dbresult=$db->query("SELECT url_hash,title,description FROM ".$db->dbPrefix()."projects_urls WHERE project_id=? AND content_type=? AND http_code=?",array($params['project_id'],'text/html','200'));
//			while ($row=$db->fetchRow($dbresult))
//			{
//				if (empty($tests['title'][$row['title']]))
//				{
//					$tests['title'][$row['title']]=array();
//				}
//				$tests['title'][$row['title']][]=$row['url_hash'];
//				
//				if (empty($tests['description'][$row['description']]))
//				{
//					$tests['description'][$row['description']]=array();
//				}
//				$tests['description'][$row['description']][]=$row['url_hash'];
//			}
//			
//			foreach ($tests as $element=>$elements)
//			{
//				$old_urls=array();
//				
//				$dbresult=$db->query("SELECT id,url_hash,element_identity FROM ".$this->dbPrefix()."reports_pages_details WHERE element_name=? AND test_type=? AND test_name=?",array($element,'element','duplicate'));
//				while ($row=$db->fetchRow($dbresult))
//				{
//					$old_urls[$row['element_identity']][$row['url_hash']]=$row['id'];
//				}
//				
//				foreach ($elements as $element_id=>$urls)
//				{
//					if (count($urls)>1)
//					{
//						$this->report->errors++;
//						
//						if (!isset($this->report->failed_tests[$element]['element']['duplicate']))
//						{
//							$this->report->failed_tests[$element]['element']['duplicate']=array('pages'=>0,'occurances'=>0);
//						}
//						
//						$this->report->failed_tests[$element]['element']['duplicate']['pages']+=count($urls);
//						$this->report->failed_tests[$element]['element']['duplicate']['occurances']+=count($urls);
//						
//						foreach ($urls as $url_hash)
//						{
//							if (!isset($old_urls[$element_id][$url_hash]))
//							{
//								$query="INSERT INTO ".$this->dbPrefix()."reports_pages_details (project_id,url_hash,element_name,element_identity,test_type,test_name,test_level) VALUES (?,?,?,?,?,?,?)";
//								$dbresult=$db->query($query,array($params['project_id'],$url_hash,$element,$element_id,'element','duplicate','error'));
//							}
//							else
//							{
//								unset($old_urls[$element_id][$url_hash]);
//							}
//						}
//					}
//				}
//				
//				foreach ($old_urls as $element_id=>$urls)
//				{
//					foreach ($urls as $url_hash=>$id)
//					{
//						$dbresult=$db->query("DELETE FROM ".$this->dbPrefix()."reports_pages_details WHERE id=?",array($id));
//					}
//				}
//			}
			
			$result=$this->report->save();
		}
		
		return $result;
	}
	
	public function eventProjectUrlsObsolete($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();
		
		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
			$ops=OS_APP_OnPage_ReportOperations::get_instance();
			
			foreach ($params['urls'] as $url_id=>$url_details)
			{
				$ops->deletePageErrorProfileLink($url_details['url_hash'],$params['project_id']);
				$ops->deletePageKeywords($url_details['url_hash'],$params['project_id']);
			}
		}
		
		return $result;
	}
	
	public function eventProjectDeleted($params)
	{
		$ops=OS_APP_OnPage_ReportOperations::get_instance();
		
		return $ops->deleteDataByProjectID($params['project_id']);
	}
	
	public function interactionWorkerOnpageKeywordScore($params)
	{
		$result=0;
		
		if (!empty($params['url_hash']) AND !empty($params['keyword']))
		{
			$ops=OS_APP_OnPage_ReportOperations::get_instance();
			
			$result=$ops->getPageKeywordScore($params['url_hash'],$params['keyword']);
		}
		
		return $result;
	}
	
	public function interactionWorkerOnpageKeywords($params)
	{
		$result=false;
		
		if (!empty($params['url_hash']))
		{
			$ops=OS_APP_OnPage_ReportOperations::get_instance();
			
			$result=$ops->getPageKeywordsBulk($params['url_hash']);
		}
		
		return $result;
	}
	
	public function interactionWorkerOnpageAnalyzer($params)
	{
		$result=false;
		
		if (!empty($params['url']))
		{
			$OS=getOS();
			$osHttp=$OS->getHttp();
			
			$response=$osHttp->get($params['url']);
			
			if (!empty($response) AND $osHttp->success())
			{
				$dom=new DOMDocument();
				
				libxml_use_internal_errors(true);
				$domLoaded=$dom->loadHTML($response);
				libxml_use_internal_errors(false);
				
				if ($domLoaded)
				{
					$analyzer=OS_APP_OnPage_Analyzer::get_instance();
					
					$bulk_info=$osHttp->getInfo();
					
					if (!empty($bulk_info['size_download']))
					{
						$size=$bulk_info['size_download'];
					}
					else
					{
						$size=strlen($response);
					}
					
					if (!empty($bulk_info['total_time']))
					{
						$load_time=$bulk_info['total_time'];
					}
					else
					{
						$load_time=false;
					}
					
					$other=array(
						'size'=>$size,
						'load_time'=>$load_time
					);
					
					$result=$analyzer->analyze($params['url'],$dom,$response,$other);;
					
					$xpath=new DOMXPath($dom);
				
					$has_gplus_authorship=false;
					$entries=$xpath->query("//link[@rel='author']");
					if ($entries->item(0))
					{
						$has_gplus_authorship=true;
					}
					if (!$has_gplus_authorship)
					{
						$entries=$xpath->query("//a");
						
						foreach ($entries as $entry)
						{
							$href=$entry->getAttribute('href');
							
							if (0===strpos($href,'https://plus.google.com/') AND false!==strpos($href,'rel=author'))
							{
								$rel=$entry->getAttribute('rel');
								
								if ($rel=='author')
								{
									$has_gplus_authorship=true;
									break;
								}
							}
						}
						
						if (!$has_gplus_authorship)
						{
							$entries=$xpath->query("//plus[@rel='author']");
							
							foreach ($entries as $entry)
							{
								if ($entries->item(0))
								{
									$has_gplus_authorship=true;
									break;
								}
							}
							
							if (!$has_gplus_authorship)
							{
								$entries=$xpath->query("//div[@class='g-plus']");
								
								foreach ($entries as $entry)
								{
									$href=$entry->getAttribute('data-href');
							
									if (0===strpos($href,'https://plus.google.com/'))
									{
										if ($rel=$entry->getAttribute('rel'))
										{
											if ($rel=='author')
											{
												$has_gplus_authorship=true;
												break;
											}
										}
										elseif ($rel=$entry->getAttribute('data-rel'))
										{
											if ($rel=='author')
											{
												$has_gplus_authorship=true;
												break;
											}
										}
									}
								}
							}
						}
					}
					
					if (!$has_gplus_authorship)
					{
						$entries=$xpath->query("//link[@rel='publisher']");
						if ($entries->item(0))
						{
							$has_gplus_authorship=true;
						}
						if (!$has_gplus_authorship)
						{
							$entries=$xpath->query("//a[@rel='publisher']");
							
							foreach ($entries as $entry)
							{
								$href=$entry->getAttribute('href');
								
								if (0===strpos($href,'https://plus.google.com/'))
								{
									$has_gplus_authorship=true;
									break;
								}
							}
							
							if (!$has_gplus_authorship)
							{
								$entries=$xpath->query("//plus");
								
								if ($entries->item(0))
								{
									$has_gplus_authorship=true;
								}
								
								if (!$has_gplus_authorship)
								{
									$entries=$xpath->query("//div[@class='g-plus']");
									
									foreach ($entries as $entry)
									{
										$href=$entry->getAttribute('data-href');
								
										if (0===strpos($href,'https://plus.google.com/'))
										{
											$has_gplus_authorship=true;
											break;
										}
									}
								}
							}
						}
					}
					
					if (!$has_gplus_authorship)
					{
						$result['failed_tests']['gplus_authorship']['overall']['not_found']=true;
					}
					
					$osTextualizer=$OS->getTextualizer();
					
					if ($textualContent=$osTextualizer->extractTextFromDOM($dom))
					{
						$text2html=round(strlen($textualContent)*100/strlen($response),2);
						
						$failed_test=false;
						$failed_test_level=false;
						
						if ($text2html<5)
						{
							$failed_test='extremely_low';
							$failed_test_level='error';
						}
						elseif ($text2html<10)
						{
							$failed_test='low';
							$failed_test_level='warning';
						}
						
						if ($failed_test)
						{
							$result['failed_tests']['text2html']['element']["{$text2html} %"][$failed_test]=true;
						}
					}
					
					$osTextualizer->setEngine('fullbody');
					
					if ($bodyTextualContent=$osTextualizer->extractTextFromDOM($dom))
					{
						$wordCount=$osTextualizer->wordCount($bodyTextualContent);
						
						if ($wordCount<200)
						{
							$result['failed_tests']['thin_content']['element'][$wordCount]['thin_content']=true;
						}
					}
				}
			}
		}
		
		return $result;
	}
}
?>