<?php
class OS_APP_OnPage_Analyzer
{
	private static $_instance;
	
	private $rules;
	private $xpath;
	private $dom;
	private $html;
	
	public function __construct()
	{
		$this->setInitialValues();
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_OnPage_Analyzer();
		}
		
		return self::$_instance;
	}
	
	public function analyze($url,$dom,$html,$other=array(),$keyword=false,$keyword_only=false)
	{
		$result=false;
		
		$this->url=$url;
		$this->dom=$dom;
		$this->xpath=false;
		$this->html=$html;
		$this->embeddedImages=0;
		
		if (!$keyword)
		{
			$keyword_only=false;
		}
		
		$score=100;
		
		foreach ($this->rules as $element_name=>$element_details)
		{
			$can_run_element=true;
			
			if (!empty($element_details['requires_keyword']) AND !$keyword)
			{
				$can_run_element=false;
			}
			
			if (!empty($element_details['conditionals']))
			{
				if (!empty($element_details['conditionals']['run_if_failed']))
				{
					foreach ($element_details['conditionals']['run_if_failed'] as $cond_element=>$cond_element_tests)
					{
						foreach ($cond_element_tests as $cond_element_test_type=>$actual_cond_element_tests)
						{
							foreach ($actual_cond_element_tests as $actual_cond_element_test)
							{
								if (!isset($result[$cond_element][$cond_element_test_type][$actual_cond_element_test]))
								{
									$can_run_element=false;
								}
							}
						}
					}
				}
			}
			
			if ($can_run_element)
			{
				if ($element_details['on']=='dom')
				{
					$elements=$this->getElements($element_details['rule']);
				}
				elseif ($element_details['on']=='url')
				{
					$elements=array($url);
				}
				elseif ($element_details['on']=='html')
				{
					$elements=array($html);
				}
				elseif ($element_details['on']=='other')
				{
					if (isset($other[$element_details['rule']]))
					{
						$elements=array($other[$element_details['rule']]);
					}
					else
					{
						$elements=array();
					}
				}
				
				if ($elements)
				{
					$blocking_error_found=false;
					$kwonly_element_available=false;
					
					if (!empty($element_details['tests_overall']))
					{
						foreach ($element_details['tests_overall'] as $test_name=>$test_details)
						{
							$can_run_test=true;
							
							if ($test_details['type']=='external')
							{
								$can_run_test=false;
							}
							elseif (!empty($test_details['requires_keyword']))
							{
								$kwonly_element_available=true;
								
								if (empty($keyword))
								{
									$can_run_test=false;
								}
							}
							
							if ($can_run_test)
							{
								if (!$test_passed=$this->runOverallTest($element_details['on'],$elements,$test_details,$keyword))
								{
									$result[$element_name]['overall'][$test_name]=array('level'=>$test_details['level'],'message'=>$test_details['message']);
									
									if (!empty($test_details['score_decrease']))
									{
										$score-=$test_details['score_decrease'];
									}
									
									if (!empty($test_details['block']))
									{
										$blocking_error_found=true;
									
										break;
									}
								}
							}
						}
					}
					
					if (!$blocking_error_found)
					{
						if (!empty($element_details['tests_element']))
						{
							$scored_for=array();
							
							foreach ($elements as $key=>$element)
							{
								foreach ($element_details['tests_element'] as $test_name=>$test_details)
								{
									$can_run_test=true;
									
									if ($test_details['type']=='external')
									{
										$can_run_test=false;
									}
									elseif (!empty($test_details['requires_keyword']))
									{
										$kwonly_element_available=true;
										
										if (empty($keyword))
										{
											$can_run_test=false;
										}
									}
									
									if ($can_run_test)
									{
										if (!$test_passed=$this->runElementTest($element_details['on'],$element,$test_details,$keyword))
										{
											$identity=$this->getElementIdentificator($element_details['on'],$element,$element_details['identificator']);
											
											if (!empty($element_details['identificator_humanizer']))
											{
												$identity=$this->$element_details['identificator_humanizer']($identity);
											}
											
											if (!isset($result[$element_name]['element'][$identity]))
											{
												$result[$element_name]['element'][$identity]=array();
											}
											
											$result[$element_name]['element'][$identity][$test_name]=array('level'=>$test_details['level'],'message'=>$test_details['message']);
											
											if (!empty($test_details['score_decrease']))
											{
												if (!isset($scored_for[$test_name]))
												{
													$score-=$test_details['score_decrease'];
													$scored_for[$test_name]=true;
												}
											}
											
											
											if (!empty($test_details['block']))
											{
												break;
											}
										}
									}
								}
							}
						}
					}
					
					if ($keyword_only AND !$kwonly_element_available)
					{
						unset($result[$element_name]);
					}
				}
				elseif (!empty($element_details['not_found']))
				{
					$test_available=true;
					
					if (isset($element_details['not_found']['type']) AND $element_details['not_found']['type']=='external')
					{
						$test_available=false;
					}
					
					if ($keyword_only AND empty($element_details['not_found']['available_keyword_only']))
					{
						$test_available=false;
					}
					
					if (!$keyword AND !empty($element_details['not_found']['requires_keyword']))
					{
						$test_available=false;
					}
					
					if ($test_available)
					{
						$result[$element_name]['overall']['not_found']=array('level'=>$element_details['not_found']['level'],'message'=>$element_details['not_found']['message']);
						
						if (!empty($element_details['not_found']['score_decrease']))
						{
							$score-=$element_details['not_found']['score_decrease'];
						}
					}
				}
				
				if (!isset($result[$element_name]))
				{
					if (!empty($element_details['conditionals']))
					{
						if (!empty($element_details['conditionals']['cancel_if_successful']))
						{
							foreach ($element_details['conditionals']['cancel_if_successful'] as $cancel_element)
							{
								if (isset($result[$cancel_element]))
								{
									foreach ($result[$cancel_element] as $test_type=>$actual_tests)
									{
										foreach ($actual_tests as $actual_test_name=>$dummy)
										{
											if ($test_type=='overall' AND $actual_test_name=='not_found')
											{
												if (!empty($this->rules[$cancel_element]['not_found']['score_decrease']))
												{
													$score+=$this->rules[$cancel_element]['not_found']['score_decrease'];
												}
											}
											elseif (!empty($this->rules[$cancel_element]['tests_'.$test_type][$actual_test_name]['score_decrease']))
											{
												$score+=$this->rules[$cancel_element]['tests_'.$test_type][$actual_test_name]['score_decrease'];
											}
										}
									}
									
									unset($result[$cancel_element]);
								}
							}
						}
					}
				}
			}
		}
		
		if ($score<0)
		{
			$score=0;
		}
		
		return array('failed_tests'=>$result,'score'=>$score);
	}
	
	public function runOverallTest($on,$elements,$test_details,$keyword)
	{
		$result=false;
		
		switch($test_details['type'])
		{
			case 'max_count':
				if (count($elements)<=$test_details['value'])
				{
					$result=true;
				}
				
				break;
			
			case 'max_count_not_empty':
				$count=0;
				
				foreach ($elements as $element)
				{
					if ($this->runElementTest($on,$element,array('on'=>$test_details['on'],'type'=>'not_empty'),$keyword))
					{
						$count++;
					}
				}
				
				if ($count<=$test_details['value'])
				{
					$result=true;
				}
				
				break;
			
			case 'min_count':
				if (count($elements)>=$test_details['value'])
				{
					$result=true;
				}
				
				break;
			
			case 'min_count_equal':
				$count=0;
				
				foreach ($elements as $element)
				{
					if ($this->runElementTest($on,$element,array('on'=>$test_details['on'],'type'=>'equal','value'=>$test_details['elem_value']),$keyword))
					{
						$count++;
					}
				}
				
				if ($count>=$test_details['value'])
				{
					$result=true;
				}
				
				break;
			
			case 'min_count_containing':
				$count=0;
				
				foreach ($elements as $element)
				{
					if ($this->runElementTest($on,$element,array('on'=>$test_details['on'],'type'=>'contains_text','value'=>$test_details['elem_value']),$keyword))
					{
						$count++;
					}
				}
				
				if ($count>=$test_details['value'])
				{
					$result=true;
				}
				
				break;
			
			case 'min_count_containing_keyword':
				$count=0;
				
				foreach ($elements as $element)
				{
					if ($this->runElementTest($on,$element,array('on'=>$test_details['on'],'type'=>'contains_keyword'),$keyword))
					{
						$count++;
					}
				}
				
				if ($count>=$test_details['value'])
				{
					$result=true;
				}
				
				break;
		}
		
		return $result;
	}
	
	public function runElementTest($on,$element,$test_details,$keyword)
	{
		$result=false;
		
		$test_value=$this->getElementIdentificator($on,$element,$test_details['on']);
		
		switch ($test_details['type'])
		{
			case 'not_empty':
				if (!empty($test_value))
				{
					$result=true;
				}
				
				break;
			
			case 'empty':
				if (empty($test_value))
				{
					$result=true;
				}
				
				break;
			
			case 'equal':
				if ($test_value==$test_details['value'])
				{
					$result=true;
				}
				
				break;
			
			case 'min_value':
				if ($test_value>=$test_details['value'])
				{
					$result=true;
				}
				
				break;
			
			case 'reverse_min_value':
				$result=true;
				
				if ($test_value>=$test_details['value'])
				{
					$result=false;
				}
				
				break;
				
			case 'max_value':
				if ($test_value<=$test_details['value'])
				{
					$result=true;
				}
				
				break;
				
			case 'reverse_max_value':
				$result=true;
				
				if ($test_value<=$test_details['value'])
				{
					$result=false;
				}
				
				break;
				
			case 'min_length':
				if (strlen($test_value)>=$test_details['value'])
				{
					$result=true;
				}
				
				break;
			
			case 'reverse_min_length':
				$result=true;
				
				if (strlen($test_value)>=$test_details['value'])
				{
					$result=false;
				}
				
				break;
			
			case 'max_length':
				if (strlen($test_value)<=$test_details['value'])
				{
					$result=true;
				}
				
				break;
			
			case 'reverse_max_length':
				$result=true;
				
				if (strlen($test_value)<=$test_details['value'])
				{
					$result=false;
				}
				
				break;
			
			case 'min_words':
				$words_count=count(explode(' ',$test_value));
				
				if ($words_count>=$test_details['value'])
				{
					$result=true;
				}
				
				break;
			
			case 'max_words':
				$words_count=count(explode(' ',$test_value));
				
				if ($words_count<=$test_details['value'])
				{
					$result=true;
				}
				
				break;
			
			case 'contains_text':
				$test_value=strtolower($test_value);
				$test_details['value']=strtolower($test_details['value']);
			
				if (false===strpos($test_value,$test_details['value']))
				{
					$result=true;
				}
				
				break;
			
			case 'contains_keyword':
				$test_value=strtolower($test_value);
				$keyword==strtolower($keyword);
				
				if (false!==strpos($test_value,$keyword))
				{
					$result=true;
				}
				
				break;
			
			case 'w3c_validation':
				$result=true;
				
				$osHttp=getOS()->getHttp();
				$w3c_response=$osHttp->head("http://validator.w3.org/check?url={$test_value}");
				
				if ($w3c_response AND $osHttp->success())
				{
					if ($w3c_response=$osHttp->parseHeaders($w3c_response))
					{
						if (isset($w3c_response['x-w3c-validator-status']) AND $w3c_response['x-w3c-validator-status']=='Invalid')
						{
							$result=false;
						}
					}
				}
		}
		
		return $result;
	}
	
	public function getElements($rule)
	{
		$result=false;
		
		if (!$this->xpath)
		{
			$this->xpath=new DOMXPath($this->dom);
		}
		
		$entries=$this->xpath->query($rule);
		
		$allowed_link_schemas=array('http','https');
		
		for ($i=0;$i<$entries->length;$i++)
		{
			$valid=true;
			
			if ($rule=='//a')
			{
				$href=$entries->item($i)->getAttribute('href');
				
				if ($href)
				{
					if (0===strpos($href,'#'))
					{
						$valid=false;
					}
					else
					{
						$href=parse_url($href);
						
						if (!empty($href['scheme']))
						{
							if (!in_array($href['scheme'],$allowed_link_schemas))
							{
								$valid=false;
							}
						}
					}
				}
				else
				{
					$valid=false;
				}
			}
			
			if ($valid)
			{
				$result[]=$entries->item($i);
			}
		}
		
		return $result;
	}
	
	public function getElementIdentificator($on,$element,$identificator)
	{
		$result=false;
		
		if ($on=='dom')
		{
			if ($identificator=='node_value')
			{
				$result=$element->nodeValue;
			}
			else
			{
				$result=$element->getAttribute($identificator);

				if ($element->tagName=='img' AND $identificator=='src')
				{
					if (0===strpos($result,'data:'))
					{
						$this->embeddedImages++;
						
						$result='embedded image '.$this->embeddedImages;
					}
				}
			}
		}
		elseif ($on=='url')
		{
			if ($identificator=='self')
			{
				$result=$element;
			}
			else
			{
				$temp=parse_url($element);
				
				$result=(empty($temp[$identificator])?'':$temp[$identificator]);
			}
		}
		elseif ($on=='html')
		{
			if ($identificator=='self')
			{
				$result=$element;
			}
			elseif ($identificator=='none')
			{
				$result='';
			}
		}
		elseif ($on=='other')
		{
			if ($identificator=='self')
			{
				$result=$element;
			}
			elseif ($identificator=='none')
			{
				$result='';
			}
		}
		
		return $result;
	}
	
	public function getRules()
	{
		return $this->rules;
	}
	
	public function setInitialValues()
	{
		$this->xpath=false;
		$this->url=false;
		$this->dom=false;
		$this->html=false;
		
		$this->setDefaultRules();
	}
	
	public function getRulesCategories()
	{
		$rulesCategories=array(
			'content'=>array(
				'title'=>_("Content"),
				'groups'=>array(
					'head'=>array(
						'title'=>_("&lt;HEAD&gt; section"),
						'help_url'=>false
					),
					'headings'=>array(
						'title'=>_("Headings"),
						'help_url'=>false
					),
					'keyword'=>array(
						'title'=>_("Keyword in content"),
						'help_url'=>false
					),
					'links'=>array(
						'title'=>_("Links"),
						'help_url'=>false
					),
					'images'=>array(
						'title'=>_("Images"),
						'help_url'=>false
					),
					'other'=>array(
						'title'=>_("Other"),
						'help_url'=>false
					)
				)
			),
			'social'=>array(
				'title'=>_("Social"),
				'groups'=>array(
					'facebook'=>array(
						'title'=>"Facebook",
						'help_url'=>"http://ogp.me/"
					),
					'twitter'=>array(
						'title'=>"Twitter",
						'help_url'=>"https://dev.twitter.com/docs/cards"
					),
					'gplus'=>array(
						'title'=>"Google+",
						'help_url'=>"http://support.google.com/webmasters/bin/answer.py?hl=en&answer=1408986"
					)
				)
			),
			'general'=>array(
				'title'=>_("General"),
				'groups'=>array(
					'url'=>array(
						'title'=>"URL",
						'help_url'=>false
					),
					'css'=>array(
						'title'=>"CSS",
						'help_url'=>false
					),
					'js'=>array(
						'title'=>"Javascript",
						'help_url'=>false
					),
					'w3c'=>array(
						'title'=>_("W3C Compliance"),
						'help_url'=>false
					),
					'other'=>array(
						'title'=>_("Other"),
						'help_url'=>false
					)
				)
			)
		);
		
		return $rulesCategories;
	}
	
	public function setDefaultRules()
	{
		$this->rules=array(
			'url'=>array(
				'category'=>'general',
				'group'=>'url',
				'human_name'=>"URL",
				'on'=>'url',
				'identificator'=>'self',
				'tests_element'=>array(
					'too_long'=>array(
						'type'=>'max_length',
						'on'=>'self',
						'level'=>'warning',
						'value'=>115,
						'message'=>_("URL too long. Maximum recommended length: 115 chars"),
						'list_message'=>_("URL too long"),
						'report_message'=>_("URL too long (>115 chars)"),
						'score_decrease'=>2,
						'advice'=>_("Rule of thumb for URLs characters: keep them under 115 characters or 3-5 words.")
					),
					'dynamic'=>array(
						'type'=>'empty',
						'on'=>'query',
						'level'=>'warning',
						'message'=>_("URL seems to be dynamic"),
						'list_message'=>_("Dynamic URLs"),
						'score_decrease'=>5,
						'advice'=>_("Check out your dynamic URLs, they can get you into trouble with duplicate content.")
					),
					'no_keyword'=>array(
						'type'=>'contains_keyword',
						'on'=>'self',
						'level'=>'error',
						'message'=>_("Your URL does not contain the provided keyword"),
						'list_message'=>_("Keyword not in URL"),
						'requires_keyword'=>true
					)
				)
			),
			'title'=>array(
				'category'=>'content',
				'group'=>'head',
				'human_name'=>_("Title"),
				'on'=>'dom',
				'rule'=>'//title',
				'identificator'=>'node_value',
				'tests_overall'=>array(
					'max_count'=>array(
						'type'=>'max_count',
						'level'=>'error',
						'value'=>1,
						'message'=>_("You must have a single TITLE tag"),
						'list_message'=>_("More TITLE tags"),
						'score_decrease'=>5,
						'advice'=>_("Make sure you have only one title tag per page.")
					)
				),
				'tests_element'=>array(
					'empty'=>array(
						'type'=>'not_empty',
						'on'=>'node_value',
						'level'=>'error',
						'block'=>true,
						'message'=>_("TITLE empty"),
						'list_message'=>_("Empty TITLE"),
						'score_decrease'=>25
					),
					'duplicate'=>array(
						'type'=>'external',
						'level'=>'error',
						'message'=>_("Your page has the same TITLE as other pages in your site"),
						'list_message'=>_("Duplicate TITLE")
					),
					'min_length'=>array(
						'type'=>'min_length',
						'on'=>'node_value',
						'level'=>'warning',
						'value'=>25,
						'message'=>_("TITLE too short. Minimum length: 25 chars"),
						'list_message'=>_("TITLE too short"),
						'report_message'=>_("TITLE too short (<25 chars)"),
						'score_decrease'=>1,
						'advice'=>_("You can add up to 70 characters in your titles, don't miss any keyword opportunities.")
					),
					'max_length'=>array(
						'type'=>'max_length',
						'on'=>'node_value',
						'level'=>'warning',
						'value'=>70,
						'message'=>_("TITLE too long. Maximum length: 70 chars"),
						'list_message'=>_("TITLE too long"),
						'report_message'=>_("TITLE too long (>70 chars)"),
						'score_decrease'=>1,
						'advice'=>_("Best practice for title tag is to keep them unde 70 characters because search engines truncates them in SERPs.")
					),
					'11_words'=>array(
						'type'=>'max_words',
						'on'=>'node_value',
						'level'=>'warning',
						'value'=>12,
						'message'=>_("Your TITLE has more than 12 words, try to reduce the number"),
						'list_message'=>_("Too many words in TITLE"),
						'report_message'=>_("Too many words in TITLE (>12 words)"),
						'score_decrease'=>1,
						'advice'=>_("Keep your word count in title short for better understanding. Avoid using unnecesesary keywords.")
					),
					'no_keyword'=>array(
						'type'=>'contains_keyword',
						'on'=>'node_value',
						'level'=>'error',
						'message'=>_("Your TITLE does not contain the provided keyword"),
						'list_message'=>_("Keyword not in TITLE"),
						'requires_keyword'=>true
					)
				),
				'not_found'=>array(
					'available_keyword_only'=>true,
					'level'=>'error',
					'block'=>true,
					'message'=>_("TITLE missing"),
					'list_message'=>_("Missing TITLE tag"),
					'score_decrease'=>25,
					'advice'=>_("You're missing all the ranking power that title is giving to your site. Make sure to proper target your keywords in all title tags and improve your traffic.")
				)
			),
			'canonical_url'=>array(
				'category'=>'general',
				'group'=>'url',
				'human_name'=>_("Canonical URL"),
				'on'=>'dom',
				'rule'=>'//link[@rel="canonical"]',
				'identificator'=>'href',
				'not_found'=>array(
					'available_keyword_only'=>true,
					'level'=>'error',
					'block'=>false,
					'message'=>_("Canonical URL missing"),
					'list_message'=>_("Missing Canonical URL"),
					'score_decrease'=>15,
					'advice'=>_("Canonical tag is one of the best ways to prevent duplicate content. Use it on all you pages.")
				)
			),
			'description'=>array(
				'category'=>'content',
				'group'=>'head',
				'human_name'=>_("Meta Description"),
				'on'=>'dom',
				'rule'=>'//meta[@name="description"]',
				'identificator'=>'content',
				'tests_overall'=>array(
					'max_count'=>array(
						'type'=>'max_count',
						'level'=>'error',
						'value'=>1,
						'message'=>_("You must have a single META DESCRIPTION tag"),
						'list_message'=>_("More META DESCRIPTION tags"),
						'score_decrease'=>1,
					)
				),
				'tests_element'=>array(
					'empty'=>array(
						'type'=>'not_empty',
						'on'=>'content',
						'level'=>'error',
						'block'=>true,
						'message'=>_("META DESCRIPTION empty"),
						'list_message'=>_("Empty META DESCRIPTION"),
						'score_decrease'=>3
					),
					'duplicate'=>array(
						'type'=>'external',
						'level'=>'error',
						'message'=>_("Your page has the same META DESCRIPTION as other pages in your site"),
						'list_message'=>_("Duplicate META DESCRIPTION"),
						'score_decrease'=>1
					),
					'min_length'=>array(
						'type'=>'min_length',
						'on'=>'content',
						'level'=>'warning',
						'value'=>70,
						'message'=>_("META DESCRIPTION too short. Minimum length: 70 chars"),
						'list_message'=>_("META DESCRIPTION too short"),
						'report_message'=>_("META DESCRIPTION too short (<70 chars)"),
						'score_decrease'=>1,
						'advice'=>_("You're missing the opportunity to improve your CTR from search. Put more keywords, but keep it under 160 characters.")
					),
					'max_length'=>array(
						'type'=>'max_length',
						'on'=>'content',
						'level'=>'warning',
						'value'=>160,
						'message'=>_("META DESCRIPTION too long. Maximum length: 160 chars"),
						'list_message'=>_("META DESCRIPTION too long"),
						'report_message'=>_("META DESCRIPTION too long (>160 chars)"),
						'score_decrease'=>1,
						'advice'=>_("Keep your meta descriptions between 150-160 characters for search engines to properly show your snippet in search results.")
					),
					'70_words'=>array(
						'type'=>'max_words',
						'on'=>'content',
						'level'=>'warning',
						'value'=>70,
						'message'=>_("Try to reduce the amount of words that comprise your META DESCRIPTION to under 70"),
						'list_message'=>_("Too many words in META DESCRIPTION"),
						'report_message'=>_("Too many words in META DESCRIPTION (>70 words)"),
						'score_decrease'=>1
					),
					'no_keyword'=>array(
						'type'=>'contains_keyword',
						'on'=>'node_value',
						'level'=>'warning',
						'message'=>_("Your META DESCRIPTION does not contain the provided keyword"),
						'list_message'=>_("Keyword not in META DESCRIPTION"),
						'requires_keyword'=>true
					)
				),
				'not_found'=>array(
					'available_keyword_only'=>true,
					'level'=>'error',
					'block'=>true,
					'message'=>_("META DESCRIPTION missing"),
					'list_message'=>_("Missing META DESCRIPTION"),
					'score_decrease'=>3,
					'advice'=>_("Meta descriptions are the best way to market every page. Make them relevant and attractive for users.")
				)
			),
			'meta_robots'=>array(
				'category'=>'content',
				'group'=>'head',
				'human_name'=>_("Meta Robots"),
				'on'=>'dom',
				'rule'=>'//meta[@name="robots"]',
				'identificator'=>'content',
				'tests_element'=>array(
					'noindex'=>array(
						'type'=>'contains_text',
						'on'=>'content',
						'level'=>'error',
						'value'=>'noindex',
						'message'=>_("Your META ROBOTS NOINDEX tag prevents crawlers from indexing the page"),
						'list_message'=>_("META ROBOTS 'noindex'"),
						'score_decrease'=>100,
						'advice'=>_("These pages are not present in any search engine because you are preventing crawlers from indexing them. Make sure you want them out of index.")
					),
					'nofollow'=>array(
						'type'=>'contains_text',
						'on'=>'content',
						'level'=>'warning',
						'value'=>'nofollow',
						'message'=>_("Your META ROBOTS NOFOLLOW tag prevents crawlers from following the links on the page"),
						'list_message'=>_("META ROBOTS 'nofollow'"),
						'advice'=>_("No link from these pages will be followed by search engines. Make sure you want that.")
					),
					'nocache'=>array(
						'type'=>'contains_text',
						'on'=>'content',
						'level'=>'notice',
						'value'=>'nocache',
						'message'=>_("Your META ROBOTS NOCACHE tag prevents crawlers from caching the pages output"),
						'list_message'=>_("META ROBOTS 'nocache'"),
					),
					'noodp'=>array(
						'type'=>'contains_text',
						'on'=>'content',
						'level'=>'notice',
						'value'=>'noodp',
						'message'=>_("Your META ROBOTS NOODP tag prevents crawlers from using the site's description from DMOZ (if any)"),
						'list_message'=>_("META ROBOTS 'noodp'"),
					),
					'noydir'=>array(
						'type'=>'contains_text',
						'on'=>'content',
						'level'=>'notice',
						'value'=>'noodp',
						'message'=>_("Your META ROBOTS NOYDIR tag prevents crawlers from using the site's description from Yahoo! Directory (if any)"),
						'list_message'=>_("META ROBOTS 'noydir'"),
					)
				)
			),
			'meta_refresh'=>array(
				'category'=>'content',
				'group'=>'head',
				'human_name'=>_("Meta Refresh"),
				'on'=>'dom',
				'rule'=>'//meta[@http-equiv="refresh"]',
				'identificator'=>'content',
				'tests_overall'=>array(
					'exists'=>array(
						'type'=>'max_count',
						'level'=>'error',
						'value'=>0,
						'message'=>_("You shouldn't use META REFRESH, a 301 redirect is recommended instead"),
						'list_message'=>_("META REFRESH")
					)
				)
			),
			'h1'=>array(
				'category'=>'content',
				'group'=>'headings',
				'human_name'=>_("H1 heading"),
				'on'=>'dom',
				'rule'=>'//h1',
				'identificator'=>'node_value',
				'tests_overall'=>array(
					'max_count'=>array(
						'type'=>'max_count',
						'level'=>'error',
						'value'=>1,
						'message'=>_("You must have a single H1 tag on a page"),
						'list_message'=>_("More H1 tags"),
						'score_decrease'=>3,
						'advice'=>_("Make sure you have only one H1 tag on every page.")
					)
				),
				'tests_element'=>array(
					'empty'=>array(
						'type'=>'not_empty',
						'on'=>'node_value',
						'level'=>'error',
						'block'=>true,
						'message'=>_("H1 empty"),
						'list_message'=>_("Empty H1 tag"),
						'score_decrease'=>15
					),
					'no_keyword'=>array(
						'type'=>'contains_keyword',
						'on'=>'node_value',
						'level'=>'error',
						'message'=>_("Your H1 does not contain the provided keyword"),
						'list_message'=>_("Keyword not in H1 tag"),
						'requires_keyword'=>true
					)
				),
				'not_found'=>array(
					'available_keyword_only'=>true,
					'level'=>'error',
					'block'=>true,
					'message'=>_("H1 missing"),
					'list_message'=>_("Missing H1 tag"),
					'score_decrease'=>15,
					'advice'=>_("You're missing the opporunity to rank better for your tageted keywords. Place unique H1 tags on every page from your site.")
				)
			),
			'h2'=>array(
				'category'=>'content',
				'group'=>'headings',
				'human_name'=>_("H2 heading"),
				'on'=>'dom',
				'rule'=>'//h2',
				'identificator'=>'node_value',
				'tests_element'=>array(
					'no_keyword'=>array(
						'type'=>'contains_keyword',
						'on'=>'node_value',
						'level'=>'warning',
						'message'=>_("Your H2 does not contain the provided keyword"),
						'list_message'=>_("Keyword not in H2 tag"),
						'requires_keyword'=>true
					)
				),
				'not_found'=>array(
					'available_keyword_only'=>true,
					'level'=>'warning',
					'message'=>_("H2 missing"),
					'list_message'=>_("Missing H2 tag"),
					'score_decrease'=>5,
					'advice'=>_("H2 tags help both users and search engines to better understand your content. Make sure you use it.")
				)
			),
			'b'=>array(
				'category'=>'content',
				'group'=>'keyword',
				'human_name'=>_("Bold Keyword"),
				'on'=>'dom',
				'rule'=>'//b',
				'identificator'=>'node_value',
				'requires_keyword'=>true,
				'tests_overall'=>array(
					'bold_keyword'=>array(
						'type'=>'min_count_containing_keyword',
						'on'=>'node_value',
						'level'=>'warning',
						'value'=>1,
						'message'=>_("You should have your keyword in BOLD at least once"),
						'list_message'=>_("No BOLD keyword"),
						'requires_keyword'=>true
					)
				),
				'not_found'=>array(
					'available_keyword_only'=>true,
					'requires_keyword'=>true,
					'level'=>'warning',
					'message'=>_("You should have your keyword in BOLD at least once"),
					'list_message'=>_("No BOLD keyword")
				)
			),
			'i'=>array(
				'category'=>'content',
				'group'=>'keyword',
				'human_name'=>_("Italic Keyword"),
				'on'=>'dom',
				'rule'=>'//i',
				'identificator'=>'node_value',
				'requires_keyword'=>true,
				'tests_overall'=>array(
					'italic_keyword'=>array(
						'type'=>'min_count_containing_keyword',
						'on'=>'node_value',
						'level'=>'warning',
						'value'=>1,
						'message'=>_("You should have your keyword in ITALIC at least once"),
						'list_message'=>_("No ITALIC keyword"),
						'requires_keyword'=>true
					)
				),
				'not_found'=>array(
					'available_keyword_only'=>true,
					'requires_keyword'=>true,
					'level'=>'warning',
					'message'=>_("You should have your keyword in ITALIC at least once"),
					'list_message'=>_("No ITALIC keyword")
				)
			),
			'links'=>array(
				'category'=>'content',
				'group'=>'links',
				'human_name'=>_("Links"),
				'on'=>'dom',
				'rule'=>'//a',
				'identificator'=>'href',
				'tests_overall'=>array(
					'max_count'=>array(
						'type'=>'max_count',
						'level'=>'warning',
						'value'=>100,
						'message'=>_("You have more than 100 links on a single page"),
						'list_message'=>_("More than 100 links"),
						'score_decrease'=>2,
						'advice'=>_("Google recommends that you should use under 100 links per page for better crawling on your site. Keep the number as small as possible.")
					)
				),
				'tests_element'=>array(
					'no_title'=>array(
						'type'=>'not_empty',
						'on'=>'title',
						'level'=>'notice',
						'message'=>_("Link does not have a TITLE attribute"),
						'group_message'=>_("Your page contains links that do not have a TITLE attribute"),
						'list_message'=>_("No TITLE on link")
					),
					'title_too_long'=>array(
						'type'=>'max_length',
						'on'=>'title',
						'level'=>'notice',
						'value'=>50,
						'message'=>_("Link TITLE too long. Maximum recommended length: 50 chars"),
						'group_message'=>_("Your page contains links that have their TITLE too long."),
						'list_message'=>_("Link TITLE too long"),
						'score_decrease'=>1
					),
					'too_many_words_in_title'=>array(
						'type'=>'max_words',
						'on'=>'title',
						'level'=>'notice',
						'value'=>10,
						'message'=>_("Link TITLE contains too many words. Recommended: 10 words"),
						'group_message'=>_("Your page contains links that have too many words in their TITILE"),
						'list_message'=>_("Too many words in link TITLE"),
						'score_decrease'=>1
					)
				),
				'not_found'=>array(
					'available_keyword_only'=>true,
					'level'=>'error',
					'message'=>_("Dead-end page (no outgoing links found on page)"),
					'list_message'=>_("Dead-end pages"),
					'score_decrease'=>5,
					'advice'=>_("Pages without links are not good for search engines as well as visitors, making navigation at least problematic")
				)
			),
			'images'=>array(
				'category'=>'content',
				'group'=>'images',
				'human_name'=>_("Images"),
				'on'=>'dom',
				'rule'=>'//img',
				'identificator'=>'src',
				'tests_element'=>array(
					'no_alt'=>array(
						'type'=>'not_empty',
						'on'=>'alt',
						'level'=>'error',
						'message'=>_("Image does not have an ALT attribute"),
						'group_message'=>_("Your page contains images that do not have an ALT attribute"),
						'list_message'=>_("No ALT on image"),
						'score_decrease'=>5,
						'advice'=>_("Alt tag is the text placed on images that search engines read. You should describe your images with targeted keywords.")
					),
					'alt_too_long'=>array(
						'type'=>'max_length',
						'on'=>'alt',
						'level'=>'notice',
						'value'=>160,
						'message'=>_("Image TITLE too long. Maximum recommended length: 160 chars"),
						'group_message'=>_("Your page contains images that have their TITLE too long."),
						'list_message'=>_("Image TITLE too long"),
						'score_decrease'=>1
					),
					'too_many_words_in_alt'=>array(
						'type'=>'max_words',
						'on'=>'alt',
						'level'=>'notice',
						'value'=>20,
						'message'=>_("Image ALT contains too many words. Recommended: less than 20 words"),
						'group_message'=>_("Your page contains images that have too many words in their ALT"),
						'list_message'=>_("Too many words in image ALT"),
						'score_decrease'=>1
					),
					'no_keyword_in_alt'=>array(
						'type'=>'contains_keyword',
						'on'=>'node_value',
						'level'=>'warning',
						'message'=>_("Image ALT attribute does not contain the keyword"),
						'list_message'=>_("Keyword not in image ALT"),
						'requires_keyword'=>true
					)
				)
			),
			'iframes'=>array(
				'category'=>'content',
				'group'=>'other',
				'human_name'=>_("Iframes"),
				'on'=>'dom',
				'rule'=>'//iframe',
				'identificator'=>'src',
				'tests_overall'=>array(
					'max_count'=>array(
						'type'=>'max_count',
						'level'=>'warning',
						'value'=>2,
						'message'=>_("Try limiting the iframes on a page to 2 or fewer since they hurt your load times"),
						'list_message'=>_("More than 2 iframes"),
						'score_decrease'=>1,
						'advice'=>_("Limit iFrame usage since it can hurt your loading time.")
					)
				)
			),
//			'w3c'=>array(
//				'category'=>'general',
//				'group'=>'w3c',
//				'human_name'=>"W3C Validation",
//				'on'=>'url',
//				'identificator'=>'none',
//				'tests_element'=>array(
//					'invalid'=>array(
//						'type'=>'w3c_validation',
//						'on'=>'self',
//						'level'=>'error',
//						'message'=>"The page did not pass the W3C validation test",
//						'list_message'=>"W3C invalid"
//					)
//				)
//			),
			'external_js'=>array(
				'category'=>'general',
				'group'=>'js',
				'human_name'=>_("JS Files"),
				'on'=>'dom',
				'rule'=>'//script',
				'identificator'=>'href',
				'tests_overall'=>array(
					'max_count'=>array(
						'type'=>'max_count_not_empty',
						'on'=>'src',
						'level'=>'notice',
						'value'=>1,
						'message'=>_("You should combine external JS files in a single one to speed up you site"),
						'list_message'=>_("Multiple external JS")
					)
				)
			),
			'external_css'=>array(
				'category'=>'general',
				'group'=>'css',
				'human_name'=>_("CSS Files"),
				'on'=>'dom',
				'rule'=>'//link[@rel="stylesheet"]',
				'identificator'=>'href',
				'tests_overall'=>array(
					'max_count'=>array(
						'type'=>'max_count',
						'level'=>'notice',
						'value'=>1,
						'message'=>_("You should combine external CSS files in a single one to speed up you site"),
						'list_message'=>_("Multiple external CSS")
					)
				)
			),
			'load_time'=>array(
				'category'=>'general',
				'group'=>'other',
				'human_name'=>_("Load time"),
				'on'=>'other',
				'rule'=>'load_time',
				'identificator'=>'self',
				'identificator_humanizer'=>'humanLoadTime',
				'tests_element'=>array(
					'extreme'=>array(
						'type'=>'reverse_min_value',
						'on'=>'self',
						'value'=>5,
						'level'=>'error',
						'block'=>true,
						'message'=>_("Extreme page load time. Your page is taking more than 5 seconds to be crawled"),
						'list_message'=>_("Extreme load time"),
						'report_message'=>_("Extreme load time (>5 seconds)"),
						'score_decrease'=>10,
						'advice'=>_("These pages have an extreme loading time. This causes bad user experience and high bounce rates.")
					),
					'high'=>array(
						'type'=>'reverse_min_value',
						'on'=>'self',
						'value'=>2.5,
						'level'=>'warning',
						'message'=>_("High page load time. Your page is taking more than 2.5 seconds to be crawled"),
						'list_message'=>_("High load time"),
						'report_message'=>_("High load time (>2.5 seconds)"),
						'score_decrease'=>5,
						'advice'=>_("Make the web faster, check these pages and improve them for speed.")
					)
				)
			),
			'page_size'=>array(
				'category'=>'general',
				'group'=>'other',
				'human_name'=>_("Page size"),
				'on'=>'other',
				'rule'=>'size',
				'identificator'=>'self',
				'identificator_humanizer'=>'humanSize',
				'tests_element'=>array(
					'extreme_size'=>array(
						'type'=>'reverse_min_value',
						'on'=>'self',
						'value'=>153600,
						'level'=>'error',
						'block'=>true,
						'message'=>_("Extreme page size. Your page is higher than 150KB"),
						'list_message'=>_("Extreme page size"),
						'report_message'=>_("Extreme page size (>150KB)"),
						'score_decrease'=>10,
						'advice'=>_("You have pages wich have an extreme size. Make sure you minimize them for a better user experience.")
					),
					'high_size'=>array(
						'type'=>'reverse_min_value',
						'on'=>'self',
						'value'=>102400,
						'level'=>'warning',
						'message'=>_("High page size. Your page is higher than 100KB"),
						'list_message'=>_("High page size"),
						'report_message'=>_("High page size (>100KB)"),
						'score_decrease'=>5,
						'advice'=>_("Check these pages because they have a high page size. Keep them small.")
					)
				)
			),
			'thin_content'=>array(
				'category'=>'general',
				'group'=>'other',
				'human_name'=>_("Thin content"),
				'on'=>'html',
				'identificator'=>'none',
				'tests_element'=>array(
					'thin_content'=>array(
						'type'=>'external',
						'level'=>'warning',
						'message'=>_("This page has less than 200 words of textual content."),
						'list_message'=>_("Thin content"),
						'score_decrease'=>35,
						'advice'=>_("You should definetly add more text. Users and search engines consume text.")
					)
				)
			),
			'text2html'=>array(
				'category'=>'general',
				'group'=>'other',
				'human_name'=>_("Text-to-HTML ratio"),
				'on'=>'html',
				'identificator'=>'none',
				'tests_element'=>array(
					'extremely_low'=>array(
						'type'=>'external',
						'level'=>'error',
						'message'=>_("Your page has an extremely low text to html ratio. You should add more textual content."),
						'list_message'=>_("Extremely low Text-to-HTML Ratio"),
						'score_decrease'=>15,
						'advice'=>_("Make sure you add some text because people and search engines love text.")
					),
					'low'=>array(
						'type'=>'external',
						'level'=>'warning',
						'message'=>_("Your page has a low text to html ratio. You should add more textual content."),
						'list_message'=>_("Low Text-to-HTML Ratio"),
						'score_decrease'=>5,
						'advice'=>_("Make sure you add some text because people and search engines love text.")
					)
				)
			),
			'gplus_authorship'=>array(
				'category'=>'social',
				'group'=>'gplus',
				'report_section'=>'gplus',
				'report_section_human'=>_("Google+ Integration"),
				'human_name'=>_("Google+ Publisher"),
				'on'=>'html',
				'identificator'=>'none',
				'not_found'=>array(
					'type'=>'external',
					'level'=>'notice',
					'message'=>_("Google+ Authorship missing"),
					'list_message'=>_("Missing Google+ Authorship"),
					'score_decrease'=>1,
					'advice'=>_("You're missing the opportunity for rich snippets in SERPs. Set yourself up as an author or publisher on your pages.")
				)
			),
			'fb_og_image'=>array(
				'category'=>'social',
				'group'=>'facebook',
				'report_section'=>'facebook',
				'report_section_human'=>"Facebook OpenGraph",
				'human_name'=>_("Facebook OpenGraph Image"),
				'on'=>'dom',
				'rule'=>'//meta[@property="og:image"]',
				'identificator'=>'content',
				'not_found'=>array(
					'level'=>'warning',
					'message'=>_("Facebook OpenGraph Image missing"),
					'list_message'=>_("Missing Facebook og:image"),
					'score_decrease'=>1,
					'advice'=>_("Make sure you use Open Graph Protocol on your pages for better visuals in Facebook, like images, titles and snippets.")
				)
			),
			'fb_og_title'=>array(
				'category'=>'social',
				'group'=>'facebook',
				'report_section'=>'facebook',
				'report_section_human'=>"Facebook OpenGraph",
				'human_name'=>_("Facebook OpenGraph title"),
				'on'=>'dom',
				'rule'=>'//meta[@property="og:title"]',
				'identificator'=>'content',
				'not_found'=>array(
					'level'=>'notice',
					'message'=>_("Facebook OpenGraph Title missing"),
					'list_message'=>_("Missing Facebook og:title")
				)
			),
			'fb_og_url'=>array(
				'category'=>'social',
				'group'=>'facebook',
				'report_section'=>'facebook',
				'report_section_human'=>"Facebook OpenGraph",
				'human_name'=>_("Facebook OpenGraph URL"),
				'on'=>'dom',
				'rule'=>'//meta[@property="og:url"]',
				'identificator'=>'content',
				'not_found'=>array(
					'level'=>'notice',
					'message'=>_("Facebook OpenGraph URL missing"),
					'list_message'=>_("Missing Facebook og:url")
				)
			),
			'fb_og_site_name'=>array(
				'category'=>'social',
				'group'=>'facebook',
				'report_section'=>'facebook',
				'report_section_human'=>"Facebook OpenGraph",
				'human_name'=>_("Facebook OpenGraph Site Name"),
				'on'=>'dom',
				'rule'=>'//meta[@property="og:site_name"]',
				'identificator'=>'content',
				'not_found'=>array(
					'level'=>'notice',
					'message'=>_("Facebook OpenGraph Site Name missing"),
					'list_message'=>_("Missing Facebook og:site_name")
				)
			),
			'fb_og_type'=>array(
				'category'=>'social',
				'group'=>'facebook',
				'report_section'=>'facebook',
				'report_section_human'=>"Facebook OpenGraph",
				'human_name'=>_("Facebook OpenGraph Site Type"),
				'on'=>'dom',
				'rule'=>'//meta[@property="og:type"]',
				'identificator'=>'content',
				'not_found'=>array(
					'level'=>'notice',
					'message'=>_("Facebook OpenGraph Site Type missing"),
					'list_message'=>_("Missing Facebook og:type")
				)
			),
			'tw_card_type'=>array(
				'category'=>'social',
				'group'=>'twitter',
				'report_section'=>'twitter',
				'report_section_human'=>_("Twitter Card"),
				'human_name'=>_("Twitter Card Type"),
				'on'=>'dom',
				'rule'=>'//meta[@name="twitter:card"]',
				'identificator'=>'value',
				'not_found'=>array(
					'level'=>'warning',
					'message'=>_("Twitter Card Type missing"),
					'list_message'=>_("Missing Twitter twitter:card"),
					'score_decrease'=>1,
					'advice'=>_("Make sure you use Twitter Cards on your pages for better visuals in Twitter.")
				)
			),
			'tw_card_url'=>array(
				'category'=>'social',
				'group'=>'twitter',
				'report_section'=>'twitter',
				'report_section_human'=>_("Twitter Card"),
				'human_name'=>_("Twitter Card URL"),
				'on'=>'dom',
				'rule'=>'//meta[@name="twitter:url"]',
				'identificator'=>'value',
				'not_found'=>array(
					'level'=>'notice',
					'message'=>_("Twitter Card URL missing"),
					'list_message'=>_("Missing Twitter twitter:url")
				)
			),
			'tw_card_title'=>array(
				'category'=>'social',
				'group'=>'twitter',
				'report_section'=>'twitter',
				'report_section_human'=>_("Twitter Card"),
				'human_name'=>_("Twitter Card Title"),
				'on'=>'dom',
				'rule'=>'//meta[@name="twitter:title"]',
				'identificator'=>'value',
				'not_found'=>array(
					'level'=>'notice',
					'message'=>_("Twitter Card Title missing"),
					'list_message'=>_("Missing Twitter twitter:title")
				)
			),
			'tw_card_desc'=>array(
				'category'=>'social',
				'group'=>'twitter',
				'report_section'=>'twitter',
				'report_section_human'=>_("Twitter Card"),
				'human_name'=>_("Twitter Card Description"),
				'on'=>'dom',
				'rule'=>'//meta[@name="twitter:description"]',
				'identificator'=>'value',
				'not_found'=>array(
					'level'=>'notice',
					'message'=>_("Twitter Card Description missing"),
					'list_message'=>_("Missing Twitter twitter:description")
				)
			),
			'tw_card_image'=>array(
				'category'=>'social',
				'group'=>'twitter',
				'report_section'=>'twitter',
				'report_section_human'=>_("Twitter Card"),
				'human_name'=>_("Twitter Card Image"),
				'on'=>'dom',
				'rule'=>'//meta[@name="twitter:image"]',
				'identificator'=>'value',
				'not_found'=>array(
					'level'=>'notice',
					'message'=>_("Twitter Card Image missing"),
					'list_message'=>_("Missing Twitter twitter:image")
				)
			),
			'tw_card_site'=>array(
				'category'=>'social',
				'group'=>'twitter',
				'report_section'=>'twitter',
				'report_section_human'=>_("Twitter Card"),
				'human_name'=>_("Twitter Card Site"),
				'on'=>'dom',
				'rule'=>'//meta[@name="twitter:site"]',
				'identificator'=>'value',
				'not_found'=>array(
					'level'=>'warning',
					'message'=>_("Twitter Card Site missing"),
					'list_message'=>_("Missing Twitter twitter:site")
				)
			),
			'tw_card_creator'=>array(
				'category'=>'social',
				'group'=>'twitter',
				'report_section'=>'twitter',
				'report_section_human'=>_("Twitter Card"),
				'human_name'=>_("Twitter Card Creator"),
				'on'=>'dom',
				'rule'=>'//meta[@name="twitter:creator"]',
				'identificator'=>'value',
				'not_found'=>array(
					'level'=>'warning',
					'message'=>_("Twitter Card Creator missing"),
					'list_message'=>_("Missing Twitter twitter:creator")
				)
			),
		);
	}
	
	public function humanSize($size)
	{
		$osUtils=getOS()->getUtils();
		
		return $osUtils->humanizeSize($size);
	}
	
	public function humanLoadTime($load_time)
	{
		return round($load_time,2).' '._('seconds');
	}
}
?>