<?php
class OS_APP_OnPage_ReportOperations
{
	private static $_instance;
	
	public function __construct()
	{
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_OnPage_ReportOperations();
		}
		
		return self::$_instance;
	}
	
	public function getReportByID($report_id)
	{
		$result=false;
		
		$project=getOS()->getProject();
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE id=? AND project_id=?",array($report_id,$project->id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_APP_OnPage_Report();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getReports($offset=0,$count=10)
	{
		$result=false;
		
		$project=getOS()->getProject();
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE project_id=? ORDER BY `insert_dt` DESC LIMIT {$offset},{$count}";
		
		$dbresult=$db->query($query,array($project->id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneReport=new OS_APP_OnPage_Report();
			$oneReport->set($row);
			
			$result[$row['id']]=$oneReport;
		}
		
		return $result;
	}
	
	public function getReportsByTimeframe($start_dt,$end_dt)
	{
		$result=false;
		
		$project=getOS()->getProject();
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE project_id=? AND insert_dt>=? AND insert_dt<=? ORDER BY `insert_dt` DESC";
		
		$dbresult=$db->query($query,array($project->id,$start_dt,$end_dt));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneReport=new OS_APP_OnPage_Report();
			$oneReport->set($row);
			
			$result[$row['id']]=$oneReport;
		}
		
		return $result;
	}
	
	public function insertReport($report)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		
		$query="INSERT INTO ".$appHandler->dbPrefix()."reports (project_id,urls,errors,warnings,notices,insert_dt) VALUES (?,?,?,?,?,?)";
		$dbresult=$db->query($query,array($report->project_id,$report->urls,$report->errors,$report->warnings,$report->notices,$time));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateReport($report)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE id=? AND project_id=?";
		$dbresult=$db->query($query,array($report->id,$report->project_id));
		if ($report_row=$db->fetchRow($dbresult))
		{
			$query="UPDATE ".$appHandler->dbPrefix()."reports SET urls=?,errors=?,warnings=?,notices=? WHERE id=?";
			$dbresult=$db->query($query,array($report->urls,$report->errors,$report->warnings,$report->notices,$report->id));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function saveReportDetails($report)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("DELETE FROM ".$appHandler->dbPrefix()."reports_details WHERE project_id=?",array($report->project_id));
		
		foreach ($report->failed_tests as $element=>$test_types)
		{
			foreach ($test_types as $test_type=>$tests)
			{
				foreach ($tests as $test_name=>$details)
				{
					$query="INSERT INTO ".$appHandler->dbPrefix()."reports_details (project_id,element_name,test_type,test_name,pages,occurances) VALUES (?,?,?,?,?,?)";
					
					$dbresult=$db->query($query,array($report->project_id,$element,$test_type,$test_name,$details['pages'],$details['occurances']));
					
					if ($dbresult!==false)
					{
						$result=true;
					}
				}
			}
		}
		
		return $result;
	}
	
	public function getReportDetails($report)
	{
		$result=array();
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."reports_details WHERE project_id=?",array($report->project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['element_name']][$row['test_type']][$row['test_name']]=array('pages'=>$row['pages'],'occurances'=>$row['occurances']);
		}
		
		return $result;
	}
	
	public function getPages($element,$test_type,$test_name,$offset=0,$count=10)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$project=getOS()->getProject();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT ".$appHandler->dbPrefix()."pages_error_profiles.url_hash url_hash FROM ".$appHandler->dbPrefix()."error_profiles,".$appHandler->dbPrefix()."pages_error_profiles WHERE ".$appHandler->dbPrefix()."pages_error_profiles.project_id=? AND ".$appHandler->dbPrefix()."error_profiles.element=? AND ".$appHandler->dbPrefix()."error_profiles.test_type=? AND ".$appHandler->dbPrefix()."error_profiles.test_name=? AND ".$appHandler->dbPrefix()."error_profiles.error_profile_hash=".$appHandler->dbPrefix()."pages_error_profiles.error_profile_hash".(($offset==0 AND $count==0)?'':" LIMIT {$offset},{$count}");
		$dbresult=$db->query($query,array($project->id,$element,$test_type,$test_name));
		while ($row=$db->fetchRow($dbresult))
		{
			if ($page_row=$this->getBasicPageDetails($row['url_hash']))
			{
				$result[$row['url_hash']]=array(
					'url'=>$page_row['url'],
					'title'=>$page_row['title']
				);
			}
		}
		
		return $result;
	}
	
	public function getPagesCount($element,$test_type,$test_name)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$project=getOS()->getProject();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT COUNT(*) AS total_pages FROM ".$appHandler->dbPrefix()."error_profiles,".$appHandler->dbPrefix()."pages_error_profiles WHERE ".$appHandler->dbPrefix()."pages_error_profiles.project_id=? AND ".$appHandler->dbPrefix()."error_profiles.element=? AND ".$appHandler->dbPrefix()."error_profiles.test_type=? AND ".$appHandler->dbPrefix()."error_profiles.test_name=? AND ".$appHandler->dbPrefix()."error_profiles.error_profile_hash=".$appHandler->dbPrefix()."pages_error_profiles.error_profile_hash";
		$dbresult=$db->query($query,array($project->id,$element,$test_type,$test_name));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row['total_pages'];
		}
		
		return $result;
	}
	
	public function getPageDetails($url_hash)
	{
		$result=false;
		
		if ($row=$this->getBasicPageDetails($url_hash))
		{
			if (!$onpageData=$this->getPageErrorProfile($url_hash))
			{
				$onpageData=array('score'=>100,'failed_tests'=>array());
			}
			
			$result=array(
				'page_details'=>$row,
				'score'=>$onpageData['score'],
				'failed_tests'=>$onpageData['failed_tests'],
				'incoming_links'=>$this->getPageIncomingLinks($url_hash),
				'keyword_density'=>$this->getPageKeywords($url_hash),
			);
		}
		
		return $result;
	}
	
	public function getBasicPageDetails($url_hash)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$project=getOS()->getProject();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."projects_urls WHERE project_id=? AND url_hash=?",array($project->id,$url_hash));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row;
		}
		
		return $result;
	}
	
	public function getPageOnpageDetails($url_hash,$project_id=false)
	{
		$result=array();
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."pages_error_profiles WHERE project_id=? AND url_hash=?",array($project_id,$url_hash));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row;
		}
		else
		{
			$result=array('error_profile_hash'=>false,'score'=>100);
		}
		
		return $result;
	}
	
	public function getPageErrorProfileHash($url_hash,$project_id=false)
	{
		$result=array();
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$dbresult=$db->query("SELECT error_profile_hash FROM ".$appHandler->dbPrefix()."pages_error_profiles WHERE project_id=? AND url_hash=?",array($project_id,$url_hash));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row['error_profile_hash'];
		}
		
		return $result;
	}
	
	public function getPageErrorProfile($url_hash,$project_id=false)
	{
		$result=array();
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$dbresult=$db->query("SELECT error_profile_hash,score FROM ".$appHandler->dbPrefix()."pages_error_profiles WHERE project_id=? AND url_hash=?",array($project_id,$url_hash));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=array('score'=>$row['score'],'failed_tests'=>array());
			
			$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."error_profiles WHERE error_profile_hash=?",array($row['error_profile_hash']));
			while ($row=$db->fetchRow($dbresult))
			{
				$result['failed_tests'][$row['element']][$row['test_type']][$row['test_name']]=$row['id'];
			}
		}
		
		return $result;
	}
	
	public function deletePageErrorProfileLink($url_hash,$project_id=false)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		if ($error_hash=$this->getPageErrorProfileHash($url_hash,$project_id))
		{
			$dbresult=$db->query("DELETE FROM ".$appHandler->dbPrefix()."pages_error_profiles WHERE project_id=? AND url_hash=?",array($project_id,$url_hash));
			
			if ($dbresult!==false)
			{
				$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."pages_error_profiles WHERE error_profile_hash=? LIMIT 1",array($error_hash));
				
				if (!$row=$db->fetchRow($dbresult))
				{
					$dbresult=$db->query("DELETE FROM ".$appHandler->dbPrefix()."error_profiles WHERE error_profile_hash=?",array($error_hash));
				}
				
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function getErrorProfileHash($error_profile)
	{
		$result=false;
		
		$hash='';
		
		foreach ($error_profile as $element=>$test_types)
		{
			$hash.=$element;
			
			foreach ($test_types as $test_type=>$tests)
			{
				$hash.=$test_type;
				
				foreach ($tests as $test_name=>$dummy)
				{
					$hash.=$test_name;
				}
			}
		}
		
		if (!empty($hash))
		{
			$result=md5($hash);
		}
		
		return $result;
	}
	
	public function getPageIncomingLinks($url_hash,$project_id=false)
	{
		$result=array(
			'links'=>array(
				'links'=>0,
				'pages'=>array(),
				'nofollow'=>0,
				'dofollow'=>0,
				'image'=>0,
				'text'=>0,
				'anchors'=>0
			),
			'anchors'=>array()
		);
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."projects_urls_links WHERE project_id=? AND to_url_hash=?",array($project_id,$url_hash));
		while ($row=$db->fetchRow($dbresult))
		{
			$result['links']['pages'][$row['from_url_hash']]=true;
			
			$result['links']['links']+=$row['occurances'];
			if ($row['nofollow']=='Y')
			{
				$result['links']['nofollow']+=$row['occurances'];
			}
			else
			{
				$result['links']['dofollow']+=$row['occurances'];
			}
			if ($row['type']=='image')
			{
				$result['links']['image']+=$row['occurances'];
			}
			else
			{
				$result['links']['text']+=$row['occurances'];
			}
			
			if (!isset($result['anchors'][$row['anchor']]))
			{
				$result['anchors'][$row['anchor']]=array(
					'links'=>0
				);
			}
			$result['anchors'][$row['anchor']]['links']+=$row['occurances'];
		}
		
		$result['links']['pages']=count($result['links']['pages']);
		$result['links']['anchors']=count($result['anchors']);
		arsort($result['anchors']);
		
		return $result;
	}
	
	public function hasWordsFromList($text,$wordlist)
	{
		$result=false;
		
		$text=explode(' ',strtolower($text));
		
		foreach ($text as $word)
		{
			if (in_array($word,$wordlist))
			{
				$result=true;
				break;
			}
		}
		
		return $result;
	}
	
	public function getWordsInKeywords($keywords_list)
	{
		$result=false;
		
		if ($keywords_list)
		{
			$result=array();
			
			foreach ($keywords_list as $length=>$keywords)
			{
				foreach ($keywords as $keyword=>$dummy)
				{
					$keyword=explode(' ',$keyword);
					
					foreach ($keyword as $word)
					{
						$result[$word]=true;
					}
				}
			}
			
			$result=array_keys($result);
		}
		
		return $result;
	}
	
	public function getPageKeywords($url_hash,$project_id=false)
	{
		$result=array();
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."pages_keywords WHERE project_id=? AND url_hash=? ORDER BY length ASC,score DESC",array($project_id,$url_hash));
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['length']][$row['keyword']]=array(
				'id'=>$row['id'],
				'score'=>$row['score']
			);
		}
		
		return $result;
	}
	
	public function getPageKeywordsBulk($url_hash,$project_id=false)
	{
		$result=array();
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$dbresult=$db->query("SELECT keyword,score FROM ".$appHandler->dbPrefix()."pages_keywords WHERE project_id=? AND url_hash=? ORDER BY score DESC",array($project_id,$url_hash));
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['keyword']]=$row['score'];
		}
		
		return $result;
	}
	
	public function getPageKeywordScore($url_hash,$keyword,$project_id=false)
	{
		$result=0;
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$dbresult=$db->query("SELECT score FROM ".$appHandler->dbPrefix()."pages_keywords WHERE project_id=? AND url_hash=? AND keyword=?",array($project_id,$url_hash,$keyword));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row['score'];
		}
		
		return $result;
	}
	
	public function deletePageKeywords($url_hash,$project_id=false)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$dbresult=$db->query("DELETE FROM ".$appHandler->dbPrefix()."pages_keywords WHERE project_id=? AND url_hash=?",array($project_id,$url_hash));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deletePageOldKeywordDensity($old_density)
	{
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		foreach ($old_density as $length=>$keywords)
		{
			foreach ($keywords as $keyword=>$details)
			{
				$dbresult=$db->query("DELETE FROM ".$appHandler->dbPrefix()."pages_keywords WHERE id=?",array($details['id']));
			}
		}
	}
	
	public function deleteDataByProjectID($project_id)
	{
		$result=true;
		
//		$tables=array('reports','reports_details','error_profiles','pages_error_profiles','pages_keywords');
		$tables=array('reports','reports_details','pages_error_profiles','pages_keywords');
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		foreach ($tables as $table)
		{
			$dbresult=$db->query("DELETE FROM ".$appHandler->dbPrefix().$table." WHERE project_id=?",array($project_id));
			
			if ($dbresult===false)
			{
				$result=false;
				break;
			}
		}
		
		return $result;
	}
}
?>