<?php
class OS_APPVIEW_OnPage_KwAnalysis extends OS_AppViewBase
{
	public function __construct()
	{
		parent::__construct();
	}
	
	public function processRequest()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$requestParams=$appPlugin->getRequestParams();
		$processedRequest=array();
		
		if (empty($requestParams['url_hash']))
		{
			$OS->redirectTO($appPlugin->getAppActionUrl('view'),true);
		}
		
		if (!empty($requestParams['element']))
		{
			if (empty($requestParams['test_type']))
			{
				$OS->redirectTO($appPlugin->getAppActionUrl('view'),true);
			}
			
			if (empty($requestParams['test_name']))
			{
				$OS->redirectTO($appPlugin->getAppActionUrl('view'),true);
			}
			
			$processedRequest['back_url_details']=array(
				'url_hash'=>$requestParams['url_hash'],
				'element'=>$requestParams['element'],
				'test_type'=>$requestParams['test_type'],
				'test_name'=>$requestParams['test_name']
			);
		}
		else
		{
			$processedRequest['back_url_details']=array('url_hash'=>$requestParams['url_hash']);
		}
		
		$ops=OS_APP_OnPage_ReportOperations::get_instance();
		
		if (!$processedRequest['page_details']=$ops->getBasicPageDetails($requestParams['url_hash']))
		{
			$OS->redirectTO($appPlugin->getAppActionUrl('pagelist',array('element'=>$requestParams['element'],'test_type'=>$requestParams['test_type'],'test_name'=>$requestParams['test_name'])),true);
		}
		
		$processedRequest['hasResults']=false;
		
		if ($_SERVER['REQUEST_METHOD']=='POST')
		{
			if (empty($requestParams['keyword_box']))
			{
				$requestParams['keyword_box']='';
				
				$OS->addFieldError(_("Keyword missing"),'keyword');
			}
			else
			{
				$requestParams['keyword_box']=trim($requestParams['keyword_box']);
				
				if (empty($requestParams['keyword_box']))
				{
					$OS->addFieldError(_("Keyword missing"),'keyword');
				}
				elseif (strlen($requestParams['keyword_box'])<3)
				{
					$OS->addFieldError(_("Keyword too short. Minimum length: 3 chars"),'keyword');
				}
			}
			
			$processedRequest['keyword_box']=$requestParams['keyword_box'];
			
			if (!isset($OS->errorMessages))
			{
				$osHttp=$OS->getHttp();
				
				$response=$osHttp->get($processedRequest['page_details']['url']);
				
				if (!empty($response) AND $osHttp->success())
				{
					$dom=new DOMDocument();
					
					libxml_use_internal_errors(true);
					$domLoaded=$dom->loadHTML($response);
					libxml_use_internal_errors(false);
					
					if ($domLoaded)
					{
						$analyzer=OS_APP_OnPage_Analyzer::get_instance();
						
						$processedRequest['hasResults']=true;
						$analysis=$analyzer->analyze($processedRequest['page_details']['url'],$dom,$response,array(),$requestParams['keyword_box'],true);
						$processedRequest['failed_tests']=$analysis['failed_tests'];
						$processedRequest['score']=$analysis['score'];
					}
					else
					{
						$OS->addFieldError(_("Unable to fetch page. Try again later"));
					}
				}
				else
				{
					$OS->addFieldError(_("Unable to fetch page. Try again later"));
				}
			}
		}
		else
		{
			$processedRequest['keyword_box']='';
		}
		
		return $processedRequest;
	}
	
	public function render()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		$osUtils=$OS->getUtils();
		
		$page_details=$this->processedRequest['page_details'];
		
		$tplVars=array(
			'hasResults'=>$this->processedRequest['hasResults'],
			'keyword_box'=>$this->processedRequest['keyword_box'],
			'url'=>$this->processedRequest['page_details']['url'],
			'url_safe'=>$osUtils->getSafeURL($this->processedRequest['page_details']['url']),
			'canonical_url'=>$page_details['page_details']['canonical_url'],
			'canonical_url_safe'=>(empty($page_details['page_details']['canonical_url'])?false:$osUtils->getSafeURL($page_details['page_details']['canonical_url'])),
			'title'=>$this->processedRequest['page_details']['title'],
			'description'=>$this->processedRequest['page_details']['description'],
			'messages'=>array(),
			'form_url'=>$appPlugin->getAppUrl(),
			'form_hiddens'=>$this->processedRequest['back_url_details']
		);
		
		$appPlugin->setMenuBackLink(array_merge(array('back_view'=>'page'),$this->processedRequest['back_url_details']));
		
		if ($this->processedRequest['hasResults'])
		{
			$failed_tests=$this->processedRequest['failed_tests'];
			$status_importance=array('ok'=>0,'notice'=>1,'warning'=>2,'error'=>3);
			$status_visuals=array(
				'ok'=>array('color'=>'green','icon'=>'c','message'=>_("OK")),
				'notice'=>array('color'=>'blue','icon'=>'i','message'=>_("Minor problems found")),
				'warning'=>array('color'=>'yellow','icon'=>'!','message'=>_("Medium importance problems found, take a minute to evaluate")),
				'error'=>array('color'=>'red','icon'=>'X','message'=>_("Severe problems found, urgent attention required"))
			);
	
			$analyzer=OS_APP_OnPage_Analyzer::get_instance();
			$analyzer_rules=$analyzer->getRules();
			$analyzer_rulesCategories=$analyzer->getRulesCategories();
			
			foreach ($analyzer_rules as $element=>$element_details)
			{
				$can_show=false;
				
				$message=array(
					'title'=>$element_details['human_name'],
					'status_level'=>'ok',
					'messages'=>array()
				);
				
				if (!empty($element_details['not_found']) AND !empty($element_details['not_found']['available_keyword_only']))
				{
					$can_show=true;
					
					if (isset($failed_tests[$element]['overall']['not_found']))
					{
						$message['messages']['overall'][]=array(
							'message'=>$element_details['not_found']['message'],
							'color'=>$status_visuals[$element_details['not_found']['level']]['color'],
							'icon'=>$status_visuals[$element_details['not_found']['level']]['icon']
						);
						
						$message['status_level']=($status_importance[$element_details['not_found']['level']]>$status_importance[$message['status_level']]?$element_details['not_found']['level']:$message['status_level']);
					}
				}
				
				if (!isset($failed_tests[$element]['overall']['not_found']))
				{
					if (!empty($element_details['tests_overall']))
					{
						foreach ($element_details['tests_overall'] as $test_name=>$test_details)
						{
							if (isset($failed_tests[$element]['overall'][$test_name]))
							{
								$message['messages']['overall'][$test_name]=array(
									'message'=>$test_details['message'],
									'color'=>$status_visuals[$test_details['level']]['color'],
									'icon'=>$status_visuals[$test_details['level']]['icon']
								);
								
								$message['status_level']=($status_importance[$test_details['level']]>$status_importance[$message['status_level']]?$test_details['level']:$message['status_level']);
							}
						}
					}
					
					if (!empty($element_details['tests_element']))
					{
						foreach ($element_details['tests_element'] as $test_name=>$test_details)
						{
							if (!empty($test_details['requires_keyword']))
							{
								$can_show=true;
							}
							
							if (isset($failed_tests[$element]['element']))
							{
								foreach ($failed_tests[$element]['element'] as $elem_id=>$elem_tests)
								{
									if (isset($elem_tests[$test_name]))
									{
										$message['messages']['element'][$elem_id][$test_name]=array(
											'message'=>$test_details['message'],
											'color'=>$status_visuals[$test_details['level']]['color'],
											'icon'=>$status_visuals[$test_details['level']]['icon']
										);
										
										$message['status_level']=($status_importance[$test_details['level']]>$status_importance[$message['status_level']]?$test_details['level']:$message['status_level']);
									}
								}
							}
						}
					}
				}
				
				if ($can_show)
				{
					$message['status_visuals']=$status_visuals[$message['status_level']];
					
					if (empty($tplVars['messages'][$element_details['category']]))
					{
						$tplVars['messages'][$element_details['category']]=array(
							'title'=>$analyzer_rulesCategories[$element_details['category']]['title'],
							'status_level'=>$message['status_level'],
							'groups'=>array()
						);
					}
					else
					{
						$tplVars['messages'][$element_details['category']]['status_level']=($status_importance[$message['status_level']]>$status_importance[$tplVars['messages'][$element_details['category']]['status_level']]?$message['status_level']:$tplVars['messages'][$element_details['category']]['status_level']);
					}
					
					if (empty($tplVars['messages'][$element_details['category']]['groups'][$element_details['group']]))
					{
						$tplVars['messages'][$element_details['category']]['groups'][$element_details['group']]=array(
							'title'=>$analyzer_rulesCategories[$element_details['category']]['groups'][$element_details['group']]['title'],
							'help_url'=>$analyzer_rulesCategories[$element_details['category']]['groups'][$element_details['group']]['help_url'],
							'status_level'=>$message['status_level'],
							'elements'=>array()
						);
					}
					else
					{
						$tplVars['messages'][$element_details['category']]['groups'][$element_details['group']]['status_level']=($status_importance[$message['status_level']]>$status_importance[$tplVars['messages'][$element_details['category']]['groups'][$element_details['group']]['status_level']]?$message['status_level']:$tplVars['messages'][$element_details['category']]['groups'][$element_details['group']]['status_level']);
					}
					
					$tplVars['messages'][$element_details['category']]['groups'][$element_details['group']]['elements'][$element]=$message;
				}
			}
		}
		
		foreach ($tplVars['messages'] as $category=>$category_details)
		{
			foreach ($category_details['groups'] as $group=>$group_details)
			{
				$tplVars['messages'][$category]['groups'][$group]['status_visuals']=$status_visuals[$group_details['status_level']];
			}
			
			$tplVars['messages'][$category]['status_visuals']=$status_visuals[$category_details['status_level']];
		}
		
		$tpl=$OS->getTemplate();
		
		return $tpl->fetchTemplate('kwanalysis',$tplVars);
	}
}
?>