<?php
class OS_APPVIEW_OnPage_Page extends OS_AppViewBase
{
	public function __construct()
	{
		parent::__construct();
	}
	
	public function processRequest()
	{
		$OS=getOS();
		$osProject=$OS->getProject();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$requestParams=$appPlugin->getRequestParams();
		$processedRequest=array();
		
		if (empty($requestParams['url_hash']))
		{
			$OS->redirectTO($appPlugin->getAppActionUrl('view'),true);
		}
		
		$page=(empty($requestParams['page'])?1:$requestParams['page']);
		
		if (!empty($requestParams['element']))
		{
			if (empty($requestParams['test_type']))
			{
				$OS->redirectTO($appPlugin->getAppActionUrl('view'),true);
			}
			
			if (empty($requestParams['test_name']))
			{
				$OS->redirectTO($appPlugin->getAppActionUrl('view'),true);
			}
			
			$processedRequest['test_details']=array(
				'element'=>$requestParams['element'],
				'test_type'=>$requestParams['test_type'],
				'test_name'=>$requestParams['test_name'],
				'page'=>$page
			);
			
			$processedRequest['previous_view']='pagelist';
		}
		else
		{
			$processedRequest['test_details']=array('page'=>$page);
			$processedRequest['previous_view']='urls';
		}
		
		$ops=OS_APP_OnPage_ReportOperations::get_instance();
		
		if (!$processedRequest['page_details']=$ops->getPageDetails($requestParams['url_hash']))
		{
			$OS->redirectTO($appPlugin->getAppActionUrl($processedRequest['previous_view'],$processedRequest['test_details']),true);
		}
		
		$processedRequest['currentTab']='tests';
		
		if (!empty($requestParams['op']))
		{
			if ($requestParams['op']=='extract_keywords' OR $requestParams['op']=='analyze_anchors')
			{
				$processedRequest['currentTab']=($requestParams['op']=='extract_keywords'?'kwdensity':'linkdistrib');
				
				if ($worker=OS_Interactions::getInteractions('worker','extract_keywords_url'))
				{
					$worker=reset($worker);
					
					$keywords=OS_Interactions::performInteraction($worker['id'],array('url'=>$processedRequest['page_details']['page_details']['url'],'words_min'=>1,'words_max'=>3,'stop_words_list'=>$osProject->language,'conditionValue'=>40,'conditionType'=>'score'));
					if ($keywords!==false)
					{
						$db=$OS->getDb();
						
						foreach ($keywords as $length=>$kws)
						{
							if ($kws)
							{
								foreach ($kws as $keyword=>$score)
								{
									if (!isset($processedRequest['page_details']['keyword_density'][$length][$keyword]))
									{
										$dbresult=$db->query("INSERT INTO ".$appPlugin->dbPrefix()."pages_keywords (project_id,url_hash,length,keyword,score) VALUES (?,?,?,?,?)",array($osProject->id,$requestParams['url_hash'],$length,$keyword,$score));
									}
									else
									{
										$old_kwdensity=$processedRequest['page_details']['keyword_density'][$length][$keyword];
										
										if ($old_kwdensity['score']!=$score)
										{
											$dbresult=$db->query("UPDATE ".$appPlugin->dbPrefix()."pages_keywords SET score=? WHERE id=?",array($score,$old_kwdensity['id']));
										}
										
										unset($processedRequest['page_details']['keyword_density'][$length][$keyword]);
									}
								}
							}
						}
						
						if (!empty($processedRequest['page_details']['keyword_density']))
						{
							$ops->deletePageOldKeywordDensity($processedRequest['page_details']['keyword_density']);
						}
						
						$processedRequest['page_details']['keyword_density']=$ops->getPageKeywords($requestParams['url_hash']);
					}
				}
			}
		}
		
		$processedRequest['anchor_analysis']=false;
		if (!empty($processedRequest['page_details']['keyword_density']) AND !empty($processedRequest['page_details']['incoming_links']['anchors']))
		{
			if ($words=$ops->getWordsInKeywords($processedRequest['page_details']['keyword_density']))
			{
				$processedRequest['anchor_analysis']=true;
				
				foreach ($processedRequest['page_details']['incoming_links']['anchors'] as $anchor=>$anchor_details)
				{
					$processedRequest['page_details']['incoming_links']['anchors'][$anchor]['anchor_ok']=$ops->hasWordsFromList($anchor,$words);
				}
			}
		}
		
		return $processedRequest;
	}
	
	public function render()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		$osUtils=$OS->getUtils();
		$osCharts=$OS->getCharts();
		
		$page_details=$this->processedRequest['page_details'];
		
		$tplVars=array(
			'url'=>$page_details['page_details']['url'],
			'url_safe'=>$osUtils->getSafeURL($page_details['page_details']['url']),
			'canonical_url'=>$page_details['page_details']['canonical_url'],
			'canonical_url_safe'=>(empty($page_details['page_details']['canonical_url'])?false:$osUtils->getSafeURL($page_details['page_details']['canonical_url'])),
			'title'=>$page_details['page_details']['title'],
			'description'=>$page_details['page_details']['description'],
			'score'=>$page_details['score'],
			'messages'=>array(),
			'incoming_links'=>$page_details['incoming_links'],
			'kwdensity'=>$page_details['keyword_density'],
			'kwanalysis_url'=>$appPlugin->getAppActionUrl('kwanalysis',array_merge(array('url_hash'=>$page_details['page_details']['url_hash']),$this->processedRequest['test_details'])),
			'pagedetailed_url'=>$appPlugin->getAppActionUrl('pagedetailed',array_merge(array('url_hash'=>$page_details['page_details']['url_hash']),$this->processedRequest['test_details'])),
		);
		
		$appPlugin->setMenuBackLink(array_merge(array('back_view'=>$this->processedRequest['previous_view']),$this->processedRequest['test_details']));
		
		$headContents=array(
			'css'=>array('onpage_page'=>$appPlugin->getAppHomeUrl()."/resources/page.css")
		);
		
		//link distribution
		$total_internal=$page_details['page_details']['links_internal_nofollow']+$page_details['page_details']['links_internal_dofollow'];
		$total_external=$page_details['page_details']['links_external_nofollow']+$page_details['page_details']['links_external_dofollow'];
		
		if ($total_internal>0 OR $total_external>0)
		{
			$chartOptions = array(
				'radius' => 50,
				'values' => array($total_internal, $total_external),
				'legend' => array(_('Internal').' ('.$total_internal.')',_('External').' ('.$total_external.')'),
				'legend_position'=>'right',
				'colors' => array('#a1c132','#C13A32')
			);
				
			$chartData = $osCharts->getPieChart($chartOptions);
			
			$tplVars['link_distribution']['internal_vs_external']=$chartData['html'];
			
			$headContents=array_merge($headContents,$chartData['js']);
		}
		else
		{
			$tplVars['link_distribution']['internal_vs_external']=false;
		}
		
		if ($total_external>0)
		{
			$chartOptions = array(
				'radius' => 50,
				'values' => array($page_details['page_details']['links_external_nofollow'], $page_details['page_details']['links_external_dofollow']),
				'legend' => array('Nofollow ('.$page_details['page_details']['links_external_nofollow'].')','Dofollow ('.$page_details['page_details']['links_external_dofollow'].')'),
				'legend_position'=>'right',
				'colors' => array('#a1c132','#C13A32')
			);
				
			$chartData = $osCharts->getPieChart($chartOptions);
			
			$tplVars['link_distribution']['external_nofollow_vs_dofollow']=$chartData['html'];
			
			$headContents=array_merge($headContents,$chartData['js']);
		}
		else
		{
			$tplVars['link_distribution']['external_nofollow_vs_dofollow']=false;
		}
		
		//test results
		$failed_tests=$page_details['failed_tests'];
		$status_importance=array('ok'=>0,'notice'=>1,'warning'=>2,'error'=>3);
		$status_visuals=array(
			'ok'=>array('color'=>'green','icon'=>'c','message'=>_("OK")),
			'notice'=>array('color'=>'blue','icon'=>'i','message'=>_("Minor problems found")),
			'warning'=>array('color'=>'yellow','icon'=>'!','message'=>_("Medium importance problems found, take a minute to evaluate")),
			'error'=>array('color'=>'red','icon'=>'X','message'=>_("Severe problems found, urgent attention required"))
		);

		$analyzer=OS_APP_OnPage_Analyzer::get_instance();
		$analyzer_rules=$analyzer->getRules();
		$analyzer_rulesCategories=$analyzer->getRulesCategories();
		
		foreach ($analyzer_rules as $element=>$element_details)
		{
			if (empty($element_details['requires_keyword']))
			{
				$message=array(
					'title'=>$element_details['human_name'],
					'status_level'=>'ok',
					'messages'=>array()
				);
				
				if (!empty($element_details['not_found']) AND isset($failed_tests[$element]['overall']['not_found']))
				{
					$message['messages'][]=array(
						'message'=>$element_details['not_found']['message'],
						'color'=>$status_visuals[$element_details['not_found']['level']]['color'],
						'icon'=>$status_visuals[$element_details['not_found']['level']]['icon']
					);
					
					$message['status_level']=($status_importance[$element_details['not_found']['level']]>$status_importance[$message['status_level']]?$element_details['not_found']['level']:$message['status_level']);
				}
				else
				{
					if (!empty($element_details['tests_overall']))
					{
						foreach ($element_details['tests_overall'] as $test_name=>$test_details)
						{
							if (isset($failed_tests[$element]['overall'][$test_name]))
							{
								if ($element=='links' AND $test_name=='max_count')
								{
									$actual_message="There are ".($total_internal+$total_external)." links on this page. Try to keep the maximum number of links per page below 100.";
								}
								else
								{
									$actual_message=$test_details['message'];
								}
								
								$message['messages'][]=array(
									'message'=>$actual_message,
									'color'=>$status_visuals[$test_details['level']]['color'],
									'icon'=>$status_visuals[$test_details['level']]['icon']
								);
								
								$message['status_level']=($status_importance[$test_details['level']]>$status_importance[$message['status_level']]?$test_details['level']:$message['status_level']);
							}
						}
					}
					
					if (!empty($element_details['tests_element']))
					{
						foreach ($element_details['tests_element'] as $test_name=>$test_details)
						{
							if (isset($failed_tests[$element]['element'][$test_name]))
							{
								$message['messages'][]=array(
									'message'=>(empty($test_details['group_message'])?$test_details['message']:$test_details['group_message']),
									'analyze_url'=>(empty($test_details['group_message'])?false:$tplVars['pagedetailed_url']),
									'color'=>$status_visuals[$test_details['level']]['color'],
									'icon'=>$status_visuals[$test_details['level']]['icon']
								);
								
								$message['status_level']=($status_importance[$test_details['level']]>$status_importance[$message['status_level']]?$test_details['level']:$message['status_level']);
							}
						}
					}
				}
				
				$message['status_visuals']=$status_visuals[$message['status_level']];
				
				if (empty($tplVars['messages'][$element_details['category']]))
				{
					$tplVars['messages'][$element_details['category']]=array(
						'title'=>$analyzer_rulesCategories[$element_details['category']]['title'],
						'status_level'=>$message['status_level'],
						'groups'=>array()
					);
				}
				else
				{
					$tplVars['messages'][$element_details['category']]['status_level']=($status_importance[$message['status_level']]>$status_importance[$tplVars['messages'][$element_details['category']]['status_level']]?$message['status_level']:$tplVars['messages'][$element_details['category']]['status_level']);
				}
				
				if (empty($tplVars['messages'][$element_details['category']]['groups'][$element_details['group']]))
				{
					$tplVars['messages'][$element_details['category']]['groups'][$element_details['group']]=array(
						'title'=>$analyzer_rulesCategories[$element_details['category']]['groups'][$element_details['group']]['title'],
						'help_url'=>$analyzer_rulesCategories[$element_details['category']]['groups'][$element_details['group']]['help_url'],
						'status_level'=>$message['status_level'],
						'elements'=>array()
					);
				}
				else
				{
					$tplVars['messages'][$element_details['category']]['groups'][$element_details['group']]['status_level']=($status_importance[$message['status_level']]>$status_importance[$tplVars['messages'][$element_details['category']]['groups'][$element_details['group']]['status_level']]?$message['status_level']:$tplVars['messages'][$element_details['category']]['groups'][$element_details['group']]['status_level']);
				}
				
				$tplVars['messages'][$element_details['category']]['groups'][$element_details['group']]['elements'][$element]=$message;
			}
		}
		
		foreach ($tplVars['messages'] as $category=>$category_details)
		{
			foreach ($category_details['groups'] as $group=>$group_details)
			{
				$tplVars['messages'][$category]['groups'][$group]['status_visuals']=$status_visuals[$group_details['status_level']];
			}
			
			$tplVars['messages'][$category]['status_visuals']=$status_visuals[$category_details['status_level']];
		}
		
		$tplVars['currentTab']=$this->processedRequest['currentTab'];
		$tplVars['extractKeywordsURL']=$appPlugin->getAppActionUrl('page',array_merge($appPlugin->getRequestParams(),array('op'=>'extract_keywords')));
		if (!$this->processedRequest['anchor_analysis'])
		{
			$tplVars['analyzeAnchorsURL']=$appPlugin->getAppActionUrl('page',array_merge($appPlugin->getRequestParams(),array('op'=>'analyze_anchors')));
		}
		else
		{
			$tplVars['analyzeAnchorsURL']=false;
		}
		
		$tpl=$OS->getTemplate();
		
		$tpl->setHeadContents($headContents);
		
		return $tpl->fetchTemplate('page',$tplVars);
	}
}
?>