<?php
class OS_APPVIEW_OnPage_ReportUrls extends OS_AppViewBase
{
	public function __construct()
	{
		parent::__construct();
	}
	
	public function buildViewData()
	{
		$OS=getOS();
		
		$project=$OS->getProject();
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		$ops=OS_APP_Onpage_ReportOperations::get_instance();
		
		$viewDataVars=array();
		
		if ($report=$ops->getReports(0,1))
		{
			$report=reset($report);
			
			$report->getDetails();
			
			$analyzer=OS_APP_OnPage_Analyzer::get_instance();
			$analyzer_rules=$analyzer->getRules();
			
			$osUtils=$OS->getUtils();
			
			if ($report->failed_tests)
			{
				$failed_tests=$report->failed_tests;
				
				$reportData=array(
					'filename'=>'onpage_seo_audit_problematic_urls.pdf',
					'title'=>_('OnPage SEO Audit - Problematic URLs'),
					'sections'=>array()
				);
				
				$status_importance=array('ok'=>0,'notice'=>1,'warning'=>2,'error'=>3);
				$status_colors=array(
					'ok'=>'#27ae60',
					'notice'=>'#3498db',
					'warning'=>'#f1c40f',
					'error'=>'#C13A32'
				);
				
				$sections=array(
					'error'=>array(),
					'warning'=>array(),
					'notice'=>array()
				);
				
				$appHomeUrl=$appPlugin->getAppHomeUrl();
				$appHomePath=$appPlugin->getAppHomePath();
				
				foreach ($analyzer_rules as $element=>$element_details)
				{
					$icon_file=(empty($element_details['report_section'])?$element:$element_details['report_section']).".png";
					$icon_path=os_join_path($appHomePath,'resources','images','report',$icon_file);
					if (file_exists($icon_path))
					{
						$icon="{$appHomeUrl}/resources/images/report/{$icon_file}";
					}
					else
					{
						$icon=false;
					}
					
					if (!empty($element_details['not_found']) AND isset($failed_tests[$element]['overall']['not_found']))
					{
						$title=(empty($element_details['not_found']['report_message'])?$element_details['not_found']['list_message']:$element_details['not_found']['report_message']);
						
						if ($pages=$ops->getPages($element,'overall','not_found',0,0))
						{
							$pages_bulk='';
							$pages_count=count($pages);
							
							foreach ($pages as $page)
							{
								$pages_bulk.=(empty($pages_bulk)?'':"\n").$page['url'];
							}
							
							$reportData['sections'][$element.'_overall_not_found']=array(
								'title'=>"{$title} ({$pages_count} ".($pages_count==1?_('page'):_('pages')).')',
								'icon'=>$icon,
								'type'=>"bulk_text",
								'text'=>$pages_bulk
							);
						}
					}
					
					if (!empty($element_details['tests_overall']))
					{
						foreach ($element_details['tests_overall'] as $test_name=>$test_details)
						{
							if (isset($failed_tests[$element]['overall'][$test_name]))
							{
								$title=(empty($test_details['report_message'])?$test_details['list_message']:$test_details['report_message']);
								
								if ($pages=$ops->getPages($element,'overall',$test_name,0,0))
								{
									$pages_bulk='';
									$pages_count=count($pages);
									
									foreach ($pages as $page)
									{
										$pages_bulk.=(empty($pages_bulk)?'':"\n").$page['url'];
									}
									
									$reportData['sections'][$element.'_overall_'.$test_name]=array(
										'title'=>"{$title} ({$pages_count} ".($pages_count==1?_('page'):_('pages')).')',
										'icon'=>$icon,
										'type'=>"bulk_text",
										'text'=>$pages_bulk
									);
								}
							}
						}
					}
					
					if (!empty($element_details['tests_element']))
					{
						foreach ($element_details['tests_element'] as $test_name=>$test_details)
						{
							if (isset($failed_tests[$element]['element'][$test_name]))
							{
								$title=(empty($test_details['report_message'])?$test_details['list_message']:$test_details['report_message']);
								
								if ($pages=$ops->getPages($element,'element',$test_name,0,0))
								{
									$pages_bulk='';
									$pages_count=count($pages);
									
									foreach ($pages as $page)
									{
										$pages_bulk.=(empty($pages_bulk)?'':"\n").$page['url'];
									}
									
									$reportData['sections'][$element.'_element_'.$test_name]=array(
										'title'=>"{$title} ({$pages_count} ".($pages_count==1?_('page'):_('pages')).')',
										'icon'=>$icon,
										'type'=>"bulk_text",
										'text'=>$pages_bulk
									);
								}
							}
						}
					}
				}
				
				if (empty($reportData['sections']))
				{
					$reportData=false;
				}
				
				$viewDataVars['report']=$reportData;
			}
			else
			{
				$viewDataVars['report']=false;
			}
		}
		else
		{
			$viewDataVars['report']=false;
		}
		
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS=getOS();
		
		$viewData=$this->buildViewData();
		
		if ($viewData['report'])
		{
			$osReport=$OS->getReport();
			
			$osReport->generateReport($viewData['report']);
		}
		else
		{
			return $OS->getTemplate()->fetchTemplate('report');
		}
	}
}
?>