<?php 

class OS_APP_organicimages extends OS_AppBase
{
	private static $_instance;
	
	protected function __construct()
	{
		parent::__construct();
		
		$this->addMenuItem('view', array("name" => _("Image Traffic Analysis"), 'routerOption'=> "handleMainView"));
		$this->addMenuItem('pageview', array("name" => _("PageView"), 'parent' => 'view','routerOption'=> "handlePageView", "show_in_menu" => false));
		$this->addMenuItem('seoview', array("name" => _("SEO for Images"), 'routerOption'=> "handleSeoView"));
		$this->addMenuItem('problemview', array("name" => _("Problem Details"), 'parent' => 'seoview', 'routerOption'=> "handleProblemView", "show_in_menu" => false));
		$this->addMenuItem('imageview', array("name" => _("Image Details"), 'parent' => 'seoview', 'routerOption'=> "handleImageView", "show_in_menu" => false));
		$this->addMenuItem('groupview', array("name" => _("Group Details"), 'parent' => 'seoview', 'routerOption'=> "handleGroupView", "show_in_menu" => false));
		$this->addMenuItem('crawl_now', array("name" => _("Analyze now"), 'routerOption'=> "handleCrawlNowView"));
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_organicimages();
		}
		return self::$_instance;
	}	
	
	public function handleMainView()
	{
		require $this->getAppHomePath()."/views/mainview.php";
		$viewData = new OS_APP_organicimages_mainView();
		
		return $viewData->render();
	}
	
	public function handlePageView()
	{
		require $this->getAppHomePath()."/views/pageview.php";
		$viewData = new OS_APP_organicimages_pageView();
		
		return $viewData->render();
	}
	
	public function handleSeoView()
	{
		require $this->getAppHomePath()."/views/seoview.php";
		$viewData = new OS_APP_organicimages_seoView();
		
		return $viewData->render();
	}
	
	public function handleCrawlNowView()
	{
		require $this->getAppHomePath()."/views/crawlnow.php";
		$viewData = new OS_APP_OrganicImages_CrawlNow();
		
		return $viewData->render();
	}
	
	public function handleImageView()
	{
		require $this->getAppHomePath()."/views/imageview.php";
		$viewData = new OS_APP_OrganicImages_ImageView();
		
		return $viewData->render();
	}
	
	public function handleProblemView()
	{
		require $this->getAppHomePath()."/views/problemview.php";
		$viewData = new OS_APP_OrganicImages_ProblemView();
		
		return $viewData->render();
	}
	
	public function handleGroupView()
	{
		require $this->getAppHomePath()."/views/groupview.php";
		$viewData = new OS_APP_OrganicImages_GroupView();
		
		return $viewData->render();
	}
	
	protected function defineAppPermissions()
	{
		$this->appPermissions=array(
			'organicimages'=>array(
				'view'=>array('name'=>_("View OrganicImages Details")),
			)
		);
	}
	
	public function trackEvent($eventDetails)
	{
		$OS = getOS();
		$osUtils = $OS->getUtils();
		
		$fpath = os_join_path($OS->getConfigVar('cache_path'), 'tmp', 'trk_endpoint.log');
		$osUtils->fileWrite($fpath, var_export($eventDetails, true)."\n");
		
		$organicImagesTracker = new OS_APP_organicimages_Tracker_Actions();
		$organicImagesTracker->setRequest($eventDetails);
		$organicImagesTracker->handle();
		
		return false;	
	}
	
	public function eventProjectPageCrawled($params)
	{
		$result = false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();
		
		if ($appOps->isProjectApp($params['project_id'], $this->getAppDetail('app_id')))
		{
			$params['http_code']=(string)$params['http_code'];
			$ok_http_code = in_array($params['http_code'][0],array(1,2));
			
			$allowedContentType = (in_array($params['content_type'],array('text/html','text/plain')));
			
			if ($allowedContentType AND !empty($params['content']) AND $ok_http_code)
			{
				$appAnalyzer = OS_APP_OrganicImages_Analyzer::get_instance();
				
				$appAnalyzer->setProjectId($params['project_id']);
				$messages = $appAnalyzer->examinePageContent($params['url'], $params['dom'], $params['content']);
				$sqlData = $appAnalyzer->buildPageSQLReport($messages);
				$appAnalyzer->handleSqlData($sqlData);
				
				$result = true;
			}
		}
		
		return $result;
	}

	public function eventProjectCrawlEnd($params)
	{
		$result = false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();
		
		if ($appOps->isProjectApp($params['project_id'], $this->getAppDetail('app_id')))
		{
			$appAnalyzer = OS_APP_OrganicImages_Analyzer::get_instance();
			$appAnalyzer->setProjectId($params['project_id']);
			$result = $appAnalyzer->handleFinalReport();
		}
		
		return $result;
	}
	
	public function eventProjectDeleted($params)
	{
	}
}
?>