<?php 
class OS_APP_organicimages_Analyzer
{
	private static $_instance;
	
	private $appHandler;
	
	private $projectId;
	
	private $organicImagesTests;
	
	private $availableImageExts;
	
	private $osUtils;

	public function __construct() 
	{
		$this->appHandler = getOS()->getAppHandler('organicimages');
		
		$this->organicImagesTests = OS_APP_organicimages_Tests::get_instance();
		
		$this->osUtils = getOS()->getUtils();

		$this->availableImageExts = array('jpg','png','gif','ico','bmp','svg');
	}

	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_organicimages_Analyzer();
		}
		return self::$_instance;
	}
	
	public function examinePage($page_url)
	{
		$result = array();
		
		$currentPageUrl = $page_url;
		
		$pageDom = $this->getPageDOM($page_url);
		
		if($pageDom)
		{
			$pageContent = "";
			$result = $this->examinePageContent($page_url, $pageDom, $pageContent);
		}
		
		return $result;
	}
	
	public function examinePageContent($pageUrl, $pageDOM, $pageContent)
	{
		$result = false;
		
		if(!empty($pageDOM))
		{
			$pageTitle = $this->getPageTitle($pageDOM);
			$pageTitleKeywords = $this->getPageTitleKeywords($pageTitle);
			
			//add page url, page_url_hash, page_title
			$seoImageTests =  array(
				'page_url' => $pageUrl,
				'page_url_hash' => md5($pageUrl),
				'page_title' => $pageTitle
				);
				
			$imagesData = $this->extractImages($pageDOM);
			
			if(!empty($imagesData))
			{
				foreach($imagesData as $imageDetails)
				{
					if(!empty($imageDetails['image_url']))
					{
						$abs_image_url = md5($this->osUtils->makeAbsoluteUrl($pageUrl, $imageDetails['image_url']));
						$seoImageTests['images'][$abs_image_url] = $this->handleImageDetails($imageDetails, $pageTitleKeywords, $pageDOM, $pageUrl);
					}
				}
			}
			
			//calculate total tests by group and by type
			if(!empty($seoImageTests['images']))
			{
				foreach($seoImageTests['images'] as $details)
				{
					foreach($details['tests_type'] as $type => $total)
					{
						if(!isset($seoImageTests['total_tests_type'][$type])) $seoImageTests['total_tests_type'][$type] = 0;
	
						$seoImageTests['total_tests_type'][$type] += $total;
					}
					
					foreach($details['tests_attribute'] as $type => $total)
					{
						if(!isset($seoImageTests['total_tests_attribute'][$type])) $seoImageTests['total_tests_attribute'][$type] = 0;
	
						$seoImageTests['total_tests_attribute'][$type] += $total;
					}
				}
			}	
				
			$result = $seoImageTests;		
		}
		
		return $result;
	}

	public function buildPageSQLReport($seoImageTests)
	{
		
		$sqlData = array();
		if(isset($seoImageTests['page_url_hash'], $seoImageTests['images']))
		{
			$prevPageReport = $this->getPrevPageReport($seoImageTests['page_url_hash']);
			
			foreach($seoImageTests['images'] as $image_url_hash => $imageDetails)
			{
				$imageData = array(
					'imageDetails' => $imageDetails,
					'page_url' => $seoImageTests['page_url'],
					'page_url_hash' => $seoImageTests['page_url_hash'],
					'page_title' => $seoImageTests['page_title']
					); 
				
				if(!isset($prevPageReport[$image_url_hash]))
				{
					$tmpSqlData = $this->handleNewImage($imageData);
					$sqlData = array_merge_recursive($sqlData, $tmpSqlData);	
				}
				else
				{
					$imageData['prevPageReport'] = $prevPageReport[$image_url_hash];
					
					$tmpSqlData = $this->handleOldImage($imageData);
					$sqlData = array_merge_recursive($sqlData, $tmpSqlData);
				}
			}
	
			//detect deleted images
			$deletedImagesHashes = array_diff(array_keys($prevPageReport), array_keys($seoImageTests['images']));
			if(!empty($deletedImagesHashes))
			{
				foreach($deletedImagesHashes as $hash)
				{
					if(isset($prevPageReport[$hash]))
					{
						$deleteData = array('id'=> $prevPageReport[$hash]['image_id']);
						$query = "DELETE FROM ".$this->appHandler->dbPrefix()."seo_report_tests WHERE test_hash = ?";
						$sqlData['seo_report']['delete'][$hash] = array('query'=> $query, 'data' => array_values($deleteData));	
					}
				}
			}		
		}
	
		return $sqlData;
	}	
	
	private function handleNewImage($imageData)
	{
		$sqlData = array();
		
		$imageDetails = $imageData['imageDetails'];
		
		$page_url = $imageData['page_url'];
		
		$page_url_hash = $imageData['page_url_hash'];
		
		$page_title = $imageData['page_title'];
		
		//get image details hash
		$image_details_hash = $this->getImageDetailsHash($imageDetails);
		
		//get image tests hashes
		$tmpTestsHashed = array(); 
		foreach($imageDetails['tests'] as $testDetails)
		{
			$tmpTestsHashed[] = $this->getImageTestHash($testDetails);
		}
		
		//push data into reports table
		$insertData = array(
			'project_id' => $this->projectId, 
			'image_url' => $imageDetails['image_url'],
			'image_url_hash' => $imageDetails['image_url_hash'],
			'page_url' => $page_url,
			'page_url_hash' => $page_url_hash,
			'page_title' =>  $page_title,
			'score' => $imageDetails['image_score'],
			'errors' => (isset($imageDetails['tests_type']['error']) ? $imageDetails['tests_type']['error'] : 0),
			'warnings' => (isset($imageDetails['tests_type']['warning']) ? $imageDetails['tests_type']['warning'] : 0),
			'notices' => (isset($imageDetails['tests_type']['notice']) ? $imageDetails['tests_type']['notice'] : 0),
			'image_details_hash' => $image_details_hash,
			'image_tests_hash' => json_encode($tmpTestsHashed)
		);
		
		$query = "INSERT INTO ".$this->appHandler->dbPrefix()."seo_report (`".implode("`,`", array_keys($insertData))."`) VALUES (?,?,?,?,?,?,?,?,?,?,?,?)";
									
		$main_query_hash = md5(json_encode($insertData));
		$sqlData['seo_report']['insert'][$main_query_hash] = array('query'=> $query, 'data' => array_values($insertData));
		
		//push data into new reports_tests_table
		foreach($imageDetails['tests'] as $testDetails)
		{
			$extra_data = (isset($testDetails['extra_data']) ? json_encode($testDetails['extra_data']): "");
			
			$insertData = array(
				'image_id' => -1,
				'project_id' => $this->projectId,
				'type' => $testDetails['type'],
				'group' => $testDetails['group'],
				'name' => $testDetails['name'],
				'test_hash' => $this->getImageTestHash($testDetails),
				'extra_data' => $extra_data
			);
			
			$query = "INSERT INTO ".$this->appHandler->dbPrefix()."seo_report_tests (`".implode("`,`", array_keys($insertData))."`) VALUES (?,?,?,?,?,?,?)";
										
			$query_hash = md5($main_query_hash.json_encode($insertData));
			$sqlData['seo_report_tests']['insert'][$query_hash] = array('query'=> $query, 'data' => $insertData, 'report_hash' => $main_query_hash);
		}
		
		//push data into new reports_changes_table
		
		//sanitize alt, title input
		$insertData = array(
			'image_id' => -1,
			'project_id' => $this->projectId,
			'image_width' => $imageDetails['image_width_tag'],
			'image_height' => $imageDetails['image_height_tag'],
			'alt_content' => $imageDetails['image_alt'],
			'title_content' => $imageDetails['image_title'],
			'image_filename' =>  $imageDetails['image_filename'],
			'image_details_hash' => $image_details_hash
		);
		
		$query = "INSERT INTO ".$this->appHandler->dbPrefix()."seo_report_changes (`".implode("`,`", array_keys($insertData))."`) VALUES (?,?,?,?,?,?,?,?)";
									
		$query_hash = md5($main_query_hash.json_encode($insertData));
		$sqlData['seo_report_changes']['insert'][$query_hash] = array('query'=> $query, 'data' => $insertData, 'report_hash' => $main_query_hash);
		
		return $sqlData;
	}

	private function handleOldImage($imageData)
	{
		$sqlData = array();
		
		//get prev tests
		$prevPageReport = $imageData['prevPageReport'];
		
		$imageDetails = $imageData['imageDetails'];
		
		$currentPagePrevTests = $prevPageReport['tests'];
		
		$current_image_id = $prevPageReport['image_id'];
		
		$image_details_hash = $this->getImageDetailsHash($imageDetails);
			
		//Handle reports table
		
		//build update query for reports table with new details (errors,warnings, notices, score)
		
		$test_errors = (isset($imageDetails['tests_type']['error']) ? $imageDetails['tests_type']['error'] : 0);
		$test_warnings = (isset($imageDetails['tests_type']['warning']) ? $imageDetails['tests_type']['warning'] : 0);
		$test_notices = (isset($imageDetails['tests_type']['notice']) ? $imageDetails['tests_type']['notice'] : 0);
		
		$currentTestHash = md5($test_errors.$test_warnings.$test_notices); 
		
		//update only if different from previous data
		$update_image_report = false;
		if($currentTestHash != $prevPageReport['tests_hash']) $update_image_report = true;
		elseif($image_details_hash != $prevPageReport['image_details_hash']) $update_image_report = true;
		
		if($update_image_report)
		{
			$testsHashed = array();
			foreach($imageDetails['tests'] as $testDetails)
			{
				$testsHashed[] = $this->getImageTestHash($testDetails); 
			}
			
			$updateData = array(
				'errors' => $test_errors,
				'warnings' => $test_warnings,
				'notices' => $test_notices,
				'score' => $imageDetails['image_score'],
				'image_details_hash' => $image_details_hash,
				'image_tests_hash' => json_encode($testsHashed),
				'image_id' => $current_image_id
			);
			
			$query = "UPDATE ".$this->appHandler->dbPrefix()."seo_report SET `errors` = ?, `warnings` = ?, `notices` = ?, `score` = ?, `image_details_hash` = ?, `image_tests_hash` = ? WHERE `id` = ?";
										
			$query_hash = md5(json_encode($updateData));
			$sqlData['seo_report']['update'][$query_hash] = array('query'=> $query, 'data' => array_values($updateData));
		}
		
		//Handle reports_tests
		
		//get current page tests
		$currentPageTests = array();
		foreach($imageDetails['tests'] as $testDetails)
		{
			$hash = $this->getImageTestHash($testDetails);
			$currentPageTests[] = $hash;
			$currentPageTestsFull[$hash] = $testDetails;
		}
		
		//compare with existing tests
		$insertList = array_diff($currentPageTests, $currentPagePrevTests);
		
		$deleteList = array_diff($currentPagePrevTests, $currentPageTests);
		
		//build insert, detele queries for reports_tests table
		if(!empty($insertList))
		{
			foreach($insertList as $hash)
			{
				if(isset($currentPageTestsFull[$hash]))
				{
					$testDetails = $currentPageTestsFull[$hash];
					
					$extra_data = (isset($testDetails['extra_data']) ? json_encode($testDetails['extra_data']): "");
					
					$insertData = array(
						'project_id' => $this->projectId,					
						'image_id' => $current_image_id,
						'type' => $testDetails['type'],
						'group' => $testDetails['group'],
						'name' => $testDetails['name'],
						'test_hash' => $this->getImageTestHash($testDetails),
						'extra_data' => $extra_data
					);
					
					$query = "INSERT INTO ".$this->appHandler->dbPrefix()."seo_report_tests (`".implode("`,`", array_keys($insertData))."`) VALUES (?,?,?,?,?,?,?)";
												
					$query_hash = md5($current_image_id.json_encode($insertData));
					$sqlData['seo_report_tests']['insert'][$query_hash] = array('query'=> $query, 'data' => $insertData, 'report_hash' => "");
				}
			}
		} 
		
		if(!empty($deleteList))
		{
			foreach($deleteList as $hash)
			{
				$deleteData = array('test_hash'=> $hash);
				$query = "DELETE FROM ".$this->appHandler->dbPrefix()."seo_report_tests WHERE test_hash = ?";
				
				$sqlData['seo_report_tests']['delete'][$hash] = array('query'=> $query, 'data' => array_values($deleteData));
			}
		}
		
		
		//Handle Image Changes
		if($prevPageReport['image_details_hash'] != $image_details_hash)
		{
			//sanitize alt, title input
			$insertData = array(
				'image_id' => $current_image_id,
				'project_id' => $this->projectId,
				'image_width' => $imageDetails['image_width_tag'],
				'image_height' => $imageDetails['image_height_tag'],
				'alt_content' => $imageDetails['image_alt'],
				'title_content' => $imageDetails['image_title'],
				'image_filename' => $imageDetails['image_filename'],
				'image_details_hash' => $image_details_hash
			);
			
			$query = "INSERT INTO ".$this->appHandler->dbPrefix()."seo_report_changes (`".implode("`,`", array_keys($insertData))."`) VALUES (?,?,?,?,?,?,?,?)";
										
			$query_hash = md5($current_image_id.json_encode($insertData));
			$sqlData['seo_report_changes']['insert'][$query_hash] = array('query'=> $query, 'data' => $insertData, 'report_hash' => "");
		}
		
		return $sqlData;
	}

	public function handleSqlData($sqlData)
	{
		//Handle SQL Queries
		$OS = getOS();
		$db = $OS->getDb(); 
		
		//insert new image report
		if(isset($sqlData['seo_report']['insert']))
		{
			foreach($sqlData['seo_report']['insert'] as $main_query_hash => $queryData)
			{
				$dbresult = $db->query($queryData['query'], $queryData['data']);
				$current_report_id = $db->getInsertID();
				
				if($current_report_id)
				{
					foreach($sqlData['seo_report_tests']['insert'] as $query_hash => $qData)
					{
						if($qData['report_hash'] == $main_query_hash)
						{
							$sqlData['seo_report_tests']['insert'][$query_hash]['data']['image_id'] = $current_report_id;
						}	
					}
					
					foreach($sqlData['seo_report_changes']['insert'] as $query_hash => $qData)
					{
						if($qData['report_hash'] == $main_query_hash)
						{
							$sqlData['seo_report_changes']['insert'][$query_hash]['data']['image_id'] = $current_report_id;
						}	
					}
				}
			}	
		}
		
		//insert image reports tests
		if(isset($sqlData['seo_report_tests']['insert']))
		{
			foreach($sqlData['seo_report_tests']['insert'] as $query_hash => $queryData)
			{
				$dbresult = $db->query($queryData['query'], array_values($queryData['data']));
			}
		}
		
		//insert image reports changes
		if(isset($sqlData['seo_report_changes']['insert']))
		{
			foreach($sqlData['seo_report_changes']['insert'] as $query_hash => $queryData)
			{
				$dbresult = $db->query($queryData['query'], array_values($queryData['data']));
			}
		}
		
		//update current image reports
		if(isset($sqlData['seo_report']['update']))
		{
			foreach($sqlData['seo_report']['update'] as $query_hash => $queryData)
			{
				$dbresult = $db->query($queryData['query'], $queryData['data']);
			}
		}
		
		//detele image reports tests
		if(isset($sqlData['seo_report_tests']['delete']))
		{
			foreach($sqlData['seo_report_tests']['delete'] as $query_hash => $queryData)
			{
				$dbresult = $db->query($queryData['query'], $queryData['data']);
			}
		}
		
		//delete old image reports
		if(isset($sqlData['seo_report']['delete']))
		{
			foreach($sqlData['seo_report']['delete'] as $query_hash => $queryData)
			{
				$dbresult = $db->query($queryData['query'], $queryData['data']);
			}
		}
	}	
	
	private function getPageTitleKeywords($pageTitle)
	{
		$result = array();
		if($pageTitle)
		{
			$pageTitleWords = str_word_count($pageTitle, 1);
			
			foreach($pageTitleWords as $word)
			{
				if(strlen($word) > 3) $pageTitleKeywords[strtolower($word)] = true;
			} 
			
			if(!empty($pageTitleKeywords))
			{
				$result = array_keys($pageTitleKeywords);
			}
		}
		
		return $result;
	}
	
	private function getPageDOM($page_url)
	{
		$result  = false;
		
		$osHttp = getOS()->getHttp();
		
		$bulkData = $osHttp->get($page_url);
		if(($osHttp->success()) && (!empty($bulkData)))
		{
			$domLoaded = false;
			$dom=new DOMDocument();
			libxml_use_internal_errors(true);
			$domLoaded = $dom->loadHTML($bulkData);
			libxml_use_internal_errors(false);
			
			if ($domLoaded)
			{
				$result = $dom;
			}
		}

		return $result; 
	}
	
	
	private function getPrevPageReport($page_url_hash)
	{
		$db = getOS()->getDb();
		
		//get previous report data
		$prevPageReport = array();
		$query = "SELECT * FROM ".$this->appHandler->dbPrefix()."seo_report WHERE `page_url_hash` = ?";
		$dbresult = $db->query($query, array($page_url_hash));
		while ($row = $db->fetchRow($dbresult))
		{
			$tmpData = (!empty($row['image_tests_hash']) ? json_decode($row['image_tests_hash'], true) : array());
			$testsHashed = (!empty($tmpData) ? $tmpData : array());
			
			$prevPageReport[$row['image_url_hash']] = array(
				'total_tests' => 0,
				'image_id' => $row['id'],
				'tests_hash' => md5($row['errors'].$row['warnings'].$row['notices']),
				'total_tests' => count($testsHashed),
				'tests' => $testsHashed,
				'image_details_hash' => $row['image_details_hash']
				);
			
			/* Old Method
			  	
			//get information about tests
			$query2 = "SELECT * FROM ".$this->appHandler->dbPrefix()."seo_report_tests WHERE `image_id` = ?";
			$dbresult2 = $db->query($query2, array($row['id']));
			while($row2 = $db->fetchRow($dbresult2))
			{
				$prevPageReport[$row['image_url_hash']]['total_tests']++;
				$prevPageReport[$row['image_url_hash']]['tests'][] = $row2['test_hash']; 
			}
			
			//get information about image changes
			$query3 = "SELECT * FROM ".$this->appHandler->dbPrefix()."seo_report_changes WHERE `image_id` = ? ORDER BY id DESC LIMIT 1";
			$dbresult3 = $db->query($query3, array($row['id']));
			if($row3 = $db->fetchRow($dbresult3))
			{
				$prevPageReport[$row['image_url_hash']]['image_details_hash'] = $row3['image_details_hash'];
			}
			*/
		}
		
		return $prevPageReport;
	}
	
	
	private function handleImageDetails($imageDetails, $pageTitleKeywords, $pageDOM, $pageUrl) 
	{
		$imageTests = array('tests'=> array());
		$imageScores = array();
		
		$imageFilename = $this->getImageFilename($imageDetails['image_url']);
		
		$imageTestsData = $this->organicImagesTests->getTestsReports();
		
		foreach($imageTestsData as $testName => $testDetails)
		{
			if(isset($testDetails['handler']))
			{
				$handlerFcn = $testDetails['handler'];
				
				$params = array('imageDetails' => $imageDetails, 'pageTitleKeywords'=>$pageTitleKeywords, 'pageDOM' => $pageDOM);  
				$tmpTests = $this->organicImagesTests->$handlerFcn($params);
				
				if(!empty($tmpTests))
				{
					foreach($tmpTests as $index => $testData)
					{
						$tmpTests[$index]['group'] = $testDetails['group'];
						
						if(isset($testDetails['problems'][$testData['name']]))
						{
							$tmpTests[$index]['type'] = $testDetails['problems'][$testData['name']]['type'];
							$tmpTests[$index]['score'] = $testDetails['problems'][$testData['name']]['score'];
							
							$imageScores[$testDetails['group']][] = $tmpTests[$index]['score'];
						}	
					}
					
					$imageTests['tests'] = array_merge($imageTests['tests'], $tmpTests);
				}
			}
		}
		
		$result = array();
		
		if(!empty($imageTests['tests']))
		{
			foreach($imageTests['tests'] as $test)
			{
				if(isset($test['group']))
				{
					if(!isset($imageTests['testsbyattribute'][$test['group']])) $imageTests['testsbyattribute'][$test['group']] = 0;
					$imageTests['testsbyattribute'][$test['group']]++;
				}
				
				if(isset($test['type']))
				{
					if(!isset($imageTests['testsbytype'][$test['type']])) $imageTests['testsbytype'][$test['type']] = 0;
					$imageTests['testsbytype'][$test['type']]++;
				}
			}	

			//Calculate total image score
			$totalImagesScore = array();
			foreach($imageScores as $groupName => $scores)
			{
				$badKey = array_search(-1, $scores);
				$totalImagesScore[] = (($badKey === false) ? array_sum($scores) : 0);
			}
			
			$imageScore = array_sum($totalImagesScore); 
			
			$abs_image_url = $this->osUtils->makeAbsoluteUrl($pageUrl, $imageDetails['image_url']);
			
			$result = array(
				'image_url'=> $abs_image_url,
				'image_url_hash'=> md5($abs_image_url),
				'image_score' => $imageScore,
				'image_width_tag' => $imageDetails['width'], 
    			'image_height_tag' => $imageDetails['height'], 
    			'image_alt' =>  $imageDetails['alt'],
    			'image_title' =>  $imageDetails['title'],
				'image_filename' =>  $imageFilename, 				
				'tests' => $imageTests['tests'],
				'tests_type'=> $imageTests['testsbytype'],
				'tests_attribute'=> $imageTests['testsbyattribute']
				);
		}
		
		return $result;
	}
	
	private function getPageTitle($domDoc)
	{
		$result=false;
		
		$xpath = new DOMXPath($domDoc);
		
		$entries = $xpath->query("//title");
		
		if (!empty($entries))
		{
			$entries = $entries->item(0);
			
			if (!empty($entries))
			{
				$result = $entries->nodeValue;
			}
		}
		
		return $result;
	}
	
	
	private function extractImages($domDoc)
	{
		$imagesData = array();
		
		$extractionRules = array(
			'image_data'=>array(
				'type'=>'xpath',
				'query'=>'//img',
				'src'=>array(
					'location'=>'attribute',
					'attribute'=>'src'
				),
				'title'=>array(
					'location'=>'attribute',
					'attribute'=>'title'
				),
				'alt'=>array(
					'location'=>'attribute',
					'attribute'=>'alt'
				),
				'width'=>array(
					'location'=>'attribute',
					'attribute'=>'width'
				),
				'height'=>array(
					'location'=>'attribute',
					'attribute'=>'height'
				)
			)
		);
		
		$xpath = new DOMXPath($domDoc);
		
		foreach ($extractionRules as $ruleName => $rule)
		{
			if ($rule['type']=='xpath')
			{
				$entries = $xpath->query($rule['query']);
				
				foreach ($entries as $entry)
				{
					$image_url = $this->extractRuleElement($entry, $rule['src']);
					
					$add_image = true;
					if(empty($image_url)) $add_image = false;
					elseif(strpos($image_url,"data:image") === 0)  $add_image = false;
					
					if($add_image)
					{
						$imagesData[] = array(
							'image_url' => $image_url,
							'width' => $this->extractRuleElement($entry, $rule['width']),
							'height' => $this->extractRuleElement($entry, $rule['height']),
							'alt' => $this->extractRuleElement($entry, $rule['alt']),
							'title' => $this->extractRuleElement($entry, $rule['title'])
						);
					}
				}
			}
		}

		return $imagesData;
	}
	
	private function extractRuleElement($entry, $elementDetails)
	{
		$result=false;
		
		if ($elementDetails)
		{
			if ($elementDetails['location']=='nodeValue')
			{
				$result = $entry->nodeValue;
			}
			elseif ($elementDetails['location']=='attribute')
			{
				$result = $entry->getAttribute($elementDetails['attribute']);
			}
		}
		
		return $result;
	}

	public function setProjectId($projectID)
	{
		$result = false;
		if(is_numeric($projectID))
		{
			$this->projectId = $projectID;
			$result = true;	
		}
		
		return $result;
	}
	
	public function getProjectId()
	{
		return $this->projectId;
	}
	
	private function getImageDetailsHash($imageDetails)
	{
		$tmpData = array(
			$imageDetails['image_width_tag'],
			$imageDetails['image_height_tag'],
			$imageDetails['image_alt'],
			$imageDetails['image_title'],		
			$imageDetails['image_filename']
		);
		
		return md5(json_encode($tmpData));		
	}
	
	private function getImageTestHash($testDetails)
	{
		$tmpData = array(
			$testDetails['type'],
			$testDetails['group'],
			$testDetails['name'],
		);
		
		return md5(json_encode($tmpData));		
	}
	
	private function getImageFilename($image_url)
	{
		$image_filename = "";
		
		$tmpFilename = basename($image_url);
		$parts = explode(".", $tmpFilename);
		if(isset($parts[1])) 
		{
			if(in_array($parts[1], $this->availableImageExts))
			{
				$image_filename = $tmpFilename;	
			}
		}
		
		return $image_filename;
	}
	
	public function handleFinalReport()
	{
		$OS = getOS();
		$db = $OS->getDb();
		
		$project_id = $this->getProjectId();

		$result = false;
		
		$tmpCounts = array();  $totalTypes = array();
		$query = "SELECT COUNT(id) AS `total`,`name`,`group`,`type` FROM `".$this->appHandler->dbPrefix()."seo_report_tests` WHERE project_id = ? GROUP BY `name`,`group`,`type`";
		$dbresult = $db->query($query, array($project_id));
		while($row = $db->fetchRow($dbresult))
		{
			$tmpCounts[$row['type']][$row['group']][$row['name']] = $row['total'];
			
			if(!isset($totalTypes[$row['type']])) $totalTypes[$row['type']] = 0;
			$totalTypes[$row['type']] += $row['total'];
		}
		
		if(!empty($tmpCounts))
		{
			//clean stats_reports_details table
			$query = "DELETE FROM ".$this->appHandler->dbPrefix()."stats_report_details WHERE project_id = ?";
			$dbresult = $db->query($query, array($project_id));
			
			//prepare to insert new rows into stats_reports_details table
			$sqlData = array();
			foreach($tmpCounts as $typeName => $types)
			{
				foreach($types as $groupName => $groups)
				{
					foreach($groups as $elName => $total)	
					{
						$insertData = array(
							'project_id' => $project_id,
							'type' => $typeName, 
							'group' => $groupName,
							'name' =>  $elName,
							'total' =>  $total
						);
						
						$query_hash = md5($typeName.$groupName.$elName);
						$query = "INSERT INTO ".$this->appHandler->dbPrefix()."stats_report_details (`".implode("`,`", array_keys($insertData))."`) VALUES (?,?,?,?,?)";
						
						$sqlData['stats_report_details']['insert'][$query_hash] = array('query'=> $query, 'data' => array_values($insertData));
					}	
				}	
			}
			
			//handle stats_reports_details queries
			if(isset($sqlData['stats_report_details']['insert']))
			{
				foreach($sqlData['stats_report_details']['insert'] as $queryData)
				{
					$dbresult = $db->query($queryData['query'], $queryData['data']);
				}
			}
			
			
			//build main raport
			$pages_total = "1";
			$pages_problems = "2";
			$images_total = "3";
			$images_problems = "4";
			$report_d = date("Y-m-d");
			
			//push data into stats_reports table
			$insertData = array(
				'project_id' => $project_id, 
				'report_d' => $report_d,
				'errors' => (isset($totalTypes['error']) ? $totalTypes['error'] : 0),
				'warnings' => (isset($totalTypes['warning']) ? $totalTypes['warning'] : 0),
				'notices' => (isset($totalTypes['notice']) ? $totalTypes['notice'] : 0),
				'pages_total' => $pages_total,
				'pages_problems' => $pages_problems,
				'images_total' => $images_total,
				'images_problems' => $images_problems
			);
			
			$query = "INSERT INTO ".$this->appHandler->dbPrefix()."stats_report (`".implode("`,`", array_keys($insertData))."`) VALUES (?,?,?,?,?,?,?,?,?)";
			$dbresult = $db->query($query, array_values($insertData));
			$insert_id = $db->getInsertID();
			
			if(!empty($insert_id))
			{
				$result = true;
			}
		}
		
		return $result;
	}
}
?>