<?php 
class OS_APP_organicimages_Consolidation
{
	private static $_instance;
	
	private $appHandler;

	public function __construct() 
	{
		$this->appHandler = getOS()->getAppHandler('organicimages');
	}

	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_organicimages_Consolidation();
		}
		return self::$_instance;
	}
	
	public function getAvailableDimensions()
	{
		$availableDimensions = array(
			'image_url' => array('name'=> 'content_url', 'table_name' => 'track_content', 'title' => "Image URL", 'group'=>'traffic', 'type'=> 'default'),
			'keyword' => array('name'=> 'referer_keywords', 'table_name' => 'track_referer', 'title' => "Keyword", 'group'=>'traffic', 'type'=> 'default'),
			'landing_page' => array('name'=> 'page_url', 'table_name' => 'track_page', 'title' => "Landing Page", 'group'=>'traffic'),
			//'source' => array('name'=> 'source', 'title' => "Source", 'group'=>'traffic'),
			'country' => array('name'=> 'location_country_name', 'table_name' => 'track_location', 'title' => "Country", 'group'=>'visitor', 'type'=> 'default'),
			'continent' => array('name'=> 'location_continent_name', 'table_name' => 'track_location', 'title' => "Continent", 'group'=>'visitor'),
			//'language' => array('name'=> 'location_language', 'title' => "Language", 'group'=>'visitor'),
			//'config_os' => array('name'=> 'location_country_name', 'title' => "Operating System", 'group'=>'technology'),
			//'config_mobile' => array('name'=> 'config_mobile', 'title' => "Mobile Devices", 'group'=>'technology'),
			//'config_browser' => array('name'=> 'config_browser', 'title' => "Browser", 'group'=>'technology')
		);

		return $availableDimensions;
	}
	
	public function getData($consolidation_name, $params)
	{
		$OS = getOS();
		$db = $OS->getDb();
		$appHandler = $this->appHandler;
		
		$result = false;
		
		$project_id = $params['project_id'];
		$start_d = $params['start_d'];
		$end_d = $params['end_d'];
		
		$datesRange = $this->createDateRangeArray($start_d, $end_d);
		
		//check if interval is valid
		$datesRangeFlip = array_flip($datesRange);
		
		$keyData = $params;
		unset($keyData['project_id'],$keyData['start_d'],$keyData['end_d'],$keyData['set'],$keyData['max_rows']);
		
		$consolidation_key = md5($consolidation_name.json_encode($keyData));
		
		$consolidationDetails = array('name' => $consolidation_name, 'key' => $consolidation_key);
		
		//Check is valid Consolidation Range
		$consolidation_data_id = false; $current_consolidation_dates = array();
		$query = "SELECT * FROM ".$appHandler->dbPrefix()."stats_log WHERE `project_id`=? AND `name`=? AND `consolidation_key`=?";
		$dbresult = $db->query($query, array($project_id, $consolidationDetails['name'], $consolidationDetails['key']));
		if($row = $db->fetchRow($dbresult))
		{
			$consolidation_data_id = $row['id'];
			
			$current_consolidation_dates = json_decode($row['consolidation_dates'], true);
			
			foreach($current_consolidation_dates as $date_span)
			{
				$tmpRange = $this->createDateRangeArray($date_span[0], $date_span[1]);
				foreach($tmpRange  as $cdate)
				{
					if(isset($datesRangeFlip[$cdate]))
					{
						unset($datesRangeFlip[$cdate]);
					}
				}
			}
		}
		
		$valid_consolidation = false;
		if(count($datesRangeFlip) == 0)
		{
			$valid_consolidation = true;
		}
		else
		{
			$datesRangeFlip = array_flip($datesRangeFlip);
			$consolidationDatesRanges = $this->grupDatesArray($datesRangeFlip);
			
			if(!empty($consolidationDatesRanges))
			{
				//exec build function on selected dates
				$buildFunctionName = "{$consolidation_name}Build";
				
				if(method_exists($this, $buildFunctionName))
				{
					$buildResult = false;
					
					foreach($consolidationDatesRanges as $dateDetails)
					{
						$buildParams = $params;
						
						$buildParams['start_d'] = $dateDetails[0];
						$buildParams['end_d'] = $dateDetails[1]; 
						
						$buildResult = $this->$buildFunctionName($buildParams, $consolidationDetails);
					}
					
					if($buildResult)
					{
						//update consolidation logs
						$current_consolidation_dates[] = array($start_d, $end_d);
						$consolidation_dates_json = json_encode($current_consolidation_dates);
						
						if($consolidation_data_id !== false)
						{
							$query="UPDATE ".$appHandler->dbPrefix()."stats_log SET `consolidation_dates`=? WHERE id=?";
							$db->query($query, array($consolidation_dates_json, $consolidation_data_id));
						}
						else
						{
							$query="INSERT INTO ".$appHandler->dbPrefix()."stats_log (`project_id`, `name`,`consolidation_key`,`consolidation_dates`) VALUES (?,?,?,?)";
							$db->query($query, array($project_id, $consolidationDetails['name'], $consolidationDetails['key'], $consolidation_dates_json));
						}
						
						$valid_consolidation = true;
					}
				}
			}
		}
		
		
		if($valid_consolidation)
		{
			//exec read function on selected dates
				
			$readFunctionName = "{$consolidation_name}Read";
			
			if(method_exists($this, $readFunctionName))
			{
				$readResult = $this->$readFunctionName($params, $consolidationDetails);
				
				$result = $readResult;
			}
			
		}
		
		return $result;
	}
	
	public function createDateRangeArray($strDateFrom, $strDateTo)
	{
	    $aryRange = array();
	
	    $iDateFrom = mktime(1,0,0,substr($strDateFrom,5,2), substr($strDateFrom,8,2),substr($strDateFrom,0,4));
	    $iDateTo = mktime(1,0,0,substr($strDateTo,5,2), substr($strDateTo,8,2),substr($strDateTo,0,4));
	
	    if ($iDateTo >= $iDateFrom)
	    {
	        $aryRange[] = date('Y-m-d',$iDateFrom);
	        while ($iDateFrom<$iDateTo)
	        {
	            $iDateFrom += 86400;
	            $aryRange[] = date('Y-m-d',$iDateFrom);
	        }
	    }
	    return $aryRange;
	}
	
	private function grupDatesArray($dates, $max_period = 30)
	{
		$tmpData = array();
		$tmpData2 = array();
		
		foreach($dates as $cdate)
		{
			$tmpData[strtotime($cdate)] = true;	
		}
		
		ksort($tmpData);
		
		$start_ts = key($tmpData);
		$end_ts = $start_ts; 
		unset($tmpData[$start_ts]);
		
		$counter = 0; $is_valid = true;
		foreach($tmpData as $tsdate => $dummy)
		{
			$is_valid = true;
			if($tsdate != ($end_ts + (24*60*60))) $is_valid = false;
			elseif($counter > $max_period) $is_valid = false;
			
			if($is_valid)
			{
				$counter++;
				$end_ts = $tsdate;
			}
			else
			{
				$tmpData2[] = array(date("Y-m-d", $start_ts), date("Y-m-d", $end_ts));
				
				$start_ts = $tsdate; 
				$end_ts = $tsdate;
				$counter = 0;
			}
		}
		
		//Build final period
		if($is_valid)
		{
			$tmpData2[] = array(date("Y-m-d", $start_ts), date("Y-m-d", $end_ts));	
		}
		
		return $tmpData2;
	}
		
	/*Add Build and Read function for each new view */

	
	private function getCustomReportBuild($params, $consolidationDetails)
	{
		$response = true;

		$OS = getOS();
		$db = $OS->getDb();
		$appHandler = $this->appHandler;
		
		$project_id = $params['project_id'];
		$start_d = $params['start_d'];
		$end_d = $params['end_d'];
		
		$consolidationHasLimits = false;
		
		if(isset($params['set'], $params['max_rows']))
		{
			$consolidationHasLimits = true;
			$current_set =  $params['set'];
			$max_rows = $params['max_rows'];
			$limit = (($current_set * $max_rows) - $max_rows);
		}
				
		$dimensionsData = array();
		if(!empty($params['primary_dimension']))
		{
			$dimensionsData['primary_dimension'] = $params['primary_dimension']; 
		}
		
		if(!empty($params['secondary_dimension']))
		{
			$dimensionsData['secondary_dimension'] = $params['secondary_dimension'];
		}
		
		//select from main table values by time periods
		$consolidationData = array();
		
		$selectValues = array_merge(array('COUNT(id) AS total', 'visitor_d'), $dimensionsData);
		$groupValues = array_values($dimensionsData);
		
		//$limitValues = ($consolidationHasLimits ?  "ORDER BY total LIMIT {$limit},{$max_rows}": "");
		$query = sprintf("SELECT %s FROM ".$appHandler->dbPrefix()."images WHERE `project_id`=? AND `visitor_d`>=? AND `visitor_d`<=? GROUP BY %s", implode(", ", $selectValues), implode(", ", $groupValues));
		$dbresult = $db->query($query, array($project_id, $start_d, $end_d));
		
		while($row = $db->fetchRow($dbresult))
		{
			$primary_metric = $row[$dimensionsData['primary_dimension']];
			$primary_metric_hash = md5($primary_metric);
			
			$tmpValues = array('primary_metric' => $primary_metric,'total' => $row['total']);
			$tmpData = $tmpValues;	
			
			//replace with md5() and add human extra_data info
			if(isset($dimensionsData['secondary_dimension']))
			{
				$secondary_metric = $row[$dimensionsData['secondary_dimension']];
				$secondary_metric_hash = md5($secondary_metric);
				
				$tmpValues['secondary_metric'] = $secondary_metric;
				$tmpData = array($secondary_metric_hash => $tmpValues);
			}
			
			$consolidationData[$row['visitor_d']][$primary_metric_hash] = $tmpData;
		}
		
		if(!empty($consolidationData))
		{
			//group details by date and insert in consolidated table
			foreach($consolidationData as $sdate => $details)
			{
				foreach($details as $primary_metric_hash => $subDetails)
				{
					if(isset($dimensionsData['secondary_dimension']))
					{
						foreach($subDetails as $secondary_metric_hash => $values)
						{
							//check if insert or update here
							
							$primary_metric = str_replace(array("\r\n","\n"),array("\n"," "), $values['primary_metric']);
							$secondary_metric = str_replace(array("\r\n","\n"),array("\n"," "), $values['secondary_metric']);
							$extraDataJson = json_encode(array('primary_metric'=> $primary_metric, 'secondary_metric' => $secondary_metric));
							
							$query = "INSERT INTO ".$appHandler->dbPrefix()."stats_days (`project_id`, `consolidation_name`, `consolidation_key`, `primary_dimension`,`primary_metric_hash`,`secondary_dimension`,`secondary_metric_hash`,`stats_d`,`total_value`,`extra_data`) VALUES (?,?,?,?,?,?,?,?,?,?)";
							$db->query($query, array($project_id, $consolidationDetails['name'], $consolidationDetails['key'], $dimensionsData['primary_dimension'], $primary_metric_hash, $dimensionsData['secondary_dimension'], $secondary_metric_hash, $sdate, $values['total'], $extraDataJson));
						}
					}
					else
					{
						$primary_metric = str_replace(array("\r\n","\n"),array("\n"," "), $subDetails['primary_metric']);
						$extraDataJson = json_encode(array('primary_metric'=> $primary_metric));
					
						$query="INSERT INTO ".$appHandler->dbPrefix()."stats_days (`project_id`, `consolidation_name`, `consolidation_key`, `primary_dimension`,`primary_metric_hash`,`stats_d`,`total_value`,`extra_data`) VALUES (?,?,?,?,?,?,?,?)";
						$db->query($query, array($project_id, $consolidationDetails['name'], $consolidationDetails['key'], $dimensionsData['primary_dimension'], $primary_metric_hash, $sdate, $subDetails['total'], $extraDataJson));
					}
				}
			}	
		}	
		
		return $response;
	}
	
	private function getCustomReportRead($params, $consolidationDetails)
	{
		$OS = getOS();
		$db = $OS->getDb();
		$appHandler = $this->appHandler;
		
		$response = array();
		
		$project_id = $params['project_id'];
		$start_d = $params['start_d'];
		$end_d = $params['end_d'];
		$primary_dimension = $params['primary_dimension'];
		$secondary_dimension = (isset($params['secondary_dimension']) ? $params['secondary_dimension'] : '');
		
		$query = "SELECT stats_d,SUM(total_value) AS total,primary_dimension,primary_metric_hash,secondary_dimension,secondary_metric_hash,extra_data FROM ".$appHandler->dbPrefix()."stats_days WHERE `project_id`=? AND `consolidation_name`=? AND `consolidation_key`=? AND `primary_dimension`=? AND `secondary_dimension`=? AND `stats_d`>=? AND `stats_d`<=? GROUP BY primary_metric_hash,secondary_metric_hash ORDER BY total DESC";
		$dbresult = $db->query($query, array($project_id, $consolidationDetails['name'], $consolidationDetails['key'],$primary_dimension, $secondary_dimension, $start_d, $end_d));
		
		while ($row = $db->fetchRow($dbresult))
		{
			$tmpData = array(
				'primary_dimension' => $row['primary_dimension'],
				'secondary_dimension' => $row['secondary_dimension'],
				'primary_metric_hash' => $row['primary_metric_hash'],
				'secondary_metric_hash' => $row['secondary_metric_hash'],
				'total' => $row['total'],
				'primary_metric' => "",
				'secondary_metric' => ""
				);
			
			if(!empty($row['extra_data']))
			{
				$extraData = json_decode($row['extra_data'], true);

				foreach($extraData as $field => $value)
				{
					$tmpData[$field] = $value;					
				}
			}	
			
			$response[] = $tmpData;
		}
		
		return $response;
	}
	
	private function getCustomReportUnitBuild($params, $consolidationDetails)
	{
		$response = true;

		$OS = getOS();
		$db = $OS->getDb();
		$appHandler = $this->appHandler;
		
		$project_id = $params['project_id'];
		
		$dimensionsData = array();
		if(!empty($params['primary_dimension']))
		{
			$dimensionsData['primary_dimension'] = $params['primary_dimension']; 
		}
		
		if(!empty($params['secondary_dimension']))
		{
			$dimensionsData['secondary_dimension'] = $params['secondary_dimension'];
		}
		
		//select from main table values by time periods
		$consolidationData = array();
		
		$selectValues = array_merge(array('COUNT(id) AS total', 'visitor_d'), $dimensionsData);
		$groupValues = array_values($dimensionsData);
		
		$query = sprintf("SELECT %s FROM ".$appHandler->dbPrefix()."images WHERE `project_id`=? AND `visitor_d`>=? AND `visitor_d`<=? AND `%s` = ? GROUP BY %s", implode(", ", $selectValues), $params['main_dimension_name'], implode(", ", $groupValues));
		
		$dbresult = $db->query($query, array($params['project_id'], $params['start_d'], $params['end_d'], $params['main_dimension_value']));
		while($row = $db->fetchRow($dbresult))
		{
			$primary_metric = $row[$dimensionsData['primary_dimension']];
			$primary_metric_hash = md5($primary_metric);
			
			$tmpValues = array('primary_metric' => $primary_metric,'total' => $row['total']);
			$tmpData = $tmpValues;	
			
			if(isset($dimensionsData['secondary_dimension']))
			{
				$secondary_metric = $row[$dimensionsData['secondary_dimension']];
				$secondary_metric_hash = md5($secondary_metric);
				
				$tmpValues['secondary_metric'] = $secondary_metric;
				$tmpData = array($secondary_metric_hash => $tmpValues);
			}
			
			$consolidationData[$row['visitor_d']][$primary_metric_hash] = $tmpData;
		}
		
		if(!empty($consolidationData))
		{
			//group details by date and insert in consolidated table
			foreach($consolidationData as $sdate => $details)
			{
				foreach($details as $primary_metric_hash => $subDetails)
				{
					if(isset($dimensionsData['secondary_dimension']))
					{
						foreach($subDetails as $secondary_metric_hash => $values)
						{
							//check if insert or update here
							
							$primary_metric = str_replace(array("\r\n","\n"),array("\n"," "), $values['primary_metric']);
							$secondary_metric = str_replace(array("\r\n","\n"),array("\n"," "), $values['secondary_metric']);
							$extraDataJson = json_encode(array('primary_metric'=> $primary_metric, 'secondary_metric' => $secondary_metric));
							
							$query = "INSERT INTO ".$appHandler->dbPrefix()."stats_days (`project_id`, `consolidation_name`, `consolidation_key`, `primary_dimension`,`primary_metric_hash`,`secondary_dimension`,`secondary_metric_hash`,`stats_d`,`total_value`,`extra_data`) VALUES (?,?,?,?,?,?,?,?,?,?)";
							$db->query($query, array($project_id, $consolidationDetails['name'], $consolidationDetails['key'], $dimensionsData['primary_dimension'], $primary_metric_hash, $dimensionsData['secondary_dimension'], $secondary_metric_hash, $sdate, $values['total'], $extraDataJson));
						}
					}
					else
					{
						$primary_metric = str_replace(array("\r\n","\n"),array("\n"," "), $subDetails['primary_metric']);
						$extraDataJson = json_encode(array('primary_metric'=> $primary_metric));
					
						$query="INSERT INTO ".$appHandler->dbPrefix()."stats_days (`project_id`, `consolidation_name`, `consolidation_key`, `primary_dimension`,`primary_metric_hash`,`stats_d`,`total_value`,`extra_data`) VALUES (?,?,?,?,?,?,?,?)";
						$db->query($query, array($project_id, $consolidationDetails['name'], $consolidationDetails['key'], $dimensionsData['primary_dimension'], $primary_metric_hash, $sdate, $subDetails['total'], $extraDataJson));
					}
				}
			}	
			
			$response = true;
		}	
		
		return $response;
	}
	

	
	private function getCustomReportUnitRead($params, $consolidationDetails)
	{
		$OS = getOS();
		$db = $OS->getDb();
		$appHandler = $this->appHandler;
		
		$response = array();
		
		$project_id = $params['project_id'];
		$start_d = $params['start_d'];
		$end_d = $params['end_d'];
		$primary_dimension = $params['primary_dimension'];
		$secondary_dimension = (isset($params['secondary_dimension']) ? $params['secondary_dimension'] : '');
		
		$query = "SELECT stats_d,SUM(total_value) AS total,primary_dimension,primary_metric_hash,secondary_dimension,secondary_metric_hash,extra_data FROM ".$appHandler->dbPrefix()."stats_days WHERE `project_id`=? AND consolidation_name = ? AND consolidation_key = ? AND `primary_dimension`=? AND `secondary_dimension`=? AND `stats_d`>=? AND `stats_d`<=? GROUP BY primary_metric_hash,secondary_metric_hash ORDER BY total DESC";
		$dbresult = $db->query($query, array($project_id, $consolidationDetails['name'], $consolidationDetails['key'], $primary_dimension, $secondary_dimension, $start_d, $end_d));
		
		while($row = $db->fetchRow($dbresult))
		{
			$tmpData = array(
				'primary_metric_hash' => $row['primary_metric_hash'],
				'secondary_metric_hash' => $row['secondary_metric_hash'],
				'total' => $row['total'],
				'primary_metric' => "",
				'secondary_metric' => ""
				);
			
			if(!empty($row['extra_data']))
			{
				$extraData = json_decode($row['extra_data'], true);

				foreach($extraData as $field => $value)
				{
					$tmpData[$field] = $value;					
				}
			}	
			
			$response[] = $tmpData;
		}
		
		return $response;
	}		
}
?>