<?php 
class OS_APP_organicimages_Tests
{
	private static $_instance;
	
	private $appHandler;
	
	private $testsDetails;
	
	private $testGroups;

	public function __construct() 
	{
		$this->appHandler = getOS()->getAppHandler('organicimages');
		
		$this->loadGroups();
		
		$this->loadTests();
	}

	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_organicimages_Tests();
		}
		return self::$_instance;
	}
	
	public function getTestsReports()
	{
		return $this->testsDetails;
	}
	
	public function getTestGroups()
	{
		return $this->testGroups;
	}
	
	private function loadTests()
	{
		$testsDetails = array(
			'alt_keywords' => array(
				'group' => 'alt',
				'handler' => 'handleAltKeywords',
				'test_message' => "Testing page title keywords presence on image ALT tag",
				'problems' => array(
					'optimal_kws' => array(
						'message' => "Image ALT attribute contains %s keywords found in the page title: %s",
						'title' => "Optimal Keywords",
						'type' => 'notice',						
						'score' => 27
						),
					'missing_kws' => array(
						'message' => "Image ALT attribute contains no keywords present in the page title: %s",
						'title' => "Missing Keywords",
						'type' => 'warning',						
						'score' => 0
						),
					'many_kws' => array(
						'message' => "Image ALT attribute contains %s keywords found in the page title: %s",
						'title' => "Too Many Keywords",
						'type' => 'error',						
						'score' => -1
						),
					'long_alt_text' => array(
						'message' => "Image ALT contains text of %s characters (longer than %s characters)",
						'title' => "Long ALT text",
						'type' => 'error',						
						'score' => -1
						)
					)
				),	
			'alt_tag' => array(
				'group' => 'alt',
				'handler' => 'handleAltTag',
				'test_message' => "Tests if ALT attribute exists on Image",
				'problems' => array(
					'missing_tag' => array(
						'message' => "Image ALT attribute is missing",
						'title' => "Missing ALT Tag",	
						'type' => 'error',
						'score' => -1
						),
					'tag_exists' => array(
						'message' => "Image ALT tag is present",
						'title' => "ALT Tag Exists",	
						'type' => 'success',
						'score' => 8
						)
					)
				),
			'title_keywords' => array(
				'group' => 'title',
				'handler' => 'handleTitleKeywords',
				'test_message' => "Testing page title keywords presence on image TITLE tag",
				'problems' => array(
					'optimal_kws' => array(
						'message' => "Image TITLE attribute contains %s keywords found in the page title: %s",
						'title' => "Optimal Keywords",
						'type' => 'notice',						
						'score' => 25
						),
					'missing_kws' => array(
						'message' => "Image TITLE attribute contains no keywords present in the page title: %s",
						'title' => "Missing Keywords",
						'type' => 'warning',						
						'score' => 0
						),
					'many_kws' => array(
						'message' => "Image TITLE attribute contains %s keywords found in the page title: %s",
						'title' => "Too Many Keywords",
						'type' => 'error',						
						'score' => -1
						),
					'long_title_text' => array(
						'message' => "Image TITLE contains text of %s characters (longer than %s characters)",
						'title' => "Long TITLE text",
						'type' => 'error',						
						'score' => -1
						)
					)	
				),	
			'title_tag' => array(
				'group' => 'title',
				'handler' => 'handleTitleTag',
				'test_message' => "Tests if TITLE attribute exists on Image",
				'problems' => array(
					'missing_tag' => array(
						'message' => "Image TITLE attribute is missing",
						'title' => "Missing TITLE Tag",
						'type' => 'error',						
						'score' => -1
						),
					'tag_exists' => array(
						'message' => "Image TITLE tag is present",
						'title' => "TITLE Tag Exists",	
						'type' => 'success',
						'score' => 12
						)
					)
				),
			'src_keywords' => array(
				'group' => 'filename',
				'handler' => 'handleSrcKeywords',
				'test_message' => "Testing page title keywords presence on image filename",
				'problems' => array(
					'optimal_kws' => array(
						'message' => "Image filename contains %s keywords found in the page title: %s",
						'title' => "Optimal Keywords",	
						'type' => 'notice',						
						'score' => 15
						),
					'missing_kws' => array(
						'message' => "Image filename attribute contains no keywords present in the page title: %s",
						'title' => "Missing Keywords",
						'type' => 'warning',						
						'score' => 0
						),
					'many_kws' => array(
						'message' => "Image filename contains %s keywords found in the page title: %s",
						'title' => "Too Many Keywords",
						'type' => 'error',						
						'score' => -1
						)
					)	
				),
			'src_tag' => array(
				'group' => 'filename',
				'handler' => 'handleSrcTag',
				'test_message' => "Test image filename structure",	
				'problems' => array(
					'bad_filename' => array(
						'message' => "Image filename (%s) contains `%s` and should be replaced with `-` (Exp: %s)",
						'title' => "Bad Filename",
						'type' => 'warning',						
						'score' => 0
						),
					'long_filename_text' => array(
						'message' => "Image filename contains %s characters and should contain only %s characters",
						'title' => "Bad Filename",
						'type' => 'error',						
						'score' => -1
						)
					)
				),	
			'dimensions_tag' => array(
				'group' => 'width_height',
				'handler' => 'handleDimensionsTag',
				'test_message' => "Tests if WIDTH & HEIGHT  attributes exists on Image",
				'problems' => array(
					'missing_tag' => array(
						'message' => "Image does not contain WIDTH or HEIGHT attributes",
						'title' => "Missing Tag",		
						'type' => 'warning',				
						'score' => 5
						),
					'missing_height' => array(
						'message' => "Image does not contain the WIDTH attribute",
						'title' => "Missing Height Attribute",
						'type' => 'warning',						
						'score' => 5
						),
					'missing_width' => array(
						'message' => "Image does not contain WIDTH and HEIGHT attributes",
						'title' => "Missing Widgth Attribute",
						'type' => 'warning',						
						'score' => 5
						)
					)	
				)
			);
	
		$this->testsDetails = $testsDetails; 
	}
	
	private function loadGroups()
	{
		$testsGroups = array(
			'title' => array('title'=> "TITLE Tag", 'score' => 20),	
			'alt' => array('title'=> "ALT Tag", 'score' => 40),
			'filename' => array('title'=> "Filename", 'score' => 15),
			'width_height' => array('title'=> "Width & Height", 'score' => 15),
			'content' => array('title'=> "Content", 'score' => 10)
		);
		
		$this->testGroups = $testsGroups; 
	}

	public function prepareTestsReports()
	{
		$tmpTests = array();
		
		foreach($this->testsDetails as $test_name => $test_details)
		{
			//show only problems not the success ones
			$tmpTests[$test_details['group']][$test_name] = array(
				'test_message' => $test_details['test_message'],
				'problems' => $test_details['problems'] 
				);
		}
		
		return $tmpTests;
	}
	
	public function prepareTestsReportsByType()
	{
		$tmpTests = array();
		
		foreach($this->testsDetails as $test_name => $test_details)
		{
			foreach($test_details['problems'] as $problem_name => $details)
			{
				$tmpTests[$details['type']][$test_details['group']][$problem_name] = array(
					'test_message' => $test_details['test_message'],
					'problem_message' => $details['message'],
					'title' => $details['title'] 
					);
			}
		}
		
		return $tmpTests;
	}
	
	
	
	public function handleAltTag($params)
	{
		$imageTests = array();

		$problemName = 'missing_tag';
		if($params['imageDetails']['alt'])
		{
			if(!empty($params['imageDetails']['alt']))
			{
				$problemName = 'tag_exists';		
			}
		}
		
		$imageTests[] = array('name' => $problemName);
		
		return $imageTests;
	}
	
	public function handleAltKeywords($params)
	{
		$imageDetails = $params['imageDetails'];
		$pageTitleKeywords = $params['pageTitleKeywords'];
		
		//test if image alt contains keywords
		$image_alt_text = $imageDetails['alt'];  	
		$imageAltKws = array(); 
		
		$imageTests = array(); $maxAltLength = 125;
		
		if(strlen($image_alt_text) > $maxAltLength)
		{
			$imageTests[] = array('name' => 'long_alt_text', 'extra_data' => array(strlen($image_alt_text), $maxAltLength));
		}
		else
		{
			foreach($pageTitleKeywords as $keyword)
			{
				if(strpos($image_alt_text, $keyword) !== false)
				{
					$imageAltKws[] = $keyword;
				}
			}
			
			$imageAltKwsCount = count($imageAltKws); 
			if($imageAltKwsCount == 0)
			{
				$imageTests[] = array('name' => 'missing_kws', 'extra_data' => array(implode(", ", $pageTitleKeywords)));
			}
			elseif(($imageAltKwsCount >=1) && ($imageAltKwsCount < 4))
			{
				$imageTests[] = array('name' => 'optimal_kws', 'extra_data' => array($imageAltKwsCount,  implode(", ", $imageAltKws)));
			}
			else
			{
				$imageTests[] = array('name' => 'many_kws', 'extra_data' => array($imageAltKwsCount, implode(", ", $imageAltKws)));
			}
		}
		
		return $imageTests;
	}
	
	
	public function handleTitleTag($params)
	{
		$problemName = 'missing_tag';
		if($params['imageDetails']['title'])
		{
			if(!empty($params['imageDetails']['title']))
			{
				$problemName = 'tag_exists';		
			}
		}
		
		$imageTests[] = array('name' => $problemName);
		
		return $imageTests;
	}

	public function handleTitleKeywords($params)
	{
		$imageDetails = $params['imageDetails'];
		$pageTitleKeywords = $params['pageTitleKeywords'];
		
		//test if image alt contains keywords
		$image_title_text = $imageDetails['title'];  	
		$imageTitleKws = array(); $maxTitleLength = 70;

		
		if(strlen($image_title_text) > $maxTitleLength)
		{
			$imageTests[] = array('name' => 'long_title_text', 'extra_data' => array(strlen($image_title_text), $maxTitleLength));
		}
		else
		{
			foreach($pageTitleKeywords as $keyword)
			{
				if(strpos($image_title_text, $keyword) !== false)
				{
					$imageTitleKws[] = $keyword;
				}
			}
			
			$imageTitleKwsCount = count($imageTitleKws); 
			if($imageTitleKwsCount == 0)
			{
				$imageTests[] = array('name' => 'missing_kws', 'extra_data' => array(implode(", ", $pageTitleKeywords)));
			}
			elseif(($imageTitleKwsCount >=1) && ($imageTitleKwsCount < 5))
			{
				$imageTests[] = array('name' => 'optimal_kws', 'extra_data' => array($imageTitleKwsCount,  implode(", ", $imageTitleKws)));
			}
			else
			{
				$imageTests[] = array('name' => 'many_kws', 'extra_data' => array($imageTitleKwsCount, implode(", ", $imageTitleKws)));
			}
		}
		
		return $imageTests;
	}
	
	public function handleSrcKeywords($params)
	{
		$imageDetails = $params['imageDetails'];
		$pageTitleKeywords = $params['pageTitleKeywords'];
		
		$image_filename = basename($imageDetails['image_url']);
				
		$imageTests = array();
		
		//test if image filename contains keywords
		$filenameKws = array(); 
		foreach($pageTitleKeywords as $keyword)
		{
			if(strpos($image_filename, $keyword) !== false)
			{
				$filenameKws[] = $keyword;
			}
		}
		
		$filenameKwsCount = count($filenameKws); 
		if($filenameKwsCount == 0)
		{
			$imageTests[] = array('name' => 'missing_kws', 'extra_data' => array(implode(", ", $pageTitleKeywords)));
		}
		elseif(($filenameKwsCount >=1) && ($filenameKwsCount < 4))
		{
			$imageTests[] = array('name' => 'optimal_kws', 'extra_data' => array($filenameKwsCount,  implode(", ", $filenameKws)));
		}
		else
		{
			$imageTests[] = array('name' => 'many_kws', 'extra_data' => array($filenameKwsCount, implode(", ", $filenameKws)));
		}
		
		return $imageTests;
	}
	
	public function handleSrcTag($params)
	{
		$imageDetails = $params['imageDetails'];
		
		$imageTests = array();
		
		$image_filename = basename($imageDetails['image_url']);
		
		//test bad chars in image filename
		$filenameBadChars = array(" ","_"); 
		foreach($filenameBadChars as $badChar)
		{
			if(strpos($image_filename, $badChar) !== false)
			{
				$good_image_filename = str_replace($badChar, "-", $image_filename);
				
				$imageTests[] = array('name' => 'bad_filename', 'extra_data' => array($image_filename,$badChar, $good_image_filename));
			}	
		}

		$maxFilenameLength = 50;
		if(strlen($image_filename) > $maxFilenameLength) 
		{
			$imageTests[] = array('name' => 'long_filename_text', 'extra_data' => array(strlen($image_filename), $maxFilenameLength));
		}
		
		return $imageTests;
	}
	
	public function handleDimensionsTag($params)
	{
		$imageDetails = $params['imageDetails'];
		
		$imageTests = array();
		
		//Handle WIDTH & HEIGHT problems 
		if(!$imageDetails['width'] && !$imageDetails['height'])
		{
			$imageTests[] = array('name' => 'missing_tag');
		}
		elseif(!$imageDetails['width'])
		{
			$imageTests[] = array('name' => 'missing_width');
		}
		elseif(!$imageDetails['height'])
		{
			$imageTests[] = array('name' => 'missing_height');
		}
		else
		{
		
		}
		
		return $imageTests;
	}
}
?>	