<?php

interface OS_APP_organicimages_Tracker_Actions_Interface
{
	function setRequest($requestArray);
	function handle();
}

class OS_APP_organicimages_Tracker_Actions implements OS_APP_organicimages_Tracker_Actions_Interface
{
	private $request;
	
	private $visitorInfo;
	
	private $project_id;
	
	private $extraData;
	
	protected $currentTimeUTC;
	
	protected $rootPath;
	
	protected $refererTypes;
	
	private $availableImagesExts;
	
	private $appHandler;
	
	public function __construct($requestArray = array())
	{
		$OS = getOS();
		
		if(!empty($requestArray))
		{
			$this->setRequest($requestArray);
		}
		
		$this->appHandler = $OS->getAppHandler('organicimages');
		
		$this->currentTimeUTC = gmdate("Y-m-d H:i:s");
		
		$this->rootPath = $OS->getConfigVar('root_path');
		
		$this->availableEvents = array('organicImagesTracker');
		
		$this->availableImagesExts = array('jpg','jpeg','bmp','gif','png','svg','webp','ico');
	}
	
	public function setRequest($requestArray)
	{
		if(isset($requestArray['project_id'], $requestArray['events']))
		{
			if(empty($requestArray['project_id'])) $this->error('102','General_ExceptionInvalidProjectAccount');
			else
			{
				$this->project_id = $requestArray['project_id'];
				
				$this->extraData = (isset($requestArray['extra']) ? $requestArray['extra'] : array());
				
				$availableEvents = array_flip($this->availableEvents);
				
				foreach($requestArray['events'] as $eventName => $values)
				{
					if(isset($availableEvents[$eventName]))
					{
						$this->request[$eventName] = $requestArray['events'][$eventName]['handlerResult'];	
					}
				}
			}
		}
	}
	
	public function handle()
	{
		$OS = getOS();
		
		$page_url = $this->getPageUrl();
		
		$visior_ua = $this->getUserAgent();
		
		$visior_ip = $this->getVisitorIp();
		
		$osGeoIP = $OS->getGeoIP();
		
		$locationDetails = $osGeoIP->getLocation($visior_ip);
		
		$this->visitorInfo = array(
			'project_id' => $this->project_id,
			'visitor_dt' => date("Y-m-d H:i:s"),
			'visitor_d' => date("Y-m-d"),
			'visitor_ip' => $visior_ip,
			'page_url' => $page_url,
			'page_url_hash' => md5($page_url),
			'page_title' =>  $this->getPageTitle(),
			'location_continent_code' => ($locationDetails['continent_code'] != false ? $locationDetails['continent_code'] : ''),
			'location_continent_name' => ($locationDetails['continent_name'] != false ? $locationDetails['continent_name'] : ''),
			'location_country_code' => ($locationDetails['country_code'] != false ? $locationDetails['country_code'] : ''),
			'location_country_name' => ($locationDetails['country_name'] != false ? $locationDetails['country_name'] : ''),
		);		
		
		if(isset($this->request['organicImagesTracker']))
		{
			$this->handleOrganicImages($this->request['organicImagesTracker']);
		}
	}
	
	private function handleOrganicImages($request)
	{
		$handler_info = $this->visitorInfo;
		
		//$content_text = $this->sanitizeText($request['ct']);
		$content_url = urldecode($request['imgurl']);
		$content_filename = basename($content_url);
		
		$handler_info['content_url'] = $content_url;
		
		$filenameIsImage = false;
		foreach($this->availableImagesExts as $imgExt)
		{
			if(strpos($content_filename,$imgExt) !== false)
			{
				$filenameIsImage = true;
			}
		}
		
		if($filenameIsImage)
		{
			$handler_info['content_filename'] = $content_filename;
			$handler_info['content_filename_length'] = strlen($content_filename);
		}
		
		if(isset($request['keyword']))
		{
			$handler_info['referer_keywords'] = $request['keyword'];	
		}
		
		if(isset($request['imgurl_width']))
		{
			$handler_info['content_width'] = $request['imgurl_width'];
		}
		
		if(isset($request['imgurl_height']))
		{
			$handler_info['content_height'] = $request['imgurl_height'];
		}
		
		if(isset($request['imgurl_title']))
		{
			$handler_info['content_title'] = $this->sanitizeText($request['imgurl_title']);
		}
		
		if(isset($request['imgurl_alt']))
		{
			$handler_info['content_alt'] = $this->sanitizeText($request['imgurl_alt']);
		}
		
		if(isset($request['link_href']))
		{
			$handler_info['image_link_url'] = $request['link_href'];
		}
		
		if(isset($request['link_title']))
		{
			$handler_info['image_link_title'] = $this->sanitizeText($request['link_title']);
		}
		
		if(isset($request['link_rel']))
		{
			$handler_info['image_link_rel'] = $request['link_rel'];
		}
		
		if(isset($request['link_target']))
		{
			$handler_info['image_link_target'] = $request['link_target'];
		}
		
		/*
		$OS = getOS();
		$osUtils = $OS->getUtils();
		$fpath = os_join_path($OS->getConfigVar('cache_path'), 'tmp', 'trk_organicimages_endpoint.log');
		$osUtils->fileWrite($fpath, var_export($handler_info, true)."\n");
		*/
		
		$this->saveHandlerInformation($handler_info);	
	}
	
	private function saveHandlerInformation($handler_info)
	{
		if($this->project_id <= 0) return (false);
		
		//build sql query and save it to file
		
		//save query to file for later insertion into mysql database
		
		/*
		$oneImage = new OS_APP_organicimages_Image();
		$oneImage->set($handler_info);
		$oneImage->save();
		*/
		
		//buffer result to parse it later
		$log_file_path = $this->getLogFile();
		$dirname = dirname($log_file_path);
		if (!file_exists($dirname)) mkdir($dirname, 0755, true);
		
		if ($file = fopen($log_file_path, 'a+'))
		{
			$buffer = json_encode($handler_info);
			
			fwrite($file, $buffer."\n");
			fclose($file);
		}
	}
	
	private function getLogFile()
	{
		return os_join_path($this->appHandler->getAppStoragePath(),'buffer',floor(time()/3600).'.log');
	}	

	private function getRemoteAddr(){return (isset($_SERVER['REMOTE_ADDR']) ? $_SERVER['REMOTE_ADDR'] : '0.0.0.0');}
	
	private function getUserAgent() {return ( isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : '' );}
	
	private function getVisitorIp() {return $this->getRemoteAddr();}
	
	private function getPageUrl() {return (isset($this->extraData['url']) ? urldecode($this->extraData['url']) : '');}
	
	private function getPageTitle() {return (isset($this->extraData['pt']) ? $this->extraData['pt'] : '' );} 
	
	private function getCurrentTimestamp() {return time();}
	
	private function getCurrentDate( $format = "Y-m-d") {return date($format, $this->getCurrentTimestamp());}
	
	private function getBrowserLanguage() {return $this->extraData['lg'];}

	private function isHostKnownAliasHost($urlHost){return (false);}
	
	private function sanitizeText($text)
	{
		if(function_exists('iconv'))
		{
			$charset = 'iso-8859-2';
			$text = @iconv($charset, 'utf-8//IGNORE', $text);	
		}
		
		return $text;
	}

	private function error($error,$error_code,$header="HTTP/1.0 400 Bad Request")
	{
		//trigger_error("OrganicImages :: {$error_code} | {$error} | {$this->jsonString}", E_WARNING);	
	}
}	