<?php
class OS_APP_OrganicImages_ImageView extends OS_AppViewBase
{
	private $appPlugin;
	
	private $imageUrlHash;
	
	private $pageUrlHash;
	
	private $groupName;
	
	private $groupValue;
	
	private $problemName;
	
	private $projectId;
	
	private $problemsTypes;
	
	private $backView;
	
	public function __construct()
	{
		$OS = getOS();
		
		$this->projectId = $OS->getProject()->id;
		
		$this->appPlugin = $OS->getAppHandler()->getAppPlugin();
		
		$this->problemsTypes = array(
			'error' => array('score'=> 3,'color'=> "red"),
			'warning'=> array('score'=> 2,'color'=> "yellow"),
			'notice' => array('score'=> 1,'color'=> "blue"),
			'success' => array('score'=> 0,'color'=> "green")
			); 
		
		parent::__construct();
	}
	
	public function processRequest()
	{
		$requestParams = $this->appPlugin->getRequestParams();
		
		if(isset($requestParams['image_hash'],$requestParams['page_hash']))
		{
			if((strlen($requestParams['image_hash']) == 32) && (strlen($requestParams['page_hash']) == 32))
			{
				$this->imageUrlHash = $requestParams['image_hash'];

				$this->pageUrlHash = $requestParams['page_hash'];
			}
		}
		
		if(isset($requestParams['gn']))
		{
			$this->groupName = $requestParams['gn'];
		}
		
		if(isset($requestParams['gv']))
		{
			$this->groupValue = $requestParams['gv'];
		}
		
		if(isset($requestParams['pb']))
		{
			$this->problemName = $requestParams['pb'];
		}
		
		if(isset($requestParams['back_view']))
		{
			$this->backView = $requestParams['back_view'];
		}
	}
		
	public function buildViewData()
	{
		$OS = getOS();
		
		$organicImagesOps = OS_APP_organicimages_Operations::get_instance();
		
		$imageReportData = $organicImagesOps->getImageReportData(array('project_id'=> $this->projectId, 'image_url_hash'=> $this->imageUrlHash, 'page_url_hash'=> $this->pageUrlHash));
		if(!empty($imageReportData))
		{
			$imageReportData = current($imageReportData);
			
			$tmpTests = array();
			foreach($imageReportData['tests'] as $testDetails)
			{
				$tmpTests[$testDetails['group']][$testDetails['name']] = array(
					'type' => $testDetails['type'],
					'name' => $testDetails['name'],
					'extra_data' => $testDetails['extra_data'],
					);
			}
			
			$osTemplateOps = OS_TemplateOperations::get_instance();
			
			$cache_image_url = $osTemplateOps->getCachedImagePath($imageReportData['image_url'], array('width'=> 320, 'height' => 240));
			if($cache_image_url == false)
			{
				//TODO: replace with "Not-Available" Image path if not good image
				$cache_image_url = $imageReportData['image_url'];
			}
			
			$viewDataVars['imageReportData']['imageDetails'] = array(
				'image_url' => $imageReportData['image_url'],
				'cache_image_url' => $cache_image_url,
				'image_url_hash' => $imageReportData['image_url_hash'],
				'page_url' => $imageReportData['page_url'],
				'page_url_hash' => $imageReportData['page_url_hash'],
				'page_title' => $imageReportData['page_title'],
				'errors' => $imageReportData['errors'],
				'warnings' => $imageReportData['warnings'],
				'notices' => $imageReportData['notices'],
				'score' => $imageReportData['score']
			);
			
			$availableImageDetails = array('alt_content', 'title_content', 'image_width', 'image_height', 'image_filename');
			
			foreach($availableImageDetails as $imgDetail)
			{
				if(!empty($imageReportData['image_details'][$imgDetail]))
				{	
					$viewDataVars['imageReportData']['imageDetails'][$imgDetail] = $imageReportData['image_details'][$imgDetail]; 
				}
			}
			
			$viewDataVars['imageReportData']['testsDetails'] = $tmpTests;
		}
		
		return $viewDataVars;
	}
	
	public function render()
	{
		//throw error
		//if(!isset($this->imageUrlHash))
		
		$OS = getOS();
		
		$tplVars = array();
		
		$headContents = array();
		
		$viewData = $this->buildViewData();
		
		$organicImagesTests = OS_APP_organicimages_Tests::get_instance();
		
		$testGroups = $organicImagesTests->getTestGroups();
		$imageTests = $organicImagesTests->prepareTestsReports();
		$imageProblems = array();
		
		if(isset($viewData['imageReportData']))
		{
			$imageProblems = $viewData['imageReportData']['testsDetails'];
			
			$tplVars['imageDetails'] = $viewData['imageReportData']['imageDetails'];
		}
		
		$tplVars['testsReport'] = array();
		foreach($imageTests as $groupName => $tests)
		{
			$boxProblemType = 'success'; $boxTotalProblems = 0;
			foreach($tests as $testName => $testDetails)
			{
				//check if there are any problems for this test
				$tmpData = array('test' => array('message' => $testDetails['test_message']), 'result' => array('type' => 'success'));
				
				$testProblems = array_keys($testDetails['problems']);
				
				if(isset($imageProblems[$groupName]))
				{
					foreach($testProblems as $messageKey)
					{
						if(isset($imageProblems[$groupName][$messageKey]))
						{
							//handle problem message
							$problem_message = $testDetails['problems'][$messageKey]['message'];
							
							$tmpData['result']['message'] = $problem_message;
							
							if(!empty($imageProblems[$groupName][$messageKey]['extra_data']))
							{
								$extraData = json_decode($imageProblems[$groupName][$messageKey]['extra_data'], true);
								if(!empty($extraData))
								{
									$tmpData['result']['message'] = vsprintf($problem_message, $extraData);	
								}
							}
							
							//handle problem type
							$tmpData['result']['type'] = $imageProblems[$groupName][$messageKey]['type'];
							$boxTotalProblems++;
							
							//check box problem type
							if($this->problemsTypes[$tmpData['result']['type']]['score'] > $this->problemsTypes[$boxProblemType]['score'])
							{
								$boxProblemType = $tmpData['result']['type'];
							}
						}
					}
				}
				
				$tplVars['testsReport'][$groupName]['tests'][$testName] = $tmpData;
			}
			
			$tplVars['testsReport'][$groupName]['title'] = $testGroups[$groupName]['title'];
			$tplVars['testsReport'][$groupName]['total_problems'] = $boxTotalProblems; 
			$tplVars['testsReport'][$groupName]['box_problem_type'] = $boxProblemType;
			$tplVars['testsReport'][$groupName]['box_problem_type_color'] = $this->problemsTypes[$boxProblemType]['color'];
		}
		
		
		$menuBackLinks = array('back_view'=> 'seoview');
		
		if(isset($this->backView))
		{
			if($this->backView == 'problemview')
			{
				$menuBackLinks = array('back_view'=> 'problemview', 'gn' => $this->groupName , 'pb' => $this->problemName);	
			}
			elseif($this->backView == 'groupview')
			{
				$menuBackLinks = array('back_view'=> 'groupview', 'gn' => $this->groupName , 'gv' => $this->groupValue);
			}
		}
		
		
		$this->appPlugin->setMenuBackLink($menuBackLinks);
		
		$tpl = $OS->getTemplate();
		
		return $tpl->fetchTemplate('imageview', $tplVars);
	}
}
?>