<?php 
class OS_APP_OrganicImages_mainView extends OS_AppViewBase
{
	private $primaryDimension;
	
	private $primaryDimensionName;
	
	private $secondaryDimension;
	
	private $secondaryDimensionName;
	
	private $availableDimensions;
	
	private $availableGroups;
	
	private $currentSet;
	
	private $maxRows;
	
	private $availableTotalRows;
	
	private $startCounter;
	
	public function __construct()
	{
		$this->availableDimensions = array(
			'image_url' => array('name'=> 'content_url', 'table_name' => 'track_content', 'title' => _("Image URL"), 'group'=>'traffic', 'type'=> 'default'),
			'keyword' => array('name'=> 'referer_keywords', 'table_name' => 'track_referer', 'title' => _("Keyword"), 'group'=>'traffic', 'type'=> 'default'),
			'landing_page' => array('name'=> 'page_url', 'table_name' => 'track_page', 'title' => _("Landing Page"), 'group'=>'traffic'),
			//'source' => array('name'=> 'source', 'title' => _("Source"), 'group'=>'traffic'),
			'country' => array('name'=> 'location_country_name', 'table_name' => 'track_location', 'title' => _("Country"), 'group'=>'visitor', 'type'=> 'default'),
			'continent' => array('name'=> 'location_continent_name', 'table_name' => 'track_location', 'title' => _("Continent"), 'group'=>'visitor'),
			//'language' => array('name'=> 'location_language', 'title' => _("Language"), 'group'=>'visitor'),
			//'config_os' => array('name'=> 'location_country_name', 'title' => _("Operating System"), 'group'=>'technology'),
			//'config_mobile' => array('name'=> 'config_mobile', 'title' => _("Mobile Devices"), 'group'=>'technology'),
			//'config_browser' => array('name'=> 'config_browser', 'title' => _("Browser"), 'group'=>'technology')
		);	
		
		//add image properties
		
		$this->availableGroups = array(
			'traffic' => array("title" => _("Traffic")),
			'visitor' => array("title" => _("Visitor")),
			'technology' => array("title" => _("Technology"))
		);
		
		$this->availableTotalRows = array(10,25,50,100);
		
		parent::__construct();
	}
	
	public function processRequest()
	{
		//handle get & post requests
		$OS = getOS();
		
		$osAppPlugin = $OS->getAppHandler()->getAppPlugin();
		
		$requestParams = $osAppPlugin->getRequestParams();
		
		$this->primaryDimension = 'content_url'; 
		$this->primaryDimensionName = 'image_url';
		$this->secondaryDimension = false;
		$this->secondaryDimensionName = false;
		
		//Detect primary dimension
		if(isset($requestParams['pd']))
		{
			if(isset($this->availableDimensions[$requestParams['pd']]))
			{
				$this->primaryDimension = $this->availableDimensions[$requestParams['pd']]['name'];

				$this->primaryDimensionName = $requestParams['pd'];
			}
		}
		
		//Detect secondary dimension
		if(isset($requestParams['sd']))
		{
			if(isset($this->availableDimensions[$requestParams['sd']]))
			{
				$this->secondaryDimension = $this->availableDimensions[$requestParams['sd']]['name'];

				$this->secondaryDimensionName = $requestParams['sd'];
			}
		}
		
		$this->maxRows = 10;
		if(isset($requestParams['rows']))
		{
			if(in_array($requestParams['rows'], $this->availableTotalRows))
			{
				$this->maxRows = $requestParams['rows'];			
			}
		}
				
		$this->currentSet = 1;
		if(isset($requestParams['page']))
		{
			if(is_numeric($requestParams['page']))
			{
				if($requestParams['page'] > 0)
				{
					$this->currentSet = $requestParams['page'];
					$this->startCounter = (($requestParams['page'] * $this->maxRows) - $this->maxRows);			
				}
			}
		}
	}
	
	public function buildViewData()
	{
		$OS = getOS();
		
		$osProject = $OS->getProject();
		
		$organicImagesOps = OS_APP_organicimages_Operations::get_instance();
		
		$project_id = $osProject->id;

		//get images timeframe
		
		//get gobal timeframe
		$osTimeframe = $OS->getTimeframe();
		$timeframe = $osTimeframe->getTimeframe();
		$start_d = $timeframe['first'];
		$end_d = $timeframe['last'];
				
		$viewDataVars = array();
		
		//cache results
		$osCache = $OS->getCache();
		
		$params = array('project_id' => $project_id, 'start_d' => $start_d, 'end_d' => $end_d);
		
		$cache_key = md5('organicimages'.'timeframe'.implode(".", $params)); 
		$timeFrameResult = $osCache->get($cache_key);
		if($timeFrameResult === false)
		{
			$timeFrameResult = $organicImagesOps->getProjectImagesTimeframe($params);
		}	
		$viewDataVars['timeFrameResult'] = $timeFrameResult; 
		
		//build smart table data
		$params['primary_dimension'] = $this->primaryDimension;
		$params['secondary_dimension'] = $this->secondaryDimension;
		$params['set'] = $this->currentSet;
		$params['max_rows'] = $this->maxRows;
		
		$cache_key = md5('organicimages'.'stable'.implode(".", $params));
		$imageUrlReport = $osCache->get($cache_key);
		if($imageUrlReport === false)
		{
			$imageUrlReport = $organicImagesOps->getCustomReport($params);	
		}
		$viewDataVars['imageUrlReport'] = $imageUrlReport;
		
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS = getOS();
		
		$tplVars = array();
		
		$viewData = $this->buildViewData();
		
		$osAppPlugin = $OS->getAppHandler()->getAppPlugin();
			
		$chartValues = array(); $chartTooltips = array(); $chartLabels = array(); $headContents = array();
		
		if(!empty($viewData['timeFrameResult']))
		{
			foreach ($viewData['timeFrameResult'] as $day => $totalVisits)
			{
				$chartValues[] = $totalVisits;
				if (date('N',strtotime($day)) == 6)
				{
					$chartLabels[] = date('d M', strtotime($day));
				}
				else
				{
					$chartLabels[] = false;
				}
				$chartTooltips[] = "{$totalVisits} "._("Visits")."\n".date('d M', strtotime($day));
			}
			
			$charts = $OS->getCharts();
			
			$chartOptions = array(
				'values' => array_values($chartValues),
				'labels' => $chartLabels,
				'tooltips' => $chartTooltips,
				'fill' => true,
				'normalize' => true
			);
			
			$chartData = $charts->getLineChart($chartOptions);
			
			$tplVars['chart_html'] = $chartData['html'];
			
			foreach ($chartData['js'] as $key=>$val)
			{
				$headContents['chart_'.$key]=$val;
			}
		}
		
		//build available dimensions
		$availableDimensions = array();
		foreach($this->availableGroups as $group_type=>$group_details)
		{
			$tmpData = array('title' => $group_details['title']);

			foreach($this->availableDimensions as $dimension_type=>$dimension_details)
			{
				if((isset($dimension_details['group'])) && ($dimension_details['group'] == $group_type))
				{
					$tmpData['dimensions'][$dimension_type] = array(
						'title' => $dimension_details['title'],
						'option' => $dimension_type,
					);	
				}
			}

			$availableDimensions[$group_type] = $tmpData;
		}
		
		
		//Build live table
		$tplVars['liveTable'] = array(
			'title' => _("Visitor Segmentation"),
			'column_3_name' => _("Unique visitors"),
			'availableDimensions' => $availableDimensions,
			'currentPrimaryDimension' => $this->primaryDimensionName,
			'currentSecondaryDimension' => $this->secondaryDimensionName,
			'availableTotalRows' => $this->availableTotalRows,
			'currentCurrentRowsRange' =>  $this->maxRows,
			'currentTableView' => 'view'
			);
		
		if(!empty($viewData['imageUrlReport']))
		{
			$osGeoIP = $OS->getGeoIP();
			$geoCountries = $osGeoIP->getGeoCountries();
			
			foreach($viewData['imageUrlReport'] as $index => $values)
			{
				$tplVars['liveTable']['reportData'][$index] = array(
					'primary_metric' => $values['primary_metric'],
					'secondary_metric' => $values['secondary_metric'],
					'total' => $values['total_value'],
					'percentage' => $values['percentage'],
					'view_link' => $osAppPlugin->getAppActionUrl("pageview", array('dn'=> $this->primaryDimensionName,'dv'=> $values["primary_metric"])),
					);
					 
				if($this->primaryDimensionName == 'country')
				{
					$contryCode = $geoCountries->getCodeByCountryName($values['primary_metric']);
					if($contryCode)
					{
						$tplVars['liveTable']['reportData'][$index]['primary_flag_code'] = "flag-".strtolower($contryCode); 			
					}
					
				}
				elseif($this->secondaryDimensionName == 'country')
				{
					$contryCode = $geoCountries->getCodeByCountryName($values['secondary_metric']);
					if($contryCode)
					{
						$tplVars['liveTable']['reportData'][$index]['secondary_flag_code'] = "flag-".strtolower($contryCode);	
					}
				}
			}
		}
		
		$root_url =  $OS->getConfigVar('root_url');
		$headContents['flags.css'] = "<link href='{$root_url}/lib/css/flags.css' rel='stylesheet' type='text/css' />";
		
		$tpl = $OS->getTemplate();
		
		$tpl->setHeadContents($headContents);
		
		return $tpl->fetchTemplate('mainview', $tplVars);
	}
}
?>