<?php 
class OS_APP_OrganicImages_pageView extends OS_AppViewBase
{
	private $mainDimension;
	
	private $mainDimensionName;
	
	private $mainDimensionValue;
	
	private $primaryDimension;
	
	private $primaryDimensionName;
	
	private $secondaryDimension;
	
	private $secondaryDimensionName;
	
	private $availableDimensions;
	
	private $availableGroups;
	
	private $currentSet;
	
	private $maxRows;
	
	private $availableTotalRows;
	
	private $startCounter;
	
	public function __construct()
	{
		$this->availableDimensions = array(
			'image_url' => array('name'=> 'content_url', 'title' => _("Image URL"), 'group'=>'traffic', 'type'=> 'default'),
			'keyword' => array('name'=> 'referer_keywords', 'title' => _("Keyword"), 'group'=>'traffic', 'type'=> 'default'),
			'landing_page' => array('name'=> 'page_url', 'title' => _("Landing Page"), 'group'=>'traffic'),
			//'source' => array('name'=> 'source', 'title' => _("Source"), 'group'=>'traffic'),
			'country' => array('name'=> 'location_country_name', 'title' => _("Country"), 'group'=>'visitor', 'type'=> 'default'),
			'continent' => array('name'=> 'location_continent_name', 'title' => _("Continent"), 'group'=>'visitor'),
			//'language' => array('name'=> 'location_language', 'title' => _("Language"), 'group'=>'visitor'),
			//'config_os' => array('name'=> 'location_country_name', 'title' => _("Operating System"), 'group'=>'technology'),
			//'config_mobile' => array('name'=> 'config_mobile', 'title' => _("Mobile Devices"), 'group'=>'technology'),
			//'config_browser' => array('name'=> 'config_browser', 'title' => _("Browser"), 'group'=>'technology')
		);	
		
		//add image properties
		$this->availableGroups = array(
			'traffic' => array("title" => _("Traffic")),
			'visitor' => array("title" => _("Visitor")),
			'technology' => array("title" => _("Technology"))
		);
		
		$this->appPlugin = getOS()->getAppHandler()->getAppPlugin();
		
		$this->availableTotalRows = array(10,25,50,100);
		
		parent::__construct();
	}
	
	public function processRequest()
	{
		//handle get & post requests
		$OS = getOS();
		
		$requestParams = $this->appPlugin->getRequestParams();

		//Detect current dimension
		if(isset($requestParams['dn'], $requestParams['dv']))
		{
			if(isset($this->availableDimensions[$requestParams['dn']]))
			{
				$this->mainDimension = $this->availableDimensions[$requestParams['dn']]['name'];;
				$this->mainDimensionName = $requestParams['dn'];
				$this->mainDimensionValue = $requestParams['dv'];
			}
		}
		
		//if not valid main dimension exit
		
		$this->primaryDimension = $this->mainDimension; 
		$this->primaryDimensionName = $this->mainDimensionName;
		$this->secondaryDimension = false;
		$this->secondaryDimensionName = false;
		
		//Detect primary dimension
		if(isset($requestParams['pd']))
		{
			if(isset($this->availableDimensions[$requestParams['pd']]))
			{
				$this->primaryDimension = $this->availableDimensions[$requestParams['pd']]['name'];

				$this->primaryDimensionName = $requestParams['pd'];
			}
		}
		
		//Detect secondary dimension
		if(isset($requestParams['sd']))
		{
			if(isset($this->availableDimensions[$requestParams['sd']]))
			{
				$this->secondaryDimension = $this->availableDimensions[$requestParams['sd']]['name'];

				$this->secondaryDimensionName = $requestParams['sd'];
			}
		}
		
		$this->maxRows = 10;
		if(isset($requestParams['rows']))
		{
			if(in_array($requestParams['rows'], $this->availableTotalRows))
			{
				$this->maxRows = $requestParams['rows'];			
			}
		}
				
		$this->currentSet = 1;
		if(isset($requestParams['page']))
		{
			if(is_numeric($requestParams['page']))
			{
				if($requestParams['page'] > 0)
				{
					$this->currentSet = $requestParams['page'];
					$this->startCounter = (($requestParams['page'] * $this->maxRows) - $this->maxRows);			
				}
			}
		}
	}
	
	public function buildViewData()
	{
		$OS = getOS();
		
		$osProject = $OS->getProject();
		
		$organicImagesOps = OS_APP_organicimages_Operations::get_instance();
		
		$project_id = $osProject->id;

		//get images timeframe
		
		//get gobal timeframe
		$osTimeframe = $OS->getTimeframe();
		$timeframe = $osTimeframe->getTimeframe();
		$start_d = $timeframe['first'];
		$end_d = $timeframe['last'];
				
		$viewDataVars = array();
		
		//add cache here
		$params = array('project_id' => $project_id, 'start_d' => $start_d, 'end_d' => $end_d, 'main_dimension_name' => $this->mainDimension, 'main_dimension_value' => $this->mainDimensionValue);

		//cache results
		$osCache = $OS->getCache();
		
		$cache_key = md5('organicimages'.'timeframe'.implode('.',$params)); 
		$timeFrameResult = $osCache->get($cache_key);
		if($timeFrameResult === false)
		{
			$timeFrameResult = $organicImagesOps->getProjectImagesTimeframeUnit($params);
		}
		$viewDataVars['timeFrameResult'] = $timeFrameResult;

		//build smart table data
		$params['primary_dimension'] = $this->primaryDimension;
		$params['secondary_dimension'] = $this->secondaryDimension;
		$params['set'] = $this->currentSet;
		$params['max_rows'] = $this->maxRows;
				
		$cache_key = md5('organicimages'.'stable'.implode('.',$params));
		$imageUrlReport = $osCache->get($cache_key);
		if($imageUrlReport === false)
		{
			$imageUrlReport = $organicImagesOps->getCustomReportUnit($params);	
		}
		$viewDataVars['imageUrlReport'] = $imageUrlReport;
				
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS = getOS();
		
		$tplVars = array();
		
		$viewData = $this->buildViewData();
		
		$chartValues = array(); $chartTooltips = array(); $chartLabels = array(); $headContents = array();
		
		if(!empty($viewData['timeFrameResult']))
		{
			foreach ($viewData['timeFrameResult'] as $day => $images)
			{
				$chartValues[] = $images;
				if (date('N',strtotime($day)) == 6)
				{
					$chartLabels[] = date('d M', strtotime($day));
				}
				else
				{
					$chartLabels[] = false;
				}
				$chartTooltips[] = date('d M', strtotime($day))."\n{$images} "._("images");
			}
			
			$charts = $OS->getCharts();
			
			$chartOptions = array(
				'values' => array_values($chartValues),
				'labels' => $chartLabels,
				'tooltips' => $chartTooltips,
				'fill' => true,
				'normalize' => true
			);
			
			$chartData = $charts->getLineChart($chartOptions);
			
			$tplVars['chart_html'] = $chartData['html'];
			
			foreach ($chartData['js'] as $key=>$val)
			{
				$headContents['chart_'.$key]=$val;
			}
		}
		
		
		//build available dimensions
		$availableDimensions = array();
		foreach($this->availableGroups as $group_type=>$group_details)
		{
			$tmpData = array(
				'title' => $group_details['title']
				);		

			foreach($this->availableDimensions as $dimension_type=>$dimension_details)
			{
				if((isset($dimension_details['group'])) && ($dimension_details['group'] == $group_type))
				{
					$tmpData['dimensions'][$dimension_type] = array(
						'title' => $dimension_details['title'],
						'option' => $dimension_type,
					);	
				}
			}

			$availableDimensions[$group_type] = $tmpData;
		}
		
		
		//Build live table
		$tplVars['liveTable'] = array(
			'title' => _("Visitor Segmentation"),
			'column_3_name' => "Unique visitors",
			'availableDimensions' => $availableDimensions,
			'currentPrimaryDimension' => $this->primaryDimensionName,
			'currentSecondaryDimension' => $this->secondaryDimensionName,
			'availableTotalRows' => $this->availableTotalRows,
			'currentCurrentRowsRange' => $this->maxRows,
			'mainDimensionName' => $this->mainDimensionName,
			'mainDimensionValue' => $this->mainDimensionValue,
			'currentTableView' => 'pageview'
			);
		
		
		if(!empty($viewData['imageUrlReport']))
		{
			$osGeoIP = $OS->getGeoIP();
			$geoCountries = $osGeoIP->getGeoCountries();
			
			foreach($viewData['imageUrlReport'] as $index => $values)
			{
				$tplVars['liveTable']['reportData'][$index] = array(
					'primary_metric' => $values['primary_metric'],
					'secondary_metric' => $values['secondary_metric'],
					'total' => $values['total_value'],
					'percentage' => $values['percentage']
					); 
					
				if($this->primaryDimensionName == 'country')
				{
					$contryCode = $geoCountries->getCodeByCountryName($values['primary_metric']);
					if($contryCode)
					{
						$tplVars['liveTable']['reportData'][$index]['primary_flag_code'] = "flag-".strtolower($contryCode); 			
					}
					
				}
				elseif($this->secondaryDimensionName == 'country')
				{
					$contryCode = $geoCountries->getCodeByCountryName($values['secondary_metric']);
					if($contryCode)
					{
						$tplVars['liveTable']['reportData'][$index]['secondary_flag_code'] = "flag-".strtolower($contryCode);	
					}
				}
					
			}
		}
		
		$this->appPlugin->setMenuBackLink( array('back_view'=> 'mainview'));
		
		$root_url =  $OS->getConfigVar('root_url');
		$headContents['flags.css'] = "<link href='{$root_url}/lib/css/flags.css' rel='stylesheet' type='text/css' />";
		
		$tpl = $OS->getTemplate();
		
		$tpl->setHeadContents($headContents);
		
		return $tpl->fetchTemplate('pageview', $tplVars);
	}
}
?>