<?php
class OS_APP_OrganicImages_ProblemView extends OS_AppViewBase
{
	private $appPlugin;
	
	private $groupName;
	
	private $problemName;
	
	private $projectId;
	
	private $currentSet;
	
	private $maxRows;
	
	private $availableTotalRows;
	
	private $startCounter;
	
	public function __construct()
	{
		$OS = getOS();
		
		$this->projectId = $OS->getProject()->id;
		
		$this->appPlugin = $OS->getAppHandler()->getAppPlugin();
		
		$this->availableTotalRows = array(10,25,50,100);
		
		$this->startCounter = 0;
		
		parent::__construct();
	}
	
	public function processRequest()
	{
		$requestParams = $this->appPlugin->getRequestParams();
		
		if(isset($requestParams['gn'],$requestParams['pb']))
		{
			$this->groupName = $requestParams['gn'];

			$this->problemName = $requestParams['pb'];
		}
		
		$this->maxRows = 10;
		if(isset($requestParams['rows']))
		{
			if(in_array($requestParams['rows'], $this->availableTotalRows))
			{
				$this->maxRows = $requestParams['rows'];			
			}
		}
		
		$this->currentSet = 1;
		if(isset($requestParams['page']))
		{
			if(is_numeric($requestParams['page']))
			{
				if($requestParams['page'] > 0)
				{
					$this->currentSet = $requestParams['page'];
					$this->startCounter = (($requestParams['page'] * $this->maxRows) - $this->maxRows);			
				}
			}
		}
	}
		
	public function buildViewData()
	{
		$OS = getOS();
		
		$viewDataVars = array();
		
		$organicImagesOps = OS_APP_organicimages_Operations::get_instance();
		
		$imagesReportsByProblem = $organicImagesOps->getImagesReportsByProblem(array('project_id'=> $this->projectId, 'group_name'=> $this->groupName, 'problem_name'=> $this->problemName, 'set'=> $this->currentSet, 'max_rows'=> $this->maxRows));
		$viewDataVars['imagesReportsByProblem'] = $imagesReportsByProblem;
		
		return $viewDataVars;
	}
	
	public function render()
	{
		//throw error
		//if(!isset($this->groupName))
		
		$OS = getOS();
		
		$tplVars = array();
		
		$headContents = array();
		
		$viewData = $this->buildViewData();
		
		$tplVars['imagesScoreStats'] = array();
		if(isset($viewData['imagesReportsByProblem']))
		{
			foreach($viewData['imagesReportsByProblem'] as $report_id => $details)
			{
				$tplVars['imagesScoreStats'][$report_id] = array(
					'image_url' => $details['image_url'],
					'image_details_link' => $this->appPlugin->getAppActionUrl("imageview", array('image_hash'=> $details["image_url_hash"], 'page_hash'=> $details["page_url_hash"], 'gn'=>$this->groupName , 'pb'=>$this->problemName, 'back_view' => 'problemview')),
					'errors' => $details['errors'],
					'warnings' => $details['warnings'],
					'notices' => $details['notices'],
					'score'	 => $details['score']
					);
			}
		}
		
		
		$prev_page = ($this->currentSet > 1 ? ($this->currentSet - 1): 1);
		$next_page = $this->currentSet +1;
		
		$this->appPlugin->setMenuBackLink(array('back_view'=> 'seoview'));
		
		$linkParams = array('gn'=>$this->groupName , 'pb'=>$this->problemName, 'rows' => $this->maxRows);
		$tplVars['prev_link'] = $this->appPlugin->getAppActionUrl("problemview", array_merge($linkParams, array('page' => $prev_page)));
		$tplVars['next_link'] = $this->appPlugin->getAppActionUrl("problemview", array_merge($linkParams, array('page' => $next_page)));
		
		$tplVars['availableTotalRows'] = $this->availableTotalRows;
		$tplVars['maxRows'] = $this->maxRows;
		$tplVars['startCounter'] = $this->startCounter;
		$tplVars['linkParams'] = array_merge($linkParams, array('app' => 'organicimages', 'view' => 'problemview'));
		
		$tpl = $OS->getTemplate();
		
		return $tpl->fetchTemplate('problemview', $tplVars);
	}
}
?>