<?php 
class OS_APP_OrganicImages_seoView extends OS_AppViewBase
{
	private $appPlugin;
	
	private $projectId;
	
	private $currentSet;
	
	private $maxRows;
	
	private $availableTotalRows;
	
	private $startCounter;
	
	private $currentListTab;
	
	
	public function __construct()
	{
		$OS = getOS();
		
		$this->projectId = $OS->getProject()->id;
		
		$this->appPlugin = $OS->getAppHandler()->getAppPlugin();
		
		$this->availableTotalRows = array(10,25,50,100);
		
		parent::__construct();
	}
	
	public function processRequest()
	{
		//handle get & post requests
		$requestParams = $this->appPlugin->getRequestParams();
		
		$this->currentListTab = 'score_images';
		if(isset($_GET['list-type']))
		{
			if(in_array($_GET['list-type'], array('score_images','score_pages')))
			{
				$this->currentListTab = $_GET['list-type'];
			}
		}

		$this->maxRows = array('score_images'=> 10, 'score_pages' => 10);
		if(isset($requestParams['rows']))
		{
			if(in_array($requestParams['rows'], $this->availableTotalRows))
			{
				$this->maxRows[$this->currentListTab] = $requestParams['rows'];			
			}
		}
		
		$this->currentSet = array('score_images'=> 1, 'score_pages' => 1);
		$this->startCounter = array('score_images'=> 0, 'score_pages' => 0);
		
		if(isset($requestParams['page']))
		{
			if(is_numeric($requestParams['page']))
			{
				if($requestParams['page'] > 0)
				{
					$this->currentSet[$this->currentListTab] = $requestParams['page'];
					$this->startCounter[$this->currentListTab] = (($requestParams['page'] * $this->maxRows[$this->currentListTab]) - $this->maxRows[$this->currentListTab]);			
				}
			}
		}
	}
	
	public function buildViewData()
	{
		$OS = getOS();
		
		$osProject = $OS->getProject();
		
		$project_id = $osProject->id;
		
		//get images timeframe
		
		//get gobal timeframe
		$osTimeframe = $OS->getTimeframe();
		$timeframe = $osTimeframe->getTimeframe();
		$start_d = $timeframe['first'];
		$end_d = $timeframe['last'];
				
		$organicImagesOps = OS_APP_organicimages_Operations::get_instance();
				
		$viewDataVars = array();
		
		$imagesStatsTimeFrame = $organicImagesOps->getImagesStatsTimeFrame(array('project_id'=> $project_id, 'start_d'=> $start_d, 'end_d'=> $end_d));
		$viewDataVars['imagesStatsTimeFrame'] = $imagesStatsTimeFrame;
		
		$imagesStatsReports = $organicImagesOps->getImagesStatsReports(array('project_id'=> $project_id));
		$viewDataVars['imagesStatsReports'] = $imagesStatsReports;

		$tmpParams = array('project_id'=> $project_id, 'set'=> $this->currentSet['score_images'], 'max_rows'=> $this->maxRows['score_images']);			
		$imagesStatsByScore = $organicImagesOps->getImagesStatsByScore($tmpParams);
		$viewDataVars['imagesStatsByScore'] = $imagesStatsByScore;
		
		$tmpParams = array('project_id'=> $project_id, 'set'=> $this->currentSet['score_pages'], 'max_rows'=> $this->maxRows['score_pages']);
		$imagesStatsByPage = $organicImagesOps->getImagesStatsByPage($tmpParams);
		$viewDataVars['imagesStatsByPage'] = $imagesStatsByPage;
		
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS = getOS();
		
		$osProject = $OS->getProject();
		
		$tplVars = array();
		
		$headContents = array();
		
		$viewData = $this->buildViewData();
		
		$organicImagesTests = OS_APP_organicimages_Tests::get_instance();
		$imageTests = $organicImagesTests->prepareTestsReports();
		
		$mainTypes = array(
			'error' => array('name' => _('Images Errors'), 'title'=>_('Images with errors on optimization'), 'color'=>'red', 'color_hash' => "#C13A32"),
			'warning' => array('name' => _('Images Warnings'), 'title'=>_('Images with warnings on optimization'), 'color'=>'yellow', 'color_hash' => "#f1c40f"),
			'notice' => array('name' => _('Images Notices'), 'title'=>_('Images with notices on optimization'), 'color'=>'blue', 'color_hash' => "#3498db")
			);
		
		//Handle SEO Images TimeFrame
		if(isset($viewData['imagesStatsTimeFrame']))
		{
			$charts = $OS->getCharts();
			
			foreach($mainTypes as $typeName => $typeDetails)
			{
				$flag = false;
				$chartValues = array(); $chartTooltips = array(); $chartLabels = array();
				
				foreach ($viewData['imagesStatsTimeFrame'] as $stats_d => $stats_entry)
				{
					$total = $stats_entry[$typeName.'s'];
					$chartValues[] = $total;
					if (date('N',strtotime($stats_d)) == 6)
					{
						$chartLabels[] = date('d M', strtotime($stats_d));
					}
					else
					{
						$chartLabels[] = false;
					}
					$chartTooltips[] = "{$total} ".$typeDetails['name']."\n".date('d M', strtotime($stats_d));
				}
				
				$chartOptions = array(
					'values' => array_values($chartValues),
					'labels' => $chartLabels,
					'tooltips' => $chartTooltips,
					'color' => array($typeDetails['color_hash']),
					'fill' => true,
					'normalize' => true
				);
				
				$chartData = $charts->getLineChart($chartOptions);
				
				$tplVars['chartData']['html'][$typeName] = $chartData['html'];
				
				if(!$flag)
				{
					foreach ($chartData['js'] as $key=>$val)
					{
						$headContents['chart_'.$key]=$val;
					}
					$flag = true;
				}
			}
		}
		
		
		//Handle SEO Images Problems
		$imageTests = $organicImagesTests->prepareTestsReportsByType();
		$testGroups = $organicImagesTests->getTestGroups();
		
		$drillDownTests = (isset($viewData['imagesStatsReports']['drilldown']) ? $viewData['imagesStatsReports']['drilldown'] : array());
		
		foreach($mainTypes as $typeName => $typeData)
		{
			if(isset($imageTests[$typeName]))
			{
				$typeDetails = $imageTests[$typeName];
				
				$typeProblemsCounter = 0;
				
				$tmpGroups = array();
				foreach($typeDetails as $groupName => $groupDetails)
				{
					$groupTitle = $testGroups[$groupName]['title'];
					foreach($groupDetails as $problemKey => $problemDetails)
					{
						$tmpData = array('title' => $groupTitle.' - '.$problemDetails['title'], 'total' => 0);
						
						if(isset($drillDownTests[$typeName][$groupName][$problemKey]))
						{
							$total = $drillDownTests[$typeName][$groupName][$problemKey];
							$tmpData['view_link'] = $this->appPlugin->getAppActionUrl("problemview", array('gn'=> $groupName, 'pb'=> $problemKey));
							$tmpData['total'] = $total;
							$typeProblemsCounter += $total;
						}
						
						$tmpGroups[] = $tmpData;
					}
				}

				$tplVars['imagesStatsReports']['groupsView'][$typeName] = array(
					'total' => $typeProblemsCounter,
					'groups' => $tmpGroups,
					'typeTitle' => $typeData['title'],
					'typeName' => $typeData['name'],
					'typeColor' => $typeData['color'], 
					);
			}
		}

		
		//Handle SEO Images By Score
		if(!empty($viewData['imagesStatsByScore']))
		{
			foreach($viewData['imagesStatsByScore'] as $report_id => $details)
			{
				$tplVars['imagesScoreStats'][$report_id] = array(
					'image_url' => $details['image_url'],
					//'image_details_link' => $this->appPlugin->getAppActionUrl("imageview", array('image_hash'=> $details["image_url_hash"], 'page_hash'=> $details["page_url_hash"])),
					'image_details_link' => $this->appPlugin->getAppActionUrl("groupview", array('gn' => 'image_url_hash', 'gv'=> $details["image_url_hash"])),
					'errors' => $details['errors'],
					'warnings' => $details['warnings'],
					'notices' => $details['notices'],
					'score'	 => $details['score'],
					'total_pages' => $details['total_pages']
					);
			}
		}
		
		//Handle SEO Images By Score
		if(!empty($viewData['imagesStatsByPage']))
		{
			foreach($viewData['imagesStatsByPage'] as $report_id => $details)
			{
				$tplVars['imagesPageStats'][$report_id] = array(
					'page_url' => $details['page_url'],
					'image_details_link' => $this->appPlugin->getAppActionUrl("groupview", array('gn' => 'page_url_hash', 'gv'=> $details["page_url_hash"])),
					'errors' => $details['errors'],
					'warnings' => $details['warnings'],
					'notices' => $details['notices'],
					'score'	 => $details['score'],
					'total_images' => $details['total_images']
					);
			}
		}
		
		
		
		$prev_page = ($this->currentSet['score_images'] > 1 ? ($this->currentSet['score_images'] - 1): 1);
		$next_page = $this->currentSet['score_images'] + 1;
		
		$tplVars['prev_link_images'] = $this->appPlugin->getAppActionUrl("seoview", array('page' => $prev_page, 'list-type' => 'score_images', 'rows' => $this->maxRows['score_images']));
		$tplVars['next_link_images'] = $this->appPlugin->getAppActionUrl("seoview", array('page' => $next_page, 'list-type' => 'score_images', 'rows' => $this->maxRows['score_images']));

		$prev_page = ($this->currentSet['score_pages'] > 1 ? ($this->currentSet['score_pages'] - 1): 1);
		$next_page = $this->currentSet['score_pages'] + 1;
		
		$tplVars['prev_link_pages'] = $this->appPlugin->getAppActionUrl("seoview", array('page' => $prev_page, 'list-type' => 'score_pages', 'rows' => $this->maxRows['score_pages']));
		$tplVars['next_link_pages'] = $this->appPlugin->getAppActionUrl("seoview", array('page' => $next_page, 'list-type' => 'score_pages', 'rows' => $this->maxRows['score_pages']));
		
		
		$tplVars['availableTotalRows'] = $this->availableTotalRows;
		$tplVars['maxRows'] = $this->maxRows;
		$tplVars['startCounter'] = $this->startCounter;
		
		
		$tplVars['linkParamsImages'] = array('app' => 'organicimages', 'view' => 'seoview', 'list-type' => 'score_images');
		$tplVars['linkParamsPages'] = array('app' => 'organicimages', 'view' => 'seoview', 'list-type' => 'score_pages');
		
		
		//handle this
		$tplVars['currentListTab'] = $this->currentListTab; 
		
		$tpl = $OS->getTemplate();
		
		$tpl->setHeadContents($headContents);
		
		return $tpl->fetchTemplate('seoview', $tplVars);
	}
}
?>