<?php
class OS_APP_OutgoingLinks_LinkOperations
{
	private static $_instance;
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_OutgoingLinks_LinkOperations();
		}
		
		return self::$_instance;
	}
	
	public function getLinkByID($link_id,$project_id=false)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."links WHERE id=? AND project_id=?",array($link_id,$project_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_APP_OutgoingLinks_Link();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getLinks($project_id=false,$offset=0,$count=10,$arrayKey='id')
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		if ($count==0)
		{
			$query="SELECT * FROM ".$appHandler->dbPrefix()."links WHERE project_id=? ORDER BY `check_dt` DESC";
		}
		else
		{
			$query="SELECT * FROM ".$appHandler->dbPrefix()."links WHERE project_id=? ORDER BY `check_dt` DESC LIMIT {$offset},{$count}";
		}
		
		$dbresult=$db->query($query,array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneLink=new OS_APP_OutgoingLinks_Link();
			$oneLink->set($row);
			
			$result[$row[$arrayKey]]=$oneLink;
		}
		
		return $result;
	}
	
	public function getLinksCount($project_id=false)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT COUNT(id) AS total_reports FROM ".$appHandler->dbPrefix()."links WHERE project_id=?";
		
		$dbresult=$db->query($query,array($project_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row['total_reports'];
		}
		
		return $result;
	}
	
	public function getLatestLinks($project_id=false,$count=2)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."links WHERE project_id=? ORDER BY `insert_dt` DESC LIMIT {$count}",array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneLink=new OS_APP_OutgoingLinks_Link();
			$oneLink->set($row);
			
			$result[$row['id']]=$oneLink;
		}
		
		return $result;
	}
	
	public function getLinksForChecking($project_id=false,$count=50)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."links WHERE project_id=? ORDER BY `check_dt` DESC LIMIT {$count}",array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneLink=new OS_APP_OutgoingLinks_Link();
			$oneLink->set($row);
			
			$result[$row['id']]=$oneLink;
		}
		
		return $result;
	}
	
	public function insertLink($link)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="INSERT INTO ".$appHandler->dbPrefix()."links (project_id,url,url_hash,http_code,occurances,check_dt,seen_dt) VALUES (?,?,?,?,?,?,?)";
		$dbresult=$db->query($query,array($link->project_id,$link->url,$link->url_hash,$link->http_code,$link->occurances,$link->check_dt,$link->seen_dt));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateLink($link)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="UPDATE ".$appHandler->dbPrefix()."links SET http_code=?,occurances=?,check_dt=?,seen_dt=? WHERE id=?";
		$dbresult=$db->query($query,array($link->http_code,$link->occurances,$link->check_dt,$link->seen_dt,$link->id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteLinkByID($link_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."links WHERE id=?";
		$dbresult=$db->query($query,array($link_id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteObsoleteLinks($project_id,$seen_dt)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."links WHERE project_id=? AND seen_dt<?";
		$dbresult=$db->query($query,array($project_id,$seen_dt));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
}
?>