<?php
class OS_APP_OutgoingLinks_ReportOperations
{
	private static $_instance;
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_OutgoingLinks_ReportOperations();
		}
		
		return self::$_instance;
	}
	
	public function generateReport($project_id=false,$forceBrokenChecking=false)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$report_start_dt=$db->DBTimeStamp(time());
					
		$report=OS_APP_OutgoingLinks_Report::get_instance();
		
		$report->project_id=$project_id;
		
		$linking_urls=array();
		$linked_urls=array();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."projects_urls_links_external WHERE project_id=?",array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			if (!isset($linking_urls[$row['from_url']]))
			{
				$report->linking_urls++;
				$linking_urls[$row['from_url']]=true;
			}
			
			if (!isset($linked_urls[$row['to_url']]))
			{
				$report->linked_urls++;
				$linked_urls[$row['to_url']]=array('url_hash'=>$row['to_url_hash'],'occurances'=>0);
			}
			$linked_urls[$row['to_url']]['occurances']+=$row['occurances'];
			
			if (empty($row['nofollow']))
			{
				$report->occurances_dofollow+=$row['occurances'];
			}
			else
			{
				$report->occurances_nofollow+=$row['occurances'];
			}
			
			$report->occurances_total+=$row['occurances'];
		}
		
		$linkOps=OS_APP_OutgoingLinks_LinkOperations::get_instance();
		
		$existingLinks=$linkOps->getLinks($project_id,0,0,'url_hash');
		
		$osHttp=$OS->getHttp();
		foreach ($linked_urls as $url=>$details)
		{
			$shouldCheck=true;
			
			if (isset($existingLinks[$details['url_hash']]))
			{
				$oneLink=$existingLinks[$details['url_hash']];
				unset($existingLinks[$details['url_hash']]);
				
				if (!$forceBrokenChecking)
				{
					if (time()-strtotime($oneLink->check_dt)<86400)
					{
						$shouldCheck=false;
						$httpCode=$oneLink->http_code;
					}
				}
				
				$oneLink->occurances=$details['occurances'];
			}
			else
			{
				$oneLink=new OS_APP_OutgoingLinks_Link();
				$oneLink->project_id=$project_id;
				$oneLink->url=$url;
				$oneLink->url_hash=$details['url_hash'];
				$oneLink->occurances=$details['occurances'];
			}
			
			$dt=$db->DBTimeStamp(time());
			
			if ($shouldCheck)
			{
				$osHttp->get($url);
				
				$httpCode=$osHttp->responseCode;
				
				$oneLink->http_code=$osHttp->responseCode;
				$oneLink->check_dt=$dt;
			}
			
			$oneLink->seen_dt=$dt;
			
			$oneLink->save();
			
			if ($httpCode==0 OR $httpCode>400)
			{
				$report->broken_linked_urls++;
			}
		}
		
		if (!empty($existingLinks))
		{
			$linkOps->deleteObsoleteLinks($project_id,$report_start_dt);
		}
		
		if ($report->save())
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function getReportByID($report_id,$project_id=false)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE id=? AND project_id=?",array($report_id,$project_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_APP_OutgoingLinks_Report();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getReports($project_id=false,$offset=0,$count=10)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE project_id=? ORDER BY `insert_dt` DESC LIMIT {$offset},{$count}";
		
		$dbresult=$db->query($query,array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneReport=new OS_APP_OutgoingLinks_Report();
			$oneReport->set($row);
			
			$result[$row['id']]=$oneReport;
		}
		
		return $result;
	}
	
	public function getReportsCount($project_id=false)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT COUNT(id) AS total_reports FROM ".$appHandler->dbPrefix()."reports WHERE project_id=?";
		
		$dbresult=$db->query($query,array($project_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row['total_reports'];
		}
		
		return $result;
	}
	
	public function getLatestReports($project_id=false,$count=2)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE project_id=? ORDER BY `insert_dt` DESC LIMIT {$count}",array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneReport=new OS_APP_OutgoingLinks_Report();
			$oneReport->set($row);
			
			$result[$row['id']]=$oneReport;
		}
		
		return $result;
	}
	
	public function insertReport($report)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$query="INSERT INTO ".$appHandler->dbPrefix()."reports (project_id,linking_urls,linked_urls,broken_linked_urls,occurances_nofollow,occurances_dofollow,occurances_total,insert_dt) VALUES (?,?,?,?,?,?,?,?)";
		$dbresult=$db->query($query,array($report->project_id,$report->linking_urls,$report->linked_urls,$report->broken_linked_urls,$report->occurances_nofollow,$report->occurances_dofollow,$report->occurances_total,$time));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateReport($report)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$query="UPDATE ".$appHandler->dbPrefix()."reports SET linking_urls=?,linked_urls=?,broken_linked_urls=?,occurances_nofollow=?,occurances_dofollow=?,occurances_total=? WHERE id=?";
		$dbresult=$db->query($query,array($report->linking_urls,$report->linked_urls,$report->broken_linked_urls,$report->occurances_nofollow,$report->occurances_dofollow,$report->occurances_total,$report->id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteReportByID($report_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."reports WHERE id=?";
		$dbresult=$db->query($query,array($report_id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteDataByProjectID($project_id)
	{
		$result=true;
		
		$tables=array('reports','links');
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		foreach ($tables as $table)
		{
			$dbresult=$db->query("DELETE FROM ".$appHandler->dbPrefix().$table." WHERE project_id=?",array($project_id));
			
			if ($dbresult===false)
			{
				$result=false;
				break;
			}
		}
		
		return $result;
	}
}
?>