<?php
class OS_APPVIEW_OutgoingLinks_Url extends OS_AppViewBase
{
	private $urlTypes=array('from','to');
	
	private $filters;
	
	private $tableHeaders;
	
	public function __construct()
	{
		parent::__construct();
		
		$this->filters=array(
			'nofollow'=>array(
				'field'=>'nofollow',
				'value'=>'Y',
				'remove_headers'=>array('nofollow','dofollow'),
				'title_prepend'=>"Nofollow "
			),
			'dofollow'=>array(
				'field'=>'nofollow',
				'value'=>'',
				'remove_headers'=>array('nofollow','dofollow'),
				'title_prepend'=>"Dofollow "
			),
			'image'=>array(
				'field'=>'type',
				'value'=>'image',
				'remove_headers'=>array('text','image'),
				'title_prepend'=>_("Image")." "
			),
			'text'=>array(
				'field'=>'type',
				'value'=>'text',
				'remove_headers'=>array('text','image'),
				'title_prepend'=>_("Text")." "
			),
		);
		
		$this->tableHeaders=array('url'=>"URL",'total'=>_("Total"),'dofollow'=>"Dofollow",'nofollow'=>"Nofollow",'text'=>_("Text"),'image'=>_("Image"));
	}
	
	public function processRequest()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$requestParams=$appPlugin->getRequestParams();
		$processedRequest=array();
		
		if (empty($requestParams['url_type']))
		{
			$OS->redirectTO($appPlugin->getAppActionUrl('view'),true);
		}
		elseif (!in_array($requestParams['url_type'],$this->urlTypes))
		{
			$OS->redirectTO($appPlugin->getAppActionUrl('view'),true);
		}
		
		$processedRequest['url_type']=$requestParams['url_type'];
		$processedRequest['title_prepend']='';
		$processedRequest['where']=array();
		
		$this->tableHeaders['url']=($processedRequest['url_type']=='from'?_("To URL"):_("From URL"));
		
		if (!empty($requestParams['filters']))
		{
			$processedRequest['filters']=$requestParams['filters'];
			$filters=explode('|',$requestParams['filters']);

			foreach ($filters as $filter)
			{
				if (isset($this->filters[$filter]))
				{
					$processedRequest['where'][$this->filters[$filter]['field']]=$this->filters[$filter]['value'];
					
					if (!empty($this->filters[$filter]['remove_headers']))
					{
						foreach ($this->filters[$filter]['remove_headers'] as $header)
						{
							if (isset($this->tableHeaders[$header]))
							{
								unset($this->tableHeaders[$header]);
							}
						}
					}
					
					if (!empty($this->filters[$filter]['title_prepend']))
					{
						$processedRequest['title_prepend'].=$this->filters[$filter]['title_prepend'];
					}
				}
			}
		}
		else
		{
			$processedRequest['filters']=false;
		}
		
		if (empty($requestParams['url_hash']))
		{
			$OS->redirectTO($appPlugin->getAppActionUrl('urls',array('url_type'=>$requestParams['url_type'],'filters'=>$processedRequest['filters'])),true);
		}
		
		$processedRequest['url_hash']=$requestParams['url_hash'];
		$processedRequest['export']=(isset($requestParams['export']));

		return $processedRequest;
	}
	
	public function buildViewData()
	{
		$OS=getOS();
		
		$project=$OS->getProject();
		$db=$OS->getDb();
		$ops=OS_APP_OutgoingLinks_ReportOperations::get_instance();
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$url_type=$this->processedRequest['url_type'];
		
		$viewDataVars=array(
			'url_type'=>$url_type,
			'urls'=>array()
		);
		
		$opposite_url_type=($url_type=='to'?'from':'to');
		
		$query="SELECT * FROM ".$db->dbPrefix()."projects_urls_links_external WHERE project_id=? AND {$url_type}_url_hash=?";
		$query_params=array($project->id,$this->processedRequest['url_hash']);
		
		if (!empty($this->processedRequest['where']))
		{
			$first=true;
			
			foreach ($this->processedRequest['where'] as $field=>$value)
			{
				$query.=" AND {$field}=?";
				$query_params[]=$value;
				
				$first=false;
			}
		}

		$dbresult=$db->query($query,$query_params);
		while ($row=$db->fetchRow($dbresult))
		{
			if (!isset($viewDataVars['urls'][$row["{$opposite_url_type}_url_hash"]]))
			{
				$viewDataVars['urls'][$row["{$opposite_url_type}_url_hash"]]=array(
					'url'=>$row["{$opposite_url_type}_url"],
					'total'=>0,
					'nofollow'=>0,
					'dofollow'=>0,
					'image'=>0,
					'text'=>0
				);
			}
			
			$viewDataVars['urls'][$row["{$opposite_url_type}_url_hash"]]['total']+=$row['occurances'];
			
			if ($row['nofollow']=='Y')
			{
				$viewDataVars['urls'][$row["{$opposite_url_type}_url_hash"]]['nofollow']+=$row['occurances'];
			}
			else
			{
				$viewDataVars['urls'][$row["{$opposite_url_type}_url_hash"]]['dofollow']+=$row['occurances'];
			}
			
			if ($row['type']=='text')
			{
				$viewDataVars['urls'][$row["{$opposite_url_type}_url_hash"]]['text']+=$row['occurances'];
			}
			else
			{
				$viewDataVars['urls'][$row["{$opposite_url_type}_url_hash"]]['image']+=$row['occurances'];
			}
		}
		
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$tplVars=$this->buildViewData();
		
		if ($this->processedRequest['export'] AND !empty($tplVars['urls']))
		{
			$csv='';
			foreach ($this->tableHeaders as $header=>$name)
			{
				$csv.=(empty($csv)?'':',').$name;
			}
			
			foreach ($tplVars['urls'] as $url)
			{
				$line='';
				foreach ($this->tableHeaders as $header=>$name)
				{
					$line.=(empty($line)?'':',').$url[$header];
				}
				
				$csv.="\n{$line}";
			}
			
			header('Content-Type: text/plain');
			header('Content-Disposition: attachment; filename="links.csv"');
			
			echo $csv;
			exit;
		}
		else
		{
			$tplVars['tableHeaders']=$this->tableHeaders;
			
			$tplVars['tableTitle']=$this->processedRequest['title_prepend']._("Links");
			
			$tpl=$OS->getTemplate();
			
			if (!empty($tplVars['urls']))
			{
				$tplVars['export_url']=$appPlugin->getAppActionUrl('urls',array('url_type'=>$this->processedRequest['url_type'],'filters'=>$this->processedRequest['filters'],'export'=>'yes'));
			}
	
			return $tpl->fetchTemplate('url',$tplVars);
		}
	}
}
?>