<?php
class OS_APPVIEW_OutgoingLinks_Urls extends OS_AppViewBase
{
	private $urlTypes=array('from','to','broken');
	
	private $filters;
	
	private $tableHeaders;
	
	public function __construct()
	{
		parent::__construct();
		
		$this->filters=array(
			'nofollow'=>array(
				'field'=>'nofollow',
				'value'=>'Y',
				'remove_headers'=>array('nofollow','dofollow'),
				'title_prepend'=>"Nofollow "
			),
			'dofollow'=>array(
				'field'=>'nofollow',
				'value'=>'',
				'remove_headers'=>array('nofollow','dofollow'),
				'title_prepend'=>"Dofollow "
			),
			'image'=>array(
				'field'=>'type',
				'value'=>'image',
				'remove_headers'=>array('text','image'),
				'title_prepend'=>_("Image")." "
			),
			'text'=>array(
				'field'=>'type',
				'value'=>'text',
				'remove_headers'=>array('text','image'),
				'title_prepend'=>_("Text")." "
			),
		);
		
		$this->tableHeaders=array('url'=>"URL",'total'=>_("Total"),'dofollow'=>"Dofollow",'nofollow'=>"Nofollow",'text'=>_("Text"),'image'=>_("Image"));
	}
	
	public function processRequest()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$requestParams=$appPlugin->getRequestParams();
		$processedRequest=array();
		
		if (empty($requestParams['url_type']))
		{
			$OS->redirectTO($appPlugin->getAppActionUrl('view'),true);
		}
		elseif (!in_array($requestParams['url_type'],$this->urlTypes))
		{
			$OS->redirectTO($appPlugin->getAppActionUrl('view'),true);
		}
		
		$processedRequest['url_type']=$requestParams['url_type'];
		$processedRequest['title_prepend']='';
		$processedRequest['where']=array();
		
		$this->tableHeaders['url']=($processedRequest['url_type']=='from'?"From URL":"To URL");
		
		if ($requestParams['url_type']=='broken')
		{
			$processedRequest['filters']=false;
			
			$this->tableHeaders=array('url'=>"URL",'http_code'=>"HTTP Code",'total'=>"Total");
		}
		elseif (!empty($requestParams['filters']))
		{
			$processedRequest['filters']=$requestParams['filters'];
			$filters=explode('|',$requestParams['filters']);

			foreach ($filters as $filter)
			{
				if (isset($this->filters[$filter]))
				{
					$processedRequest['where'][$this->filters[$filter]['field']]=$this->filters[$filter]['value'];
					
					if (!empty($this->filters[$filter]['remove_headers']))
					{
						foreach ($this->filters[$filter]['remove_headers'] as $header)
						{
							if (isset($this->tableHeaders[$header]))
							{
								unset($this->tableHeaders[$header]);
							}
						}
					}
					
					if (!empty($this->filters[$filter]['title_prepend']))
					{
						$processedRequest['title_prepend'].=$this->filters[$filter]['title_prepend'];
					}
				}
			}
		}
		else
		{
			$processedRequest['filters']=false;
		}
		
		$processedRequest['export']=(isset($requestParams['export']));

		return $processedRequest;
	}
	
	public function buildViewData()
	{
		$OS=getOS();
		
		$project=$OS->getProject();
		$db=$OS->getDb();
		$ops=OS_APP_OutgoingLinks_ReportOperations::get_instance();
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$url_type=$this->processedRequest['url_type'];
		
		$viewDataVars=array(
			'url_type'=>$url_type,
			'urls'=>array()
		);
		
		if ($url_type=='broken')
		{
			$dbresult=$db->query("SELECT * FROM ".$appPlugin->dbPrefix()."links WHERE project_id=? AND (http_code=? OR http_code>?)",array($project->id,0,400));
			while ($row=$db->fetchRow($dbresult))
			{
				$viewDataVars['urls'][$row['url_hash']]=array(
					'url'=>$row['url'],
					'http_code'=>$row['http_code'],
					'total'=>$row['occurances'],
					'urls'=>array(
						'total'=>$appPlugin->getAppActionUrl('url',array('url_type'=>'to','url_hash'=>$row['url_hash']))
					)
				);
			}
		}
		else
		{
			$query="SELECT * FROM ".$db->dbPrefix()."projects_urls_links_external WHERE project_id=?";
			$query_params=array($project->id);
			
			if (!empty($this->processedRequest['where']))
			{
				$first=true;
				
				foreach ($this->processedRequest['where'] as $field=>$value)
				{
					$query.=" AND {$field}=?";
					$query_params[]=$value;
					
					$first=false;
				}
			}

			$dbresult=$db->query($query,$query_params);
			while ($row=$db->fetchRow($dbresult))
			{
				if (!isset($viewDataVars['urls'][$row["{$url_type}_url_hash"]]))
				{
					$viewDataVars['urls'][$row["{$url_type}_url_hash"]]=array(
						'url'=>$row["{$url_type}_url"],
						'total'=>0,
						'nofollow'=>0,
						'dofollow'=>0,
						'image'=>0,
						'text'=>0,
						'urls'=>array(
							'total'=>$appPlugin->getAppActionUrl('url',array('url_type'=>$url_type,'url_hash'=>$row["{$url_type}_url_hash"],'filters'=>(empty($this->processedRequest['filters'])?'':$this->processedRequest['filters']))),
							'nofollow'=>$appPlugin->getAppActionUrl('url',array('url_type'=>$url_type,'url_hash'=>$row["{$url_type}_url_hash"],'filters'=>(empty($this->processedRequest['filters'])?'':$this->processedRequest['filters'].'|').'nofollow')),
							'dofollow'=>$appPlugin->getAppActionUrl('url',array('url_type'=>$url_type,'url_hash'=>$row["{$url_type}_url_hash"],'filters'=>(empty($this->processedRequest['filters'])?'':$this->processedRequest['filters'].'|').'dofollow')),
							'image'=>$appPlugin->getAppActionUrl('url',array('url_type'=>$url_type,'url_hash'=>$row["{$url_type}_url_hash"],'filters'=>(empty($this->processedRequest['filters'])?'':$this->processedRequest['filters'].'|').'image')),
							'text'=>$appPlugin->getAppActionUrl('url',array('url_type'=>$url_type,'url_hash'=>$row["{$url_type}_url_hash"],'filters'=>(empty($this->processedRequest['filters'])?'':$this->processedRequest['filters'].'|').'text')),
						)
					);
				}
				
				$viewDataVars['urls'][$row["{$url_type}_url_hash"]]['total']+=$row['occurances'];
				
				if ($row['nofollow']=='Y')
				{
					$viewDataVars['urls'][$row["{$url_type}_url_hash"]]['nofollow']+=$row['occurances'];
				}
				else
				{
					$viewDataVars['urls'][$row["{$url_type}_url_hash"]]['dofollow']+=$row['occurances'];
				}
				
				if ($row['type']=='text')
				{
					$viewDataVars['urls'][$row["{$url_type}_url_hash"]]['text']+=$row['occurances'];
				}
				else
				{
					$viewDataVars['urls'][$row["{$url_type}_url_hash"]]['image']+=$row['occurances'];
				}
			}
		}
		
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$tplVars=$this->buildViewData();
		
		if ($this->processedRequest['export'] AND !empty($tplVars['urls']))
		{
			$csv='';
			foreach ($this->tableHeaders as $header=>$name)
			{
				$csv.=(empty($csv)?'':',').$name;
			}
			
			foreach ($tplVars['urls'] as $url)
			{
				$line='';
				foreach ($this->tableHeaders as $header=>$name)
				{
					$line.=(empty($line)?'':',').$url[$header];
				}
				
				$csv.="\n{$line}";
			}
			
			header('Content-Type: text/plain');
			header('Content-Disposition: attachment; filename="links.csv"');
			
			echo $csv;
			exit;
		}
		else
		{
			$tplVars['tableHeaders']=$this->tableHeaders;
			
			$tplVars['tableTitle']=$this->processedRequest['title_prepend']."Links";
			
			$tpl=$OS->getTemplate();
			
			if (!empty($tplVars['urls']))
			{
				$tplVars['export_url']=$appPlugin->getAppActionUrl('urls',array('url_type'=>$this->processedRequest['url_type'],'filters'=>$this->processedRequest['filters'],'export'=>'yes'));
			}
	
			return $tpl->fetchTemplate('urls',$tplVars);
		}
	}
}
?>