<?php
class OS_APP_RelatedKws extends OS_AppBase
{
	private static $_instance;
	
	protected function __construct()
	{
		parent::__construct();
		
		$this->addMenuItem('view', array("name" => _("Main"), 'routerOption'=> "handleMainView"));
		$this->addMenuItem('analyze', array("name" => _("Analyze keyword"), 'routerOption'=> "handleAnalyzeView"));
		
		$this->setRouterOption("report", "handleReportView");
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_RelatedKws();
		}
		return self::$_instance;
	}
	
	public function handleMainView()
	{
		getOS()->getUser()->forcePerm('relatedkws','view');
		
		$viewData=new OS_APPVIEW_RelatedKws_Main();
		
		return $viewData->render();
	}
	
	public function handleAnalyzeView()
	{
		getOS()->getUser()->forcePerm('relatedkws','view');
		
		$viewData=new OS_APPVIEW_RelatedKws_Analyze();
		
		return $viewData->render();
	}
	
	public function handleReportView()
	{
		getOS()->getUser()->forcePerm('relatedkws','view');
		
		$viewData=new OS_APPVIEW_RelatedKws_Report();
		
		return $viewData->render();
	}
	
	protected function defineAppPermissions()
	{
		$this->appPermissions=array(
			'relatedkws'=>array(
				'view'=>array('name'=>_("View related keywords")),
			)
		);
	}
	
	public function interactionWorkerGetRelatedKeywords($params)
	{
		$result=false;
		
		if (!empty($params['keyword']) AND !empty($params['options']))
		{
			$requiredOptions=array('bing'=>array('locale'),'google'=>array('locale'),'google_suggest'=>array('language'));
			
			$sides=array();$valid=true;
			foreach ($requiredOptions as $side=>$sideOptions)
			{
				if (isset($params['options'][$side]))
				{
					foreach ($sideOptions as $option)
					{
						if (empty($params['options'][$side][$option]))
						{
							$valid=false;
							break(2);
						}
					}
					
					$sides[$side]=true;
				}
			}
			
			if ($valid AND !empty($sides))
			{
				$oneReport=new OS_APP_RelatedKws_Report();
				
				$oneReport->project_id=$params['project_id'];
				$oneReport->keyword=$params['keyword'];
				$oneReport->bing_locale=(isset($sides['bing'])?$params['options']['bing']['locale']:'');
				$oneReport->google_locale=(isset($sides['google'])?$params['options']['google']['locale']:'');
				$oneReport->google_suggest_options=(isset($sides['google_suggest'])?array('language'=>$params['options']['google_suggest']['language'],'sources'=>array('web')):array());
				
				if ($oneReport->save())
				{
					$ops=OS_APP_RelatedKws_ReportOperations::get_instance();
					$ops->getRelated($oneReport);
					
					$oneReport->load();
					
					if ($oneReport->status=='D')
					{
						$result=array('status'=>'done','related_keywords'=>$oneReport->result);
					}
					else
					{
						$result=array('status'=>'queued','queue_id'=>$oneReport->id);
					}
				}
			}
		}
		
		return $result;
	}
	
	public function eventProjectDeleted($params)
	{
		$ops=OS_APP_RelatedKws_ReportOperations::get_instance();
		
		return $ops->deleteDataByProjectID($params['project_id']);
	}
	
	public function eventSearchEngineQueried($params)
	{
		$result=false;
		
		$ops=OS_APP_RelatedKws_ReportOperations::get_instance();
		$result=$ops->eventSearchEngineQueried($params);
		
		return $result;
	}
}
?>