<?php
class OS_APP_RelatedKws_Report
{
	private static $_instance;
	
	public $id;
	public $project_id;
	public $keyword;
	public $bing_locale;
	public $google_locale;
	public $google_suggest_options;
	public $insert_dt;
	public $insert_ip;
	public $status;
	public $status_dt;
	public $status_ip;
	public $result;
	
	public function __construct()
	{
		$this->setInitialValues();
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_RelatedKws_Report();
		}
		
		return self::$_instance;
	}
	
	public function setInitialValues()
	{
		$this->id=false;
		$this->project_id=0;
		$this->keyword='';
		$this->bing_locale='';
		$this->google_locale='';
		$this->google_suggest_options=array();
		$this->insert_dt='';
		$this->insert_ip='';
		$this->status='';
		$this->status_dt='';
		$this->status_ip='';
		$this->result=array();
	}
	
	public function set($data)
	{
		$result = false;
		
		$objVars = get_object_vars($this);
		
		foreach($objVars as $key=>$val)
		{
			if(isset($data[$key]))
			{
				$this->$key = $data[$key];
				$result = true;
			}
		}
		
		return $result;
	}
	
	public function save()
	{
		$result=false;
		
		$ops=OS_APP_RelatedKws_ReportOperations::get_instance();
		
		if (!$this->id)
		{
			if ($this->id=$ops->insertReport($this))
			{
				$result=true;
			}
		}
		else
		{
			$result=$ops->updateReport($this);
		}
		
		return $result;
	}
	
	public function load()
	{
		$result = false;
		
		if ($this->id)
		{
			$ops=OS_APP_RelatedKws_ReportOperations::get_instance();
			
			if ($data=$ops->getReportByID($this->id))
			{
				$this->set(get_object_vars($data));
				
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function delete()
	{
		$result = false;
		
		if ($this->id)
		{
			$ops=OS_APP_RelatedKws_ReportOperations::get_instance();
			
			$result=$ops->deleteReportByID($this->id);
		}
		
		return $result;
	}
	
	public function toTemplate()
	{
		if (!$this->id) return false;
		
		$utils=getOS()->getUtils();
		$app=getOS()->getAppHandler()->getAppPlugin();
		
		$ops=OS_APP_RelatedKws_ReportOperations::get_instance();
		
		$suggestLanguages=$ops->googleSuggestLanguages;
		
		$searchEngineOps=getOS()->getSearchEngineOps();
		
		$searchEngines=$searchEngineOps->getAvailableSearchEnginesFull();
		
		$allowedSearchEngines=array('google','bing');
		
		foreach ($searchEngines as $engine=>$details)
		{
			if (!in_array($engine,$allowedSearchEngines))
			{
				unset($searchEngines[$engine]);
			}
		}
		
		$statuses=array('W'=>_('Processing...'),'F'=>_('Failed'),'D'=>_('Done'));
		
		$canView=false;
		
		foreach ($this->result as $key=>$val)
		{
			if ($val!==false)
			{
				$canView=true;
				break;
			}
		}
		
		$result=array(
			'keyword'=>$this->keyword,
			'bing_locale'=>$this->bing_locale,
			'google_locale'=>$this->google_locale,
			'google_suggest_options'=>$this->google_suggest_options,
			'insert_dt_human'=>$utils->humanizeDate($this->insert_dt),
			'status'=>$this->status,
			'status_human'=>$statuses[$this->status],
			'status_dt_human'=>$utils->humanizeDate($this->status_dt),
			'result'=>$this->result,
			'details_url'=>($canView?$app->getAppActionUrl('report',array('report_id'=>$this->id)):false),
			'delete_url'=>$app->getAppActionUrl('main',array('op'=>'delete','report_id'=>$this->id)),
		);
		
		$datasources='';
		
		if (!empty($this->bing_locale))
		{
			$result['bing_locale_human']='Bing '.$searchEngines['bing']['_locales'][$this->bing_locale]['title'];
			$datasources.=(empty($datasources)?'':', ').$result['bing_locale_human'];
		}
		
		if (!empty($this->google_locale))
		{
			$result['google_locale_human']='Google '.$searchEngines['google']['_locales'][$this->google_locale]['title'];
			$datasources.=(empty($datasources)?'':', ').$result['google_locale_human'];
		}
		
		if (!empty($this->google_suggest_options) AND isset($suggestLanguages[$this->google_suggest_options['language']]))
		{
			$result['google_suggest_human']=array('language'=>$suggestLanguages[$this->google_suggest_options['language']]['name']);
			
			$result['google_suggest_human_full']='Google Autocomplete - '.$result['google_suggest_human']['language'].' (';
			
			$sources='';
			foreach ($this->google_suggest_options['sources'] as $source)
			{
				if (!empty($ops->googleSuggestSources[$source]))
				{
					$result['google_suggest_human']['sources'][$source]=$ops->googleSuggestSources[$source]['name'];
					
					$sources.=(empty($sources)?'':', ').$result['google_suggest_human']['sources'][$source];
				}
			}
			
			$result['google_suggest_human_full'].=$sources.')';
			
			$datasources.=(empty($datasources)?'':', ').$result['google_suggest_human_full'];
		}
		
		$result['datasources_human']=$datasources;
				
		return $result;
	}
}
?>