<?php
class OS_APP_RelatedKws_ReportOperations
{
	private static $_instance;
	
	public $googleSuggestLanguages=array(
		'en-US'=>array('name'=>"English/US",'tld'=>'com','hl'=>'en'),
		'en-GB'=>array('name'=>"English/UK",'tld'=>'co.uk','hl'=>'en'),
		'en-AU'=>array('name'=>"English/Australia",'tld'=>'com.au','hl'=>'en'),
		'ro'=>array('name'=>"Romanian",'tld'=>'ro','hl'=>'ro')
	);
	
	public $googleSuggestSources=array(
		'web'=>array('name'=>"Web",'ds'=>false),
		'images'=>array('name'=>"Images",'ds'=>'i'),
		'products'=>array('name'=>"Products",'ds'=>'pr'),
		'recipes'=>array('name'=>"Recipes",'ds'=>'r'),
		'youtube'=>array('name'=>"YouTube",'ds'=>'yt'),
		'news'=>array('name'=>"News",'ds'=>'n'),
		'books'=>array('name'=>"Books",'ds'=>'bo')
	);
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_RelatedKws_ReportOperations();
		}
		
		return self::$_instance;
	}
	
	public function getReportByID($report_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE id=?",array($report_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$row['google_suggest_options']=json_decode($row['google_suggest_options'],true);
			$row['result']=json_decode($row['result'],true);
			
			$result=new OS_APP_RelatedKws_Report();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getReports($project_id=false,$offset=0,$count=10)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE project_id=? ORDER BY `insert_dt` DESC LIMIT {$offset},{$count}";
		
		$dbresult=$db->query($query,array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['google_suggest_options']=json_decode($row['google_suggest_options'],true);
			$row['result']=json_decode($row['result'],true);
			
			$oneReport=new OS_APP_RelatedKws_Report();
			$oneReport->set($row);
			
			$result[$row['id']]=$oneReport;
		}
		
		return $result;
	}
	
	public function getReportsByStatus($status,$project_id=false,$count=10)
	{
		$result=false;
		
		if ($project_id===false)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE ".($project_id?"project_id=? AND ":'')."status=? ORDER BY `status_dt` ASC LIMIT {$count}";
		
		$dbresult=$db->query($query,($project_id?array($project_id,$status):array($status)));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['google_suggest_options']=json_decode($row['google_suggest_options'],true);
			$row['result']=json_decode($row['result'],true);
			
			$oneReport=new OS_APP_RelatedKws_Report();
			$oneReport->set($row);
			
			$result[$row['id']]=$oneReport;
		}
		
		return $result;
	}
	
	public function getReportsCount($project_id=false)
	{
		$result=false;
		
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT COUNT(id) AS total_reports FROM ".$appHandler->dbPrefix()."reports WHERE project_id=?";
		
		$dbresult=$db->query($query,array($project_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row['total_reports'];
		}
		
		return $result;
	}
	
	public function insertReport($report)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$json_result=json_encode($report->result);
		
		if (empty($report->status))
		{
			$report->status='W';
		}
		
		$query="INSERT INTO ".$appHandler->dbPrefix()."reports (project_id,keyword,bing_locale,google_locale,google_suggest_options,insert_dt,insert_ip,status,status_dt,status_ip,result) VALUES (?,?,?,?,?,?,?,?,?,?,?)";
		$dbresult=$db->query($query,array($report->project_id,$report->keyword,$report->bing_locale,$report->google_locale,json_encode($report->google_suggest_options),$time,$ip,$report->status,$time,$ip,$json_result));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateReport($report)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$json_result=json_encode($report->result);
		
		$query="UPDATE ".$appHandler->dbPrefix()."reports SET keyword=?,bing_locale=?,google_locale=?,google_suggest_options=?,result=?,status=?,status_dt=?,status_ip=? WHERE id=?";
		$dbresult=$db->query($query,array($report->keyword,$report->bing_locale,$report->google_locale,json_encode($report->google_suggest_options),$json_result,$report->status,$time,$ip,$report->id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function setReportRelated($report_id,$source,$keywords)
	{
		$result=false;

		if ($report=$this->getReportByID($report_id))
		{
			$report->result[$source]=$keywords;
			
			if (!$this->getPendingRelated($report))
			{
				$report->status='D';
				
				$eventParams=array(
					'status'=>'done',
					'report_id'=>$report->id,
					'related_keywords'=>$report->result
				);
				
				OS_Events::triggerEvent("relatedKeywordsReportFinished",$eventParams);
			}
			
			$report->save();
			
			$result=true;
		}
		
		return $result;
	}
	
	public function getPendingRelated($report)
	{
		$result=false;
		
		if (!empty($report->bing_locale) AND !isset($report->result['bing']))
		{
			$result['bing']=array('locale'=>$report->bing_locale);
		}
		
		if (!empty($report->google_locale) AND !isset($report->result['google']))
		{
			$result['google']=array('locale'=>$report->google_locale);
		}
		
		if (!empty($report->google_suggest_options) AND !isset($report->result['google_suggest']))
		{
			$result['google_suggest']=$report->google_suggest_options;
		}
		
		return $result;
	}
	
	public function getRelated($report)
	{
		if ($options=$this->getPendingRelated($report))
		{
			if (!empty($options['google_suggest']))
			{
				$this->setReportRelated($report->id,'google_suggest',$this->getGoogleSuggest($report,$options['google_suggest']));
			}
			
			if (!empty($options['google']))
			{
				$this->fetchRelated($report,'google',$options['google']['locale']);
			}
			
			if (!empty($options['bing']))
			{
				$this->fetchRelated($report,'bing',$options['bing']['locale']);
			}
		}
		else
		{
			$report->status='D';
			$report->save();
			
			$eventParams=array(
				'status'=>'done',
				'report_id'=>$report->id,
				'related_keywords'=>$report->result
			);
			
			OS_Events::triggerEvent("relatedKeywordsReportFinished",$eventParams);
		}
	}
	
	public function parseRelated($serp,$engine)
	{
		$result=array();
		
		$dom=new DOMDocument();
				
		libxml_use_internal_errors(true);
		$domLoaded=$dom->loadHTML($serp);
		libxml_use_internal_errors(false);
		
		if ($domLoaded)
		{
			$xpath=new DOMXPath($dom);
			
			if ($engine=='bing')
			{
				$entries=$xpath->query("//li[@class='rrrs_itm']");
				
				foreach ($entries as $entry)
				{
					$result[]=$entry->nodeValue;
				}
			}
			elseif ($engine=='google')
			{
				$entries=$xpath->query("//p[@class='msrl']");
					
				if (!$entries->item(0))
				{
					$entries=$xpath->query("//div[@class='brs_col']/p");
				}
				
				foreach ($entries as $entry)
				{
					$result[]=$entry->nodeValue;
				}
			}
		}
		
		return $result;
	}
	
	public function fetchRelated($report,$engine,$locale)
	{
		$result=false;
		
		$osSE=getOS()->getSearchEngine();
		if ($serp=$osSE->getSerp($report->keyword,$engine,$locale))
		{
			if ($serp['status']=='done')
			{
				$this->setReportRelated($report->id,$engine,$this->parseRelated($serp['data'],$engine));
			}
			elseif ($serp['status']=='queued')
			{
				$this->queueRelated($report->id,$serp['queue_id'],$engine);
			}
		}
		
		return $result;
	}
	
	public function queueRelated($report_id,$queue_id,$queue_type)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$dbresult=$db->query("INSERT INTO ".$appHandler->dbPrefix()."queue (report_id,queue_id,queue_type) VALUES (?,?,?)",array($report_id,$queue_id,$queue_type));
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function eventSearchEngineQueried($params)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$project_ids=array();
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."queue WHERE queue_id=?",array($params['queue_id']));
		while ($row=$db->fetchRow($dbresult))
		{
			$report_ids[$row['report_id']]=$row['queue_type'];
		}
		
		if (!empty($report_ids))
		{
			foreach ($report_ids as $report_id=>$engine)
			{
				if ($oneReport=$this->getReportByID($report_id))
				{
					if ($params['status']=='done')
					{
						$result=$this->setReportRelated($oneReport->id,$engine,$this->parseRelated($params['data']['getSerp'],$engine));
					}
					elseif ($params['status']=='failed')
					{
						$locale=$engine.'_locale';
						$result=$this->fetchRelated($oneReport,$engine,$oneReport->$locale);
					}
				}
			}
		}
		
		return $result;
	}
	
	public function getGoogleSuggest($report,$options)
	{
		$result=false;
		
		$http=getOS()->getHttp();
		$ops=OS_APP_RelatedKws_ReportOperations::get_instance();
		
		if (!empty($options['language']))
		{
			if (!isset($ops->googleSuggestLanguages[$options['language']]))
			{
				return false;
			}
			else
			{
				$options['tld']=$ops->googleSuggestLanguages[$options['language']]['tld'];
				$options['hl']=$ops->googleSuggestLanguages[$options['language']]['hl'];
			}
		}
		
		$sources=array();
		
		if (empty($options['sources']))
		{
			$options['sources']=array('web');
		}
		
		foreach ($options['sources'] as $source)
		{
			if (isset($ops->googleSuggestSources[$source]))
			{
				$sources[$source]=$ops->googleSuggestSources[$source]['ds'];
			}
		}
		
		if (empty($dss))
		{
			$sources['web']=false;
		}
		
		if (empty($options['domain']))
		{
			if (empty($options['tld']))
			{
				$options['domain']='google.com';
			}
			else
			{
				$options['domain']='google.'.$options['tld'];
			}
		}
		
		$url="http://{$options['domain']}/complete/search?output=chrome&q=".urlencode($report->keyword).(!empty($options['hl'])?"&hl={$options['hl']}":'');

		foreach ($sources as $source=>$ds)
		{
			$actual_url=$url.($ds?"&ds={$ds}":'');
			
			$response=$http->get($actual_url);
			
			if ($response AND $http->success())
			{
				$result[$source]=array();
				
				if ($response=json_decode($response,true))
				{
					if (!empty($response[1]))
					{
						foreach ($response[1] as $position=>$keyword)
						{
							if (!empty($response[4]['google:suggesttype'][$position]) AND $response[4]['google:suggesttype'][$position]=='QUERY')
							{
								$result[$source][]=$keyword;
							}
						}
					}
				}
			}
		}
		
		return $result;
	}
	
	public function deleteReportByID($report_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."reports WHERE id=?";
		$dbresult=$db->query($query,array($report_id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteDataByProjectID($project_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."reports WHERE project_id=?";
		$dbresult=$db->query($query,array($project_id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
}
?>