<?php
class OS_APPVIEW_RelatedKws_Analyze extends OS_AppViewBase
{
	public function __construct()
	{
		parent::__construct();
	}
	
	public function processRequest()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$searchEngineOps=$OS->getSearchEngineOps();
		
		$searchEngines=$searchEngineOps->getAvailableSearchEnginesFull();
		
		$allowedSearchEngines=array('google','bing');
		
		foreach ($searchEngines as $engine=>$details)
		{
			if (!in_array($engine,$allowedSearchEngines))
			{
				unset($searchEngines[$engine]);
			}
		}
		
		$ops=OS_APP_RelatedKws_ReportOperations::get_instance();
		
		$requestParams=$appPlugin->getRequestParams();
		$requestParams['search_engines']=$searchEngines;
		$requestParams['suggest_languages']=$ops->googleSuggestLanguages;
		$requestParams['suggest_sources']=$ops->googleSuggestSources;
		
		if ($_SERVER['REQUEST_METHOD']=='POST')
		{
			if (empty($requestParams['keyword_box']))
			{
				$OS->addFieldError(_("Keyword missing"),'keyword');
			}
			else
			{
				$requestParams['keyword_box']=trim($requestParams['keyword_box']);
				
				if (strlen($requestParams['keyword_box'])<3)
				{
					$OS->addFieldError(_("Keyword too short. Minimum length: 3 chars"),'keyword');
				}
			}
			
			$datasourceSelected=false;
			
			if (empty($requestParams['bing_box']))
			{
				$requestParams['bing_locale_box']='';
			}
			else
			{
				$datasourceSelected=true;
				
				if (!isset($searchEngines['bing']['_locales'][$requestParams['bing_locale_box']]))
				{
					$OS->addFieldError(_("Unknown locale"),'bing');
				}
			}
			
			if (empty($requestParams['google_box']))
			{
				$requestParams['google_locale_box']='';
			}
			else
			{
				$datasourceSelected=true;
				
				if (!isset($searchEngines['google']['_locales'][$requestParams['google_locale_box']]))
				{
					$OS->addFieldError(_("Unknown locale"),'google');
				}
			}
			
			if (empty($requestParams['google_suggest_box']))
			{
				$requestParams['google_suggest_language_box']='';
			}
			else
			{
				$datasourceSelected=true;
				
				if (!isset($ops->googleSuggestLanguages[$requestParams['google_suggest_language_box']]))
				{
					$OS->addFieldError(_("Unknown language"),'google_suggest');
				}
				else
				{
					$suggestSources=array('web');
					
					foreach ($ops->googleSuggestSources as $source=>$details)
					{
						if ($source!='web')
						{
							if (!empty($requestParams['google_suggest_source_'.$source.'_box']))
							{
								$suggestSources[]=$source;
							}
						}
					}
				}
			}
			
			if (!$datasourceSelected)
			{
				$OS->addFieldError(_("Select at least one datasource"),'bing');
			}
			
			if (!isset($OS->errorMessages))
			{
				$oneReport=OS_APP_RelatedKws_Report::get_instance();
				
				$oneReport->project_id=$OS->getProject()->id;
				$oneReport->keyword=$requestParams['keyword_box'];
				$oneReport->bing_locale=$requestParams['bing_locale_box'];
				$oneReport->google_locale=$requestParams['google_locale_box'];
				if ($requestParams['google_suggest_language_box'])
				{
					$oneReport->google_suggest_options=array(
						'language'=>$requestParams['google_suggest_language_box'],
						'sources'=>$suggestSources
					);
				}
				else
				{
					$oneReport->google_suggest_options=array();
				}
				
				if ($oneReport->save())
				{
					$ops->getRelated($oneReport);
				}
				
				$OS->redirectTO($appPlugin->getAppActionUrl('main',array('msg'=>'analyze_ok')),true);
			}
		}
		else
		{
			$requestParams['keyword_box']='';
			
			$requestParams['bing_box']='';
			$requestParams['bing_locale_box']='';
			
			$requestParams['google_box']='';
			$requestParams['google_locale_box']='';
			
			$requestParams['google_suggest_box']='';
			$requestParams['google_suggest_language_box']='';
		}
		
		return $requestParams;
	}
	
	public function render()
	{
		$OS=getOS();

		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$tplVars=$this->processedRequest;
		$tplVars['appURL']=$appPlugin->getAppUrl();
		
		$tpl = $OS->getTemplate();
		
		return $tpl->fetchTemplate('analyze',$tplVars);
	}
}
?>