<?php
class OS_APP_Reporting_TemplateOperations
{
	private static $_instance;
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_Reporting_TemplateOperations();
		}
		
		return self::$_instance;
	}
	
	public function getTemplates($project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."templates WHERE project_id=?",array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneTemplate=new OS_APP_Reporting_Template();
			$oneTemplate->set($row);
			
			$result[$row['id']]=$oneTemplate;
		}
		
		return $result;
	}
	
	public function getTemplateByID($template_id,$project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."templates WHERE id=? AND project_id=?",array($template_id,$project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_APP_Reporting_Template();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getDefaultTemplate($project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."templates WHERE project_id=? AND `default`=? LIMIT 1",array($project_id,'Y'));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_APP_Reporting_Template();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function insertTemplate($template)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$query="INSERT INTO ".$appHandler->dbPrefix()."templates (project_id,name,`default`,insert_dt,insert_ip,update_dt,update_ip) VALUES (?,?,?,?,?,?,?)";
		$dbresult=$db->query($query,array($template->project_id,$template->name,$template->default,$time,$ip,$time,$ip));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateTemplate($template)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$query="UPDATE ".$appHandler->dbPrefix()."templates SET name=?,`default`=?,update_dt=?,update_ip=? WHERE id=?";
		$dbresult=$db->query($query,array($template->name,$template->default,$time,$ip,$template->id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteTemplateByID($template_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		if ($template=$this->getTemplateByID($template_id))
		{
			$query="DELETE FROM ".$appHandler->dbPrefix()."templates WHERE id=?";
			$dbresult=$db->query($query,array($template_id));
			
			if ($dbresult!==false)
			{
				if ($storage_path=$this->getTemplateStoragePath($template))
				{
					$osUtils=$OS->getUtils();
					$osUtils->removeDir($storage_path);
				}
				
				$db->query("UPDATE ".$appHandler->dbPrefix()."templates SET `default`=? WHERE project_id=? LIMIT 1",array('Y',$template->project_id));
				
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function getTemplateStoragePath($template,$www_friendly=false)
	{
		$OS=getOS();
		$appHandler=$OS->getAppHandler();
		
		$result=os_join_path($appHandler->getAppStoragePath(),'templates',$template->id);
		
		if ($www_friendly)
		{
			$result=str_replace(array($OS->getConfigVar('root_path'),'\\'),array($OS->getConfigVar('root_url'),'/'),$result);
		}
		
		return $result;
	}
	
	public function getTemplateFiles($template,$www_friendly=false)
	{
		$result=array(
			'header'=>false,
			'cover'=>false,
			'footer'=>false
		);
		
		$path=$this->getTemplateStoragePath($template);
		if ($www_friendly)
		{
			$www_path=$this->getTemplateStoragePath($template,true);
		}
		
		foreach ($result as $type=>$dummy)
		{ 
			$type_file=os_join_path($path,"{$type}.jpg");
			
			if (file_exists($type_file))
			{
				$result[$type]=($www_friendly?$www_path.'/'.$type.'.jpg':$type_file);
			}
		}
		
		return $result;
	}
	
	public function getTemplateFilesFull($template,$www_friendly=false)
	{
		$OS=getOS();
		
		$default_path=($www_friendly?$OS->getConfigVar('root_url').'/lib/imgs/report':os_join_path($OS->getConfigVar('root_path'),'lib','imgs','report'));
		$result=array(
			'header'=>($www_friendly?$default_path.'/header.png':os_join_path($default_path,'header.png')),
			'cover'=>($www_friendly?$default_path.'/cover.png':os_join_path($default_path,'cover.png')),
			'footer'=>($www_friendly?$default_path.'/footer.png':os_join_path($default_path,'footer.png')),
		);
		
		if ($template)
		{
			if ($template_files=$this->getTemplateFiles($template,$www_friendly))
			{
				foreach ($template_files as $type=>$file)
				{
					if ($file)
					{
						$result[$type]=$file;
					}
				}
			}
		}
		
		return $result;
	}
	
	public function setTemplateAsDefault($template)
	{
		$result=false;
		
		if ($template->default=='Y')
		{
			$result=true;
		}
		else
		{
			$OS=getOS();
			$db=$OS->getDb();
			$appHandler=$OS->getAppHandler();
			
			$db->query("UPDATE ".$appHandler->dbPrefix()."templates SET `default`=? WHERE project_id=?",array('',$template->project_id));
			
			$dbresult=$db->query("UPDATE ".$appHandler->dbPrefix()."templates SET `default`=? WHERE id=?",array('Y',$template->id));
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
}
?>