<?php
class OS_APPVIEW_Reporting_Generate extends OS_AppViewBase
{
	public function __construct()
	{
		parent::__construct();
	}
	
	public function processRequest()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$ops=OS_APP_Reporting_ReportOperations::get_instance();
		
		$requestParams=$appPlugin->getRequestParams();
		
		$reportType='overview';
		
		if (!empty($requestParams['report_type']) AND in_array($requestParams['report_type'],array('overview','evolution')))
		{
			$reportType=$requestParams['report_type'];
		}
		else
		{
			$requestParams['report_type']='overview';
		}
		
		$availableTemplates=array();
		$templateOps=OS_APP_Reporting_TemplateOperations::get_instance();
		if ($templates=$templateOps->getTemplates())
		{
			foreach ($templates as $template)
			{
				$availableTemplates[$template->id]=array(
					'name'=>$template->name,
					'default'=>($template->default=='Y'?true:false),
					'files'=>$templateOps->getTemplateFilesFull($template,true)
				);
			}
		}
		
		$availableData=$ops->getAvailableReportData($reportType);
		
		if ($availableData)
		{
			if ($_SERVER['REQUEST_METHOD']=='POST')
			{
				$reportData=array();
				
				$templateFiles=array();
				if (!empty($availableTemplates))
				{
					if (empty($requestParams['template_box']))
					{
						$OS->addFieldError(_("Template missing"),'template');
					}
					elseif (!isset($availableTemplates[$requestParams['template_box']]))
					{
						$OS->addFieldError(_("Unknown template"),'template');
					}
					else
					{
						$templateFiles=$availableTemplates[$requestParams['template_box']]['files'];
					}
				}
				
				foreach ($availableData as $app=>$details)
				{
					if (!empty($requestParams["{$app}_box"]))
					{
						foreach ($details['report']['sections'] as $section=>$section_details)
						{
							if (!empty($requestParams["{$app}_{$section}_box"]))
							{
								if (!isset($reportData['main_sections'][$app]))
								{
									$reportData['main_sections'][$app]=array(
										'title'=>$details['report']['title'],
										'sections'=>array()
									);
								}
								
								$reportData['main_sections'][$app]['sections']["{$app}_{$section}"]=$section_details;
								
								if (!empty($requestParams["{$app}_{$section}_extra_box"]))
								{
									$reportData['main_sections'][$app]['sections']["{$app}_{$section}"]['extraText']=$requestParams["{$app}_{$section}_extra_box"];
								}
							}
						}
					}
				}
				
				if (empty($reportData))
				{
					$OS->addBoxError(_("You have to choose at least one section to generate a report"));
				}
				
				if (empty($OS->errorMessages))
				{
					$reportData['filename']='opens_'.$reportType.'_seo_report.pdf';
					$reportData['title']=_("SEO Report");
					
					$osReport=$OS->getReport();
					$osReport->setTemplateFiles($templateFiles);
					$osReport->generateReport($reportData,'pdf');
				}
			}
			else
			{
				foreach ($availableData as $app=>$details)
				{
					$requestParams["{$app}_box"]='Y';
					
					foreach ($details['report']['sections'] as $section=>$section_details)
					{
						$requestParams["{$app}_{$section}_box"]='Y';
						
						if (!empty($section_details['extraText']))
						{
							$requestParams["{$app}_{$section}_extra_box"]=$section_details['extraText'];
						}
					}
				}
			}
		}
		else
		{
			$requestParams=array();
		}

		$result=array(
			'availableTemplates'=>$availableTemplates,
			'availableData'=>$availableData,
			'requestParams'=>$requestParams
		);
		
		return $result;
	}
	
	public function render()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$appPlugin->setMenuBackLink(array('back_view'=>'new'));
		
		$tplVars=$this->processedRequest;
				
		$tpl=$OS->getTemplate();
		
		$headContents=array('report_js'=>"<script type='text/javascript' src='".$appPlugin->getAppHomeUrl()."/js/report.js'></script>");
		
		$defaultReportData=array(
			'title'=>"SEO Report",
			'filename'=>'opens_seo_report.html',
			'main_sections'=>array()
		);
		
		foreach ($tplVars['availableData'] as $app=>$app_details)
		{
			$defaultReportData['main_sections'][$app]=array(
				'title'=>$app_details['report']['title'],
				'sections'=>array()
			);
			
			foreach ($app_details['report']['sections'] as $section=>$section_details)
			{
				$defaultReportData['main_sections'][$app]['sections'][$section]=$section_details;
			}
		}
		
		$osReport=$OS->getReport();
		
		$tplVars['defaultReport']=$osReport->generateReport($defaultReportData,'html',true,true);
		
		$tpl->setHeadContents($headContents);

		return $tpl->fetchTemplate('generate',$tplVars);
	}
}
?>