<?php
class OS_APP_SelfCrawl extends OS_AppBase
{
	private static $_instance;
	
	public $httpCodesStatuses;
	
	protected function __construct()
	{
		parent::__construct();
		
		$this->defineHttpCodesStatuses();
		
		$this->addMenuItem('view', array("name" => _("Main"), 'routerOption'=> "handleMainView"));
		$this->addMenuItem('crawl_now', array("name" => _("Crawl now"), 'routerOption'=> "handleCrawlNowView"));
				
		$this->setRouterOption("view_details", "handleDetailsView");
		$this->setRouterOption("links", "handleLinksView");
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_SelfCrawl();
		}
		return self::$_instance;
	}
	
	public function handleMainView()
	{
		getOS()->getUser()->forcePerm('selfcrawl','view');

		$viewData = new OS_APPVIEW_SelfCrawl_main();
		
		return $viewData->render();
	}
	
	public function handleDetailsView()
	{
		getOS()->getUser()->forcePerm('selfcrawl','view');
		
		$viewData = new OS_APPVIEW_SelfCrawl_Details();
		
		return $viewData->render();
	}
	
	public function handleLinksView()
	{
		getOS()->getUser()->forcePerm('selfcrawl','view');
		
		$viewData = new OS_APPVIEW_SelfCrawl_Links();
		
		return $viewData->render();
	}
	
	public function handleCrawlNowView()
	{
		$viewData = new OS_APPVIEW_SelfCrawl_CrawlNow();
		
		return $viewData->render();
	}
	
	protected function defineAppPermissions()
	{
		$this->appPermissions=array(
			'selfcrawl'=>array(
				'view'=>array('name'=>_("View project crawls")),
			)
		);
	}
	
	public function defineHttpCodesStatuses()
	{
		$this->httpCodesStatuses=array(
			'100'=>'Continue',
			'101'=>'Switching Protocols',
			'102'=>'Processing (WebDAV)',
			'200'=>'OK',
			'201'=>'Created',
			'202'=>'Accepted',
			'203'=>'Non-Authorative Information (HTTP/1.1)',
			'204'=>'No Content',
			'205'=>'Reset Content',
			'206'=>'Partial Content',
			'207'=>'Multi-Status (WebDAV)',
			'208'=>'Already Reported (WebDAV)',
			'226'=>'IM Used',
			'300'=>'Multiple Choices',
			'301'=>'Moved Permanently',
			'302'=>'Moved Temporarily',
			'303'=>'See Other (HTTP/1.1)',
			'304'=>'Not Modified',
			'305'=>'Use Proxy (HTTP/1.1)',
			'306'=>'Switch Proxy',
			'307'=>'Temporary Redirect (HTTP/1.1)',
			'308'=>'Permanent Redirect (experimental)',
			'400'=>'Bad Request',
			'401'=>'Unauthorized',
			'402'=>'Payment Required',
			'403'=>'Forbidden',
			'404'=>'Not Found',
			'405'=>'Method Not Allowed',
			'406'=>'Not Acceptable',
			'407'=>'Proxy Authentication Required',
			'408'=>'Request Timeout',
			'409'=>'Conflict',
			'410'=>'Gone',
			'411'=>'Length Required',
			'412'=>'Precondition Failed',
			'413'=>'Request Entity Too Large',
			'414'=>'Request-URI Too Long',
			'415'=>'Unsupported Media Type',
			'416'=>'Requested Range Not Satisfiable',
			'417'=>'Expectation Failed',
			'420'=>'Enhance Your Calm (Twitter)',
			'422'=>'Unprocessable Entity (WebDAV)',
			'423'=>'Locked (WebDAV)',
			'424'=>'Failed Dependency (WebDAV)',
			'425'=>'Unordered Collection (draft)',
			'426'=>'Upgrade Required',
			'428'=>'Precondition Required',
			'429'=>'Too Many Requests',
			'431'=>'Request Header Fields Too Large',
			'444'=>'No Response (Nginx)',
			'449'=>'Retry With (Microsoft)',
			'450'=>'Blocked by Windows Parental Controls (Microsoft)',
			'451'=>'Redirect (Microsoft - Exchange ActiveSync)',
			'492'=>'Request Header Too Large (Nginx)',
			'495'=>'Cert Error (Nginx)',
			'496'=>'No Cert (Nginx)',
			'497'=>'HTTP to HTTPS (Nginx)',
			'499'=>'Client Closed Request (Nginx)',
			'500'=>'Internal Server Error',
			'501'=>'Not Implemented',
			'502'=>'Bad Gateway',
			'503'=>'Service Unavailable',
			'504'=>'Gateway Timeout',
			'505'=>'HTTP Version Not Supported',
			'506'=>'Variant Also Negotiates',
			'507'=>'Insufficient Storage (WebDAV)',
			'508'=>'Loop Detected (WebDAV)',
			'509'=>'Bandwidth Limit Exceeded (Apache)',
			'510'=>'Not Extended',
			'511'=>'Network Authentication Required',
			'598'=>'Network read timeout error (Microsoft)',
			'599'=>'Network connect timeout error (Microsoft)'
		);
	}
	
	public function getHttpCodeStatus($http_code)
	{
		$result=false;
		
		if (isset($this->httpCodesStatuses[$http_code]))
		{
			$result=$this->httpCodesStatuses[$http_code];
		}
		
		return $result;
	}
}
?>