<?php
class OS_APPVIEW_SelfCrawl_Main extends OS_AppViewBase
{
	private $currentSet;
	
	private $maxRows;
	
	private $availableTotalRows;
	
	private $startCounter;
	
	public function __construct()
	{
		$OS = getOS();
		
		$this->projectId = $OS->getProject()->id;
		
		$this->appPlugin = $OS->getAppHandler()->getAppPlugin();
		
		$this->availableTotalRows = array(10,25,50,100);
		
		$this->startCounter = 0;
		
		parent::__construct();
	}
	
	public function processRequest()
	{
		$requestParams = $this->appPlugin->getRequestParams();
		
		$this->maxRows = 10;
		if(isset($requestParams['rows']))
		{
			if(in_array($requestParams['rows'], $this->availableTotalRows))
			{
				$this->maxRows = $requestParams['rows'];			
			}
		}
		
		$this->currentSet = 1;
		if(isset($requestParams['page']))
		{
			if(is_numeric($requestParams['page']))
			{
				if($requestParams['page'] > 0)
				{
					$this->currentSet = $requestParams['page'];
					$this->startCounter = (($requestParams['page'] * $this->maxRows) - $this->maxRows);			
				}
			}
		}
	}
	
	public function buildViewData()
	{
		$OS=getOS();
		
		$viewDataVars=array();
		
		$project=$OS->getProject();
		
		$ops=$OS->getProjectCrawlOps();
		
		$viewDataVars['crawls']=$ops->getProjectCrawls(array('project_id' => $project->id, 'set' => $this->currentSet, 'max_rows' => $this->maxRows));
		
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS = getOS();
		
		$tplVars = array();
		
		$viewData = $this->buildViewData();
		
		$osAppPlugin = $OS->getAppHandler()->getAppPlugin();
		$utils=$OS->getUtils();
				
		$crawls_processed=array();$headContents=array();
		
		if ($viewData['crawls'])
		{
			foreach ($viewData['crawls'] as $crawl)
			{
				$crawl_arr=array(
					'id'=>$crawl->id,
					'urls'=>$crawl->urls,
					'urls_2xx'=>$crawl->urls_2xx,
					'urls_3xx'=>$crawl->urls_3xx,
					'urls_4xx'=>$crawl->urls_4xx,
					'urls_5xx'=>$crawl->urls_5xx,
					'crawl_d'=>$utils->humanizeDate($crawl->start_dt,'date'),
					'start_dt'=>$utils->humanizeDate($crawl->start_dt),
					'end_dt'=>($crawl->status!='D'?'-':$utils->humanizeDate($crawl->end_dt)),
					'status'=>$crawl->status,
					'runtime'=>($crawl->status!='D'?'-':$utils->humanizeTime(strtotime($crawl->end_dt)-strtotime($crawl->start_dt)))
				);
				
				if ($crawl->urls_3xx>0)
				{
					$crawl_arr['urls_3xx_details_url']=$osAppPlugin->getAppActionUrl('view_details',array('crawl_id'=>$crawl->id,'http_code_group'=>3));
				}
				else
				{
					$crawl_arr['urls_3xx_details_url']=false;
				}
				
				if ($crawl->urls_4xx>0)
				{
					$crawl_arr['urls_4xx_details_url']=$osAppPlugin->getAppActionUrl('view_details',array('crawl_id'=>$crawl->id,'http_code_group'=>4));
				}
				else
				{
					$crawl_arr['urls_4xx_details_url']=false;
				}
				
				if ($crawl->urls_5xx>0)
				{
					$crawl_arr['urls_5xx_details_url']=$osAppPlugin->getAppActionUrl('view_details',array('crawl_id'=>$crawl->id,'http_code_group'=>5));
				}
				else
				{
					$crawl_arr['urls_5xx_details_url']=false;
				}
				
				$crawls_processed[$crawl->id]=$crawl_arr;
			}
		}
		
		$tplVars['crawls']=$crawls_processed;
		$tplVars['crawlNowUrl']=$osAppPlugin->getAppActionUrl('crawl_now');
		
		if (!empty($crawls_processed))
		{
			$latest=reset($crawls_processed);
			
			$headContents['css']['selfcrawl']=$osAppPlugin->getAppHomeUrl()."/resources/style.css";
			
			$tplVars['latest']=array(
				'2xx'=>array('urls'=>$latest['urls_2xx'],'color'=>'green','title'=>_('Successful (2XX)'),'description'=>_("URLs that were successfully loaded"),'clickable'=>false,'details_url'=>false),
				'3xx'=>array('urls'=>$latest['urls_3xx'],'color'=>'blue','title'=>_('Redirects (3XX)'),'description'=>_("URLs that initiated a redirection"),'clickable'=>true,'details_url'=>$latest['urls_3xx_details_url']),
				'4xx'=>array('urls'=>$latest['urls_4xx'],'color'=>'orange','title'=>_('Client Errors (4XX)'),'description'=>_("URLs that were not available"),'clickable'=>true,'details_url'=>$latest['urls_4xx_details_url']),
				'5xx'=>array('urls'=>$latest['urls_5xx'],'color'=>'red','title'=>_('Server Errors (5XX)'),'description'=>_("URLs on which the server encountered an error"),'clickable'=>true,'details_url'=>$latest['urls_5xx_details_url']),
			);
		}
		
		//smart table pagination
		$prev_page = ($this->currentSet > 1 ? ($this->currentSet - 1): 1);
		$next_page = $this->currentSet +1;
		
		$linkParams = array('rows' => $this->maxRows);
		$tplVars['prev_link'] = $this->appPlugin->getAppActionUrl("main", array_merge($linkParams, array('page' => $prev_page)));
		$tplVars['next_link'] = $this->appPlugin->getAppActionUrl("main", array_merge($linkParams, array('page' => $next_page)));
		
		$tplVars['availableTotalRows'] = $this->availableTotalRows;
		$tplVars['maxRows'] = $this->maxRows;
		$tplVars['startCounter'] = $this->startCounter;
		$tplVars['linkParams'] = array_merge($linkParams, array('app' => 'selfcrawl', 'view' => 'main'));
		
		
		$tpl = $OS->getTemplate();
		
		$tpl->setHeadContents($headContents);
		
		return $tpl->fetchTemplate('view', $tplVars);
	}
}
?>