<?php
class OS_APP_sitemapgen_sitemapoperations
{
	private static $_instance;
	
	public function __construct()
	{
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_APP_sitemapgen_sitemapoperations();
		}
		return self::$_instance;
	}
	
	public function getSitemaps($project_id=false)
	{
		if (!$project_id)
		{
			$project_id=getOS()->getProject()->id;
		}
		
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$sitemaps=array();
		$query="SELECT * FROM ".$appHandler->dbPrefix()."sitemaps WHERE project_id=? ORDER BY `generate_dt` DESC";
		$result=$db->query($query,array($project_id));
		while ($row=$db->fetchRow($result))
		{
			$sitemap=new OS_APP_sitemapgen_sitemap();
			$sitemap->set($row);
			
			$sitemaps[$sitemap->id]=$sitemap;
		}
		
		return $sitemaps;
	}
	
	public function getSitemapByID($day_id)
	{
		$project=getOS()->getProject();
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."sitemaps WHERE id=? AND project_id=?";
		$result=$db->query($query,array($day_id,$project->id));
		if (!$row=$db->fetchRow($result)) return false;
		
		$sitemap=new OS_APP_sitemapgen_sitemap();
		$sitemap->set($row);
		
		return $sitemap;
	}
	
	public function insertSitemap($sitemap)
	{
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="INSERT INTO ".$appHandler->dbPrefix()."sitemaps (project_id,urls,generate_dt) VALUES (?,?,?)";
		$result=$db->query($query,array($sitemap->project_id,$sitemap->urls,$sitemap->generate_dt));
		
		if ($result===false) return false;
		
		return $db->getInsertId();
	}
	
	public function updateSitemap($sitemap)
	{
		$db=getOS()->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."sitemaps WHERE id=? AND project_id=?";
		$result=$db->query($query,array($sitemap->id,$sitemap->project_id));
		if (!$sitemap_row=$db->fetchRow($result)) return false;
		
		$query="UPDATE ".$appHandler->dbPrefix()."sitemaps SET urls=?,`genrate_dt`=?,ping=?,ping_dt=? WHERE id=?";
		$result=$db->query($query,array($sitemap->urls,$sitemap->generate_dt,$sitemap->ping,$sitemap->ping_dt,$sitemap->id));
		
		if ($result!==false) return true;
		
		return false;
	}
	
	public function deleteSitemapByID($id)
	{
		$result=false;
		
		if ($sitemap=$this->getSitemapByID($id))
		{
			$db=getOS()->getDb();
			$appHandler=getOS()->getAppHandler();
			
			$query="DELETE FROM ".$appHandler->dbPrefix()."sitemaps WHERE id=?";
			$dbresult=$db->query($query,array($id));
			if ($dbresult!==false)
			{
				$osUtils=getOS()->getUtils();
				
				$sitemapPath=$this->getSitemapPath($sitemap);
				
				$result=$osUtils->removeDir($sitemapPath);
			}
		}
		
		return $result;
	}
	
	public function getUrlPriorityByDepth($depth)
	{
		$result=false;
		
		if ($depth>5)
		{
			$result=0.2;
		}
		else
		{
			$result=1-($depth-1)*0.2;
		}
		
		return $result;
	}
	
	public function getUrlChangeFreqByDepth($depth)
	{
		$result=false;
		
		if ($depth<4)
		{
			$result='weekly';
		}
		else
		{
			$result='monthly';
		}
		
		return $result;
	}
	
	public function getSitemapPath($sitemap)
	{
		$app=getOS()->getAppHandler()->getAppPlugin();
		
		$sitemap_id=str_pad($sitemap->id,3,'0',STR_PAD_LEFT);
		
		return os_join_path($app->getAppStoragePath(),$sitemap->project_id,$sitemap_id[0],$sitemap_id[1],$sitemap_id[2],$sitemap_id);
	}

	public function deleteDataByProjectID($project_id)
	{
		$result=true;
		
		$sitemaps=$this->getSitemaps($project_id);
		
		foreach ($sitemaps as $sitemap)
		{
			if (!$sitemap->delete())
			{
				$result=false;
			}
		}
		
		return $result;
	}
	
	public function writeSitemapFile($sitemap)
	{
		$result=false;
		
		if ($sitemap->_bulkUrls)
		{
			$sitemapPath=$this->getSitemapPath($sitemap);
			
			if (!file_exists($sitemapPath))
			{
				mkdir($sitemapPath,0755,true);
			}
			
			$urls_in_sitemap=0;
			$sitemap_number=0;
			$sitemap_txt='';
			$sitemaps=array();
			
			foreach ($sitemap->_bulkUrls as $url_id=>$url_details)
			{
				if ($urls_in_sitemap==0)
				{
					$sitemap_file="<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<urlset xmlns=\"http://www.sitemaps.org/schemas/sitemap/0.9\">\n";
					$sitemaps[$sitemap_number+1]=$url_details['update_dt'];
				}
				
				$sitemap_file.="<url>\n<loc>{$url_details['url']}</loc>\n<lastmod>".date(DATE_W3C,strtotime($url_details['update_dt']))."</lastmod>\n";
				
				if (!empty($url_details['depth']))
				{
					$sitemap_file.="<changefreq>".$this->getUrlChangeFreqByDepth($url_details['depth'])."</changefreq>\n";
					$sitemap_file.="<priority>".$this->getUrlPriorityByDepth($url_details['depth'])."</priority>\n";
				}
				
				$sitemap_file.="</url>\n";
				
				$urls_in_sitemap++;
				
				if ($urls_in_sitemap==10000)
				{
					$sitemap_file.="</urlset>";
					
					$sitemap_number++;
					
					$sitemap_file_path=os_join_path($sitemapPath,'sitemap_'.$sitemap_number.'.xml');
					
					file_put_contents($sitemap_file_path,$sitemap_file);
					
					$urls_in_sitemap=0;
				}
				
				$sitemap_txt.="{$url_details['url']}\n";
			}
			
			if ($urls_in_sitemap!=0)
			{
				$sitemap_file.="</urlset>";
				
				if ($sitemap_number)
				{
					$sitemap_number++;
					
					$sitemap_file_path=os_join_path($sitemapPath,'sitemap_'.$sitemap_number.'.xml');
				}
				else
				{
					$sitemap_file_path=os_join_path($sitemapPath,'sitemap.xml');
				}
				
				file_put_contents($sitemap_file_path,$sitemap_file);
				
				$sitemap_txt_file_path=os_join_path($sitemapPath,'sitemap.txt');
				
				file_put_contents($sitemap_txt_file_path,$sitemap_txt);
			}
			
			if ($sitemap_number)
			{
				$sitemap_file="<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<sitemapindex xmlns=\"http://www.sitemaps.org/schemas/sitemap/0.9\">\n";
				
				for ($i=1;$i<=$sitemap_number;$i++)
				{
					$sitemap_file.="<sitemap>\n<loc></loc><lastmod>".date(DATE_W3C,strtotime($sitemaps[$i]))."</lastmod>\n</sitemap>\n";
				}
				
				$sitemap_file_path=os_join_path($sitemapPath,'sitemap.xml');
				
				file_put_contents($sitemap_file_path,$sitemap_file);
			}
			
			if (isset($sitemap_file))
			{
				unset($sitemap_file);
			}
			
			if (isset($sitemap_file_path))
			{
				unset($sitemap_file_path);
			}
			
			unset($sitemaps);
		}
		
		return $result;
	}
}
?>