<?php
class OS_APP_SocialSignals extends OS_AppBase
{
	private static $_instance;
	
	public function __construct()
	{
		parent::__construct();
		
		$this->addMenuItem('view', array("name" => _("Main"), 'routerOption'=> "handleMainView"));
		
		$this->setRouterOption("url", "handleUrlView");
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_SocialSignals();
		}
		
		return self::$_instance;
	}
	
	public function handleMainView()
	{
		getOS()->getUser()->forcePerm('socialsignals','view');
		
		$viewData=new OS_APPVIEW_SocialSignals_Main();
		
		return $viewData->render();
	}
	
	public function handleUrlView()
	{
		getOS()->getUser()->forcePerm('socialsignals','view');
		
		$viewData=new OS_APPVIEW_SocialSignals_Url();
		
		return $viewData->render();
	}
	
	protected function defineAppPermissions()
	{
		$this->appPermissions=array(
			'socialsignals'=>array(
				'view'=>array('name'=>_("Access Social Signals")),
			)
		);
	}
	
	public function eventProjectPageCrawled($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();
		
		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
			$params['http_code']=(string)$params['http_code'];
			$ok_http_code=in_array($params['http_code'][0],array(1,2));
			
			$allowedContentType=(in_array($params['content_type'],array('text/html','text/plain')));
			
			if ($allowedContentType AND !empty($params['content']) AND $ok_http_code)
			{
				$ops=OS_APP_SocialSignals_UrlOperations::get_instance();
				
				if (!$oneUrl=$ops->getUrlByUrlHash($params['url_hash'],$params['project_id']))
				{
					$oneUrl=new OS_APP_SocialSignals_Url();
					
					$oneUrl->project_id=$params['project_id'];
					$oneUrl->url=$params['url'];
					//$oneUrl->title=$params['title'];
					$oneUrl->url_hash=$params['url_hash'];
					
					$getSignals=true;
				}
				else
				{
					$getSignals=$ops->shouldGetSignals($oneUrl);
				}
				
				if ($getSignals)
				{
					if ($signals=$ops->getUrlSocialSignals($oneUrl->url))
					{
						$oneUrl->signals=$signals;
						
						$signals_total=0;
						
						foreach ($signals as $network=>$value)
						{
							if ($network!='facebook')
							{
								$signals_prop='signals_'.$network;
								$oneUrl->$signals_prop=$value;
								$signals_total+=$value;
							}
							else
							{
								foreach ($value as $network_action=>$actual_value)
								{
									$signals_prop='signals_facebook_'.$network_action;
									$oneUrl->$signals_prop=$actual_value;
								}
								
								$signals_total+=$value['total'];
							}
						}
						
						$oneUrl->signals_total=$signals_total;
						
						$ts=time();
						$oneUrl->signals_dt=date('Y-m-d H:i:s',$ts);
						$oneUrl->timeout=$ops->getRefreshTimeout($oneUrl);
						$oneUrl->refresh_dt=date('Y-m-d H:i:s',$ts+$oneUrl->timeout);
					}
					
					$result=$oneUrl->save();
				}
				else
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public function eventProjectCrawlEnd($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();
		
		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
			$result=OS_Fork::fork('app','socialsignals','generate_report',array('project_id'=>$params['project_id']));
		}
		
		return $result;
	}
	
	public function eventProjectUrlsObsolete($params)
	{
		$result=false;
		
		$OS=getOS();
		$appOps=$OS->getAppOps();
		
		if ($appOps->isProjectApp($params['project_id'],$this->getAppDetail('app_id')))
		{
			$ops=OS_APP_SocialSignals_UrlOperations::get_instance();
			
			foreach ($params['urls'] as $url_id=>$url_details)
			{
				$ops->deleteUrlByUrlHash($url_details['url_hash'],$params['project_id']);
			}
		}
		
		return $result;
	}
	
	public function eventProjectDeleted($params)
	{
		$ops=OS_APP_SocialSignals_ReportOperations::get_instance();
		
		return $ops->deleteDataByProjectID($params['project_id']);
	}
}
?>