<?php
class OS_APP_SocialSignals_ReportOperations
{
	private static $_instance;
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_SocialSignals_ReportOperations();
		}
		
		return self::$_instance;
	}
	
	public function getReportByID($report_id,$project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE id=? AND project_id=?",array($report_id,$project_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$row['signals']=json_decode($row['signals'],true);
			
			$result=new OS_APP_SocialSignals_Report();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getReportByProjectID($project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."reports WHERE project_id=?",array($project_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$row['signals']=json_decode($row['signals'],true);
			
			$result=new OS_APP_SocialSignals_Report();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function insertReport($report)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$query="INSERT INTO ".$appHandler->dbPrefix()."reports (project_id,signals) VALUES (?,?)";
		$dbresult=$db->query($query,array($report->project_id,json_encode($report->signals)));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
			
			$report->id=$result;
			$this->logReportHistory($report);
		}
		
		return $result;
	}
	
	public function updateReport($report)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$query="UPDATE ".$appHandler->dbPrefix()."reports SET signals=? WHERE id=?";
		$dbresult=$db->query($query,array(json_encode($report->signals),$report->id));
		
		if ($dbresult!==false)
		{
			$this->logReportHistory($report);
			$result=true;
		}
		
		return $result;
	}
	
	public function logReportHistory($report)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$history_d=date('Y-m-d',time());
		
		if ($hasHistory=$this->getReportHistory($report,$history_d))
		{
			$dbresult=$db->query("UPDATE ".$appHandler->dbPrefix()."reports_history SET signals=? WHERE report_id=? AND history_d=?",array(json_encode($report->signals),$report->id,$history_d));
		}
		else
		{
			$dbresult=$db->query("INSERT INTO ".$appHandler->dbPrefix()."reports_history (project_id,report_id,signals,history_d) VALUES (?,?,?,?)",array($report->project_id,$report->id,json_encode($report->signals),$history_d));
		}
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function getReportHistory($report,$history_d=false)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."reports_history WHERE report_id=?".($history_d?" AND history_d=?":'');
		$dbresult=$db->query($query,($history_d?array($report->id,$history_d):array($report->id)));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=json_decode($row['signals'],true);
		}
		
		return $result;
	}
	
	public function getReportEvolution($report,$count=10)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."reports_history WHERE report_id=? ORDER BY history_d DESC LIMIT {$count}";
		$dbresult=$db->query($query,array($report->id));
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['history_d']]=json_decode($row['signals'],true);
		}
		
		return $result;
	}
	
	public function deleteReportHistoryByReportID($report_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."reports_history WHERE report_id=?";
		$dbresult=$db->query($query,array($report_id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteReportByID($report_id)
	{
		$result=false;
		
		if ($this->deleteReportHistoryByReportID($report_id))
		{
			$OS=getOS();
			$db=$OS->getDb();
			$appHandler=$OS->getAppHandler();
			
			$query="DELETE FROM ".$appHandler->dbPrefix()."reports WHERE id=?";
			$dbresult=$db->query($query,array($report_id));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function deleteDataByProjectID($project_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."urls WHERE project_id=?";
		$dbresult=$db->query($query,array($project_id));
		
		if ($dbresult!==false)
		{
			$query="DELETE FROM ".$appHandler->dbPrefix()."reports WHERE project_id=?";
			$dbresult=$db->query($query,array($project_id));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
}
?>