<?php
class OS_APP_SocialSignals_UrlOperations
{
	private static $_instance;
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_SocialSignals_UrlOperations();
		}
		
		return self::$_instance;
	}
	
	public function getUrlByID($url_id,$project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."urls WHERE id=? AND project_id=?",array($url_id,$project_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$row['signals']=json_decode($row['signals'],true);
			
			$result=new OS_APP_SocialSignals_Url();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getUrls($project_id=false,$offset=0,$count=10,$order_by='total',$min_value=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."urls WHERE project_id=? ".($min_value?"AND `signals_{$order_by}`>=?":'')." ORDER BY signals_{$order_by} DESC".(($offset!==false AND $count!==false)?" LIMIT {$offset},{$count}":''),($min_value?array($project_id,$min_value):array($project_id)));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['signals']=json_decode($row['signals'],true);
			
			$oneUrl=new OS_APP_SocialSignals_Url();
			$oneUrl->set($row);
			
			$result[$row['id']]=$oneUrl;
		}
		
		return $result;
	}
	
	public function getUrlsPendingRefresh($project_id=false,$limit=20)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."urls WHERE project_id=? AND refresh_dt<=? ORDER BY refresh_dt ASC LIMIT {$limit}",array($project_id,$time));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['signals']=json_decode($row['signals'],true);
			
			$oneUrl=new OS_APP_SocialSignals_Url();
			$oneUrl->set($row);
			
			$result[$row['id']]=$oneUrl;
		}
		
		return $result;
	}
	
	public function getUrlsCount($project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$dbresult=$db->query("SELECT COUNT(*) AS total_urls FROM ".$appHandler->dbPrefix()."urls WHERE project_id=?",array($project_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row['total_urls'];
		}
		
		return $result;
	}
	
	public function getUrlByUrlHash($url_hash,$project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		$appHandler=getOS()->getAppHandler();
		
		$dbresult=$db->query("SELECT * FROM ".$appHandler->dbPrefix()."urls WHERE url_hash=? AND project_id=?",array($url_hash,$project_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$row['signals']=json_decode($row['signals'],true);
			
			$result=new OS_APP_SocialSignals_Url();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function insertUrl($url)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$query="INSERT INTO ".$appHandler->dbPrefix()."urls (project_id,url_hash,url,title,signals,signals_stumbleupon,signals_reddit,signals_facebook_comments,signals_facebook_likes,signals_facebook_shares,signals_facebook_total,signals_delicious,signals_gplus,signals_twitter,signals_diggs,signals_pinterest,signals_linkedin,signals_total,signals_dt,timeout,refresh_dt) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		$dbresult=$db->query($query,array($url->project_id,$url->url_hash,$url->url,$url->title,json_encode($url->signals),$url->signals_stumbleupon,$url->signals_reddit,$url->signals_facebook_comments,$url->signals_facebook_likes,$url->signals_facebook_shares,$url->signals_facebook_total,$url->signals_delicious,$url->signals_gplus,$url->signals_twitter,$url->signals_diggs,$url->signals_pinterest,$url->signals_linkedin,$url->signals_total,$url->signals_dt,$url->timeout,$url->refresh_dt));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
			
			$url->id=$result;
			$this->logUrlHistory($url);
		}
		
		return $result;
	}
	
	public function updateUrl($url)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$time=$db->DBTimeStamp(time());
		$ip=$OS->getRemoteAddr();
		
		$query="UPDATE ".$appHandler->dbPrefix()."urls SET signals=?,signals_stumbleupon=?,signals_reddit=?,signals_facebook_comments=?,signals_facebook_likes=?,signals_facebook_shares=?,signals_facebook_total=?,signals_delicious=?,signals_gplus=?,signals_twitter=?,signals_diggs=?,signals_pinterest=?,signals_linkedin=?,signals_total=?,signals_dt=?,timeout=?,refresh_dt=? WHERE id=?";
		$dbresult=$db->query($query,array(json_encode($url->signals),$url->signals_stumbleupon,$url->signals_reddit,$url->signals_facebook_comments,$url->signals_facebook_likes,$url->signals_facebook_shares,$url->signals_facebook_total,$url->signals_delicious,$url->signals_gplus,$url->signals_twitter,$url->signals_diggs,$url->signals_pinterest,$url->signals_linkedin,$url->signals_total,$url->signals_dt,$url->timeout,$url->refresh_dt,$url->id));
		
		if ($dbresult!==false)
		{
			$this->logUrlHistory($url);
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteUrlByUrlHash($url_hash)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		if ($this->deleteUrlHistoryByUrlHash($url_hash))
		{
			$query="DELETE FROM ".$appHandler->dbPrefix()."urls WHERE url_hash=?";
			$dbresult=$db->query($query,array($url_hash));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function getUrlSocialSignals($url)
	{
		$OS=getOS();
		
		$osSocialSignals=$OS->getSocialSignals();
		$osSocialSignals->setSocialNetwork('sharedcount');
		
		return $osSocialSignals->getSocialSignals($url);
	}
	
	public function shouldGetSignals($url)
	{
		$result=false;
		
		if (strtotime($url->signals_dt)+$url->timeout<=time())
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function logUrlHistory($url)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$history_d=date('Y-m-d',time());
		
		$hasHistory=$this->getUrlHistory($url,$history_d);
		
		if ($hasHistory===false)
		{
			$dbresult=$db->query("INSERT INTO ".$appHandler->dbPrefix()."urls_history (project_id,url_hash,signals,history_d) VALUES (?,?,?,?)",array($url->project_id,$url->url_hash,json_encode($url->signals),$history_d));
		}
		else
		{
			$dbresult=$db->query("UPDATE ".$appHandler->dbPrefix()."urls_history SET signals=? WHERE url_hash=? AND history_d=?",array(json_encode($url->signals),$url->url_hash,$history_d));
		}
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function getUrlHistory($url,$history_d=false)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."urls_history WHERE url_hash=?".($history_d?" AND history_d=?":'');
		$dbresult=$db->query($query,($history_d?array($url->url_hash,$history_d):array($url->url_hash)));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=json_decode($row['signals'],true);
		}
		
		return $result;
	}
	
	public function getUrlEvolution($url,$count=10)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="SELECT * FROM ".$appHandler->dbPrefix()."urls_history WHERE url_hash=? ORDER BY history_d DESC LIMIT {$count}";
		$dbresult=$db->query($query,array($url->url_hash));
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['history_d']]=json_decode($row['signals'],true);
		}
		
		return $result;
	}
	
	public function deleteUrlHistoryByUrlHash($url_hash)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		$appHandler=$OS->getAppHandler();
		
		$query="DELETE FROM ".$appHandler->dbPrefix()."urls_history WHERE url_hash=?";
		$dbresult=$db->query($query,array($url_hash));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function getRefreshTimeout($url,$min=3600,$max=2592000)
	{
		$result=false;
		
		if ($url->id)
		{
			if ($current_url=$this->getUrlByID($url->id,$url->project_id))
			{
				if ($url->signals==$current_url->signals)
				{
					$result=min($max,2*$current_url->timeout);
				}
				else
				{
					$result=max($min,round($current_url->timeout/2));
				}
			}
			else
			{
				$result=86400;
			}
		}
		else
		{
			$reportOps=OS_APP_SocialSignals_ReportOperations::get_instance();
			
			if ($report=$reportOps->getReportByProjectID($url->project_id))
			{
				$result=3600;
			}
			else
			{
				$result=86400;
			}
		}
		
		return $result;
	}
}
?>