<?php
class OS_APPVIEW_SocialSignals_Main extends OS_AppViewBase
{
	public $urlsPerPage=10;
	
	public $chartTypes;
	
	public function __construct()
	{
		parent::__construct();
		
		$this->chartTypes=array(
			'overall'=>array('name'=>_("Overall")),
			'facebook'=>array('name'=>"Facebook",'signal_name'=>_("Actions")),
			'gplus'=>array('name'=>"Google+",'signal_name'=>_("+1s")),
			'twitter'=>array('name'=>"Twitter",'signal_name'=>_("Tweets")),
			'pinterest'=>array('name'=>"Pinterest",'signal_name'=>_("Pins")),
			'linkedin'=>array('name'=>"LinkedIN",'signal_name'=>_("Shares")),
			'delicious'=>array('name'=>"Delicious",'signal_name'=>_("Shares")),
			'stumbleupon'=>array('name'=>"StumbleUpon",'signal_name'=>_("Stumbles")),
			'diggs'=>array('name'=>"Digg",'signal_name'=>_("Diggs")),
			'reddit'=>array('name'=>"Reddit",'signal_name'=>_("Actions"))
		);
	}
	
	public function processRequest()
	{
		$OS=getOS();
		
		$osProject=$OS->getProject();
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		$reportOps=OS_APP_SocialSignals_ReportOperations::get_instance();
		
		$requestParams=$appPlugin->getRequestParams();
		$processedRequest=array(
			'export'=>false
		);
		
		if ($processedRequest['report']=$reportOps->getReportByProjectID($osProject->id))
		{
			if (isset($requestParams['export']))
			{
				$processedRequest['export']=true;
			}
			else
			{
				$urlOps=OS_APP_SocialSignals_UrlOperations::get_instance();
				
				$processedRequest['urlsCount']=$urlOps->getUrlsCount();
				$processedRequest['page']=1;
				
				if (!empty($requestParams['page']) AND ($requestParams['page']>0) AND (($requestParams['page']-1)*$this->urlsPerPage<$processedRequest['urlsCount']))
				{
					$processedRequest['page']=$requestParams['page'];
				}
			}
		}
		
		return $processedRequest;
	}
	
	public function buildViewData()
	{
		$OS=getOS();
		
		$osProject=$OS->getProject();
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$viewDataVars=array();
		
		if ($this->processedRequest['report'])
		{
			if ($this->processedRequest['export'])
			{
				$urlOps=OS_APP_SocialSignals_UrlOperations::get_instance();
				
				$viewDataVars['export']=true;
				$viewDataVars['urls']=$urlOps->getUrls($osProject->id,false,false,'total');
			}
			else
			{
				$reportOps=OS_APP_SocialSignals_ReportOperations::get_instance();
				
				$viewDataVars['report']=$this->processedRequest['report'];
				
				$viewDataVars['report_evolution']=$reportOps->getReportEvolution($viewDataVars['report']);
				
				if ($this->processedRequest['urlsCount'])
				{
					$urlOps=OS_APP_SocialSignals_UrlOperations::get_instance();
					
					$viewDataVars['urlsCount']=$this->processedRequest['urlsCount'];
					
					$viewDataVars['urls']=$urlOps->getUrls($osProject->id,($this->processedRequest['page']-1)*$this->urlsPerPage,$this->urlsPerPage);
				}
			}
		}
		
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$viewData=$this->buildViewData();
		$tplVars=array();
		$headContents=array();
		
		if (!empty($viewData['export']))
		{
			$csv="URL,Facebook Shares,Facebook Likes,Facebook Comments,Google+,Twitter,Pinterest,LinkedIn,Delicious,StumbleUpon,Digg,Reddit,Total signals";
			
			foreach ($viewData['urls'] as $url)
			{
				$csv.="\n{$url->url},{$url->signals_facebook_shares},{$url->signals_facebook_likes},{$url->signals_facebook_comments},{$url->signals_gplus},{$url->signals_twitter},{$url->signals_pinterest},{$url->signals_linkedin},{$url->signals_delicious},{$url->signals_stumbleupon},{$url->signals_diggs},{$url->signals_reddit},{$url->signals_total}";
			}
			
			header('Content-Type: text/csv');
			header('Content-Disposition: attachment; filename="project_social_signals.csv"');
			
			echo $csv;
			
			exit;
		}
		elseif (!empty($viewData['report']))
		{
			$tplVars['report']=$viewData['report']->toTemplate();
			
			$tplVars['imagesURL']=$appPlugin->getAppHomeUrl().'/resources/images/social';
			$tplVars['exportURL']=$appPlugin->getAppActionUrl('view',array('export'=>'Y'));
			
			if (!empty($viewData['report_evolution']) AND count($viewData['report_evolution'])>=2)
			{
				$tplVars['chartTypes']=$this->chartTypes;
				
				$charts = $OS->getCharts();
				
				$stats=array_reverse($viewData['report_evolution'],true);
				
				$prev_signals_overall=false;$prev_signals=array();
				
				foreach ($this->chartTypes as $type=>$details)
				{
					$prev_signals[$type]=false;
				}
				
				$chartValues=array();$chartTooltips=array();$chartLabels=array();
				$day_index=0;
				foreach ($stats as $day=>$signals)
				{
					$signals['facebook']=$signals['facebook']['total'];
					$signals_overall=array_sum($signals);
					
					if ($day_index%3==0)
					{
						$chartLabels[]=date('d M',strtotime($day));
					}
					else
					{
						$chartLabels[]=false;
					}
					$day_index++;
					
					$chartValues['overall'][]=$signals_overall;
					$chartTooltips['overall'][]=date('d M',strtotime($day))."\n"._("Signals").": {$signals_overall}".($prev_signals_overall!==false?"\n"._("Change").": ".($signals_overall-$prev_signals_overall):'');
					$prev_signals_overall=$signals_overall;
					
					foreach ($this->chartTypes as $type=>$details)
					{
						if ($type!='overall')
						{
							$chartValues[$type][]=$signals[$type];
							$chartTooltips[$type][]=date('d M',strtotime($day))."\n{$details['signal_name']}: {$signals[$type]}".($prev_signals[$type]!==false?"\n"._("Change").": ".($signals[$type]-$prev_signals[$type]):'');
							$prev_signals[$type]=$signals[$type];
						}
					}
				}
				
				foreach ($this->chartTypes as $type=>$details)
				{
					$chartOptions=array(
						'values'=>array_values($chartValues[$type]),
						'labels'=>$chartLabels,
						'tooltips'=>array_values($chartTooltips[$type]),
						'fill'=>true,
						'normalize'=>true,
						'height'=>174
					);
					$chartData = $charts->getLineChart($chartOptions);
					
					$tplVars['report_evolution'][$type]=$chartData['html'];
				}
			}
			else
			{
				$tplVars['report_evolution']=false;
			}
			
			if ($viewData['urlsCount'])
			{
				foreach ($viewData['urls'] as $url_id=>$url)
				{
					$tplVars['urls'][$url_id]=$url->toTemplate();
				}
			}
			else
			{
				$tplVars['urls']=false;
			} 
			
			if ($this->processedRequest['page']>1)
			{
				$tplVars['prev_page_url']=$appPlugin->getAppActionUrl('main',array('page'=>$this->processedRequest['page']-1));
			}
			else
			{
				$tplVars['prev_page_url']=false;
			}
			
			if (($this->processedRequest['page']*$this->urlsPerPage)<$viewData['urlsCount'])
			{
				$tplVars['next_page_url']=$appPlugin->getAppActionUrl('main',array('page'=>$this->processedRequest['page']+1));
			}
			else
			{
				$tplVars['next_page_url']=false;
			}
		}
		else
		{
			$tplVars['report']=false;
		}
		
		$tpl=$OS->getTemplate();
		
		if (!empty($tplVars['report_evolution']))
		{
			$headContents['chartJS']=implode("\n",$chartData['js']);
			$headContents['css']['socialsignalsnow']=$appPlugin->getAppHomeUrl()."/resources/style.css";
			
			$headContents['socialsignalsnow']="<script type='text/javascript'>
				var currentType='all';

				function socialSignalsNowChangeType(selectedIndex)
				{
					$('#chartsContainer').css('margin-top',(-selectedIndex*174)+'px')
				}
			</script>";
			
			$tpl->setHeadContents($headContents);
		}
		
		return $tpl->fetchTemplate('view',$tplVars);
	}
}
?>