<?php
class OS_APPVIEW_SocialSignals_Url extends OS_AppViewBase
{
	public $chartTypes;
	
	public function __construct()
	{
		parent::__construct();
		
		$this->chartTypes=array(
			'overall'=>array('name'=>_("Overall")),
			'facebook'=>array('name'=>"Facebook",'signal_name'=>_("Actions")),
			'gplus'=>array('name'=>"Google+",'signal_name'=>_("+1s")),
			'twitter'=>array('name'=>"Twitter",'signal_name'=>_("Tweets")),
			'pinterest'=>array('name'=>"Pinterest",'signal_name'=>_("Pins")),
			'linkedin'=>array('name'=>"LinkedIN",'signal_name'=>_("Shares")),
			'delicious'=>array('name'=>"Delicious",'signal_name'=>_("Shares")),
			'stumbleupon'=>array('name'=>"StumbleUpon",'signal_name'=>_("Stumbles")),
			'diggs'=>array('name'=>"Digg",'signal_name'=>_("Diggs")),
			'reddit'=>array('name'=>"Reddit",'signal_name'=>_("Actions"))
		);
	}
	
	public function processRequest()
	{
		$OS=getOS();
		
		$osProject=$OS->getProject();
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$requestParams=$appPlugin->getRequestParams();
		
		if (empty($requestParams['url_id']))
		{
			$OS->redirectTO($appPlugin->getAppActionUrl('view'),true);
		}
		
		$ops=OS_APP_SocialSignals_UrlOperations::get_instance();
		
		if (!$url=$ops->getUrlByID($requestParams['url_id']))
		{
			$OS->redirectTO($appPlugin->getAppActionUrl('view'),true);
		}
		
		return array(
			'url'=>$url,
			'url_evolution'=>$ops->getUrlEvolution($url)
		);
	}
	
	public function render()
	{
		$OS=getOS();
		
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		
		$viewData=$this->buildViewData();
		$tplVars=array(
			'url'=>$this->processedRequest['url']->toTemplate(),
			'imagesURL'=>$appPlugin->getAppHomeUrl().'/resources/images/social'
		);
		
		if (!empty($this->processedRequest['url_evolution']) AND count($this->processedRequest['url_evolution'])>=2)
		{
			$tplVars['chartTypes']=$this->chartTypes;
			
			$charts = $OS->getCharts();
			
			$stats=array_reverse($this->processedRequest['url_evolution'],true);
			
			$prev_signals_overall=false;$prev_signals=array();
				
			foreach ($this->chartTypes as $type=>$details)
			{
				$prev_signals[$type]=false;
			}
			
			$chartValues=array();$chartTooltips=array();$chartLabels=array();
			$day_index=0;
			foreach ($stats as $day=>$signals)
			{
				$signals['facebook']=$signals['facebook']['total'];
				$signals_overall=array_sum($signals);
				
				if ($day_index%3==0)
				{
					$chartLabels[]=date('d M',strtotime($day));
				}
				else
				{
					$chartLabels[]=false;
				}
				$day_index++;
				
				$chartValues['overall'][]=$signals_overall;
				$chartTooltips['overall'][]=date('d M',strtotime($day))."\n"._("Signals").": {$signals_overall}".($prev_signals_overall!==false?"\n"._("Change").": ".($signals_overall-$prev_signals_overall):'');
				$prev_signals_overall=$signals_overall;
				
				foreach ($this->chartTypes as $type=>$details)
				{
					if ($type!='overall')
					{
						$chartValues[$type][]=$signals[$type];
						$chartTooltips[$type][]=date('d M',strtotime($day))."\n{$details['signal_name']}: {$signals[$type]}".($prev_signals[$type]!==false?"\n"._("Change").": ".($signals[$type]-$prev_signals[$type]):'');
						$prev_signals[$type]=$signals[$type];
					}
				}
			}
			
			foreach ($this->chartTypes as $type=>$details)
			{
				$chartOptions=array(
					'values'=>array_values($chartValues[$type]),
					'labels'=>$chartLabels,
					'tooltips'=>array_values($chartTooltips[$type]),
					'fill'=>true,
					'normalize'=>true,
					'height'=>174
				);
				$chartData = $charts->getLineChart($chartOptions);
				
				$tplVars['evolution'][$type]=$chartData['html'];
			}
		}
		else
		{
			$tplVars['evolution']=false;
		}
		
		$tpl=$OS->getTemplate();
		
		if (!empty($tplVars['evolution']))
		{
			$headContents['chartJS']=implode("\n",$chartData['js']);
			$headContents['css']['socialsignalsnow']=$appPlugin->getAppHomeUrl()."/resources/style.css";
			
			$headContents['socialsignalsnow']="<script type='text/javascript'>
				var currentType='all';

				function socialSignalsNowChangeType(selectedIndex)
				{
					$('#chartsContainer').css('margin-top',(-selectedIndex*174)+'px')
				}
			</script>";
			
			$tpl->setHeadContents($headContents);
		}
		
		return $tpl->fetchTemplate('url',$tplVars);
	}
}
?>