<?php
class OS_APP_WebsiteAudit extends OS_AppBase
{
	private static $_instance;
	
	public function __construct()
	{
		parent::__construct();
		
		$this->addMenuItem('view', array("name" => _("Main"), 'routerOption'=> "handleMainView"));
		$this->addMenuItem('refresh', array("name" => _("Refresh Info"), 'routerOption'=> "handleRefreshView"));
		$this->addMenuItem('reports', array("name" => _("Reports"), 'routerOption'=> "handleReportsView"));
		
		$this->setRouterOption("report", "handleReportView");
		$this->setRouterOption("reportevolution", "handleReportEvolutionView");
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_APP_WebsiteAudit();
		}
		
		return self::$_instance;
	}
	
	public function handleMainView()
	{
		getOS()->getUser()->forcePerm('websiteaudit','view');
		
		$viewData=new OS_APPVIEW_WebsiteAudit_Main();
		
		return $viewData->render();
	}
	
	public function handleRefreshView()
	{
		getOS()->getUser()->forcePerm('websiteaudit','view');
		
		$viewData=new OS_APPVIEW_WebsiteAudit_Refresh();
		
		return $viewData->render();
	}
	
	public function handleReportsView()
	{
		getOS()->getUser()->forcePerm('websiteaudit','view');
		
		$viewData=new OS_APPVIEW_WebsiteAudit_Reports();
		
		return $viewData->render();
	}
	
	public function handleReportView()
	{
		getOS()->getUser()->forcePerm('websiteaudit','view');
		
		$viewData=new OS_APPVIEW_WebsiteAudit_Report();
		
		return $viewData->render();
	}
	
	public function handleReportEvolutionView()
	{
		getOS()->getUser()->forcePerm('websiteaudit','view');
		
		$viewData=new OS_APPVIEW_WebsiteAudit_ReportEvolution();
		
		return $viewData->render();
	}
	
	protected function defineAppPermissions()
	{
		$this->appPermissions=array(
			'websiteaudit'=>array(
				'view'=>array('name'=>_("View Website Audit")),
			)
		);
	}
	
	public function getReportingData($type='overview')
	{
		$result=false;
		
		getOS()->getUser()->forcePerm('websiteaudit','view');
		
		$availableTypes=$this->getReportingTypes();
		
		if (isset($availableTypes[$type]))
		{
			if ($type=='overview')
			{
				$viewData=new OS_APPVIEW_WebsiteAudit_Report();
			}
			elseif ($type=='evolution')
			{
				$viewData=new OS_APPVIEW_WebsiteAudit_ReportEvolution();
			}
			
			$reportData=$viewData->buildViewData();
			
			if ($reportData['report'])
			{
				$result=$reportData['report'];
			}
		}
		
		return $result;
	}
	
	public function getReportingTypes()
	{
		return array(
			'overview'=>"Overview report",
			'evolution'=>"Evolution report"
		);
	}
	
	public function eventAppAddedToProject($params)
	{
		$result=false;
		
		if ($params['app_name']=='websiteaudit')
		{
			$report=OS_APP_WebsiteAudit_Report::get_instance();
			
			$report->project_id=$params['project_id'];
			
			if ($report->save())
			{
				$result=OS_Fork::fork('app','websiteaudit','generate_audit',array('project_id'=>$params['project_id'],'report_id'=>$report->id));
			}
		}
		
		return $result;
	}
	
	public function eventProjectDeleted($params)
	{
		$ops=OS_APP_WebsiteAudit_ReportOperations::get_instance();
		
		return $ops->deleteDataByProjectID($params['project_id']);
	}
	
	public function eventSearchEngineQueried($params)
	{
		$result=false;
		
		$ops=OS_APP_WebsiteAudit_Auditor::get_instance();
		$result=$ops->eventSearchEngineQueried($params);
		
		return $result;
	}
}
?>