<?php
class OS_APPVIEW_WebsiteAudit_Report extends OS_AppViewBase
{
	public function __construct()
	{
		parent::__construct();
	}
	
	public function buildViewData()
	{
		$OS=getOS();
		
		$project=$OS->getProject();
		$appPlugin=$OS->getAppHandler()->getAppPlugin();
		$ops=OS_APP_WebsiteAudit_ReportOperations::get_instance();
		
		$viewDataVars=array('report'=>false);
		
		if ($report=$ops->getLatestReports($project->id,1))
		{
			$report=reset($report);
			
			$report=$report->result;
			
			if (!empty($report['site_available']))
			{
				$osUtils=$OS->getUtils();
				
				$appHomeUrl=$appPlugin->getAppHomeUrl();
				
				$reportData=array(
					'filename'=>'website_info.pdf',
					'title'=>_('Website Info'),
					'sections'=>array()
				);
				
				$reportData['sections']['server']=array(
					'title'=>_("Server details"),
					'icon'=>"{$appHomeUrl}/resources/images/report/server_details.png",
					'type'=>'messages',
					'messages'=>array()
				);
				
				if ($report['server']['cms'])
				{
					$cmsDetector=getOS()->getCMSDetector();
					
					$cms=$cmsDetector->getCMSDetails($report['server']['cms']);
					$cms=$cms['name'];
					
					$reportData['sections']['server']['messages'][]=array(
						'type'=>'label_value',
						'label'=>array(
							'text'=>'CMS'
						),
						'value'=>array(
							'text'=>$cms
						)
					);
					
					$reportData['sections']['server']['messages'][]=array('type'=>'blank');
				}
				
				$reportData['sections']['server']['messages'][]=array(
					'type'=>'label_value',
					'label'=>array(
						'text'=>_('Load time')
					),
					'value'=>array(
						'text'=>$report['server']['load_time'].' seconds'
					)
				);
				
				$reportData['sections']['server']['messages'][]=array('type'=>'blank');
				
				$reportData['sections']['server']['messages'][]=array(
					'type'=>'label_value',
					'label'=>array(
						'text'=>'IP'
					),
					'value'=>array(
						'text'=>$report['server']['ip']
					)
				);
				
				if (!empty($report['server']['location']))
				{
					$location_text='';
					$location=$report['server']['location'];
					
					if (!empty($location['city']))
					{
						$location_text.=$location['city'];
					}
					
					if (!empty($location['region_name']))
					{
						$location_text.=(empty($location_text)?'':', ').$location['region_name'];
					}
					
					if (!empty($location['country_name']))
					{
						$location_text.=(empty($location_text)?'':', ').$location['country_name'];
					}
					
					if (!empty($location['continent_name']))
					{
						$location_text.=(empty($location_text)?'':', ').$location['continent_name'];
					}
					
					if (!empty($location_text))
					{
						$reportData['sections']['server']['messages'][]=array(
							'type'=>'label_value',
							'label'=>array(
								'text'=>_('Location')
							),
							'value'=>array(
								'text'=>$location_text
							)
						);
					}
				}
				
				if (!empty($report['server']['reverse_ip']))
				{
					$reportData['sections']['server']['messages'][]=array('type'=>'blank');
					
					$reportData['sections']['server']['messages'][]=array(
						'type'=>'label_value',
						'label'=>array(
							'text'=>'Reverse IP'
						),
						'value'=>array(
							'text'=>count($report['server']['reverse_ip']).' other domains hosted on this IP'
						)
					);
				}
				
				if ($report['onsite']['analyzed'])
				{
					$headings_text='';
					
					foreach ($report['onsite']['headings'] as $heading=>$count)
					{
						if ($count>0)
						{
							$headings_text.=(empty($headings_text)?'':', ').$osUtils->humanizeInteger($count).' x '.strtoupper($heading);
						}
					}
					
					$reportData['sections']['content']=array(
						'title'=>"Content",
						'icon'=>"{$appHomeUrl}/resources/images/report/content.png",
						'type'=>'messages',
						'messages'=>array(
							array(
								'type'=>'label_value',
								'label'=>array(
									'text'=>'URL'
								),
								'value'=>array(
									'text'=>$report['onsite']['url']
								)
							),
							array('type'=>'blank'),
							array(
								'type'=>'label_value',
								'label'=>array(
									'text'=>_('Title')
								),
								'value'=>array(
									'text'=>(empty($report['onsite']['title'])?'n/a':$report['onsite']['title'])
								)
							),
							array(
								'type'=>'label_value',
								'label'=>array(
									'text'=>_('Description')
								),
								'value'=>array(
									'text'=>(empty($report['onsite']['description'])?'n/a':$report['onsite']['description'])
								)
							),
							array('type'=>'blank'),
							array(
								'type'=>'label_value',
								'label'=>array(
									'text'=>_('Headings')
								),
								'value'=>array(
									'text'=>(empty($headings_text)?'n/a':$headings_text)
								)
							),
							array(
								'type'=>'label_value',
								'label'=>array(
									'text'=>_('Images')
								),
								'value'=>array(
									'text'=>(empty($report['onsite']['images']['total'])?'n/a':$osUtils->humanizeInteger($report['onsite']['images']['total']).' images, '.(empty($report['onsite']['images']['no_alt'])?'all having ALTs':$osUtils->humanizeInteger($report['onsite']['images']['no_alt']).' missing the ALT attribute'))
								)
							)
						)
					);
				}
				
				$reportData['sections']['compliance_usability']=array(
					'title'=>_("Compliance & Usability"),
					'icon'=>"{$appHomeUrl}/resources/images/report/usability.png",
					'type'=>'messages',
					'messages'=>array(
						array(
							'type'=>'label_value',
							'label'=>array(
								'text'=>'Favicon'
							),
							'value'=>array(
								'text'=>($report['usability']['favicon']?'Yes':'No')
							)
						),
						array(
							'type'=>'label_value',
							'label'=>array(
								'text'=>'robots.txt'
							),
							'value'=>array(
								'text'=>($report['compliance']['robots']?'Yes':'No')
							)
						),
						array(
							'type'=>'label_value',
							'label'=>array(
								'text'=>'Sitemap'
							),
							'value'=>array(
								'text'=>($report['compliance']['sitemap']?'Yes':'No')
							)
						),
						array(
							'type'=>'label_value',
							'label'=>array(
								'text'=>'Google Analytics'
							),
							'value'=>array(
								'text'=>($report['compliance']['ga']?'Yes':'No')
							)
						),
					)
				);
				
				$reportData['sections']['rankings']=array(
					'title'=>_("Rankings"),
					'icon'=>"{$appHomeUrl}/resources/images/report/rankings.png",
					'type'=>'messages',
					'messages'=>array(
						array(
							'type'=>'label_value',
							'label'=>array(
								'text'=>_('Alexa rank')
							),
							'value'=>array(
								'text'=>(empty($report['rankings']['alexa'])?'n/a':$osUtils->humanizeInteger($report['rankings']['alexa']))
							)
						),
						array(
							'type'=>'label_value',
							'label'=>array(
								'text'=>'Pagerank'
							),
							'value'=>array(
								'text'=>$report['rankings']['pagerank'].' / 10'
							)
						)
					)
				);
				
				if (!empty($report['rankings']['moz_da']))
				{
					$reportData['sections']['rankings']['messages'][]=array(
						'type'=>'label_value',
						'label'=>array(
							'text'=>'Moz DomainAuthority'
						),
						'value'=>array(
							'text'=>$report['rankings']['moz_da'].' / 100'
						)
					);
				}
				if (!empty($report['rankings']['moz_pa']))
				{
					$reportData['sections']['rankings']['messages'][]=array(
						'type'=>'label_value',
						'label'=>array(
							'text'=>'Moz PageAuthority'
						),
						'value'=>array(
							'text'=>$report['rankings']['moz_pa'].' / 100'
						)
					);
				}
				if (!empty($report['rankings']['majestic_cf']))
				{
					$reportData['sections']['rankings']['messages'][]=array(
						'type'=>'label_value',
						'label'=>array(
							'text'=>'Majestic CitationFlow'
						),
						'value'=>array(
							'text'=>$report['rankings']['majestic_cf'].' / 100'
						)
					);
				}
				if (!empty($report['rankings']['majestic_tf']))
				{
					$reportData['sections']['rankings']['messages'][]=array(
						'type'=>'label_value',
						'label'=>array(
							'text'=>'Majestic TrustFlow'
						),
						'value'=>array(
							'text'=>$report['rankings']['majestic_tf'].' / 100'
						)
					);
				}
				
				$reportData['sections']['indexed']=array(
					'title'=>_("Indexed Pages"),
					'icon'=>"{$appHomeUrl}/resources/images/report/indexed_pages.png",
					'type'=>'messages',
					'messages'=>array(
						array(
							'type'=>'label_value',
							'label'=>array(
								'text'=>'Google'
							),
							'value'=>array(
								'text'=>$osUtils->humanizeInteger($report['indexed']['google']).' pages'
							)
						),
						array(
							'type'=>'label_value',
							'label'=>array(
								'text'=>'Bing'
							),
							'value'=>array(
								'text'=>$osUtils->humanizeInteger($report['indexed']['bing']).' pages'
							)
						)
					)
				);
				
				$reportData['sections']['social']=array(
					'title'=>_("Social Signals"),
					'icon'=>"{$appHomeUrl}/resources/images/report/social.png",
					'type'=>'messages',
					'messages'=>array(
						array(
							'type'=>'label_value',
							'label'=>array(
								'text'=>'Facebook'
							),
							'value'=>array(
								'text'=>$osUtils->humanizeInteger($report['social']['facebook']['shares']).' shares, '.$osUtils->humanizeInteger($report['social']['facebook']['likes']).' likes, '.$osUtils->humanizeInteger($report['social']['facebook']['comments']).' comments'
							)
						),
						array(
							'type'=>'label_value',
							'label'=>array(
								'text'=>'Twitter'
							),
							'value'=>array(
								'text'=>$osUtils->humanizeInteger($report['social']['twitter']['tweets']).' tweets'
							)
						)
					)
				);
				
				$viewDataVars['report']=$reportData;
			}
		}
		
		return $viewDataVars;
	}
	
	public function render()
	{
		$OS=getOS();
		
		$viewData=$this->buildViewData();
		
		if ($viewData['report'])
		{
			$osReport=$OS->getReport();
			
			$osReport->generateReport($viewData['report']);
		}
		else
		{
			return $OS->getTemplate()->fetchTemplate('report');
		}
	}
}
?>