<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */
class OS_Installer
{
	private static $_instance;
	
	private $loadedClasses;
	
	private $installParams;
	
	private $internalOptions;
	
	private $currentInstallStep;
	
	private $maxInstallSteps;
	
	private $installSteps;
	
	//os installer constructor
	protected function __construct()
	{
		$OS = getOS();
		$osUtils = $OS->getUtils();
		
		$this->maxInstallSteps = 9;
		
		//define internal options
		$os_install_path = dirname(dirname(dirname(__FILE__)));
		
		$os_root_path = dirname($os_install_path);
		
		$relative_url=str_replace(array(str_replace('/',DIRECTORY_SEPARATOR,$_SERVER['DOCUMENT_ROOT']),DIRECTORY_SEPARATOR),array("",'/'),$os_root_path);

		$os_root_url = 'http://' . $osUtils->stripifyURL($_SERVER['HTTP_HOST'] . $relative_url);
		
		//check install key
		if(empty($_SESSION['install']['install_key']))
		{
			$_SESSION['install']['install_key'] = $osUtils->generateCryptKey(12,true);
		}
		
		//always check if templates_c exists
		if(isset($_SESSION['ui']['file_exists']['templates_c']))
		{
			unset($_SESSION['ui']['file_exists']['templates_c']);
		}
		
		$install_menu = array(
			1 => array("name"=>_("License Agreement"),"icon"=>'P'),	
			2 => array("name"=>_("Checking Requirements"),"icon"=>'v'),
			3 => array("name"=>_("Server Configuration"),"icon"=>'D'),
			4 => array("name"=>_("User Credentials"),"icon"=>'u'),
			5 => array("name"=>_("Project Details"),"icon"=>'Y'),
			6 => array("name"=>_("Summary"),"icon"=>'@'),
			7 => array("name"=>_("Install Apps"),"icon"=>'R'),
			8 => array("name"=>_("OpenS API Credentials"),"icon"=>"\\"),
			9 => array("name"=>_("Finish"),"icon"=>'c')
			);
		
		$internalOptions = array(
			'os_root_url' => $os_root_url,
			'os_install_path'=> $os_install_path,
			'os_root_path' => $os_root_path,
			'install_key' => $_SESSION['install']['install_key'],
			);
			
		//handle install params
		$installParams = array();
		if(!empty($_POST['install_vals_box']))
		{
			//get data from install-values and push them in the class details
			$decryptedParams = json_decode($osUtils->stringDecode($_POST['install_vals_box'], $internalOptions['install_key']), true);
			if(!is_null($decryptedParams)) $installParams += $decryptedParams;
		}
		$this->setInstallParams($installParams);
		

		//handle install type
		if(!empty($installParams[1]))
		{
			if(isset($installParams[1]['install_type']))
			{
				$internalOptions['install_type'] = $installParams[1]['install_type'];
			}
			
			if(isset($installParams[1]['install_version']))
			{
				$internalOptions['install_version'] = $installParams[1]['install_version'];
			}
			
			if(isset($installParams[1]['os_version']))
			{
				$internalOptions['os_version'] = $installParams[1]['os_version'];
			}
		}
		
		$this->setInternalOptions($internalOptions);
		
	
		//handle current install step
		$this->installSteps = $this->getInstallSteps();
		
		
		//add install menu
		foreach($install_menu as $step => $values)
		{
			if(!in_array($step,$this->installSteps)) unset($install_menu[$step]);	
		}
		
		$this->setInternalOptions(array('install_menu' => $install_menu));
		
		
		//set initial current step 
		if(!isset($this->currentInstallStep))
		{
			$this->setCurrentInstallStep(1);
		}		
		
		if(!empty($installParams['current_step']))
		{
			if($this->validInstallStep($installParams['current_step']))
			{
				$this->setCurrentInstallStep($installParams['current_step']);
			}
		}
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_Installer();
		}
		return self::$_instance;
	}
	
	public function getCurrentInstallStep()
	{
		return $this->currentInstallStep;
	}
	
	public function setCurrentInstallStep($installStep)
	{
		if($this->validInstallStep($installStep))
		{
			$this->currentInstallStep = $installStep;	
		}
	}

	public function getInstallParams()
	{
		return $this->installParams;
	}

	public function getInstallParamsEncrypted()
	{
		return getOS()->getUtils()->stringEncode($this->getInstallParams2JSON(), $this->getInternalOption('install_key'));
	}
	
	public function getInstallParams2JSON()
	{
		return json_encode($this->installParams);
	}
	
	
	public function setInstallParams($installParams)
	{
		if(!empty($installParams))
		{
			if(is_array($installParams))
			{
				if(!isset($this->installParams)) $this->installParams = array();
				 
				foreach($installParams as $var => $val)
				{
					$this->installParams[$var] = $val; 
				}		
			}
		}
	}
	
	public function setInternalOptions($internalOptions)
	{
		if(!empty($internalOptions))
		{
			if(is_array($internalOptions))
			{
				foreach($internalOptions as $var => $val)
				{
					$this->internalOptions[$var] = $val; 
				}		
			}
		}
	}
	
	public function getInternalOption($optionName)
	{
		$result = false;
		
		if(!empty($optionName))
		{
			if(isset($this->internalOptions[$optionName]))
			{
				$result = $this->internalOptions[$optionName];
			}
		}
		return $result;
	}

	
	public function processSubmit()
	{
		$currentInstallStep = $this->getCurrentInstallStep();
		
		if (isset($_POST['prev-btn']))
		{
			//handle previous button click
			$tmpSteps = array_flip($this->installSteps);
			$prevInstallIndex = $tmpSteps[$currentInstallStep];

			$tmpVal = ($prevInstallIndex - 1);
			if(isset($this->installSteps[$tmpVal]))
			{
				$prevInstallIndex = $tmpVal;
			}
			
			$this->setCurrentInstallStep($this->installSteps[$prevInstallIndex]);
		}
		elseif (isset($_POST['retry-btn']))
		{
			//handle retry button click
			$this->setCurrentInstallStep($currentInstallStep);
		}
		elseif ((isset($_POST['continue-btn'])) || (isset($_POST['os_create_account_btn'])) || (isset($_POST['os_check_account_btn'])) || (isset($_POST['action_update_btn'])) || (isset($_POST['action_install_btn'])))
		{
			//handle continue button click
			$installStepDetails = $this->getInstallStepDetails($currentInstallStep);
			
			$stepSubmitResult = $installStepDetails->processRequest();
			
			//check auth code
			$check_auth_code = (isset($_SESSION['install']['check_auth_code'])? $_SESSION['install']['check_auth_code'] : true);
			
			if($check_auth_code)
			{
				$checkResult = $this->checkAuthCode();
				if(!$checkResult) {getOS()->redirectTO("/install/index.php?msg=badauthcode");}	 
			}
			
			
			if($stepSubmitResult !== false)
			{
				//handle install steps
				$this->installSteps = $this->getInstallSteps();
				
				//update install params
				$installParams = $this->getInstallParams();
				
				$installParams[$currentInstallStep] = $stepSubmitResult;
				
				$this->setInstallParams($installParams);

				//go to next install step
				$tmpSteps = array_flip($this->installSteps);
				$nextInstallIndex = $tmpSteps[$currentInstallStep];
	
				$tmpVal = ($nextInstallIndex + 1);
				if(isset($this->installSteps[$tmpVal]))
				{
					$nextInstallIndex = $tmpVal;
				}
				
				$this->setCurrentInstallStep($this->installSteps[$nextInstallIndex]);
			}
		}
		
		$this->setInstallParams(array('current_step' => $this->getCurrentInstallStep()));
		
		//auto-fill current page params
		$installParams = $this->getInstallParams();
		$currentInstallStep = $this->getCurrentInstallStep();
		
		if(isset($installParams[$currentInstallStep]))
		{
			if(is_array($installParams[$currentInstallStep]))
			{
				foreach($installParams[$currentInstallStep] as $param => $value)
				{
					if(!isset($_POST["{$param}_box"])) $_POST["{$param}_box"] = $value; 
				}
			}
		}

		return NULL;
	}
	
	private function validInstallStep($installStep)
	{
		$result = true;
		
		//validate install step
		if(!is_numeric($installStep)) $result = false;
		elseif(!in_array($installStep, $this->installSteps)) $result = false;
		
		return $result;
	}
	
	public function checkAuthCode()
	{
		$result = false;
		$installParams = $this->getInstallParams();
		
		if(!empty($_SESSION['install']['auth_code']))
		{
			$internalAuth = true;
			$currentInstallStep = $this->getCurrentInstallStep(); 
			
			if(!isset($installParams[1]['auth_code'])) $internalAuth = false;
			elseif($_SESSION['install']['auth_code'] != $installParams[1]['auth_code']) $internalAuth = false;
			
			if($internalAuth)
			{
				if($currentInstallStep > 5) {$result = true;}
				else
				{
					$config_auth_code = getOS()->getConfigVar('auth_code');
					if(!empty($config_auth_code))
					{
						if($config_auth_code == $_SESSION['install']['auth_code'])
						{
							$result = true;	
						}
					}
				}	
			}
		}
		
		return $result;
	}
	
	public function getInstallOps()
	{
		$this->loadClass('InstallerOperations');
		
		return $this->runInstance('InstallerOperations');	
	}
	
	public function getMaxInstallSteps()
	{
		return $this->maxInstallSteps;
	}
	
	public function getInstallStepDetails($installStep)
	{
		$result = false;
		
		if($this->validInstallStep($installStep))
		{
			$className = "installStep{$installStep}";
		
			$this->loadClass($className);
			
			//add install internal options
			//$this->loadedClasses[$className]->internalOptions = $this->internalOptions;
			
			$result = $this->runInstance($className); 
		}
		
		return $result;
	}
	
	public function getInstallSteps()
	{
		$installSteps = range(1,$this->maxInstallSteps);
		
		$install_type = $this->getInternalOption('install_type');
		if($install_type == 'update')
		{
			$installSteps = array(1,6,7,9);
		}		
		
		return $installSteps; 
	}	

	private function loadClass($className)
	{
		$result = false;
		
		if(isset($this->loadedClasses[$className]))
		{
			 $result = true;
		}
		else
		{
			$OS = getOS();
			
			$osClassName = "OS_{$className}"; 
			
			$lowercase = strtolower($osClassName);
			
			$fn = os_join_path($this->getInternalOption('os_root_path'),'install','lib','classes',"class.{$lowercase}.php");
			
			
			if(file_exists($fn))
			{
				require_once($fn);
				
				$this->loadedClasses[$className] = new $osClassName();
	
				$result = true;
			}
		}
		
		return $result;
	}
	
	private function runInstance($className)
	{
		if(isset($this->loadedClasses[$className]))
		{
			$currentClass = $this->loadedClasses[$className];
			
			return call_user_func(array($currentClass,'get_instance'));
//			return $currentClass::get_instance();	
		} 
		else 
		{
			return false;
		}
	}
}
?>