<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */
class OS_InstallerOperations
{
	private static $_instance;

	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_InstallerOperations();
		}
		return self::$_instance;
	}
	
	public function __construct() {}
	
	
	public function extension_loaded_or($test)
	{
		$a = extension_loaded(strtolower($test));
		$b = extension_loaded(strtoupper($test));
		return (bool)($a | $b);
	}

	public function getSupportedDBDriver()
	{
		return array(
			'mysql'=>array('server'=>'mysql' ,'name'=>"MySQL"),	
			'mysqli'=>array('server'=>'mysql' ,'name'=>"MySQLi"),
			'postgres7'=>array('server'=>'postgres7' ,'name'=>"pqSQL")
			);
	}
	
	public function getApacheModules( $module = false )
	{
		if(function_exists('apache_get_modules'))
		{
			$modules = apache_get_modules();
			if($module)
			{
				if(in_array($module, $modules)) return true;
				else return false;
			}
			return $modules;
		}
	
		return false;
	}
	
	public function getTestValues( $property )
	{
		$range = array(
			'php_version'			=> array('minimum'=>'5.2.11', 'recommended'=>'5.3'),
			'gd_version'			=> array('minimum'=>2),
			'memory_limit'			=> array('minimum'=>'128M', 'recommended'=>'256M'),
			'max_execution_time'	=> array('minimum'=>30, 'recommended'=>60),
			'post_max_size'			=> array('minimum'=>'2M', 'recommended'=>'10M'),
			'upload_max_filesize'	=> array('minimum'=>'2M', 'recommended'=>'10M'),
	
			'mysql_version'			=> array('minimum'=>'5.0', 'recommended'=>'5.1'),
			'pgsql_version'			=> array('minimum'=>'7.4', 'recommended'=>'8'),
			'sqlite_version'		=> array('minimum'=>'', 'recommended'=>''),
		);
	
		if(array_key_exists($property, $range))
		{
			if(empty($range[$property]['recommended']))
			{
				$range[$property]['recommended'] = $range[$property]['minimum'];
			}
			return array($range[$property]['minimum'], $range[$property]['recommended']);
		}
	
		return array();
	}
	
	
	public function testGlobal( $result, $set = false )
	{
		static $continueon = true;
		static $special_failed = false;
	
		if( ($set) && (is_array($result)) )
		{
			$return = array($continueon, $special_failed);
			list($continueon, $special_failed) = $result;
			return $return;
		}
	
		if($result === '')
		{
			return array($continueon, $special_failed);
		}
		elseif($result == true)
		{
			$continueon = false;
		}
		elseif($result == false)
		{
			$special_failed = true;
		}
	
		return array($continueon, $special_failed);
	}
	
	
	public function & testRange( $required, $title, $var, $message = '', $minimum, $recommended, $ini = true, $test_as_bytes = false, $unlimited = null, $error_fragment = '' )
	{
		$test = $this->getTestOptions();
		$test['test']['message'] = $title;
		
		if($ini)
		{
			$this->testIni($test, $var, 'string');
			if(isset($test['result']['message']))
			{
				$required = false;
			}
		}
		else
		{
			$test['ini_val'] = $var;
		}
	
		$test['result']['value'] = $test['ini_val'];
		$test['result']['secondvalue'] = null;
		if($test_as_bytes)
		{
			$test['ini_val'] = $this->returnBytes($test['ini_val']);
			$minimum = $this->returnBytes($minimum);
			$recommended = $this->returnBytes($recommended);
		}
	
		if( (! is_null($unlimited)) && ((int) $test['ini_val'] == (int) $unlimited) )
		{
			$test['result']['value'] = ilang(_('Unlimited'));
			$test['result']['type'] = 'success';
			$this->getTestReturn($test, $required);
		}
		elseif((int) $test['ini_val'] < $minimum)
		{
			$test['result']['type'] = 'error';
			$this->getTestReturn($test, $required, $message, $error_fragment);
		}
		elseif((int) $test['ini_val'] < $recommended)
		{
			$test['result']['type'] = 'warning';
			$this->getTestReturn($test, false, $message, $error_fragment);
		}
		else
		{
			$test['result']['type'] = 'success';
			$this->getTestReturn($test, $required);
		}
	
		return $test;
	}
	
	public function & testVersionRange( $required, $title, $var, $message = '', $minimum, $recommended, $ini = true, $unlimited = null, $error_fragment='' )
	{
		$test = $this->getTestOptions();
		$test['test']['message'] = $title;
	
		if($ini)
		{
			$this->testIni($test, $var, 'string');
			if(isset($test['result']['message']))
			{
				$required = false;
			}
		}
		else
		{
			$test['ini_val'] = $var;
		}
	
		$test['result']['value'] = $test['ini_val'];
		$test['result']['secondvalue'] = null;
	
		if( (! is_null($unlimited)) && ($test['ini_val'] == (string) $unlimited) )
		{
			$test['result']['value'] = ilang(_('Unlimited'));
			$test['result']['type'] = 'success';
			$this->getTestReturn($test, $required);
		}
		elseif(version_compare($test['ini_val'], $minimum) < 0)
		{
			$test['result']['type'] = 'error';
			$this->getTestReturn($test, $required, $message, $error_fragment);
		}
		elseif(version_compare($test['ini_val'], $recommended) < 0)
		{
			$test['result']['type'] = 'warning';
			$this->getTestReturn($test, false, $message, $error_fragment);
		}
		else
		{
			$test['result']['type'] = 'success';
			$this->getTestReturn($test, $required);
		}
	
		return $test;
	}
	
	public function & testIntegerMask($required,$title,$var,$mask,$message = '',$ini = true,$negate = false,$display_value = true,$error_fragment = '')
	{
		$test = $this->getTestOptions();
		$test['test']['message'] = $title;
		
		if( $ini )
		{
			$this->testIni($test,$var,'and',$mask);
		}
		else
		{
			$test['ini_val'] = $var;
		}
		
		// did the ini test work.
		if( $test['ini_val'] === '' )
		{
			$test['result']['value'] = 0;
		}
		else
		{
			$test['result']['value'] = $test['ini_val'];
		}
	
		$res = $test['result']['value'];
		if( $negate )
		{
			$res = !(int)$res;
		}
	
		if(empty($res))
		{
			if($required)
			{
				$test['result']['type'] = 'error';
			}
			else
			{
				$test['result']['type'] = 'warning';
			}
		}
		else
		{
			$test['result']['type'] = 'success';
		}
	
		$test['display_value'] = $display_value;
		$this->getTestReturn($test, $required, $message, $error_fragment);
		return $test;
	}
	
	public function & testInteger( $required, $title, $var, $message = '', $ini = true, $empty_is_ok = true, $error_fragment = '' )
	{
		
		$test = $this->getTestOptions();
		$test['test']['message'] = $title;
	
		if($ini)
		{
			$this->testIni($test, $var, 'integer');
		}
		else
		{
			$test['ini_val'] = $var;
		}
	
		if($test['ini_val'] === '')
		{
			if($empty_is_ok) $test['result']['value'] = ilang(_('On'));
			else $test['result']['value'] = 0;
		}
		else
		{
			$test['result']['value'] = $test['ini_val'];
		}
	
		if(empty($test['result']['value']))
		{
			if($required)
			{
				$test['result']['type'] = 'error';
			}
			else
			{
				$test['result']['type'] = 'warning';
			}
		}
		else
		{
			$test['result']['type'] = 'success';
		}
	
		$this->getTestReturn($test, $required, $message, $error_fragment);
		return $test;
	}
	
	public function & testString( $required, $title, $var, $message = '', $ini = true, $code_empty = 'success', $code_not_empty = 'warning', $error_fragment = '' )
	{
		$test = $this->getTestOptions();
		$test['test']['message'] = $title;
	
		if($ini)
		{
			$this->testIni($test, $var, 'string');
		}
		else
		{
			$test['ini_val'] = $var;
		}
	
		$test['result']['value'] = $test['ini_val'];
		if(empty($test['result']['value']))
		{
			$test['result']['type'] = $code_empty;
		}
		else
		{
			$test['result']['value'] = str_replace(',', ', ', $test['result']['value']);
			$test['result']['type'] = $code_not_empty;
		}
	
		$this->getTestReturn($test, $required, $message, $error_fragment);
		return $test;
	}
	
	public function & testBoolean( $required, $title, $var, $message = '', $ini = true, $negative_test = false, $error_fragment = '' )
	{
		
		$test = $this->getTestOptions();
		$test['test']['message'] = $title;
	
		if($ini)
		{
			$this->testIni($test, $var, 'boolean');
		}
		else
		{
			$test['ini_val'] = $var;
		}
		$test['ini_val'] = $negative_test ? (! (bool) $test['ini_val']) : (bool) $test['ini_val'];
	
		if($test['ini_val'] == false)
		{
			$test['result']['value'] = $negative_test ? ilang(_('On')) : ilang(_('Off'));
			$test['result']['secondvalue'] = $negative_test ? ilang(_('True')) : ilang(_('False'));
			if($required)
			{
				$test['result']['type'] = 'error';
			}
			else
			{
				$test['result']['type'] = 'warning';
			}
		}
		else
		{
			$test['result']['value'] = $negative_test ? ilang(_('Off')) : ilang(_('On'));
			$test['result']['secondvalue'] = $negative_test ? ilang(_('False')) : ilang(_('True'));
			$test['result']['type'] = 'success';
		}
	
		$this->getTestReturn($test, $required, $message, $error_fragment);
		return $test;
	}
	
	public function returnBytes( $val )
	{
		if(is_string($val) && $val != '')
		{
			$val = trim($val);
			$last = strtolower(substr($val, strlen($val/1), 1));
			switch($last)
			{
				case 'g':
					$val *= 1024;
				case 'm':
					$val *= 1024;
				case 'k':
					$val *= 1024;
			}
		}
	
		return (int) $val;
	}
	
	public function & testRemoteFile( $required, $title, $url = '', $message = '', $debug = false, $timeout = 10, $search = 'opens' )
	{
		
		if(empty($url))
		{
			//change this
			$default_version_check_url = "http://opens.com";
			
			$url = $default_version_check_url;
		}
	
		$test = $this->getTestOptions();
		$test['test']['message'] = $title;
		//$test['result']['value'] = $url;
	
		if(! $url_info = parse_url($url))
		{
			// Relative or invalid URL?
			$test['result']['type'] = 'error';
			$this->getTestReturn($test, $required, '', '', ilang(_('Invalid test param value!')));
			return $test;
		}
	
		if( !isset($url_info['scheme']) || !isset($url_info['host']) )
		{
			$test['result']['type'] = 'error';
			$this->getTestReturn($test, $required, '', '', ilang(_('The page URL specified is invalid.  It should contain only alphanumeric characters, or - or /.  It is also possible that the URL specified is already in use.')));
			return $test;
		}
		else
		{
			switch($url_info['scheme'])
				{
				case 'https':
					$scheme = 'ssl://';
					$port = (isset($url_info['port'])) ? $url_info['port'] : 443;
					break;
				case 'http':
				default:
					$scheme = '';
					$port = (isset($url_info['port'])) ? $url_info['port'] : 80;
				}
				
			$complete_url  = (isset($url_info['path'])) ? $url_info['path'] : '/';
			$complete_url .= (isset($url_info['query'])) ? '?'.$url_info['query'] : '';
		}
	
		return $test;
	}
	
	public function getTestReturn( &$test, $required, $message = '', $error_fragment = '', $error = '' )
	{
		
		switch($test['result']['type'])
		{
			case 'success':
				list($test['result']['continueon'], $test['result']['special_failed']) = $this->testGlobal('');
				$test['result']['res_text'] = ilang(_('Success'));
				break;
			case 'warning':
			case 'error':
				list($test['result']['continueon'], $test['result']['special_failed']) = $this->testGlobal($required);
				if($test['result']['type'] == 'warning')
				{
					$test['result']['res_text'] = ilang(_('Caution'));
				}
				elseif($test['result']['type'] == 'error')
				{
					$test['result']['res_text'] = ilang(_('Failure'));
				}
	
				if(trim($message) != '')
				{
					$test['result']['message'] = $message;
				}
				if(trim($error_fragment) != '')
				{
					$test['result']['error_fragment'] = $error_fragment;
				}
				if(trim($error) != '')
				{
					$test['result']['message'] = $error;
				}
				break;
		}
	
		return true;
	}
	
	public function & testCreateDirAndFile( $required, $title, $message = '', $debug = false, $dir = '_test_dir_file_', $file = '_test_dir_file_' )
	{
		$test = $this->getTestOptions();
		$_test = false;
		
		$OSInstaller = getOSInstaller();
		$cache_dir_path = os_join_path($OSInstaller->getInternalOption('os_root_path'), "cache");
		
		$test['test']['message'] = $title;
		$dir = os_join_path($cache_dir_path, $dir);
		$file = os_join_path($dir, $file);
		
		if($debug)
		{
			if(file_exists($file)) unlink($file);
			if( (is_dir($dir)) && (false !== strpos($dir, $cache_dir_path))) rmdir($dir); 
			
			if(! mkdir($dir)) $test['result']['message'] = ilang(_('No permission to write in directory.  This could be caused by file permissions and ownership.  Safe mode may also be in effect.')) .' ('. $dir . ')';
			if(! touch($file)) $test['result']['message'] = ilang(_('Could not create a file (permissions problem?)')) .' ('. $file . ')';
			
			$_test = file_exists($file);
		}
		else
		{
			if(file_exists($file)) @unlink($file);
			if( (@is_dir($dir)) && (false !== strpos($dir, $cache_dir_path)) ) @rmdir($dir);
	
			@mkdir($dir);
			@touch($file);
			$_test = file_exists($file);
			@unlink($file);
			@rmdir($dir);
		}
	
		if(!$_test)
		{
			$test['result']['type'] = 'error';
			$this->getTestReturn($test, $required, $message, "Can't_create_file");
		}
		else
		{
			$test['result']['type'] = 'success';
			$this->getTestReturn($test, $required);
			
			if((file_exists($file)) && (!$debug))
			{
				@unlink($file);
			} 
		}
		
		return $test;
	}
	
	public function & testDirWrite( $required, $title, $dir, $message = '', $quick = 0, $debug = false, $file = '_test_dir_write_', $data = 'this is a test' )
	{
		$test = $this->getTestOptions();
		$test['test']['message'] = $title;
	
		if(empty($dir))
		{
			$OSInstaller = getOSInstaller();
			$dir = os_join_path($OSInstaller->getInternalOption('os_root_path'), "cache");
		}
		
		$test['result']['value'] = $dir;
		$test['result']['secondvalue'] = substr(sprintf('%o', @fileperms($dir)), -4);
	
		$_test = true;
		if($debug)
		{
			if( (! is_dir($dir)) || (! is_writable($dir)) ) $_test = false;
		}
		else
		{
			if( (! @is_dir($dir)) || (! @is_writable($dir)) ) $_test = false;
		}
	
	
		if($_test)
		{
			if($quick)
			{
				// we're only doing the quick test which sucks
				$test['result']['type'] = 'success';
				$this->getTestReturn($test, $required);
				return $test;
			}
	
			$test_file = $dir . DIRECTORY_SEPARATOR . $file;
			if(file_exists($test_file))
			{
				if($debug) unlink($test_file);
				else      @unlink($test_file);
			}
	
			if($debug) $fp = fopen($test_file, "w");
			else       $fp = @fopen($test_file, "w");
			if($fp !== false)
			{
				$_return = '';
	//			flock($fp, LOCK_EX); //no on NFS filesystem
				if($debug) $_return = fwrite($fp, $data);
				else       $_return = @fwrite($fp, $data);
	//			flock($fp, LOCK_UN);
				@fclose($fp);
	
				if(! $debug) unlink($test_file);
	
				if(! empty($_return))
				{
					$test['result']['type'] = 'success';
					$this->getTestReturn($test, $required);
					return $test;
				}
			}
		}
	
		$test['result']['type'] = 'error';
		
		$this->getTestReturn($test, $required, $message, 'Directory_not_writable', ilang(_('No permission to write in directory.  This could be caused by file permissions and ownership.  Safe mode may also be in effect.')).' ('.$dir.')');
		return $test;
	}
	
	public function & testFileWritable( $required, $title, $file, $message = '', $debug = false )
	{
		$test = $this->getTestOptions();
		$test['test']['message'] = $title;
		
		if(empty($file))
		{
			$test['result']['message'] = ilang(_('File not found!'));
			return $test;
		}
	
		$test['result']['value'] = $file;
		$test['result']['secondvalue'] = substr(sprintf('%o', @fileperms($file)), -4);
	
		$_test = true;
		if($debug)
		{
			if( (! is_file($file)) || (! is_writable($file)) ) $_test = false;
		}
		else
		{
			if( (! @is_file($file)) || (! @is_writable($file)) ) $_test = false;
		}
	
	
		if($_test)
		{
			$_test = file_exists($file);
	
			if($debug) $fp = fopen($file, "a");
			else       $fp = @fopen($file, "a");
			if($fp !== false)
			{
				@fclose($fp);
				if(! $_test) @unlink($file);
	
				$test['result']['type'] = 'success';
				$this->getTestReturn($test, $required);
				return $test;
			}
		}
	
		$test['result']['type'] = 'error';
		$this->getTestReturn($test, $required, $message, 'File_not_writable', ilang(_('File not writable!')).' ('.$file.')');
		return $test;
	}
	
	
	public function & testSupportedDatabase( $required, $title, $db = false, $message = '' )
	{
		
		$drivers = $this->getSupportedDBDriver();
	
	//TODO?
		if($db)
		{
			$serverInfo = $db->ServerInfo();
			$_test = $this->testConfig('', 'dbms');
			
			if(! empty($_test->value))
			{
				$dbms = $_test->value;
				list($minimum, $recommended) = $this->getTestValues($drivers[$dbms]['server'].'_version');
				$test = $this->testVersionRange('', $title, $serverInfo['version'], $message, $minimum, $recommended, false);
				$test['opt'] = $serverInfo['description'];
				$test['result']['type'] = 'success';
				$this->getTestReturn($test, $required);
				return $test;
			}
			
			$test = $this->getTestOptions();
			$test['test']['message'] = $title;
			if($required)
			{
				$test['result']['type'] = 'error';
			}
			else
			{
				$test['result']['type'] = 'warning';
			}
			$this->getTestReturn($test, $required, $message);
			return $test;
		}
	//TODO
	
		$test = $this->getTestOptions();
		$test['test']['message'] = $title;
	
		if(count($drivers) > 0)
		{
			$return = array();
			foreach($drivers as $driver=>$values)
			{
				if($this->extension_loaded_or($driver))
				{
					$return[] = $driver;
				}
			}
	
			$test['result']['value'] = implode(', ', $return);
			$test['result']['secondvalue'] = $return;
	
			if(count($return) > 0)
			{
				$test['result']['type'] = 'success';
			}
			else
			{
				if($required)
				{
					$test['result']['type'] = 'error';
				}
				else
				{
					$test['result']['type'] = 'warning';
				}
			}
			$this->getTestReturn($test, $required, $message, 'DB_driver_missing');
		}
		else
		{
			$test['result']['type'] = 'error';
			$this->getTestReturn($test, $required, $message, 'DB_driver_missing', ilang(_('No compatible database drivers found')));
		}
		
		return $test;
	}
	
	public function testSessionSavePath( $sess_path )
	{
		if(empty($sess_path))
		{
			$sess_path = ini_get('session.save_path');
		}
	
		if('files' == ini_get('session.save_handler'))
		{
			if(empty($sess_path))
			{
				if(! function_exists('sys_get_temp_dir'))
				{
					if(! empty($_ENV['TMP'])) return realpath($_ENV['TMP']);
					if(! empty($_ENV['TMPDIR'])) return realpath($_ENV['TMPDIR']);
					if(! empty($_ENV['TEMP'])) return realpath($_ENV['TEMP']);
					if( ('1' != ini_get('safe_mode')) && ($tempfile = tempnam('', 'opens')) )
					{
						if(file_exists($tempfile))
						{
							@unlink($tempfile);
							return realpath(dirname($tempfile));
						}
					}
				}
				else
				{
					return rtrim(sys_get_temp_dir(), '\\/');
				}
			}
			else
			{
				if (strrpos($sess_path, ";") !== false)
				{
					$sess_path = substr($sess_path, strrpos($sess_path, ";")+1);
				}
				return $sess_path;
			}
		}
	
		return '';
	}
	
	public function & testDummy( $title, $value, $return, $message = '', $error_fragment = '', $error = '' )
	{
		$test = $this->getTestOptions();
		$test['test']['message'] = $title;
		$test['result']['value'] = $value;
		$test['result']['secondvalue'] = null;
		$test['result']['type'] = $return;
	
		$this->getTestReturn($test, '', $message, $error_fragment, $error);
		return $test;
	}
	
	public function testIni( &$test, $varname, $type, $opt = '' )
	{
		$error = null;
		$str = ini_get($varname);
	
		switch($type)
		{
	  	    case 'and':
				if($str === '') break;
				$str = (int) $str;
				if( empty($str) )
				{
					$str = (int)$str;
				}
				else
				{
					$str = (int)$str & (int)$opt;
				}
				break;
			case 'boolean':
				if( !is_numeric($str) )
				{
					$str2 = strtolower($str);
					switch( $str2 )
					{
					case 'on':
					case 'yes':
					case 'y':
						$str = TRUE;
						break;
					default:
						$str = FALSE;
					}
				}
				$str = (bool) $str;
				break;
			case 'integer':
				if($str === '') break;
				$str = (int) $str;
				break;
			case 'string':
				$str = (string) $str;
				if(empty($str))
				{
					#$error = lang('could_not_retrieve_a_value');
					if((string) get_cfg_var($varname) != '')
					{
						$str = (string) get_cfg_var($varname);
						#$error .= lang('displaying_the_value_originally');
					}
				}
				break;
		}
	
		$test['ini_val'] = $str;
		$test['result']['message'] = $error;
		return true;
	}
	
	public function & testGDVersion( $required, $title, $minimum, $message = '', $error_fragment = '' )
	{
		$test = $this->getTestOptions();
		$test['test']['message'] = $title;
	
		$gd_version_number = $this->GDVersion();
		$test['result']['value'] = $gd_version_number;
		$test['result']['secondvalue'] = null;
	
		if($gd_version_number < $minimum)
		{
			if($required)
			{
				$test['result']['type'] = 'error';
			}
			else
			{
				$test['result']['type'] = 'warning';
			}
		}
		else
		{
			$test['result']['type'] = 'success';
		}
	
		$this->getTestReturn($test, $required, $message, $error_fragment);
		return $test;
	}
	
	public function GDVersion()
	{
		static $gd_version_number = null;
	
		if(is_null($gd_version_number)) {
			if(extension_loaded('gd')) {
				if(defined('GD_MAJOR_VERSION')) {
					$gd_version_number = GD_MAJOR_VERSION;
					return $gd_version_number;
				}
				$gdinfo = @gd_info();
				if(preg_match('/\d+/', $gdinfo['GD Version'], $gdinfo)) {
					$gd_version_number = (int) $gdinfo[0];
				} else {
					$gd_version_number = 1;
				}
				return $gd_version_number;
			}
			$gd_version_number = 0;
		}
	
		return $gd_version_number;
	}
	
	public function detectInstallType()
	{
		$detectData = array('install_type' => 'install');
		$hasConfigFile = false;
		$hasSettingsFile = false; 
		$hasInstallSchema = false;
		
		$OS = getOS();
		$osUtils = $OS->getUtils();
		$OSInstaller = getOSInstaller();
		 
		$os_root_path = $OSInstaller->getInternalOption('os_root_path');

		//check if config.php  exists
		$config_path = os_join_path($os_root_path, 'configs' ,'config.php');
		
		if(file_exists($config_path))
		{
			$configData = $osUtils->confRead($config_path);
			
			if(!empty($configData))
			{
				if(isset($configData['os_version']))
				{
					$hasConfigFile = true;
					
					$detectData['os_version'] = $configData['os_version'];	
				} 
			}
		}
		
		//check if settings.php exists
		$settings_path = os_join_path($os_root_path, 'configs', 'settings.php');
		if(file_exists($settings_path))
		{
			$settingsData = $osUtils->confRead($settings_path);
			
			if(!empty($settingsData))
			{
				$hasSettingsFile = true;
			}
		}
		
		//check if install schema exists
		$install_schema_path = os_join_path($OSInstaller->getInternalOption('os_install_path'), "schema", "install_schema.php");
		if(file_exists($install_schema_path))
		{
			$installSchemaDetails = $osUtils->jsonRead($install_schema_path);
			
			if(!empty($installSchemaDetails))
			{
				if(isset($installSchemaDetails['os_version']))
				{
					$hasInstallSchema = true;
					
					$detectData['install_version'] = $installSchemaDetails['os_version'];
				}	
			}
		}	
		
		// test if version from config.php is lower than the one from the install schema
		if(($hasConfigFile) && ($hasInstallSchema)) //$hasSettingsFile
		{
			if (version_compare($configData['os_version'], $installSchemaDetails['os_version']) <= 0)
			{
				$detectData['install_type'] = 'update';
			}
		}
		
		return $detectData;
	}
	
	public function getTestOptions()
	{
		$result = array();
		
		
		return $result;
	}

	public function removeOSTables($db_prefix = false)
	{
		$result = false;
		
		if($db_prefix == false)
		{
			$dbPrefix = $OS->getConfigVar('db_prefix');
			if(!empty($dbPrefix)) $db_prefix = $dbPrefix; 
			else return $result;
		}
		
		$OS = getOS();
		$db = $OS->getDb();
		$osDbOps = $OS->getDbOps();
		
		$db->setDbPrefix($db_prefix);
		
		//drop each table
		$tblDetails = $osDbOps->getDbTablesFull(array('apps'));
		
		if(!empty($tblDetails))
		{
			foreach($tblDetails as $tblName => $columns)
			{
				$db->query("DROP TABLE {$db_prefix}{$tblName}");
				$result = true;
			}
		}
		
		return $result;
	}
}