<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_installStep1
{
	private static $_instance;
	
	private $stepDetails;

	private $submitData;

	//os installStep2 constructor
	public function __construct()
	{
	
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_installStep1();
		}
		return self::$_instance;
	}
	
	public function processRequest()
	{
		$submitData = array();
		
		$OS = getOS();
		$osInstaller = getOSInstaller();
		$OSInstallOps = $osInstaller->getInstallOps();
		
		//detect install/update procedure
		$detectDetails = $OSInstallOps->detectInstallType();

		if(isset($detectDetails['install_version']))
		{
			$submitData['install_version'] = $detectDetails['install_version'];
		}
		
		if(isset($detectDetails['os_version']))
		{
			$submitData['os_version'] = $detectDetails['os_version'];
		}
		
		//check licence box
		if(!isset($_POST['check_license_box'])) $OS->addFieldError(_("Licence agreement not accepted"),"check_license");
		else $submitData['check_license'] = $_POST['check_license_box'];
		

		$submitData['install_type'] = 'install';
		
		//only check these if update procedure
		if($detectDetails['install_type'] == 'update')
		{
			//check auth code
			if(empty($_POST['auth_code_box'])) $OS->addFieldError(_("Auth Code is missing"),"auth_code");
			else
			{
				$config_auth_code = $OS->getConfigVar('auth_code');
				if(empty($config_auth_code)) $OS->addFieldError(_("Invalid Auth Code"),"auth_code"); 
				elseif($_POST['auth_code_box'] != $config_auth_code) $OS->addFieldError(_("Invalid Auth Code"),"auth_code");
				else
				{
					$_SESSION['install']['auth_code'] = $config_auth_code;
					$submitData['auth_code'] = $config_auth_code;
				}
			}
			
			//user-changed install type
			if(!isset($_POST['install_type_box'])) $OS->addFieldError(_("Choose Installation type"),"install_type");
			elseif($_POST['install_type_box'] == 'update') $submitData['install_type'] = 'update';
			elseif($_POST['install_type_box'] == 'install') $submitData['install_type'] = 'install';
		}
		
		//set check auth code
		$_SESSION['install']['check_auth_code'] = ($detectDetails['install_type'] == 'update' ? true : false);
		
		//set installParams and internalOptions
		$osInstaller->setInstallParams(array('1'=>$submitData));
		$osInstaller->setInternalOptions($submitData);

		$this->submitData = $submitData;

		if(!isset($OS->errorMessages)) return $submitData;
		else return false;
	}
	
	public function prepareStepDetails()
	{
		$OS = getOS();
		$osInstaller = getOSInstaller();
		$OSInstallOps = $osInstaller->getInstallOps();
		
		$stepDetails = array();
		
		
		//detect install/update procedure
		$detectDetails = $OSInstallOps->detectInstallType();

		$internalOptions = array('install_type' => $detectDetails['install_type']);

		if(isset($detectDetails['install_version']))
		{
			$internalOptions['install_version'] = $detectDetails['install_version'];
		}
		else
		{
			$internalOptions['install_version'] = '0.1';
		}

		if(isset($detectDetails['os_version']))
		{
			$internalOptions['os_version'] = $detectDetails['os_version'];
		}
		else
		{
			$internalOptions['os_version'] = '0.1';
		}
		
		//hide prev/btn buttons
		$stepDetails['show_prev_btn'] = false;
		$stepDetails['show_retry_btn'] = false;
		
		$stepDetails['install_type'] = $internalOptions['install_type'];
		
		//set installParams and internalOptions
		$osInstaller->setInstallParams(array('1'=>$internalOptions));
		$osInstaller->setInternalOptions($internalOptions);
		
		$this->stepDetails = $stepDetails;
		
		//auto-complete install type
		if(!isset($_POST['install_type_box']))
		{
			$_POST['install_type_box'] = $stepDetails['install_type'];
		}
		
		//get GPL text
		$fpath = os_join_path($osInstaller->getInternalOption("os_install_path"), "templates", "gpl.html");
		$stepDetails['gpl_text'] = (file_exists($fpath) ? file_get_contents($fpath) : "");
		$stepDetails['config_file_path']=os_join_path($OS->getConfig()->getParam('root_path'), 'configs', 'config.php');
		
		return $stepDetails;
	}
	
	public function render()
	{
		$OS = getOS();
		
		$tpl = $OS->getTemplate();
		
		return $tpl->getTemplate('installstep1');
	}
	
}
?>