<?php
/*
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_installStep2
{
	private static $_instance;

	private $stepDetails;

	private $submitData;

	public $debug;

	//os installStep2 constructor
	public function __construct()
	{
		$this->debug = false;
	}

	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_installStep2();
		}
		return self::$_instance;
	}

	public function processRequest()
	{
		$submitData = array();

		return $submitData;
	}

	public function prepareStepDetails()
	{
		$OS = getOS();
		$osInstaller = getOSInstaller();
		$OSInstallOps = $osInstaller->getInstallOps();

		$stepDetails = array();
		$step_has_errors = false;

		$os_root_path = $osInstaller->getInternalOption('os_root_path');
		$config_file_path = os_join_path($os_root_path, 'configs', "config.php");
		$settings_file_path = os_join_path($os_root_path, 'configs', "settings.php");

		$safe_mode = ini_get('safe_mode');

		$open_basedir = ini_get('open_basedir');

		//Info Settings
		$infoDetails = array();
		$infoDetails['server_software'] = array('name'=>_("Server Software"), 'value'=> $_SERVER['SERVER_SOFTWARE']);
		$infoDetails['server_api'] = array('name'=>_("Server API"), 'value'=> PHP_SAPI);
		$infoDetails['server_os'] = array('name'=>_("Server OS"), 'value'=> PHP_OS .' '. php_uname('r') .' '. ilang(_('on')) .' '. php_uname('m'));

		if($OSInstallOps->extension_loaded_or('apache2handler'))
		{
			$infoDetails['mod_security'] = array('name'=>"Mod Security", 'value'=> $OSInstallOps->getApacheModules('mod_security') ? ilang(_('on')) : ilang(_('off')));
		}

		$settings = array();

		//Required Settings
		$tmpTests = array(); $totalTests = array();
			
		list($minimum, $recommended) = $OSInstallOps->getTestValues('php_version');
		$tmpTests[] = $OSInstallOps->testVersionRange(1, ilang(_('Checking for PHP version').' %s+', $minimum) .'<br />'. ilang('('._('minimum').' %s, '._('recommend').' %s '._('or greater').')', $minimum, $recommended),
		phpversion(), ilang(_('OpenS requires a php version of 5.2.4 or greater').' ('._('you have').' %s), '._('but').' PHP %s '._('or greater is recommended to ensure maximum compatibility with third party addons'), phpversion(), $recommended), $minimum, $recommended, false);


		//check required functions
		$tmpTests[] = $OSInstallOps->testBoolean(1, ilang(_('Checking for md5 Function')), function_exists('md5'), '', false, false, 'Function_md5_disabled');

		$tmpTests[] = $OSInstallOps->testBoolean(1, ilang(_('Checking for exec Function')), function_exists('exec'), '', false, false, 'Function_exec_disabled');

		$tmpTests[] = $OSInstallOps->testBoolean(1, ilang(_('Checking for cURL Function')), function_exists('curl_init'), '', false, false, 'Function_curl_disabled');
		
		$tmpTests[] = $OSInstallOps->testBoolean(1, ilang(_('Checking for tempnam Function')), function_exists('tempnam'), '', false, false, 'Function_tempnam_disabled');


		//check GD Version
		list($minimum, $recommended) = $OSInstallOps->getTestValues('gd_version');
		$tmpTests[] = $OSInstallOps->testGDVersion(1, ilang(_('Checking for GD library')), $minimum, ilang(_('The GD library is mandatory for some modules and functionality.')), 'min_GD_version');


		$required_dirs = array();

		//Check chmod for required directories
		$f = os_join_path($os_root_path, "apps");
		if(!is_dir($f)) $required_dirs[] = $f;
		else
		{
			$tmpTests[] = $OSInstallOps->testDirWrite(0, ilang(_('Checking if').' %s '._('is writable'), $f), $f, ilang(_('The apps folder is not writable. Must change permissions of `apps` dir to 777.')), 0, $this->debug);
		}

		$f = os_join_path($os_root_path, "plugins");
		if(!is_dir($f)) $required_dirs[] = $f;
		else
		{
			$tmpTests[] = $OSInstallOps->testDirWrite(0, ilang(_('Checking if').' %s '._('is writable'), $f), $f, ilang(_('The plugins folder is not writable. Must change permissions of `apps` dir to 777.')), 0, $this->debug);
		}

		$f = os_join_path($os_root_path, "widgets");
		if(!is_dir($f)) $required_dirs[] = $f;
		else
		{
			$tmpTests[] = $OSInstallOps->testDirWrite(0, ilang(_('Checking if').' %s '._('is writable'), $f), $f, ilang(_('The widgets folder is not writable. Must change permissions of `widgets` dir to 777.')), 0, $this->debug);
		}

		$f = os_join_path($os_root_path, "configs");
		if(!is_dir($f)) $required_dirs[] = $f;
		else
		{
			$tmpTests[] = $OSInstallOps->testDirWrite(0, ilang(_('Checking if').' %s '._('is writable'), $f), $f, ilang(_('The configs folder is not writable. Must change permissions of `configs` dir to 777.')), 0, $this->debug);
		}


		$f = os_join_path($os_root_path, "cache");
		if(!is_dir($f)) $required_dirs[] = $f;
		else
		{
			$tmpTests[] = $OSInstallOps->testDirWrite(0, ilang(_('Checking if').' %s '._('is writable'), $f), $f, ilang(_('The cache folder is not writable. Must change permissions of `cache` dir to 777.')), 0, $this->debug);
		}


		$f = os_join_path($os_root_path, "storage");
		if(!is_dir($f)) $required_dirs[] = $f;
		else
		{
			$tmpTests[] = $OSInstallOps->testDirWrite(0, ilang(_('Checking if').' %s '._('is writable'), $f), $f, ilang(_('The storage folder is not writable. Must change permissions of `storage` dir to 777.')), 0, $this->debug);
		}


		if(!empty($required_dirs))
		{
			foreach($required_dirs as $dirname)
			{
				$tmpTests[] = array('test' => array('message'=> sprintf(_('Checking if').' %s '._('is writable'), $dirname)), 'result'=> array('type' => 'error', 'message' => sprintf(_('Directory').' %s '._('does not exist. Please create it.'), $dirname)));
			}
		}

		/* deprecated
		 //check config file
		 if(file_exists($config_file_path))
		 {
			$tmpTests[] = $OSInstallOps->testFileWritable(1, ilang('Checking write permission on') . ' config.php', $config_file_path, ilang('This file may not exist yet. If it does not, you should create an empty file with this name. Please also ensure that this file writable by the web server process.'), $this->debug);
			}

			//check settings file
			if(file_exists($settings_file_path))
			{
			$tmpTests[] = $OSInstallOps->testFileWritable(1, ilang('Checking write permission on') . ' settings.php', $settings_file_path, ilang('This file may not exist yet. If it does not, you should create an empty file with this name. Please also ensure that this file writable by the web server process.'), $this->debug);
			}
		*/


		$tmpTests[] = $OSInstallOps->testBoolean(1, ilang(_('Magic quotes in runtime')), 'magic_quotes_runtime', ilang(_('When magic_quotes are on, most functions that return data from any sort of external source including databases and text files will have quotes escaped with a backslash. This will cause problems with OpenS.')), true, true, 'magic_quotes_runtime_On');

		$tmpTests[] = $OSInstallOps->testSupportedDatabase(1, ilang(_('DB drivers')), false, ilang(_('No DB drivers found')));

		$tmpTests[] = $OSInstallOps->testCreateDirAndFile(1, ilang(_('Checking if the httpd process can create a file inside of a directory it created.')), ilang(_('The HTTP Process owner cannot create a file inside a directory that it owns. This probably means that safe mode is enabled in some way. Many functions inside OpenS will not operate properly without this ability. Continuing is not possible.')), $this->debug);

		$settings['required'] = array('name'=> _('Required'), 'tests'=> $tmpTests);
		$totalTests = $tmpTests;


		//Recommended Settings
		$tmpTests = array();
		list($minimum, $recommended) = $OSInstallOps->getTestValues('memory_limit');
		$tmpTests[] = $OSInstallOps->testIntegerMask(0,ilang(_('Testing error_reporting to ensure E_STRICT is disabled')), 'error_reporting',E_STRICT,ilang(_('E_STRICT is enabled')),true,true,false);

		if( defined('E_DEPRECATED') )
		{
			$tmpTests[] = $OSInstallOps->testIntegerMask(0,ilang(_('Testing error_reporting to ensure E_DEPRECATED is disabled')), 'error_reporting',E_DEPRECATED,ilang(_('E_DEPRECATED is enabled')),true,true,false);
		}

		$tmpTests[] = $OSInstallOps->testRange(0, ilang(_('Checking PHP memory limit')) .'<br />'. ilang(_('(minimum %s, recommend %s or greater)'), $minimum, $recommended),
				'memory_limit', ilang(_('You may not have enough memory to run OpenS correctly, or with all of your desired addons. If possible, you should try to get your system admin to raise this value. Proceed with caution.')), $minimum, $recommended, true, true, null, 'memory_limit_range');

		list($minimum, $recommended) = $OSInstallOps->getTestValues('max_execution_time');
		$tmpTests[] = $OSInstallOps->testRange(0, ilang(_('Checking PHP time limit in second')) .'<br />'. ilang(_('(minimum %s, recommend %s or greater)'), $minimum, $recommended),
				'max_execution_time', ilang(_('Number of seconds a script is allowed to run. If this is reached, the script returns a fatal error.')), $minimum, $recommended, true, false, 0, 'max_execution_time_range');

		$tmpTests[] = $OSInstallOps->testBoolean(0, ilang(_('Checking PHP register globals')), 'register_globals', ilang(_('PHP register globals is active. For security reasons, this should be disabled.')), true, true, 'register_globals_enabled');

		$tmpTests[] = $OSInstallOps->testInteger(0, ilang(_('Checking output buffering')), 'output_buffering', ilang(_('Output buffering is disabled. You will probably not be able to use any of functionality that requires this')), true, true, 'output_buffering_disabled');

		$tmpTests[] = $OSInstallOps->testString(0, ilang(_('Checking PHP disable functions')), 'disable_functions', ilang(_('Warning: this is a list of functions disabled on your server.')), true, 'success', 'warning', 'disable_functions_not_empty');


		$tmpTests[] = $OSInstallOps->testBoolean(0, ilang(_('Checking for safe mode')), 'safe_mode', ilang(_('PHP safe mode could create some problems with uploading files and other functions. It all depends on how strict your server safe mode settings are.')), true, true, 'safe_mode_enabled');

		$tmpTests[] = $OSInstallOps->testString(0, ilang(_('Check for PHP Open Basedir')), $open_basedir, ilang(_('Open basedir restrictions are in effect. You may have difficulty with some addon functionality with this restriction.')), false, 'success', 'warning', 'open_basedir_enabled');

		//check remote file write
		//$tmpTests[] = $OSInstallOps->testRemoteFile(0, ilang('Test for remote URL'), '', ilang('You will probably not be able to open a file on a remote web server.'), $this->debug);

		$tmpTests[] = $OSInstallOps->testBoolean(0, ilang(_('Checking file uploads')), 'file_uploads', ilang(_('When file uploads are disabled you will not be able to use any of the file uploading facilities included in OpenS. If possible, this restriction should be lifted by your system admin to properly use all file management features of the system. Proceed with caution.')), true, false, 'Function_file_uploads_disabled');

		list($minimum, $recommended) = $OSInstallOps->getTestValues('post_max_size');
		$tmpTests[] = $OSInstallOps->testRange(0, ilang(_('Checking max post size')) .'<br />'. ilang(_("(minimum %s, recommend %s or greater)"), $minimum, $recommended),
				'post_max_size', ilang(_('You will probably not be able to submit (larger) data. Please be aware of this restriction.')), $minimum, $recommended, true, true, null, 'min_post_max_size');

		list($minimum, $recommended) = $OSInstallOps->getTestValues('upload_max_filesize');
		$tmpTests[] = $OSInstallOps->testRange(0, ilang(_('Checking max upload file size')) .'<br />'. ilang(_("(minimum %s, recommend %s or greater)"), $minimum, $recommended),
				'upload_max_filesize', ilang(_('You will probably not be able to upload (larger) files using the included file management functions. Please be aware of this restriction.')), $minimum, $recommended, true, true, null, 'min_upload_max_filesize');


		$session_save_path = $OSInstallOps->testSessionSavePath('');
		if(empty($session_save_path))
		{
			$tmpTests[] = $OSInstallOps->testDummy(ilang(_('Checking if session.save_path is writable')), '', 'warning', ilang(_('Your session.save_path is empty. PHP will use the temporary directory of your OS.')), 'session_save_path_empty', '');
		}
		elseif (! empty($open_basedir))
		{
			$tmpTests[] = $OSInstallOps->testDummy(ilang(_('Checking if session.save_path is writable')), '', 'warning', ilang(_('Open basedir restrictions appear to be in effect. If you have SESSION problems and ini_set works, you can try to enable sessions with cookies adding: ini_set(\'session.use_only_cookies\', 1);  to top of config.php')), 'No_check_session_save_path_with_open_basedir', '');
		}
		else
		{
			$tmpTests[] = $OSInstallOps->testDirWrite(0, ilang(_('Checking if session.save_path is writable')), $session_save_path,
			ilang(_('Your session.save_path is "%s". Not having this as writable may make logins to the Admin Panel not work. You may want to look into making this path writable if you have trouble logging into the Admin Panel. This test may fail if safe_mode is enabled (see below).'), $session_save_path), 1, $this->debug);
		}
		$tmpTests[] = $OSInstallOps->testBoolean(0, 'session.use_cookies', 'session.use_cookies', ilang('Sessions are allowed to use Cookies'));

		$tmpTests[] = $OSInstallOps->testBoolean(0, ilang(_('Checking for basic XML (expat) support')),
		$OSInstallOps->extension_loaded_or('xml'), ilang(_('XML support is not compiled into your php install. You can still use the system, but will not be able to use any of the remote module installation functions.')), false, false, 'Function_xml_disabled');

		$tmpTests[] = $OSInstallOps->testBoolean(0, ilang(_('Checking for file_get_contents')),
		function_exists('file_get_contents'), ilang(_('You will probably not be able to use any of functionality that uses this function')), false, false, 'Function_file_get_content_disabled');

		$_log_errors_max_len = (ini_get('log_errors_max_len')) ? ini_get('log_errors_max_len').'0' : '99';

		ini_set('log_errors_max_len', $_log_errors_max_len);

		$result = (ini_get('log_errors_max_len') == $_log_errors_max_len);

		$tmpTests[] = $OSInstallOps->testBoolean(0, ilang(_('Checking if ini_set works')), $result, ilang(_('Although the ability to override php ini settings is not mandatory, some addon (optional) functionality uses ini_set to extend timeouts, and allow uploading of larger files, etc. You may have difficulty with some addon functionality without this capability. This test may fail if safe_mode is enabled (see below).')), false, false, 'ini_set_disabled');

		$settings['recommended'] = array('name'=> _('Recommended'), 'tests'=> $tmpTests);


		$totalTests = array_merge($totalTests, $tmpTests);

		foreach($totalTests as $test)
		{
			if(isset($test['result']['type']))
			{
				if($test['result']['type'] == 'error')
				{
					$step_has_errors = true;
				}
			}
		}
		
		$stepDetails['info'] = $infoDetails;
		$stepDetails['tests'] = $settings;
		$stepDetails['step_has_errors'] = $step_has_errors;

		if($step_has_errors)
		{
			$stepDetails['show_next_btn'] = false;
		}

		$this->stepDetails = $stepDetails;

		return $stepDetails;
	}

	public function render()
	{
		$OS = getOS();
		
		$tpl = $OS->getTemplate();
		
		return $tpl->getTemplate('installstep2');
	}
}
?>