<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_installStep3
{
	private static $_instance;
	
	
	//os installStep3 constructor
	public function __construct()
	{
	
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_installStep3();
		}
		return self::$_instance;
	}
	
	public function processRequest()
	{
		$submitData = array();
		
		$OS = getOS();
		$OSInstaller = getOSInstaller();
		$OSInstallerOps = $OSInstaller->getInstallOps();
		
		$osLanguagesList = $OS->getLanguagesList(); 
		
		$dbDrivers = $OSInstallerOps->getSupportedDBDriver();
		
		if($_SERVER['REQUEST_METHOD'] == 'POST')
		{
			if (empty($_POST['db_driver_box'])) 
			{
				$OS->addFieldError(_("Database Driver missing"),'db_driver');	
			}
			else
			{
				$_POST['db_driver_box'] = os_clean_value($_POST['db_driver_box']);
				
				if(!isset($dbDrivers[$_POST['db_driver_box']])) 
				{
					$OS->addFieldError(_("Invalid Database Driver"),"db_driver");
				}
				else
				{
					$submitData['db_driver'] = $_POST['db_driver_box'];
				}
			}
			
			
			if (empty($_POST['db_host_box'])) 
			{
				$OS->addFieldError(_("Database host address missing"),'db_host');	
			}
			else
			{
				$submitData['db_host'] = os_clean_value($_POST['db_host_box']);
			}
			
			
			if (empty($_POST['db_name_box'])) 
			{
				$OS->addFieldError(_("Database Name missing"),'db_name');	
			}
			else
			{
				$submitData['db_name'] = os_clean_value($_POST['db_name_box']);
			}
			
			
			if (empty($_POST['db_user_box'])) 
			{
				$OS->addFieldError(_("Database Username missing"),'db_user');	
			}
			else
			{
				$submitData['db_user'] = os_clean_value($_POST['db_user_box']);
			}
			
			
			if (empty($_POST['db_password_box'])) 
			{
				//$OS->addFieldError(_("Database Password missing"),'db_password');
				$submitData['db_password']='';	
			}
			else
			{
				$submitData['db_password'] = os_clean_value($_POST['db_password_box']);
			}
			
			
			if (empty($_POST['db_port_box'])) 
			{
				$submitData['db_port'] = "3306";	
			}
			else
			{
				$submitData['db_port'] = os_clean_value($_POST['db_port_box']);
			}
			
			
			if (empty($_POST['db_tbl_prefix_box'])) 
			{
				$OS->addFieldError(_("Database Tables Prefix missing"),'db_tbl_prefix');	
			}
			else
			{
				$submitData['db_tbl_prefix'] = os_clean_value($_POST['db_tbl_prefix_box']);
			}
			
			
			$submitData['create_tables'] = (isset($_POST['create_tables_box']) ? "Y": "");
			
			
			
			
			
			//Verify configuration details
			if (empty($_POST['root_url_box'])) 
			{
				$OS->addFieldError(_("Document Root missing"),'root_url');	
			}
			else
			{
				$submitData['root_url'] = os_clean_value($_POST['root_url_box']);
			}
			
			
			if (empty($_POST['root_path_box'])) 
			{
				$OS->addFieldError(_("Document Path missing"),'root_path');	
			}
			else
			{
				$submitData['root_path'] = os_clean_value($_POST['root_path_box']);
			}

			
			if (empty($_POST['admin_language_box'])) 
			{
				$OS->addFieldError(_("OpenS Admin Language missing"),'admin_language');	
			}
			else
			{
				$_POST['admin_language_box'] = os_clean_value($_POST['admin_language_box']);
				
				if(!isset($osLanguagesList[$_POST['admin_language_box']])) 
				{
					$OS->addFieldError(_("Invalid language"),"admin_language");
				}
				else
				{
					$submitData['admin_language'] = $_POST['admin_language_box'];
				}
			}
			
			//test dbConnection based on details provided
			if(!isset($OS->errorMessages))
			{
				$dbDbOps = $OS->getDbOps();
				
			    $dbConnectionDetails = array(
			    	'db_driver' => $submitData['db_driver'],
			    	'db_hostname' => $submitData['db_host'],
			    	'db_name' => $submitData['db_name'],
			    	'db_username' => $submitData['db_user'],
			    	'db_password' => $submitData['db_password']
			    	);
				
			    $testResponse = $dbDbOps->testDBConnection($dbConnectionDetails);
				
				if($testResponse['result'] === true)
				{
					//test Database priviliges
					//$testResponse = $dbDbOps->testDBPrivileges($dbConnectionDetails);
					
					//set database info
					$db = $OS->getDb();
					$db->addDBConnection('default',$dbConnectionDetails);
					$db->setCurrentDbConnection('default');
				    $db->setDbPrefix($submitData['db_tbl_prefix']);
					
				    $dbTables = $dbDbOps->getDbTables();
				    
				    $testTables = array('users','projects','departments','apps','widgets');
				    
				    $operation_type = 'install';
				    
				    if(!empty($dbTables))
				    {
				    	$flag = true;
				    	foreach($testTables as $tblName)
				    	{
				    		if(!in_array($tblName, $dbTables)) $flag = false; 
				    	}

				    	if($flag) $operation_type = 'update';
				    }
				    
				    $submitData['operation_type'] = $operation_type;
				}
				else
				{
					$OS->addBoxError(_("Database Connection Failed").": ".$testResponse['error']);
				}
			}
		}	
		
		if(!isset($OS->errorMessages)) return $submitData;
		else return false;
	}
	
	public function prepareStepDetails()
	{
		$OS = getOS();
		
		$OSInstaller = getOSInstaller();
		$OSInstallerOps = $OSInstaller->getInstallOps();
		
		$osLanguagesList = $OS->getLanguagesList(); 
		
		$dbDrivers = $OSInstallerOps->getSupportedDBDriver();
		
		$stepDetails = array();
		
		$defaultValues = array(
			'db_driver' => "mysql",
			'db_host' => "localhost",
			'db_name' => "db_opens",
			'db_user' => "user_opens",
			'db_password' => "",
			'db_port' => "3306",
			'db_tbl_prefix' => "os_",
			'create_tables' => "Y",
			'root_url' => $OSInstaller->getInternalOption('os_root_url'),
			'root_path' =>	$OSInstaller->getInternalOption('os_root_path'),
			'admin_language' => "en"
			);
		
		//autocomplete values
		foreach($defaultValues as $name => $value)
		{
			$stepDetails[$name]  = (isset($_POST[$name.'_box']) ? $_POST[$name.'_box'] : $value);
		}
		
		//build  db drivers data 
		$stepDetails['dbDrivers'] = array();
		foreach($dbDrivers as $identifier=>$details)
		{
			$stepDetails['dbDrivers'][$identifier] = array('name'=>$details['name'],'is_selected'=> ($stepDetails['db_driver'] == $identifier));
		}
		
		//build  timezone data
		$stepDetails['lngList'] = array();
		if(!empty($osLanguagesList))
		{
			foreach($osLanguagesList as $identifier=>$cdata)
			{
				$stepDetails['lngList'][$identifier] = array('name'=>$cdata['name'],'is_selected'=> ($stepDetails['admin_language'] == $identifier));
			}
		}
		
		return $stepDetails;
	}
	
	public function render()
	{
		$OS = getOS();
		
		$tpl = $OS->getTemplate();
		
		return $tpl->getTemplate('installstep3');
	}
	
}
?>