<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_installStep4
{
	private static $_instance;
	
	//os installStep4 constructor
	public function __construct() {}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_installStep4();
		}
		return self::$_instance;
	}
	
	public function processRequest()
	{
		$submitData = array();
		
		$OS = getOS();
		
		$osUserOps = $OS->getUserOps();
		
		$osValidator = $OS->getValidator();
		
		//get database info
		$OSInstaller = getOSInstaller();
		
		$installParams = $OSInstaller->getInstallParams();
		
	    $installType = 'install';
		
		if(isset($installParams[3]))
	    {
	    	$stepInstallParams = $installParams[3];

			$dbConnectionDetails = array(
		    	'db_driver' => $stepInstallParams['db_driver'],
		    	'db_hostname' => $stepInstallParams['db_host'],
		    	'db_name' => $stepInstallParams['db_name'],
		    	'db_username' => $stepInstallParams['db_user'],
		    	'db_password' => $stepInstallParams['db_password']
		    	);
		    	
			$db = $OS->getDb();
			$db->addDBConnection('default',$dbConnectionDetails);
			$db->setCurrentDbConnection('default');
		    $db->setDbPrefix($stepInstallParams['db_tbl_prefix']);
		    
		    $installType = $OSInstaller->getInternalOption('install_type');
	    }
		
		
		if($_SERVER['REQUEST_METHOD'] == 'POST')
		{
			
			if (empty($_POST['username_box'])) 
			{
				$OS->addFieldError(_("Username missing"),'username');	
			}
			else
			{
				$_POST['username_box'] = os_clean_value($_POST['username_box']);
				
				if (strlen($_POST['username_box'])<3) 
				{
					$OS->addFieldError(_("Username too short"),'username');	
				}
				elseif (!$osUserOps->isValidUsername($_POST['username_box'])) 
				{
					$OS->addFieldError(_("Invalid Username"),'username');	
				}
				elseif($installType == 'install')
				{
					$submitData['username'] = $_POST['username_box'];
				}
				elseif($installType == 'update')
				{
					$oneUser = $osUserOps->getUserByUsername($_POST['username_box']);
					if($oneUser === false)
					{
						$submitData['username'] = $_POST['username_box'];
					} 
					else
					{
						$OS->addFieldError(_("This user already exists in the system"),'username');
					}
				}
			}
	
			
			if (empty($_POST['email_box']))
			{
				$OS->addFieldError(_("Email missing"),'email');	
			} 
			else
			{
				$_POST["email_box"] = os_clean_value(trim(strtolower($_POST["email_box"])));
				
				if(strpos($_POST['email_box'],'www.')===0) $_POST['email_box']=substr($_POST['email_box'],4);
				
				if (!$osValidator->is_email($_POST["email_box"]))
				{
					$OS->addFieldError(_("Invalid email")." (".$osValidator->ERROR.")",'email');
				}
				elseif($stepInstallParams['operation_type'] == 'install')
				{
					$submitData['email'] = $_POST["email_box"];
				}	
				elseif($stepInstallParams['operation_type'] == 'update')
				{
					$oneUser = $osUserOps->getUserByEmail($_POST["email_box"]);
					if($oneUser === false)
					{
						$submitData['email'] = $_POST["email_box"];
					} 
					else
					{
						$submitData['email'] = $_POST["email_box"];
						//$OS->addFieldError("Email already registered !",'email');
					}
				}
			}
		
		
			if (empty($_POST['password_box'])) 
			{
				$_POST['password_box'] = '';
				
				$OS->addFieldError(_("Password is missing"),'password');
			}
			elseif ($_POST['password_box'] != $_POST['password2_box']) 
			{
				$OS->addFieldError(_("Passwords do not match"),'password');	
			}
			elseif (strlen($_POST['password_box'])<6)
			{
				$OS->addFieldError(_("Password too short"),'password');	
			} 
			else 
			{
				$submitData['password'] = $_POST['password_box'];
			}
		}
		
		if(!isset($OS->errorMessages)) return $submitData;
		else return false;
	}
	
	public function prepareStepDetails()
	{
		$stepDetails = array();
		
		if(!empty($_POST['username_box'])) $stepDetails['username'] = $_POST['username_box'];
		else $stepDetails['username'] = "";
		
		if(!empty($_POST['email_box'])) $stepDetails['email'] = $_POST['email_box'];
		else $stepDetails['email'] = "";
		
		$stepDetails['password'] = "";$stepDetails['password2'] = "";
		if(!empty($_POST['password_box']))	
			{
			$stepDetails['password'] = $_POST['password_box'];
			$stepDetails['password2'] = $_POST['password_box'];
			} 
		
		return $stepDetails;
	}
	
	public function render()
	{
		$OS = getOS();
		
		$tpl = $OS->getTemplate();
		
		return $tpl->getTemplate('installstep4');
	}
}
?>