<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_installStep5
{
	private static $_instance;
	
	
	//os installStep5 constructor
	public function __construct()
	{
	
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_installStep5();
		}
		return self::$_instance;
	}
	
	public function processRequest()
	{
		$OS = getOS();
		
		$osValidator = $OS->getValidator();
		
		$osTimezonesList = $OS->getTimezonesList(); 
		
		$osUtils = $OS->getUtils();
		
		//get database info
		$OSInstaller = getOSInstaller();
		
		$installParams = $OSInstaller->getInstallParams();
		
		$installType = 'install';
		
	    if(isset($installParams[3]))
	    {
	    	$stepInstallParams = $installParams[3];

			$dbConnectionDetails = array(
		    	'db_driver' => $stepInstallParams['db_driver'],
		    	'db_hostname' => $stepInstallParams['db_host'],
		    	'db_name' => $stepInstallParams['db_name'],
		    	'db_username' => $stepInstallParams['db_user'],
		    	'db_password' => $stepInstallParams['db_password']
		    	);
			
			$db = $OS->getDb();
			
			$db->addDBConnection('default',$dbConnectionDetails);
			$db->setCurrentDbConnection('default');			
		    $db->setDbPrefix($stepInstallParams['db_tbl_prefix']);
		    
		    $installType = $OSInstaller->getInternalOption('install_type');
	    }
		
		
		if($_SERVER['REQUEST_METHOD'] == 'POST')
		{
			$osProjectOps = $OS->getProjectOps();
			
			if (empty($_POST['project_name_box'])) 
			{
				$OS->addFieldError(_("Project Name missing"),'project_name');	
			}
			else
			{
				$_POST['project_name_box'] = os_clean_value($_POST['project_name_box']);
				
				if (strlen($_POST['project_name_box'])<3) 
				{
					$OS->addFieldError(_("Project Name too short"),'project_name');	
				}
				else
				{
					$submitData['project_name'] = $_POST['project_name_box'];
				}
			}
	
	
			if (empty($_POST['project_url_box'])) 
			{
				$OS->addFieldError(_("Project URL missing"),'project_url');	
			}
			else
			{
				//$_POST['project_url_box'] = os_clean_value($_POST['project_url_box']);
				$_POST['project_url_box']=$osUtils->prependHTTP($_POST['project_url_box']);
			
				if (strlen($_POST['project_url_box']) < 10) 
				{
					$OS->addFieldError(_("Project URL name too short (min 10 characters)"),'project_url');
				}	
				elseif ($osValidator->has_html($_POST['project_url_box'])) 
				{
					$OS->addFieldError(_("You cannot enter HTML code as project URL"),'project_url');
				}
				elseif(!$osValidator->is_url($_POST['project_url_box'])) 
				{
					$OS->addFieldError(_("Invalid Project URL")." (".$osValidator->ERROR.")",'project_url');
				} 
				elseif($installType == 'install')
				{
					$submitData['project_url'] = $_POST['project_url_box'];
				}		
				elseif($installType == 'update')
				{
					$oneProject = $osProjectOps->getProjectByUrl($_POST['project_url_box']);
				
					if($oneProject === false)
					{
						$submitData['project_url'] = $_POST['project_url_box'];
					}
					else
					{
						$OS->addFieldError(_("This project already exists in the system"), 'project_url');
					}	
				}
			}
	
			if(!isset($_POST['timezone_box']))
			{
				$OS->addFieldError(_("Timezone missing"),"timezone");
			} 
			if($_POST['timezone_box'] == '')
			{
				$OS->addFieldError(_("Timezone missing"),"timezone");
			}
			else
			{
				$_POST['timezone_box'] = os_clean_value($_POST['timezone_box']);
				
				if(!isset($osTimezonesList[$_POST['timezone_box']])) 
				{
					$OS->addFieldError(_("Invalid timezone"),"timezone");
				}
				else
				{
					$submitData['timezone'] = $osTimezonesList[$_POST['timezone_box']];
				}
			}
			
			$submitData['crawl_project'] = (isset($_POST['crawl_project_box']) ? "Y" : "");
		}
		
		if(!isset($OS->errorMessages)) return $submitData;
		else return false;
	}
	
	public function prepareStepDetails()
	{
		$stepDetails = array();
		
		$OS =  getOS();
		
		//get timezone data
		$osTimezonesList = $OS->getTimezonesList();
		
		$osFlipTimezonesList = array_flip($osTimezonesList);
		
		if(isset($_POST['project_name_box'])) $stepDetails['project_name'] = $_POST['project_name_box'];
		else $stepDetails['project_name'] = ""; 
		
		if(isset($_POST['project_url_box'])) $stepDetails['project_url'] = $_POST['project_url_box'];
		else $stepDetails['project_url'] = "";
		
		if(isset($_POST['timezone_box']))
		{
			$stepDetails['timezone'] = (isset($osFlipTimezonesList[ $_POST['timezone_box']]) ? $osFlipTimezonesList[ $_POST['timezone_box']]: '');
		} 
		else $stepDetails['timezone'] = "";
		
		if(isset($_POST['install_sample_box'])) $stepDetails['install_sample'] = $_POST['install_sample_box'];
		else $stepDetails['install_sample'] = "Y";
		
		if(isset($_POST['crawl_project_box'])) $stepDetails['crawl_project'] = $_POST['crawl_project_box'];
		else $stepDetails['crawl_project'] = "Y";

		//build  timezone data
		$stepDetails['tzList'] = array();
		if(!empty($osTimezonesList))
		{
			foreach($osTimezonesList as $identifier=>$tzname)
			{
				$stepDetails['tzList'][$identifier] = array('name'=>$tzname,'is_selected'=> ($stepDetails['timezone'] == $identifier));
			}
		}
		
		return $stepDetails;
	}
	
	public function render()
	{
		$OS = getOS();
		
		$tpl = $OS->getTemplate();
		
		return $tpl->getTemplate('installstep5');
	}
}
?>