<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_installStep7
{
	private static $_instance;
	
	
	//os installStep7 constructor
	public function __construct() {}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_installStep7();
		}
		return self::$_instance;
	}
	
	public function processRequest()
	{
		$submitData = array();
		
		return $submitData;
	}
	
	public function prepareStepDetails()
	{
		$stepDetails = array();
		
		$OS = getOS();
		
		$OSInstaller = getOSInstaller();
		$OSInstallOps = $OSInstaller->getInstallOps();
		
		$installParams = $OSInstaller->getInstallParams();
		
		$osUtils = $OS->getUtils();
		
		$installType = $OSInstaller->getInternalOption('install_type');
		
		$os_root_path = $OSInstaller->getInternalOption('os_root_path');
		
		$installTests = array();
		
		//if current procedure is install remove everything
		if($installType == 'install')
		{
			$config_file_path = $OS->getConfigVar('config_file_path');
			
			if(file_exists($config_file_path))
			{
				//drop all OpenS related sql tables
				$OSInstallOps->removeOSTables($installParams[3]['db_tbl_prefix']);
				
				//delete all installed apps
				$f = os_join_path($os_root_path, "apps");
				if(is_dir($f)) $osUtils->removeDir($f, false);
				
				//delete all installed widgets
				$f = os_join_path($os_root_path, "widgets");
				if(is_dir($f)) $osUtils->removeDir($f, false);
				
				//delete all installed plugins
				$f = os_join_path($os_root_path, "widgets");
				if(is_dir($f)) $osUtils->removeDir($f, false);
				
				//delete storage dir
				$f = os_join_path($os_root_path, "storage");
				if(is_dir($f)) $osUtils->removeDir($f, false);
				
				//create templates_compiled dir
				$template_compile_path = os_join_path($f, "templates_compiled");
				if(!is_dir($template_compile_path)) $osUtils->createDir($template_compile_path, 0777);
				
				//delete cache dir
				$f = os_join_path($os_root_path, "cache");
				if(is_dir($f)) $osUtils->removeDir($f, false);
				
				//delete old settings file
				$settings_file_path = $OS->getConfigVar('settings_file_path');
				if(file_exists($settings_file_path)) unlink($settings_file_path);
				
				//delete old config file
				if(file_exists($config_file_path)) unlink($config_file_path);
			}
		}
		elseif($installType == 'update')
		{
			//delete cache dir
			$f = os_join_path($os_root_path, "cache");
			if(is_dir($f)) $osUtils->removeDir($f, false);
		}
		
		//Start install/update procedure
	    if($installType == 'install')
	    {
	    	$stepInstallParams = $installParams[3];	
	    }
	    elseif($installType == 'update')
	    {
			$stepInstallParams = array(
		    	'db_driver' => $OS->getConfigVar('db_driver'),
		    	'db_host' => $OS->getConfigVar('db_hostname'),
		    	'db_name' => $OS->getConfigVar('db_name'),
		    	'db_user' => $OS->getConfigVar('db_username'),
		    	'db_password' => $OS->getConfigVar('db_password')
		    	);
	    				
	    	$stepInstallParams['db_tbl_prefix'] = $OS->getConfigVar('db_prefix');
	    	$stepInstallParams['root_path'] = $OS->getConfigVar('root_path');
	    	$stepInstallParams['root_url'] = $OS->getConfigVar('root_url');
	    	$stepInstallParams['create_tables'] = "Y";
	    }
		
		//set Db connetion details
	    $dbConnectionDetails = array(
	    	'db_driver' => $stepInstallParams['db_driver'],
	    	'db_hostname' => $stepInstallParams['db_host'],
	    	'db_name' => $stepInstallParams['db_name'],
	    	'db_username' => $stepInstallParams['db_user'],
	    	'db_password' => $stepInstallParams['db_password']
	    	);			
			
		//handle Database Sync
		
		//also check if this step hasn't been already done ['create_tables'] installParam
		if($stepInstallParams['create_tables'] == "Y")
		{
			//os Dabase Creation Part
			$db = $OS->getDb();
			$db->addDBConnection('default',$dbConnectionDetails);
			$db->setCurrentDbConnection('default');						
		    $db->setDbPrefix($stepInstallParams['db_tbl_prefix']);
			
		    $osDbOps = $OS->getDbOps();
		    
		    //compare local database with OpenS install SQL schema
			
			//get schema sql info
			$sql_schema_path = os_join_path($OSInstaller->getInternalOption('os_install_path'), "schema", "sql_schema.php");
			
			$sqlBatchResponse = $osDbOps->syncCoreTablesBySchema($sql_schema_path);
			
			$testDetails['sqlsync'] = array(
				"name" => _("Manage OpenS Database tables"),
				"tests" => $sqlBatchResponse['tests']
				); 							
		}
		
		
		//build config file params
		$configParams = array(
			'os_version' => $OSInstaller->getInternalOption('install_version'),
			'root_path' => $stepInstallParams['root_path'],
			'root_url' => $stepInstallParams['root_url'],
			'debug' => "1",	
			);
		
		if($installType == 'install')
		{
		    $configParams = array_merge($configParams, $dbConnectionDetails);	
			$configParams['db_prefix'] = $stepInstallParams['db_tbl_prefix'];
			
			//generate installation crypt key
			$configParams['crypt_key'] = $osUtils->generateCryptKey(12,true);
			
			//if selected values are different from defaults write them in config file
			if($stepInstallParams['root_url'] != $OSInstaller->getInternalOption('os_root_url')) $configParams['root_url'] = $stepInstallParams['root_url'];
			if($stepInstallParams['root_path'] != $OSInstaller->getInternalOption('os_root_path')) $configParams['root_url'] = $stepInstallParams['root_url'];
			if($stepInstallParams['admin_language'] != 'en') $configParams['admin_language'] = $stepInstallParams['admin_language'];
		}
		
	
		//load install schema
		$hasInstallDetails = false; $schemaTests = array();
		$install_schema_path = os_join_path($OSInstaller->getInternalOption('os_install_path'), "schema", "install_schema.php");
		$installSchemaExists = (file_exists($install_schema_path));
		
		if(!$installSchemaExists)
		{
			$resultType = array('type'=>'error', 'message'=>_('Install Schema not Found'));
		}
		else
		{
			$installSchemaDetails = $osUtils->jsonRead($install_schema_path);
			
			if(empty($installSchemaDetails))
			{
				$resultType = array('type'=>'error', 'message'=>_('Cannot read Install Schema'));
			}
			else
			{
				$resultType = array('type'=>'success');
				$hasInstallDetails = true;
			}
		}
		$schemaTests[] = array('test'=>array('message'=>_('Loading Install Schema')),'result'=> $resultType);
		

		if($hasInstallDetails)
		{
			//add core crons
			if(isset($installSchemaDetails['coreCrons']))
			{
				//check if install list exists
				if(isset($installSchemaDetails['coreCrons']['installList']))
				{
					$registerCronsResult = OS_Crons::registerCoreCrons($installSchemaDetails['coreCrons']['installList']);
					
					$resultType = array('type'=> ($registerCronsResult['result']? 'success' : 'error'));
					$schemaTests[] = array('test'=>array('message'=>_('Installing Default Crons')),'result'=> $resultType);
					
					if((!$registerCronsResult['result']) && !empty($registerCronsResult['tests']))
					{
						foreach($registerCronsResult['tests'] as $test)
						{
							if($test['result']['type'] == 'error')
							{
								$schemaTests[] = $test;	
							}
						}
					}
				}
			}
			
			//add core daemons
			if(isset($installSchemaDetails['coreDaemons']))
			{
				//check if install list exists
				if(isset($installSchemaDetails['coreDaemons']['installList']))
				{
					$registerCronsResult = OS_Daemon::registerCoreDaemons($installSchemaDetails['coreDaemons']['installList']);
					
					$resultType = array('type'=> ($registerCronsResult['result']? 'success' : 'error'));
					$schemaTests[] = array('test'=>array('message'=>_('Installing Default Daemons')),'result'=> $resultType);
					
					if((!$registerCronsResult['result']) && !empty($registerCronsResult['tests']))
					{
						foreach($registerCronsResult['tests'] as $test)
						{
							if($test['result']['type'] == 'error')
							{
								$schemaTests[] = $test;	
							}
						}
					}
				}
			}
			
			if (isset($installSchemaDetails['coreEvents']))
			{
				if (isset($installSchemaDetails['coreEvents']['installList']))
				{
					$defineEventsResult = OS_Events::defineCoreEvents($installSchemaDetails['coreEvents']['installList']);
					
					$resultType = array('type' => ($defineEventsResult['result'] ? 'success' : 'error'));
					$schemaTests[] = array('test'=>array('message'=>_('Defining Core Events')),'result'=>$resultType);
					
					if ((!$defineEventsResult['result']) && !empty($defineEventsResult['tests']))
					{
						foreach ($defineEventsResult['tests'] as $test)
						{
							if ($test['result']['type'] == 'error')
							{
								$schemaTests[] = $test;
							}
						}
					}
				}
			}
			
			if (isset($installSchemaDetails['coreEventHandlers']))
			{
				if (isset($installSchemaDetails['coreEventHandlers']['installList']))
				{
					$defineEventsResult = OS_Events::defineCoreEventHandlers($installSchemaDetails['coreEventHandlers']['installList']);
					
					$resultType = array('type' => ($defineEventsResult['result'] ? 'success' : 'error'));
					$schemaTests[] = array('test'=>array('message'=>_('Registering Core Event Handlers')),'result'=>$resultType);
					
					if ((!$defineEventsResult['result']) && !empty($defineEventsResult['tests']))
					{
						foreach ($defineEventsResult['tests'] as $test)
						{
							if ($test['result']['type'] == 'error')
							{
								$schemaTests[] = $test;
							}
						}
					}
				}
			}
			
			//install search engines
			$osSearchEngineOps=$OS->getSearchEngineOps();
			$osSearchEngineOps->installAllSearchEngines();
			
			//install default apps
			if(isset($installSchemaDetails['coreApps']))
			{
				//check if install list exists
				if(isset($installSchemaDetails['coreApps']['installList']))
				{
					$osAppsOps = $OS->getAppOps();
					foreach($installSchemaDetails['coreApps']['installList'] as $appDetails)
					{
						$appName = $appDetails['name'];
						$appTitle=$appName;
						
						//check if appkit exists
						$appKitSrcPath = os_join_path($os_root_path, 'install', 'kits', 'apps', $appName);
						$appKitDestPath  = os_join_path($os_root_path, 'apps', $appName."_uninstalled");
						$tmpTests = array();
						
						if(!file_exists($appKitSrcPath))
						{
							$resultType = array('type'=> 'error', 'message'=> _("App Kit not Found"));
						}
						else
						{
							if ($manifest=$osUtils->confRead(os_join_path($appKitSrcPath,'osManifest.ini')))
							{
								if (!empty($manifest['details']['title']))
								{
									$appTitle=$manifest['details']['title'];
								}
							}
							
							$copyResult = $osUtils->copyDir($appKitSrcPath, $appKitDestPath);
							
							if($copyResult === false) 
							{
								$resultType = array('type'=> 'error', 'message'=> _("Cannot copy App Kit"));	
							}
							
							if(!file_exists($appKitDestPath))
							{
								$resultType = array('type'=> 'error', 'message'=> _("App Kit not Found"));
							}
							else
							{
								$appInstallResponse = $osAppsOps->installApp($appKitDestPath);
								
								if($appInstallResponse['result'])
								{
									$resultType = array('type'=> 'success');
								}
								else
								{
									$resultType = array('type'=> 'error', 'message'=> _("App cannot be installed"));
									
									foreach($appInstallResponse['tests'] as $test)
									{
										if($test['result']['type'] == 'error')
										{
											$tmpTests[] = $test;	
										}
									}
								}
							}
						}
						
						$schemaTests[] = array('test'=>array('message'=>sprintf(_('Installing App').': %s', $appTitle)),'result'=> $resultType);
						
						if(!empty($tmpTests)) $schemaTests = array_merge($schemaTests, $tmpTests); 
					}
				}
			}
			
			if(isset($installSchemaDetails['coreWidgets']))
			{
				//check if install list exists
				if(isset($installSchemaDetails['coreWidgets']['installList']))
				{
					//install default widgets
					$osWidgetOps = $OS->getWidgetOps();
					
					foreach($installSchemaDetails['coreWidgets']['installList'] as $widgetDetails)
					{
						$widgetName = $widgetDetails['name'];
						$widgetTitle = $widgetName;
						
						//check if appkit exists
						$widgetKitSrcPath = os_join_path($os_root_path, 'install', 'kits', 'widgets', $widgetName);
						$widgetKitDestPath  = os_join_path($os_root_path, 'widgets', $widgetName."_uninstalled");
						$tmpTests = array();
						
						if(!file_exists($widgetKitSrcPath))
						{
							$resultType = array('type'=> 'error', 'message'=> _("Widget Kit not Found"));
						}
						else
						{
							if ($manifest=$osUtils->confRead(os_join_path($widgetKitSrcPath,'osManifest.ini')))
							{
								if (!empty($manifest['details']['title']))
								{
									$widgetTitle=$manifest['details']['title'];
								}
							}
							
							$copyResult = $osUtils->copyDir($widgetKitSrcPath, $widgetKitDestPath);
							
							if($copyResult === false)
							{
								$resultType = array('type'=> 'error', 'message'=> _("Cannot copy Widget Kit"));
							}
							elseif(!file_exists($widgetKitDestPath))
							{
								$resultType = array('type'=> 'error', 'message'=> _("Widget Kit not Found"));
							}
							else
							{
								$widgetInstallResponse = $osWidgetOps->installWidget($widgetKitDestPath);
	
								if($widgetInstallResponse['result'])
								{
									$resultType = array('type'=> 'success');	
								}
								else
								{
									$resultType = array('type'=> 'error', 'message'=> _("Widget cannot be installed"));
									
									foreach($widgetInstallResponse['tests'] as $test)
									{
										if($test['result']['type'] == 'error')
										{
											$tmpTests[] = $test;	
										}
									}
								}
							}
						}
						
						$schemaTests[] = array('test'=>array('message'=>sprintf(_('Installing Widget').': %s', $widgetTitle)),'result'=> $resultType);
						if(!empty($tmpTests)) $schemaTests = array_merge($schemaTests, $tmpTests);
					}
				}
			}
		}
		
		$testDetails['core_components'] = array(
			"name" => _("Installing Core components"),
			"tests" => $schemaTests
			); 
			

		//Create Opens Administrators department
		if($installType == 'install')
		{
			$defaultDepartmentName = _("Administrators");
			
			$osDepartmentOps = $OS->getDepartmentOps();
			
			$tmpTest = array('test'=>array('message'=> sprintf(_("Creating `%s` Department"), $defaultDepartmentName)));
			
			$oneDepartment = $osDepartmentOps->getDepartmentByName($defaultDepartmentName);
			
			if($oneDepartment === false)
			{
				$oneDepartment = new OS_Department();
				$oneDepartment->set(array('id' => -1, 'name' => $defaultDepartmentName, 'status' => "A"));
				$depResponse = $oneDepartment->save();
				
				if($depResponse !== false)
				{
					//add All System permissions to `Administrators` department
					$osPermissions = $OS->getPermissions();
					$permissionsResponse = $osPermissions->getAllPermissions();
					
					if(!empty($permissionsResponse))
					{
						foreach($permissionsResponse as $module=>$moduleData)
						{
							foreach($moduleData as $perm=>$permValue)
							{
								$oneDepartment->addPerm(0, $module, $perm);
							}
						}		
					}
					
					$tmpTest['result'] = array('type'=> 'success');
				}
				else
				{
					$tmpTest['result'] = array('type'=> 'error', 'message'=> _("Department could not be added into the system"));
				}
			}	
			else
			{
				$tmpTest['result'] = array('type'=> 'info', 'message'=>  _("Department already created")); 
			}	
			
			$installTests[] = $tmpTest;
		}
			
		//Create OpenS admin account
		if($installType == 'install')
		{
			$stepInstallParams = $installParams[4];
			
			$osUserOps = $OS->getUserOps();
			
			$tmpTest = array('test'=>array('message'=> sprintf(_("Creating `%s` OpenS User"), $stepInstallParams['username'])));
			
			//generate password hash
			$password_hash = $osUtils->generateHash($stepInstallParams['password'], 8, $configParams['crypt_key']);

			//if admin user already exists
			$userData = $osUserOps->getUserByUsername($stepInstallParams['username']);
			if($userData === false)
			{
				//add new admin user to the database
				$userDetails =  array(
					"user" => $stepInstallParams['username'],
					"name" => "OpenS Administrator",
					"email" => $stepInstallParams['email'],
					"status" => "A",
					"timezone" => $OS->getSessionVar('os_timezone'),
					"language" => "en",
					"is_admin" => "Y",
					"password" => $password_hash
					);	
				
				$oneUser = new OS_User();
				$oneUser->set($userDetails);
				$userResponse = $oneUser->save();
				
				if($userResponse !== false)
				{
					//create project default sections
					$result = $osUserOps->createDefaultUserDetails($oneUser);
					
					$tmpTest['result'] = array('type'=> 'success');	
				}
				else
				{
					$tmpTest['result'] = array('type'=> 'error', 'message'=>  _("User could not be created"));	
				}
			}
			else
			{
				$tmpTest['result'] = array('type'=> 'info', 'message'=> _("User already exists in the system"));
				
				$oneUser = $userData;
				$oneUser->password = $password_hash;
				$oneUser->save();
			}
			
			$installTests[] = $tmpTest;
		}
		

		//Create OpenS default Project 	
		if($installType == 'install')
		{
			if(isset($installParams[5]))
			{
				$stepInstallParams = $installParams[5];
				
				//check current user
				$osProjectOps = $OS->getProjectOps();
				
				$tmpTest = array('test'=>array('message'=> sprintf(_("Creating `%s` OpenS Project"), $stepInstallParams['project_name'])));
				
				$projectData = $osProjectOps->getProjectByUrl($stepInstallParams['project_url']);
				
				if($projectData === false)
				{
					//add new admin user to the database
					
					//add new user on opens.com server
					$projectDetails = array(
						'name' => $stepInstallParams['project_name'],
						'url' => $stepInstallParams['project_url'],
						'status' => "A",
						'user_id' => $oneUser->id,
						'user' => $oneUser->user,
						'client_id'=>0,
						'timezone' => $OS->getSessionVar('os_timezone'),
						'language' => "en",
						'js_tracking' => '',
						'crawl_freq'=>7,
						'crawl_max_links'=>10000,
						'crawl_depth'=>10,
						'crawl_threads'=>10
					);

					$oneProject = new OS_Project();
					$oneProject->set($projectDetails);
					$projectResponse = $oneProject->save();
			
					if($projectResponse !== false)
					{
						//create project default sections
						$osProjectOps = $OS->getProjectOps();
						
						if ($result = $osProjectOps->createDefaultProjectDetails($oneProject, $oneUser))
						{
							if ($stepInstallParams['crawl_project'] == 'Y')
							{
								$shouldCrawlProject=true;
							}
						}
						
						$tmpTest['result'] = array('type'=> 'success');
					}
					else
					{
						$tmpTest['result'] = array('type'=> 'error', 'message'=> _("Project could not be created"));
					}
				}
				else
				{
					$tmpTest['result'] = array('type'=> 'info', 'message'=> _("This project already exists in the system")); 
				}
				
				$installTests[] = $tmpTest;
			}
		}
		
		
		//Install Default OpenS Profile
		if(!empty($installTests))
		{
			$testDetails['defaultdeps'] = array(
				"name" => _("Install Default OpenS Profile"),
				"tests" => $installTests
				); 
		}
		
		$stepDetails['tests'] = $testDetails;
		
		
		//test if install process has error
		$install_has_errors =  false;
		foreach($testDetails as $testdetails)
		{
			if(isset($testdetails['tests']))
			{
				foreach($testdetails['tests'] as $test)
				{
					if(isset($test['result']['type']))
					{
						if($test['result']['type'] == 'error') $install_has_errors = true;
					}
				}
			}
		}
		

		//if install has no errors write config file
		if(!$install_has_errors)
		{
			//Handle OpenS config file
			$osConfig = $OS->getConfig();
			
			$configParams['php_dir'] = $OS->getUtils()->guessPHPDir();
			
			if($installType == 'install')
			{
				$osConfig->flush();

				//generate auth code
				$configParams['auth_code'] = $osUtils->generateAuthCode();
			} 
			
			foreach($configParams as $key => $val)
			{
				$osConfig->setParam($key, $val);	
			}
			
			//save current configuration to file 
			$osConfig->save();		

			
			//add OpenS API credentials to settings file
			$osSettings = $OS->getSettings();

			if($installType == 'install')
			{
				$osSettings->flush();	
			} 

			//define default mail system
			$sendmail_path = '/usr/sbin/sendmail';
			if (!stristr(ini_get('sendmail_path'), 'sendmail'))
			{
				$sendmail_path = '/var/qmail/bin/sendmail';
			}			
			
			//set default opens settings
			$osSettings->setParam('cache_engine', "filesystem");
			$osSettings->setParam('geoip_library',"maxmindflatfile");
			$osSettings->setParam('community_stats', "0");
			
			$osSettings->setParam('os_mail_type', "phpmail");
			$osSettings->setParam('os_mail_sendmail_path', $sendmail_path);
	
			//save current settings to file 
			$osSettings->save();
			
			if (!empty($shouldCrawlProject))
			{
				OS_Fork::fork('core','','crawl_project',array('project_id'=>$oneProject->id));
			}
		}
		
		if($install_has_errors)
		{
			$stepDetails['show_retry_btn'] = true;
			$stepDetails['show_next_btn'] = false;
		}
		else
		{
			$stepDetails['show_prev_btn'] = false;
		}
		
		return $stepDetails;
	}
	
	public function render()
	{
		$OS = getOS();
		
		$tpl = $OS->getTemplate();
		
		return $tpl->getTemplate('installstep7');
	}
}
?>