<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_installstep7.php 2012-01-09$
 */

class OS_installStep8
{
	private static $_instance;
	
	
	//os installStep8 constructor
	public function __construct()
	{
	
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_installStep8();
		}
		return self::$_instance;
	}
	
	public function processRequest()
	{
		$OS = getOS();
		
		$osValidator = $OS->getValidator();
		
		//get database info
		$OSInstaller = getOSInstaller();
		
		$installParams = $OSInstaller->getInstallParams();
		
	    if(isset($installParams[8]))
	    {
	    	$stepInstallParams = $installParams[8];

	    }
		
		if($_SERVER['REQUEST_METHOD'] == 'POST')
		{
			$osUserOps = $OS->getUserOps();
			
			if(isset($_POST['os_create_account_btn']))
			{//handle new account
				if (empty($_POST['os_user_box'])) 
				{
					$OS->addFieldError(_("Username missing"),'os_user');	
				}
				else
				{
					$_POST['os_user_box'] = os_clean_value($_POST['os_user_box']);
					
					if (strlen($_POST['os_user_box'])<3) 
					{
						$OS->addFieldError(_("Username too short"),'os_user');	
					}
					elseif (!$osUserOps->isValidUsername($_POST['os_user_box'])) 
					{
						$OS->addFieldError(_("Invalid Username"),'os_user');	
					}
					else
					{
						$submitData['os_user'] = $_POST['os_user_box'];
					}
				}
		
				
				if (empty($_POST['os_email_box']))
				{
					$OS->addFieldError(_("Email missing"),'os_email');	
				} 
				else
				{
					$_POST["os_email_box"] = os_clean_email($_POST["os_email_box"]);
					
					if (!$osValidator->is_email($_POST["os_email_box"]))
					{
						$OS->addFieldError(_("Invalid email")." (".$osValidator->ERROR.")",'os_email');
					}
					else
					{
						$submitData['os_email'] = $_POST["os_email_box"];
					}
				}
			
			
				if (empty($_POST['os_password_box'])) 
				{
					$_POST['os_password_box'] = '';
					
					$OS->addFieldError(_("Password is missing"),'os_password');
				}
				elseif ($_POST['os_password_box'] != $_POST['os_password2_box']) 
				{
					$OS->addFieldError(_("Passwords do not match"),'os_password');	
				}
				elseif (strlen($_POST['os_password_box'])<6)
				{
					$OS->addFieldError(_("Password too short"),'os_password');	
				} 
				else 
				{
					$submitData['os_password'] = $_POST['os_password_box'];
				}

				if(!isset($OS->errorMessages))
				{
					//register user via OpenS API
					$osAppStore = $OS->getAppStoreApi();
					
					$asResponse = $osAppStore->validateUserDetails(array('user'=> $submitData['os_user'], 'email'=> $submitData['os_email']));
					if(!$osAppStore->success)
					{
						$apiError = $osAppStore->getError();
						$OS->addBoxError($apiError['message']);
					}
					else
					{
						if(!isset($asResponse['user']))
						{
							$OS->addBoxError(_("This username is already registered"));	
						}
						elseif($asResponse['user'] !== true)
						{
							$OS->addBoxError(_("This username is already registered"));
						}
						elseif(!isset($asResponse['email']))
						{
							$OS->addBoxError(_("This email is already registered"));
						}
						elseif($asResponse['email'] !== true)
						{
							$OS->addBoxError(_("This email is already registered"));
						}
						else
						{
							$asResponse = $osAppStore->registerApiUser(array('user'=> $submitData['os_user'], 'email'=> $submitData['os_email'], 'password'=> $submitData['os_password']));
							if(!$osAppStore->success)
							{
								$apiError = $osAppStore->getError();
								$OS->addBoxError($apiError['message']);
							}
							else
							{
								//add OpenS API credentials to settings file
								$osSettings = $OS->getSettings();
								
								$osSettings->setParam('osc_user', $asResponse['user_details']['user']);
								$osSettings->setParam('osc_api_key', $asResponse['user_details']['api_key']);
	
								//save current settings to file 
								$saveResult = $osSettings->save();
							}
						}
					}
				}
			}
			elseif(isset($_POST['os_check_account_btn']))
			{//handle check existing user
				if(empty($_POST["os_check_user_box"]))
				{
					$OS->addFieldError(_("Username missing"),'os_check_user');	
				} 
				else
				{
					$submitData['os_check_user'] = os_clean_value($_POST['os_check_user_box']);
					
					if(!$osUserOps->isValidUsername($submitData['os_check_user']))
					{
						$_POST["os_check_user_box"]='';
						$OS->addFieldError(_("Username is wrong"),'os_check_user');
					}
				}
			
				if(empty($_POST["os_check_password_box"]))
				{
					$OS->addFieldError(_("Password missing"),'os_check_password');	
				} 
				else
				{
					$submitData['os_check_password'] = os_clean_value($_POST['os_check_password_box']);
					
					if((strlen($submitData['os_check_password'])<3))
					{
						$OS->addFieldError(_("Password too short (min 3 characters)"),'os_check_password');	
					}	
				} 
				
				if(!isset($OS->errorMessages))
				{
					//check credentials via OpenS API
					$osAppStore = $OS->getAppStoreApi();
					
					$asResponse = $osAppStore->checkUser(array('user'=> $submitData['os_check_user'], 'password'=> $submitData['os_check_password']));
					if(!$osAppStore->success)
					{
						$apiError = $osAppStore->getError();
						$OS->addBoxError($apiError['message']);
					}
					else
					{
						if(!isset($asResponse['user_details']))
						{
							$OS->addBoxError(_("Invalid User Credentials"));
						}
						else
						{
							//add OpenS API credentials to settings file
							$osSettings = $OS->getSettings();
							
							$osSettings->setParam('osc_user', $asResponse['user_details']['user']);
							$osSettings->setParam('osc_api_key', $asResponse['user_details']['api_key']);

							//save current settings to file 
							$saveResult = $osSettings->save();
						}
					}
				}
			}
		}
		
		if(!isset($OS->errorMessages)) return $submitData;
		else return false;
	}
	
	public function prepareStepDetails()
	{
		$stepDetails = array();
		
		$OS =  getOS();
		
		if(isset($_POST['os_user_box'])) $stepDetails['os_user'] = $_POST['os_user_box'];
		else $stepDetails['os_user'] = "";

		if(isset($_POST['os_email_box'])) $stepDetails['os_email'] = $_POST['os_email_box'];
		else $stepDetails['os_email'] = ""; 
		
		if(isset($_POST['os_password_box'])) $stepDetails['os_password'] = $_POST['os_password_box'];
		else $stepDetails['os_password'] = ""; 
		
		if(isset($_POST['os_password2_box'])) $stepDetails['os_password2'] = $_POST['os_password2_box'];
		else $stepDetails['os_password2'] = "";

		if(isset($_POST['os_check_user_box'])) $stepDetails['os_check_user'] = $_POST['os_check_user_box'];
		else $stepDetails['os_check_user'] = "";
		
		if(isset($_POST['os_check_password_box'])) $stepDetails['os_check_password'] = $_POST['os_check_password_box'];
		else $stepDetails['os_check_password'] = "";
		
		$stepDetails['show_retry_btn'] = false;
		$stepDetails['show_prev_btn'] = false;
		$stepDetails['show_next_btn'] = false;
		
		return $stepDetails;
	}
	
	public function render()
	{
		$OS = getOS();
		
		$tpl = $OS->getTemplate();
		
		if(isset($_POST['os_check_account_btn'])) $active_tab = 'list-check';
		elseif(isset($_POST['os_create_account_btn'])) $active_tab = 'list-register';
		else $active_tab = 'list-register';
		
		$tpl->setVar('active_tab', $active_tab);
		
		return $tpl->getTemplate('installstep8');
	}
}
?>