<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_ajax.php 2012-01-09$
 */
class OS_Ajax
{
	private static $_instance;
	
	private $registeredClasses;
	
	private $currentClass;
	
	private $requestData;
	
	private $responseData;
	
	protected function __construct(){}
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_Ajax();
		}
		return self::$_instance;
	}
	
	public function handle()
	{
		$errMsg = $this->processRequest();
		
		if($errMsg !== false)
		{
			$osHandlerClass = $this->registeredClasses[$this->currentClass]['object'];
			
			$current_action = $this->requestData['action'];
			
			$response = $osHandlerClass->$current_action($this->requestData['params']);
				
			$this->prepareResponse($response);
		}
		
		$this->processResponse();	
	}
	
	public function setClass($className)
	{
		$change_class = false;
		
		if(isset($this->registeredClasses[$className])) 
		{
			$change_class = true;
		}
		else
		{
			if(class_exists($className))
			{
				$newClass = new $className();
				
				$classMethods = get_class_methods($newClass);
								
				$this->registeredClasses[$className] =	array(
					'object' =>$newClass,
					'methods' => array_flip($classMethods)	
					); 
				
				$change_class = true;				
			}
		}
		
		if($change_class) $this->currentClass = $className;
	}
	
	private function processRequest()
	{
		$requestResult = false;
		
		if($_SERVER['REQUEST_METHOD'] != 'POST')
		{
			$this->fetchInvalidResponse(_("Invalid transport method"));
		}
		elseif(empty($_POST['action']))
		{
			$this->fetchInvalidResponse(_("Call action is missing"));
		}
		else
		{
			$current_class = $this->currentClass;
			$current_action = $_POST['action'];
			
			if(!isset($this->registeredClasses[$current_class]))
			{
				$this->fetchInvalidResponse(sprintf(_("Invalid action")." :`%s`",$current_action));	
			}
			else
			{
				if(!isset($this->registeredClasses[$current_class]['methods'][$current_action]))
				{
					$this->fetchInvalidResponse(sprintf(_("Invalid action")." :`%s`",$current_action));
				}
				else
				{
					$OS = getOS();
					
					$osHandlerClass = $this->registeredClasses[$current_class]['object'];
			
					$validRequest = true; $permissionRequired = false;
					
					if((isset($osHandlerClass->permissionsRequired)) && (is_array($osHandlerClass->permissionsRequired)))
					{
						//check if user is logged
						if(in_array('checkUserLogged', $osHandlerClass->permissionsRequired))
						{
							$osUser = $OS->getUser();
							if(!$osUser->isUserLogged())
							{
								$validRequest = false;
								$permissionData = array('permission' => 'checkUserLogged', 'message'=> _('Credentials Not Satisfied'));	
							} 
						}
						
						//check if user is admin
						if(in_array('checkUserAdmin', $osHandlerClass->permissionsRequired))
						{
							$osUser = $OS->getUser();
							if(!$osUser->isUserAdmin())
							{
								$validRequest = false;
								$permissionData = array('permission' => 'checkUserAdmin', 'message'=> _('Credentials Not Satisfied'));	
							} 
						}
						
						//check if user has an active project
						if(in_array('checkUserProject', $osHandlerClass->permissionsRequired))
						{
							$osProject = $OS->getProject();
							if(!$osProject->selectedProject())
							{
								$validRequest = false;
								$permissionData = array('permission' => 'checkUserProject', 'message'=> _('Credentials Not Satisfied'));	
							} 
						}
						
						//check if user AppStore credentials are set
						if(in_array('checkAppstore', $osHandlerClass->permissionsRequired))
						{
							$osSettings = $OS->getSettings();
							
							$osc_user = $osSettings->getParam('osc_user');
							$osc_api_key = $osSettings->getParam('osc_api_key');

							if((empty($osc_user)) || (empty($osc_api_key)))
							{
								$validRequest = false;
								$permissionData = array('permission' => 'checkAppstore', 'message'=> _('AppStore credentials not set'));	
							}
						}
					}
					
					if(!$validRequest)
					{
						$this->fetchInvalidResponse($permissionData['message'], $permissionData['permission']);
					}
					else
					{
						$this->requestData['action'] = $_POST['action'];
					
						$this->requestData['params'] = (isset($_POST['params'])? $_POST['params']:array());
					
						$requestResult = true;
					}
				}
			}	
			
		}	
		
		return $requestResult;
	}
	
	private function processResponse()
	{
		echo json_encode($this->responseData);	
	}
	
	private function prepareResponse($response)
	{
		$responseData = array('status'=>"OK",'data'=>$response);
		 
		$this->responseData = $responseData;
	}
	
	private function fetchInvalidResponse($error, $permissionRequired = false)
	{
		$responseData = array(
			'status'=>"FAIL",
			'data'=>array(
				'actionData' => array(
					'permissionRequired' => $permissionRequired,
					'notifications'=> array(array('type'=>'error', 'message'=>$error))
					)
				)
			);
			
		$this->responseData = $responseData;
	}
}
?>