<?php
class OS_App
{
	public $id;
	
	public $category;
	
	public $name;
	
	public $title;
	
	public $description;
	
	public $version;
	
	public $status;
	
	public $status_dt;
	
	public $status_ip;
	
	public $status_by;
	
	public $manifest;
	
	public $kitname;
	
	public $install_time_ms;
	
	public function __construct()
	{
		$this->setInitialValues();
	}
	
	private function setInitialValues()
	{
		$initialValues = array(
			'id' => -1,
			'category'=> "",
			'name' => "",
			'title' => "",
			'description' => "",
			'version' => "",
			'status' => ""
			);
			
		$this->set($initialValues);	
	}
	
	public function install()
	{
		$result = false;
		
		$osAppOps = $OS->getAppOps();
		
		if ($this->id > -1)
		{
			$result = $osAppOps->updateApp($this);
		}
		else
		{
			$newid = $osAppOps->insertApp($this);
			if ($newid > -1)
			{
				$this->id = $newid;
				$result = true;
			}

		}

		return $result;
	}
	
	public function save()
	{
		$result = false;
		
		$OS = getOS();
		
		$osAppOps = $OS->getAppOps();
		
		if ($this->id > -1)
		{
			$result = $osAppOps->updateApp($this);
		}
		else
		{
			$newid = $osAppOps->insertApp($this);
			if ($newid > -1)
			{
				$this->id = $newid;
				$result = true;
			}

		}

		return $result;
	}	
	
	public function update()
	{
		$result = false;
		
		if(isset($this->name))
		{
			$OS = getOS();
			
			$osAppOps = $OS->getAppOps();
			
			$updateAppResult = $osAppOps->updateAppStoreApp($this->name);
			
			if($updateAppResult['actionStatus'] === true)
			{
				$result = true;	
			}
		}
		
		return $result;
	}
	
	public function uninstall()
	{
		$result = false;
		
		if ($this->id > -1)
		{
			$OS = getOS();
			
			$osAppOps = $OS->getAppOps();
			
			$result = $osAppOps->uninstallApp($this->id);
			if ($result)
			{
//				$this->setInitialValues(); //Only the ID should be reset, the rest are app-specific, not sql-specific
				$this->id=-1;
			}
		}

		return $result;		
	}
	
	public function getAppUrl()
	{
		$result = false;
		
		if($this->isValid())
		{
			$base_url = getOS()->getConfigVar('root_url').'/apps';
			
			$appDirName = (isset($this->kitname)? $this->kitname.'_uninstalled/app' : $this->name);
			
			$result = $base_url.'/'.$appDirName;
		}
		
		return $result;
	}
	
	public function getAppPath()
	{
		$result = false;
		
		if($this->isValid())
		{
			$base_path = getOS()->getConfigVar('root_path').'/apps';
			
			$appDirName = (isset($this->kitname)? $this->kitname.'_uninstalled' : $this->name);
			
			$result = $base_path.'/'.$appDirName;
		}
		
		return $result;
	}
	
	public function set($app_data)
	{
		$result = false;
		
		$objVars = get_object_vars($this);
		
		foreach($objVars as $key=>$val)
		{
			if(isset($app_data[$key]))
			{
				$this->$key = $app_data[$key];
				$result = true;
			}
		}
		
		return $result;
	}
	
	public function isValid()
	{
		$result = false;
		if(isset($this->id))
		{
			if($this->id > 0)
			{
				$result  = true;		
			}
		}
		
		if(!empty($this->name))
		{
			$result  = true;		
		}
		
		
		return $result;
	}
	
	public function requireUpdate($newVersion)
	{
		$result = true;
		
		if((isset($this->version)) && (!empty($newVersion)))
		{
			if (version_compare($this->version, $newVersion) <= 0)
			{
				$result = false;	
			}	
		}
		
		return $result;
	}
	
	public function getManifest()
	{
		$result = false;
		
		if(!empty($this->manifest))
		{
			$appManifest = json_decode($this->manifest, true);
			if(!empty($appManifest))
			{
				$result = $appManifest; 	
			} 
		}

		return $result;
	}
}
?>