<?php
/*
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */
abstract class OS_AppBase
{
	protected $routerOptions;

	protected $menuItems;
	
	protected $requestParams;
	protected $requestView;

	public $appDetails;
	public $appSettings;
	public $appPermissions;
	public $appPermissionsGroups;

	protected function __construct()
	{
		$this->defineAppPermissions();
		$this->defineAppPermissionsGroups();
	}

	public function getAppUrl()
	{
		return getOS()->getConfigVar('root_url').'/users/app.php?app='.$this->getAppDetail('name');
	}

	public function getAppActionUrl($view,$params=array())
	{
		return $this->getAppUrl()."&view={$view}".($params?"&".http_build_query($params):'');
	}

	public function getAppHomeUrl($secure=false)
	{
		$result=false;

		if ($secure)
		{
			$result=getOS()->getConfigVar('ssl_root_url').'/apps/'.$this->getAppDetail('name');
		}
		else
		{
			$result=getOS()->getConfigVar('root_url').'/apps/'.$this->getAppDetail('name');
		}

		return $result;
	}

	public function getAppHomePath()
	{
		return os_join_path(getOS()->getConfigVar('root_path'),'apps',$this->getAppDetail('name'));
	}

	public function getAppUserPath()
	{
		return $this->execHandlerMethod('getAppUserPath');
	}

	public function getAppStoragePath()
	{
		return $this->execHandlerMethod('getAppStoragePath');
	}

	public function getAppCachePath()
	{
		return $this->execHandlerMethod('getAppCachePath');
	}

	protected function defineAppPermissions()
	{
		$this->appPermissions=array();
	}

	protected function defineAppPermissionsGroups()
	{
		$this->appPermissionsGroups=array();
	}

	public function getPerms()
	{
		return $this->appPermissions;
	}

	public function getPermsGroups()
	{
		return $this->appPermissionsGroups;
	}
	
	public function getReportingData()
	{
		return false;
	}
	
	public function getReportingTypes()
	{
		return false;
	}

	public function getAppDetail($detail_name)
	{
		$result=false;

		$appHandler=getOS()->getAppHandler();

		if (isset($appHandler->$detail_name))
		{
			$result=$appHandler->$detail_name;
		}

		return $result;
	}

	public function saveAppSettings($settings)
	{
		//settings = array(setting=>array('value'=>value,'type'=>type));
		return $this->execHandlerMethod('saveSettings',array($settings));
	}

	public function getAppSetting($setting_name)
	{
		$result=false;

		$appHandler=getOS()->getAppHandler();

		if (isset($appHandler->settings[$setting_name]))
		{
			$result=$appHandler->settings[$setting_name];
		}

		return $result;
	}

	public function execHandlerMethod($method_name,$params=array())
	{
		$result=false;

		$app_handler=getOS()->getAppHandler();

		if (method_exists($app_handler,$method_name))
		{
			$result=call_user_func_array(array($app_handler,$method_name),$params);
		}

		return $result;
	}

	public function useDatasource($datasource_name)
	{
		$result=false;

		$datasource=getOS()->getDatasource($datasource_name);

		if ($datasource->connect('app',$this->getAppDetail('name')))
		{
			$result=true;
		}

		return $result;
	}

	public function dbPrefix()
	{
		return $this->execHandlerMethod('dbPrefix');
	}

	public function requestProjectCrawl($project_id)
	{
		return OS_Fork::fork('core','','crawl_project',array('project_id'=>$project_id,'app'=>$this->getAppDetail('name')));
	}

	public function processRequest($request)
	{
		$response = false;
		$renderfcn = false;
		$appBaseViews = array('view'=> "handleBaseMainView", 'menu_back_link' => "handleMenuBackView");
		
		if(!empty($request['params']))
		{
			$this->setRequestParams($request['params']);  
		}

		//get current View
		$currentView = 'view';
		
		if (!empty($request['view']))
		{
			$availableOptions = array('menu_back_link');
			
			if(!empty($this->routerOptions))
			{
				$availableOptions = array_merge($availableOptions, array_keys($this->routerOptions));
			}
			
			if(in_array($request['view'],$availableOptions))
			{
				$currentView = $request['view'];	
			}
		}
		
		$this->setRequestView($currentView);
		
		//check if app has an active router
		$tpl = getOS()->getTemplate();
		$tpl->setTemplateDir(os_join_path($this->getAppHomePath(), "templates"));
		
		$viewHandlerParams = (isset($this->routerOptions[$currentView]['params']) ? $this->routerOptions[$currentView]['params'] : array());
		
		//set handler function 
		if(isset($this->routerOptions[$currentView]))
		{
			//if there is a menu option for this view activate it
			$this->setActiveMenuItem($currentView);
			
			$renderfcn = $this->routerOptions[$currentView];	
		}
		elseif(isset($appBaseViews[$currentView]))
		{
			$renderfcn = $appBaseViews[$currentView];
		}
		
		if($renderfcn)
		{
			$response = (empty($viewHandlerParams) ? $this->$renderfcn() : $this->$renderfcn($viewHandlerParams));	
		}
			
		return $response;
	}

	protected function setRouterOptions($options)
	{
		$this->routerOptions = $options;
	}

	protected function setRouterOption($optionName, $optionFunction)
	{
		$this->routerOptions[$optionName] = $optionFunction;
	}

	protected function getRouterOptions()
	{
		return $this->routerOptions;
	}

	protected function getRouterOption($option)
	{
		if(!isset($this->routerOptions[$option]))
		{
			return false;
		}

		return $this->routerOptions[$option];
	}
	
	public function getMenuOptions()
	{
		return $this->menuItems;
	}

	//add element to menu
	public function addMenuItem($itemName, $itemData)
	{
		//each menu item must have router handler
		if(!isset($itemData['routerOption'])) return false;
		
		//check if order is valid
		if(empty($this->menuItems)) $this->menuItems = array();
		
		if(isset($itemData['before'])) {$order_option = $itemData['before']; $order_type = 'before';}
		elseif(isset($itemData['after'])) {$order_option = $itemData['after']; $order_type = 'after';}
		else $order_option = false;
		
		$builtItemData = $this->buildMenuItem($itemName, $itemData);
		
		//get temp menu
		$tmpMenuData = $this->menuItems; $has_parent = false;
		if(isset($itemData['parent']))
		{
			if(isset($this->menuItems[$itemData['parent']]))
			{
				$has_parent = true;
				$tmpMenuData = (empty($this->menuItems[$itemData['parent']]['suboptions'])?array():$this->menuItems[$itemData['parent']]['suboptions']);
			}
		}
		
		if($order_option)
		{
			$tmpArray = array();
			foreach($tmpMenuData as $currentItem => $menuData)
			{
				if($currentItem == $order_option)
				{
					if($order_type == 'before') $tmpArray[$itemName] = $builtItemData;
						
					$tmpArray[$currentItem] = $menuData;
						
					if($order_type == 'after') $tmpArray[$itemName] = $builtItemData;
				}
				else
				{
					$tmpArray[$currentItem] = $menuData;
				}
			}
			
			//if the item was not added , put it at the end of the menu
			if(!isset($tmpArray[$itemName])) $tmpArray[$itemName] = $builtItemData;

			if($has_parent)
			{
				$this->menuItems[$itemData['parent']]['suboptions'] = $tmpArray;
				
				foreach($tmpArray as $items => $details)
				{
					if($details['show_in_menu'])
					{
						$this->menuItems[$itemData['parent']]['visible_suboptions']++;	
					}
				}
			}
			else
			{
				$this->menuItems = $tmpArray;
			}
		}
		elseif($has_parent)
		{
			$this->menuItems[$itemData['parent']]['suboptions'][$itemName] = $builtItemData;
			if($builtItemData['show_in_menu'])
			{
				$this->menuItems[$itemData['parent']]['visible_suboptions']++;
			}
		}		
		else
		{
			$this->menuItems[$itemName] = $builtItemData;
		}
		
		return true;
	}
	
	
	private function buildMenuItem($itemName, $itemData)
	{
		//$routeName = (isset($itemData['parent']) ? $itemData['parent'].'-':"").$itemName;
		
		$routeName = $itemName;
		
		if(isset($itemData['params'])) $requestParams = $itemData['params']; 
		elseif(isset($this->requestParams)) $requestParams = $this->requestParams;
		else $requestParams = array();
		
		$menuData = array(
			'url' => $this->getAppActionUrl($routeName, $requestParams), 
			'title' => "", 
			'name' => "", 
			"show_in_menu" => true, 
			"visible_suboptions" => 0,
			"selected" => false,
			"menu_icon" => false
			);
		
		foreach($menuData as $key => $val)
		{
			if(isset($itemData[$key])) $menuData[$key] = $itemData[$key];
		}
		
		if((empty($menuData['title'])) && (!empty($menuData['name'])))
		{
			$menuData['title'] = $menuData['name']; 
		}
		
		//set router Option
		$this->setRouterOption($routeName, $itemData['routerOption']);
		return $menuData;
	}

	//remove element from menu
	public function removeMenuItem($menuItem)
	{
		//change this to work with sub-menus
		if(isset($this->menuItems[$menuItem]))
		{
			unset($this->menuItems[$menuItem]);
		}
	}
	
	public function setActiveMenuItem($selectedItem)
	{
		if (!empty($this->menuItems))
		{
			if(isset($this->menuItems[$selectedItem]))
			{
				$this->menuItems[$selectedItem]['selected'] = true;
			}
			else
			{
				foreach($this->menuItems as $action => $details)
				{
					if(isset($details['suboptions']))
					{
						$suboptions_actions = array_keys($details['suboptions']);
						
						if(in_array($selectedItem, $suboptions_actions))
						{
							$this->menuItems[$action]['selected'] = true;
						}
					}
				}
			}
		}
	}
	
	public function getRequestParams()
	{
		return $this->requestParams; 
	}
	
	public function setRequestParams($requestParams)
	{
		$this->requestParams = $requestParams;
		
		return (true);
	}
	
	public function getRequestView()
	{
		return $this->requestView;
	}
	
	public function setRequestView($requestView)
	{
		$this->requestView = $requestView;
		
		return (true);
	}
	
	public function trackEvent($eventDetails)
	{
		return false;	
	}
	
	public function setMenuBackLink($params)
	{
		$result = false;
		if(isset($params['back_view']))
		{
			$this->addMenuItem('menu_back_link', array("name" => _("Back"), 'before' => 'view', 'routerOption'=> "handleMenuBackView", 'params'=> $params, 'menu_icon' => "{"));
			$result = true;	
		}
		
		return $result;
	}
	
	private function handleMenuBackView()
	{
		$requestParams =  $this->getRequestParams();
		
		if(isset($requestParams['back_view']))
		{
			$requestParams['view'] = $requestParams['back_view'];
			unset($requestParams['back_view']);
			
			getOS()->redirectTO($this->getAppUrl().'&'.http_build_query($requestParams), true);
		}
	}
	
	private function handleBaseMainView()
	{
		echo "handleBaseMainView";
	}
}
?>