<?php
class OS_AppDeveloperOperations
{
	private static $_instance;
	
	protected function __construct()
	{
	}	

	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_AppDeveloperOperations();
		}
		return self::$_instance;
	}
	
	public function getApps()
	{
		$result=false;
		
		$db=getOS()->getDb();
		$user=getOS()->getUser();
		
		$query="SELECT * FROM ".$db->dbPrefix()."apps_devs WHERE user_id=?";
		$dbresult=$db->query($query,array($user->id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneApp=new OS_AppDeveloper();
			$oneApp->set($row);
			
			$result[$row['id']]=$oneApp;
		}
		
		return $result;
	}
	
	public function getAppByID($app_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$user=getOS()->getUser();
		
		$query="SELECT * FROM ".$db->dbPrefix()."apps_devs WHERE id=? AND user_id=?";
		$dbresult=$db->query($query,array($app_id,$user->id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_AppDeveloper();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getAppByName($app)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."apps_devs WHERE name=?";
		$dbresult=$db->query($query,array($app));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_AppDeveloper();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function insertApp($app)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$time = $db->DBTimeStamp(time());
		$ip=getOS()->getRemoteAddr();
		$user_id=getOS()->getUser()->id;
		
		$query="INSERT INTO ".$db->dbPrefix()."apps_devs (user_id,name,title,description,version,webscope,category,insert_dt,insert_ip,insert_by,status,status_dt,status_ip,status_by) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		$dbresult=$db->query($query,array($user_id,$app->name,$app->title,$app->description,$app->version,$app->webscope,$app->category,$time,$ip,$user_id,'W',$time,$ip,$user_id));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateApp($app)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$time = $db->DBTimeStamp(time());
		$ip=(!empty($_SERVER['REMOTE_ADDR'])?$_SERVER['REMOTE_ADDR']:'0.0.0.0');
		$user_id=getOS()->getUser()->id;
		
		$query="UPDATE ".$db->dbPrefix()."apps_devs SET `title`=?,`description`=?,`version`=?,webscope=?,updates=updates+1,`update_dt`=?,`update_ip`=?,`update_by`=? WHERE `id`=?";
		$dbresult=$db->query($query,array($app->title,$app->description,$app->version,$app->webscope,$time,$ip,$user_id,$app->id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteApp($app)
	{
		$result=false;
		
		$app_path=$this->getAppPath($app);
		
		if (file_exists($app_path))
		{
			$OS=getOS();
			
			$utils=$OS->getUtils();
			
			if ($utils->removeDir($app_path))
			{
				$db=$OS->getDb();
				
				$user_id=$OS->getUser()->id;
				
				$query="DELETE FROM ".$db->dbPrefix()."apps_devs WHERE id=? AND user_id=?";
				$dbresult=$db->query($query,array($app->id,$user_id));
				
				if ($dbresult!==false)
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public function packAppDev($app)
	{
		$result=false;
		
		$app_path=$this->getAppDevPath($app);
		
		if (file_exists($app_path))
		{
			$utils=getOS()->getUtils();
			
			$temp_path=$utils->getTempFile('tar.gz');
			
			if ($utils->createArchive($app_path,$temp_path,$app_path))
			{
				$result=$temp_path;
			}
		}
		
		return $temp_path;
	}
	
	public function markAppAsFinished($app)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$time = $db->DBTimeStamp(time());
		$ip=(!empty($_SERVER['REMOTE_ADDR'])?$_SERVER['REMOTE_ADDR']:'0.0.0.0');
		$user_id=getOS()->getUser()->id;
		
		$query="UPDATE ".$db->dbPrefix()."apps_devs SET status=?,status_dt=?,status_ip=?,status_by=? WHERE id=?";
		$dbresult=$db->query($query,array('F',$time,$ip,$user_id,$app->id));
		
		if ($dbresult!==false)
		{
			$appProposed=getOS()->getAppProposed();
			
			$proposedVars=get_object_vars($app);
			unset($proposedVars['id']);
			
			$appProposed->set($proposedVars);
			
			if ($appProposed->save())
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function markAppAsWork($app)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$time = $db->DBTimeStamp(time());
		$ip=(!empty($_SERVER['REMOTE_ADDR'])?$_SERVER['REMOTE_ADDR']:'0.0.0.0');
		$user_id=getOS()->getUser()->id;
		
		$query="UPDATE ".$db->dbPrefix()."apps_devs SET status=?,status_dt=?,status_ip=?,status_by=? WHERE id=?";
		$dbresult=$db->query($query,array('W',$time,$ip,$user_id,$app->id));
		
		if ($dbresult!==false)
		{
			$appProposed=getOS()->getAppProposed();
			
			$appProposed->name=$app->name;
			
			if ($appProposed->loadByName())
			{
				$result=$appProposed->delete();
			}
			else
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function createAppStructure($app)
	{
		$app_builds_path=$this->getAppBuildsPath($app);
		$app_dev_path=$this->getAppDevPath($app);
		
		mkdir($app_builds_path,0755,true);
		mkdir($app_dev_path,0755,true);
		
		$OS=getOS();		
		$utils=$OS->getUtils();
		
		$sample_app_path=os_join_path($OS->getConfigVar('root_path'),'developers','resources','sampleApp');
		
		if ($utils->copyDir($sample_app_path,$app_dev_path))
		{
			//Change #app_name# to actual name in init.php
			$script_path=os_join_path($app_dev_path,'app','init.php');
			$utils->fileWrite($script_path,str_replace('#app_name#',$app->name,$utils->fileRead($script_path)));
			
			//Change #app_name# to actual name in manage.php
			$script_path=os_join_path($app_dev_path,'manage','manage.php');
			$utils->fileWrite($script_path,str_replace('#app_name#',$app->name,$utils->fileRead($script_path)));
			
			//Manifest
			$this->updateAppManifest($app);
		}
	}
	
	public function updateAppManifest($app)
	{
		$this->syncAppVersion($app);
		
		$app_dev_path=$this->getAppDevPath($app);
		
		$manifest=array(
			'details'=>array(
				'name'=>$app->name,
				'title'=>$app->title,
				'description'=>$app->description,
				'category'=>$app->category,
				'version'=>$app->version,
				'webscope'=>$app->webscope
			),
			'requirements'=>array(
				'os_min_version'=>'0.1.0' //TODO: should be set by user
			)
		);
		
		getOS()->getUtils()->confWrite(os_join_path($app_dev_path,'osManifest.ini'),$manifest);
	}
	
	public function syncAppVersion(&$app)
	{
		$result=false;
		
		$manifest_path=os_join_path($this->getAppDevPath($app),'osManifest.ini');
		
		if (file_exists($manifest_path))
		{
			$OS=getOS();
			
			$utils=$OS->getUtils();
			
			$manifest=$utils->confRead($manifest_path);
			
			if (version_compare($app->version,$manifest['details']['version'])==1)
			{
				$manifest['details']['version']=$app->version;
				
				$result=$utils->confWrite($manifest_path,$manifest);
			}
			elseif (version_compare($app->version,$manifest['details']['version'])==-1)
			{
				$app->version=$manifest['details']['version'];
				
				if ($app->save())
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public function increaseAppBuildVersion($app)
	{
		$result=false;
		
		$version=explode('.',$app->version);
		
		while (count($version)<3)
		{
			$version[]=0;
		}
		
		$version[2]++;
		
		$version=implode('.',$version);
		
		$app->version=$version;
		
		$result=$app->save();
		
		return $result;
	}
	
	public function createAppBuild($app)
	{
		$result=false;
		
		$this->buildSqlSchemaFile($app);
		
		$app_path=$this->getAppDevPath($app);
		
		$build_path=$this->getAppBuildPath($app);
		
		$utils=getOS()->getUtils();
		
		touch($build_path);
		
		if ($utils->createArchive($app_path,$build_path,$app_path))
		{
			$result=true;
		}
		else
		{
			unlink($build_path);
		}
		
		$this->increaseAppBuildVersion($app);
		
		return $result;
	}
	
	public function buildSqlSchemaFile($app)
	{
		$schema_path=os_join_path($this->getAppDevPath($app),'manage','sql_schema.php');
		
		$utils=getOS()->getUtils();
		$dbOps=getOS()->getDbOps();
		
		$schema=$dbOps->getAppTablesFull($app->name);
		
		$utils->jsonWrite($schema_path,$utils->jsonify($schema));
	}
	
	public function getAppBuilds($app)
	{
		$result=false;
		
		$builds_path=$this->getAppBuildsPath($app);
		
		if (file_exists($builds_path))
		{
			$builds=glob(os_join_path($builds_path,'*.tar.gz'));
			
			if (!empty($builds))
			{
				foreach ($builds as $build)
				{
					$file=basename($build);
					
					$version=str_replace(array($app->name.'-','.tar.gz'),'',$build);
					
					$result[$version]=$file;
				}
			}
		}
		
		return $result;
	}
	
	public function getAppPath($app)
	{
		$user_id=str_pad(getOS()->getUser()->id,3,'0',STR_PAD_LEFT);
		
		return os_join_path(getOS()->getConfigVar('storage_path'),'users',$user_id[0],$user_id[1],$user_id[2],$user_id,'dev_apps',$app->name);
	}
	
	public function getAppBuildsPath($app)
	{
		return os_join_path($this->getAppPath($app),'builds');
	}
	
	public function getAppBuildPath($app,$version=false)
	{
		if (!$version)
		{
			$version=$app->version;
		}
		
		return os_join_path($this->getAppBuildsPath($app),$app->name.'-'.$version.'.tar.gz');
	}
	
	public function getAppDevPath($app)
	{
		return os_join_path($this->getAppPath($app),'dev');
	}
}
?>