<?php
class OS_AppHandler
{
	private static $_instance;
	private $_app;
	
	public $id;
	public $app_id;
	public $name;
	public $title;
	public $status;
	public $settings;
	public $position;
	
	public function __construct()
	{
		$this->setInitialValues();
	}
	
	public function setInitialValues()
	{
		$this->id=false;
		$this->app_id='';
		$this->name='';
		$this->title='';
		$this->status='';
		$this->settings=array();
	}
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_AppHandler();
		}
		return self::$_instance;
	}
	
	public function getAppURL()
	{
		if (!$this->id || !$this->name) return false;
		
		return getOS()->getConfigVar('root_url').'/apps/'.$this->name;
	}
	
	public function getAppUserPath($user_id=false)
	{
		$result=false;
		
		if (!$user_id)
		{
			$user=getOS()->getUser();
			
			if ($user->id > -1)
			{
				$user_id=$user->id;
			}
		}
		
		if ($user_id)
		{
			$user_id=str_pad($user_id,3,'0',STR_PAD_LEFT);
			$result=os_join_path(getOS()->getConfigVar('storage_path'),'users',$user_id[0],$user_id[1],$user_id[2],$user_id,'apps',$this->name);
		}
		
		return $result;
	}
	
	public function getAppStoragePath()
	{
		return os_join_path(getOS()->getConfigVar('storage_path'),'apps',$this->name);
	}
	
	public function getAppCachePath()
	{
		return os_join_path(getOS()->getConfigVar('cache_path'),'apps',$this->name);
	}
	
	public function dbPrefix()
	{
		$db=getOS()->getDb();
		
		return $db->dbPrefix().'app_'.$this->name.'_';
	}
	
	public function set($app_data)
	{
		$result = false;
		
		$objVars = get_object_vars($this);
		
		foreach($objVars as $key=>$val)
		{
			if(isset($app_data[$key]))
			{
				$this->$key = $app_data[$key];
				$result = true;
			}
		}
		
		return $result;
	}
	
	public function load()
	{
		$result = false;
		
		if ($this->id)
		{
			$ops=getOS()->getAppHandlerOps();
			
			if ($app_data=$ops->getAppHandlerByID($this->id))
			{
				$this->set(get_object_vars($app_data));
				
				$this->loadSettings();
				
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function loadByName()
	{
		$result = false;
		
		if ($this->name)
		{
			$ops=getOS()->getAppHandlerOps();
			
			if ($app_data=$ops->getAppHandlerByAppName($this->name))
			{
				$this->set(get_object_vars($app_data));
				
				$this->loadSettings();
				
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function loadByAppID()
	{
		$result = false;
		
		if ($this->app_id)
		{
			$ops=getOS()->getAppHandlerOps();
			
			if ($app_data=$ops->getAppHandlerByAppID($this->app_id))
			{
				$this->set(get_object_vars($app_data));
				
				$this->loadSettings();
				
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function save()
	{
		$result=false;
		
		if ($this->id)
		{
			$ops=getOS()->getAppHandlerOps();
			
			if ($ops->saveAppHandler($this))
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function & getAppPlugin()
	{
		$result=false;
		$load=false;
		
		if (!$this->_app)
		{
			$ops=getOS()->getAppHandlerOps();
			
			if ($this->_app=$ops->getAppPluginByName($this))
			{
				$result=$this->_app;
				$load=true;
			}
		}
		else
		{
			$result=$this->_app;
		}
		
		if ($load)
		{
			$appOps=getOS()->getAppOps();
			
			if ($app=$appOps->getAppByName($this->name))
			{
				$this->app_id=$app->id;
			}
		}
		
		return $result;
	}
	
	public function unloadAppPlugin()
	{
		if ($this->_app)
		{
			$this->_app=false;
		}
	}
	
	public function processAppRequest()
	{
		$result=false;
		
		if ($this->status=='E')
		{
			$result=$this->_app->processRequest($this->getAppRequest());
		}
		
		return $result;
	}

	public function getAppRequest()
	{
		$appRequest=array('view'=>false,'params'=>false);
		
		$bulk=($_SERVER['REQUEST_METHOD']=='POST'?$_POST:$_GET);
		
		if (isset($bulk['app']))
		{
			unset($bulk['app']);
		}
		
		if (empty($bulk['view']))
		{
			if ($_SERVER['REQUEST_METHOD']=='POST' AND !empty($_GET['view']))
			{
				$appRequest['view']=$_GET['view'];
			}
		}
		else
		{
			$appRequest['view']=$bulk['view'];
			unset($bulk['view']);
		}
		
		if (!empty($bulk))
		{
			$appRequest['params']=$bulk;
		}
		
		return $appRequest;
	}
	
	public function saveSettings($settings)
	{
		$result=false;
		
		if ($this->id)
		{
			$settings=getOS()->getAppHandlerOps()->saveAppSettings($this,$settings);
			
			if ($settings!==false)
			{
				$this->settings=$settings;
				
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function loadSettings()
	{
		$result=false;
		
		if ($this->id)
		{
			if ($settings=getOS()->getAppHandlerOps()->getAppSettings($this))
			{
				$this->settings=$settings;
				
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function start($project_id,$user_id)
	{
		$result=false;

		if (!$this->id OR ($this->id AND $this->status!='E'))
		{
			$appHandlerOps=getOS()->getAppHandlerOps();

			if ($result=$appHandlerOps->startUserApp($this,$project_id,$user_id))	
			{
				$this->status='E';
			}
		}
		
		return $result;
	}
	
	public function stop($project_id,$user_id)
	{
		$result=false;
		
		if ($this->id AND $this->status!='D')
		{
			$appHandlerOps=getOS()->getAppHandlerOps();
		
			$result=$appHandlerOps->stopUserApp($this,$project_id,$user_id);
		}
		
		return $result;
	}
	
	public function remove($project_id,$user_id)
	{
		$result=false;
		
		if ($this->id)
		{
			$appHandlerOps=getOS()->getAppHandlerOps();
		
			$result=$appHandlerOps->removeUserApp($this,$project_id,$user_id);
		}
		
		return $result;
	}
	
	public function trackEvent($eventDetails)
	{
		//execute App track event function
		$result = $this->getAppPlugin()->trackEvent($eventDetails);
		
		return $result;
	}
}
?>