<?php
class OS_AppOperations
{
	private static $_instance;
	
	protected function __construct()
	{
	}	

	public static function &get_instance($app=false)
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_AppOperations();
		}
		return self::$_instance;
	}
	
	public function getAvailableApps()
	{
		$db=getOS()->getDb();
		$response=array();
		
		$result=$db->query("SELECT * FROM ".$db->dbPrefix()."apps");
		while ($row=$db->fetchRow($result))
		{
			$oneApp=new OS_App();
			$oneApp->set($row);
			
			$response[$row['id']]=$oneApp;
		}
		
		if (empty($response)) $response=false;
		
		return $response;
	}

	public function getAvailableAppsNames()
	{
		$db=getOS()->getDb();
		$result=false;
		
		$dbresult=$db->query("SELECT id,name FROM ".$db->dbPrefix()."apps");
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['id']]=$row['name'];
		}
		
		return $result;
	}
	
	public function getAvailableAppsDetails()
	{
		$db=getOS()->getDb();
		$result=false;
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."apps");
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['id']]=$row;
		}
		
		return $result;
	}
	
	public function getAppByName($app_name)
	{
		$db=getOS()->getDb();
		$result=false;
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."apps WHERE name=?",array($app_name));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_App();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getAvailableAppByID($app_id)
	{
		$db=getOS()->getDb();
		$result=false;
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."apps WHERE id=?",array($app_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_App();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getUninstalledApps()
	{
		$result=false;
		
		$apps_path=os_join_path(getOS()->getConfigVar('root_path'),'apps');
		
		$uninstalled=glob(os_join_path($apps_path,"*_uninstalled"));
		foreach ($uninstalled as $uninstalled_app_path)
		{
			$app_name=str_replace(array(os_join_path($apps_path,''),'_uninstalled'),'',$uninstalled_app_path);
			
			$result[$app_name]=$uninstalled_app_path;
		}
		
		return $result;
	}
	
	public function isUninstalledApp($app)
	{
		$result=false;
		
		$app_path=$this->getUninstalledAppPath($app);
		
		return file_exists($app_path);
	}
	
	public function getUninstalledAppPath($app)
	{
		return os_join_path(getOS()->getConfigVar('root_path'),'apps',$app.'_uninstalled');
	}
	
	public function removeUninstalledApp($app)
	{
		$result=false;
		
		$app_path=$this->getUninstalledAppPath($app);
		
		if (file_exists($app_path))
		{
			$result=getOS()->getUtils()->removeDir($app_path);
		}
		
		return $result;
	}
	
	public function isAvailableApp($app_id)
	{
		$result=false;
		
		$apps=$this->getAvailableApps();
		if (isset($apps[$app_id]) AND $apps[$app_id]->status=='E')
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function isProjectApp($project_id,$app_id)
	{
		$result=false;

		$apps=$this->getAppsByProjectID($project_id);
		
		if (in_array($app_id,$apps))
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteAppByID($app_id)
	{
		$result=false;
		
		if ($this->isAvailableApp($app_id))
		{
			$db=getOS()->getDb();
			
			$dbresult=$db->query("DELETE FROM ".$db->dbPrefix()."apps WHERE id=?",array($app_id));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function insertApp($app)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$time = $db->DBTimeStamp(time());
		$ip=(!empty($_SERVER['REMOTE_ADDR'])?$_SERVER['REMOTE_ADDR']:'0.0.0.0');
		$user_id = getOS()->getUser()->id;
		
		if(is_null($user_id))
		{ 
			$user_id = -1;
		}
		
		if(is_null($app->install_time_ms))
		{
			$app->install_time_ms = 0;
		} 
		
		$query="INSERT INTO ".$db->dbPrefix()."apps (name,title,description,version,category,manifest,insert_dt,insert_ip,insert_by,install_time_ms,status,status_dt,status_ip,status_by) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		$dbresult=$db->query($query,array($app->name,$app->title,$app->description,$app->version,$app->category,$app->manifest,$time,$ip,$user_id,$app->install_time_ms,'E',$time,$ip,$user_id));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateApp($app)
	{
		$result = false;
		
		$db = getOS()->getDb();
		
		//check for app conflict
		$query = "SELECT id FROM ".$db->dbPrefix()."apps WHERE `name` = ? AND `id` != ?";
		$results =  $db->query($query,array($app->name,$app->id));
		if( $db->fetchRow($results) !== false) return $result;
		
		//get user data from database
		$oldApp = $this->getAppByName($app->name);
		
		if($oldApp !== false)
		{
			//add new details to app object
			$appDetails = get_object_vars($app); 
			$oldApp->set($appDetails);
			
			$time = $db->DBTimeStamp(time());
			$ip=(!empty($_SERVER['REMOTE_ADDR'])?$_SERVER['REMOTE_ADDR']:'0.0.0.0');
			$user_id = getOS()->getUser()->id;
			
			if(is_null($user_id))
			{
				$user_id = -1;
			}
			
			if(is_null($app->install_time_ms))
			{
				$app->install_time_ms = 0;
			} 
			
			$query = "UPDATE ".$db->dbPrefix()."apps SET `title`=?, `description`=?, `version`=?, `category`=?, `manifest`=?, `install_time_ms`=?, updates=updates+1,`update_dt`=?,`update_ip`=?,`update_by`=? WHERE `id`=?";
			$dbresult = $db->query($query,array($oldApp->title,$oldApp->description,$oldApp->version,$oldApp->category,$oldApp->manifest,$app->install_time_ms, $time,$ip,$user_id,$oldApp->id));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function updateAppStoreApp($appName)
	{
		$OS = getOS();
		$result = false;
		$responseData = array('notifications' => array(),'tests' => array());
			
		//get apps handler operations
		$osAppStore = $OS->getAppStoreApi();
		
		//here should get info from appstore api
		$asResponse = $osAppStore->getAppDetails(array('app_name'=>$appName));
		if(!$osAppStore->success)
		{
			$responseData['notifications'][] = array('type'=>'error', 'message'=>_("App not found in AppStore"));
		}
		else
		{
			$appDetails = $asResponse['app']; 
			
			if(!isset($asResponse['app']))
			{
				$responseData['notifications'][] = array('type'=>'error', 'message'=>_("AppStore data invalid"));	
			}
			else
			{
				$oneApp = $this->getAppByName($appName);
				if($oneApp === false)
				{
					$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Application is not installed on this system"));
				}
				else
				{
					//a comparison with the local version is required here
					if(!$oneApp->requireUpdate($appDetails['version']))
					{
						$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Installed App has the newest version"));	
					}
					else
					{
						//here should get info from appstore api
						$asResponse2 = $osAppStore->getAppDownloadUrl(array('app_name'=>$appName));
						if(!$osAppStore->success)
						{
							$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Application cannot be downloaded [1]"));	
						}
						else
						{
							if(!isset($asResponse2['download_url']))
							{
								$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Application cannot be downloaded [2]"));
							}
							else
							{
								$extractResult = $this->getAppFromURL($asResponse2['download_url'], $appDetails['name']);
								
								$responseData = array_merge_recursive($responseData, $extractResult);
								
								if($extractResult['result'])
								{
									$installResult = $this->installAppFromPath($extractResult['appKitName']);
									
									$responseData = array_merge_recursive($responseData, $installResult);
									
									if($installResult['result'])
									{
										$result = true;
										$responseData['app_action'] = 'up2date';
										$responseData['notifications'][] = array('type'=>'success', 'message'=>_("Application succesfully updated"));
									}
									else
									{
										$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Application could not be updated"));
									}
								}
								else
								{
									$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Application could not be updated"));
								}
							}
						}
					}
				}
			}
		}	
		
		$responseData['result'] = $result;
			
		return $responseData;
	}
	
	
	public function installAppStoreApp($appName)
	{
		$OS = getOS();
		$result = false;
		$responseData = array('notifications' => array(),'tests' => array());
		
		//get apps handler operations
		$osAppStore = $OS->getAppStoreApi();
		
		//here should get info from appstore api
		$asResponse = $osAppStore->getAppDetails(array('app_name'=>$appName));
		if(!$osAppStore->success)
		{
			$responseData['notifications'][] = array('type'=>'error', 'message'=>_("App not found in AppStore"));
		}
		else
		{
			$appDetails = $asResponse['app']; 
			
			if(!isset($asResponse['app']))
			{
				$responseData['notifications'][] = array('type'=>'error', 'message'=>_("AppStore data invalid"));	
			}
			else
			{
				//here should get info from appstore api
				$asResponse2 = $osAppStore->getAppDownloadUrl(array('app_name'=>$appName));
				if(!$osAppStore->success)
				{
					$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Application cannot be downloaded [1]"));	
				}
				else
				{
					if(!isset($asResponse2['download_url']))
					{
						$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Application cannot be downloaded [2]"));
					}
					else
					{
						$extractResult = $this->getAppFromURL($asResponse2['download_url'], $appDetails['name']);
						
						$responseData = array_merge_recursive($responseData, $extractResult);
						
						if($extractResult['result'])
						{
							$installResult = $this->installAppFromPath($extractResult['appKitName']);
							
							$responseData = array_merge_recursive($responseData, $installResult);
							$responseData['installResult'] = $installResult;
							
							if($installResult['result'])
							{
								$result = true;
								$responseData['app_action'] = 'up2date';
								$responseData['notifications'][] = array('type'=>'success', 'message'=>_("App succesfully installed"));
							}
							else
							{
								$responseData['notifications'][] = array('type'=>'error', 'message'=>_("App cannot be installed [1]"));
								$responseData['modelDetails']['install_tests'] = $extractResult['tests'];
							}
						}
						else
						{
							$responseData['notifications'][] = array('type'=>'error', 'message'=>_("App cannot be installed [2]"));
							$responseData['modelDetails']['download_tests'] = $extractResult['tests'];
						}
					}
				}
			}
		}	
		
		$responseData['result'] = $result;
			
		return $responseData;
	}	
	
	
	public function extractAppFromArchive($app_archive,$app_kit_name)
	{
		$OS = getOS();
		$utils = $OS->getUtils();
		
		$result = false;
		
		$responseData = array('tests'=>array(), 'notifications'=>array());
		
		$app_temp_path = $utils->getTempDir();
		
		$tmpTest = array('test'=>array('message'=>_('Unpack App Kit')), 'result' => array('type' => 'success'));
		
		//extract appkit from archive
		$extractArchiveResult = false;
		try{$extractArchiveResult = $utils->extractArchive($app_archive, $app_temp_path);}
		catch(Exception $e) {$tmpTest['result'] = array('type'=>'error', 'message'=> var_export($e, true));}
				
		$responseData['tests'][] = $tmpTest;
		
		if($extractArchiveResult !== false)
		{
			$app_kit_final_path = os_join_path($OS->getConfigVar('root_path'),'apps', $app_kit_name);

			$moveDirResult = $utils->moveDir($app_temp_path,$app_kit_final_path);
			
			$tmpTest = array('test'=>array('message'=>_('Move App Kit')));
			if($moveDirResult === false)
			{
				$tmpTest['result'] = array('type' => 'error', 'message'=> _('Unable to move application to the apps folder'));	
			}
			elseif(!is_dir($app_kit_final_path))
			{
				$tmpTest['result'] = array('type' => 'error', 'message'=> _('Unable to move application to the apps folder'));
			}
			else
			{
				$tmpTest['result'] = array('type' => 'success');
				$result = true;
			}
			
			$responseData['tests'][] = $tmpTest;
		}
		
		$unlinkResult = unlink($app_archive);
		
		
		$tmpTest = array('test'=>array('message'=>_('Cleaning up')));
		if(!$unlinkResult) $tmpTest['result'] = array('type' => 'warning', 'message'=>_('Cannot delete app archive'));
		else $tmpTest['result'] = array('type' => 'success');
		$responseData['tests'][] = $tmpTest;
		
		$responseData['result'] = $result;
		
		return $responseData;
	}
	
	//get apps ids links by Project ID
	public function getAppsByProjectID($project_id)
	{
		$result =  array();
		
		if($project_id >= 1)
		{
			$db = getOS()->getDb();
			
			$query = "SELECT app_id FROM ".$db->dbPrefix()."apps_users WHERE `project_id`= ? GROUP BY app_id";
			$dbresult = $db->query($query,array($project_id));
			while($row = $db->fetchRow($dbresult))
			{
				$result[] = $row['app_id'];
			}
		}
		
		return $result;		
	}
	
	//get projects ids links by App ID
	public function getProjectsByAppID($app_id)
	{
		$result =  array();
		
		if($app_id >= 1)
		{
			$db = getOS()->getDb();
			
			$query = "SELECT project_id FROM ".$db->dbPrefix()."apps_users WHERE app_id=? GROUP BY project_id";
			$dbresult = $db->query($query,array($app_id));
			while($row = $db->fetchRow($dbresult))
			{
				$result[] = $row['project_id'];
			}
		}
		
		return $result;		
	}
	
	
	//install current app
	public function installApp($appKitPath)
	{
		$install_time_start = microtime(true);

		$OS = getOS();
		$result = false;
		
		$responseData = array('tests' => array(),'notifications' => array());
		
		$validateResult = $this->validateAppKit($appKitPath);
		
		$validationOK = $validateResult['result'];
		
		if(!empty($validateResult['tests']))
		{
			$responseData['tests'] = array_merge($responseData['tests'], $validateResult['tests']);
		}
		
		if($validationOK)
		{
			$appInfo = $this->buildAppInfo($appKitPath);
			
			$oneApp = new OS_App();
			$oneApp->set($appInfo['details']);
			$oneApp->manifest = json_encode($appInfo);
			
			//check if needs install or update
			if($testApp = $this->getAppByName($oneApp->name))
			{
				$oneApp->id = $testApp->id;
			}
			$appResult = $oneApp->save();  
			
			
			$tmpTests  = array();
			
			if($appResult == false)
			{
				$returnType = array('type'=>'error', 'message'=>_('Unable to install application'));
			}
			elseif(!$oneApp->isValid())
			{
				$returnType = array('type'=>'error', 'message'=>_('Application details are invalid'));
			}
			else
			{
				//sql sync tables
				$osDbOps = $OS->getDbOps();
				
				//get schema sql info
				$schemaPath = os_join_path($appKitPath, 'manage', 'sql_schema.php');
				
				$appSqlSyncResult = $osDbOps->syncAppTablesBySchema($schemaPath, $oneApp->name);
				
				if(!empty($appSqlSyncResult['tests']))
				{
					$tmpTests = array_merge($tmpTests, $appSqlSyncResult['tests']);

				}
				
				if(!$appSqlSyncResult['result'])
				{
					$returnType = array('type'=>'error', 'message'=>_('Cannot create App SQL Tables'));	
				}
				else
				{
					//move application to /apps/appname
					$appFilesPath = os_join_path($appKitPath,'app');
					$appFinalPath = os_join_path($OS->getConfigVar('root_path'),'apps',$oneApp->name);
					
					$osUtils = $OS->getUtils();
					$copyResult = $osUtils->copyDir($appFilesPath, $appFinalPath);
					
					if($copyResult == false)
					{
						$returnType = array('type'=>'error', 'message'=>_('Application cannot be moved to apps directory'));
					}
					else
					{
						$result = true;
						
						//check if this app uses jsTracker
						$appManifest = $oneApp->getManifest();
						if(isset($appManifest['details']['useJsTracker']))
						{
							if($appManifest['details']['useJsTracker'] == 1)
							{
								//take all projects and enable jsTracker for each of them
								$osProjectOps = $OS->getProjectOps();
								$osJsTracker = $OS->getJsTracker();
								
								$osAvailableProjects = $osProjectOps->getProjects();
								
								if(!empty($osAvailableProjects))
								{
									foreach($osAvailableProjects as $oneProject)
									{
										$osJsTracker->createTrackerLink($oneApp, $oneProject->id);
									}
								}
							}
						}
						
						
						//run app developer custom functions 
						$appInstallPath = os_join_path($appKitPath, 'manage', 'manage.php');
						if (file_exists($appInstallPath))
						{
							include_once($appInstallPath);
							
							$installClassName = "OS_APP_".$oneApp->name."_manage";
							 
							$strtolowerClass = strtolower($installClassName);
							
							if(class_exists($strtolowerClass) )
							{
								$installClass = new $strtolowerClass;
								
								if(method_exists($installClass, 'run'))
								{
									$resultInstall = $installClass->run();
									
									$result = true;
									
									if (!empty($resultInstall))
									{
										if(isset($resultInstall['tests']))
										{
											$tmpTests = array_merge($tmpTests, $resultInstall['tests']);
										}
										
										if (!empty($resultInstall['actions']))
										{
											$actions=$resultInstall['actions'];
											
											if (!empty($actions['crons']))
											{
												foreach ($actions['crons'] as $cron)
												{
													OS_Crons::registerCron($cron['action'],$cron['interval'],'app',$oneApp->name,$cron['title']);
												}
											}
											
											if (!empty($actions['daemons']))
											{
												foreach ($actions['daemons'] as $daemon)
												{
													OS_Daemons::registerDaemon($daemon['action'],'app',$oneApp->name,$daemon['title']);
												}
											}
											
											if (!empty($actions['events']))
											{
												foreach ($actions['events'] as $event)
												{
													OS_Events::createEvent($event['name'],'app',$oneApp->name);
												} 
											}
											
											if (!empty($actions['eventHandlers']))
											{
												foreach ($actions['eventHandlers'] as $eventHandler)
												{
													OS_Events::addEventHandler($eventHandler['event'],'app',$oneApp->name,$eventHandler['method']);
												}
											}
											
											if (!empty($actions['datasources']))
											{
												$ds = $OS->getDatasource();
												
												foreach ($actions['datasources'] as $datasource)
												{
													$ds->setInitialValues();
													
													$ds->name=$datasource['name'];
													$ds->module='app';
													$ds->module_name=$oneApp->name;
													$ds->table=$datasource['table'];
													$ds->fields=$datasource['fields'];
													
													$ds->register();
												}
											}
											
											if (!empty($actions['interactions']))
											{
												foreach ($actions['interactions'] as $type=>$interactions)
												{
													foreach ($interactions as $interaction)
													{
														OS_Interactions::registerInteraction($type,$interaction['action'],$interaction['title'],'app',$oneApp->name,$oneApp->title,$interaction['method']);
													}
												}
											}
										}
									}
								}
							}	
						}
						
						//delete garbage _unistalled dir
						$deleteAppKitResult = $osUtils->removeDir($appKitPath);
						
						if($deleteAppKitResult === false)
						{
							$returnType = array('type'=>'error' , 'message' => _("Application Kit could not be deleted"));
						}
						else
						{
							$returnType = array('type'=>'success');	
						}					
					}
				}
			}
			
			$install_time_end = microtime(true);
			
			//calculate install time in miliseconds
			$install_time = ($install_time_end - $install_time_start) * 1000;
			
			if($result)
			{
				$appstore = $OS->getAppStoreApi();
				$appstore->installApp(array('app_name'=>$oneApp->name));
				
				$install_time_ms = (isset($oneApp->install_time_ms) ? $oneApp->install_time_ms : $install_time);
				
				//add app install_time (calculate average between past and current install time)
				$oneApp->install_time_ms = ($install_time_ms + $install_time)/2;
				$oneApp->save(); 
			}
			
			$responseData['tests'][] = array('test'=>array('message'=> _('Installing application')),'result'=> $returnType);
			
			if(!empty($tmpTests)) $responseData['tests'] = array_merge($responseData['tests'], $tmpTests);
		}	
		
		$responseData['result'] = $result;
		
		return $responseData;
	}
	
	public function linkInstalledApp($app_id)
	{
		$result=false;
		
		$user=$OS->getUser();
		if ($user->id)
		{
			$project=$OS->getProject();
			
			if ($project->selectedProject())
			{
				//TODO: add perms
			}
		}
		
		return $result;
	}
	
	public function uninstallApp($appName)
	{
		$OS = getOS();
		
		$result = false;
		$responseData = array('tests' => array(), 'notifications' => array());
		
		$oneApp = $this->getAppByName($appName);
		$appIsValid = ($oneApp !== false);
		
		if($appIsValid) $returnType = array('type'=> 'success');
		else $returnType = array('type'=> 'error', 'message' => _("Application not found !"));
		$responseData['tests'][] = array('test'=>array('message'=> _('Test if App is installed')),'result'=> $returnType);
		
		if($appIsValid)
		{
			$db = $OS->getDb();
			
			$app_id = $oneApp->id;
			
			//check if this app uses jsTracker
			$appManifest = $oneApp->getManifest();
			if(isset($appManifest['details']['useJsTracker']))
			{
				if($appManifest['details']['useJsTracker'] == 1)
				{
					//take all projects and disable jsTracker for each of them
					$osProjectOps = $OS->getProjectOps();
					$osJsTracker = $OS->getJsTracker();
					
					$osAvailableProjects = $osProjectOps->getProjects();
					
					if(!empty($osAvailableProjects))
					{
						foreach($osAvailableProjects as $oneProject)
						{
							$osJsTracker->removeTrackerLink($oneApp->id, $oneProject->id);
						}
					}
				}
			}
			
			
			//find the users using the app
			$appHandler = $OS->getAppHandler();
			$appHandler->app_id = $app_id;
			$appHandler->name = $appName;
			
			$appHandlerOps=$OS->getAppHandlerOps();
			$user_ids=$appHandlerOps->getUsersByAppID($app_id);			
			
			//users and user settings
			$appHandlerOps->removeUsersAppByAppID($app_id);
			
			//available
			$this->deleteAppByID($app_id);
			
			//app stats
			$appStatsOps=$OS->getAppStatsOps();
			$appStatsOps->deleteAppStatsFull($app_id);
			
			//datasources
			$datasourceOps=$OS->getDatasourceOps();
			$datasourceOps->unregisterDatasourcesByModule('app', $appName);
			
			//permissions
			$permissionOps=$OS->getPermissionOps();
			$permissionOps->removePermissionsByModule($appName);
			
			//event handlers
			OS_Events::removeEventHandlersByModule('app', $appName);
			if ($events=OS_Events::getEventsByModule('app', $appName))
			{
				foreach ($events as $event_details)
				{
					OS_Events::removeAllEventHandlers($event_details['name']);
					OS_Events::removeEvent($event_details['name']);
				}
			}
			
			//interactions
			OS_Interactions::unregisterInteractionsByModule('app',$appName);
			
			//crons
			OS_Crons::unregisterCronsByModule('app',$appName);
			
			//app-specific uninstall handling
			$uninstall_script_file=os_join_path($OS->getConfigVar('root_path'),'apps', $appName, $appName.'_uninstall.php');
			if (file_exists($uninstall_script_file))
			{
				include($uninstall_script_file);
			}
			
			$utils=$OS->getUtils();
			
			//delete storage files
			$app_storage_path=$appHandler->getAppStoragePath();
			if (file_exists($app_storage_path))
			{
				$utils->removeDir($app_storage_path);
			}
			
			//delete user files
			foreach ($user_ids as $user_id)
			{
				$app_user_path=$appHandler->getAppUserPath($user_id);
				
				if (file_exists($app_user_path))
				{
					$utils->removeDir($app_user_path);
				}
			}
			
			//delete cache files
			$app_storage_path=$appHandler->getAppCachePath();
			if (file_exists($app_storage_path))
			{
				$utils->removeDir($app_storage_path);
			}
			
			//delete actual app files
			$app_storage_path=os_join_path($OS->getConfigVar('root_path'), 'apps', $appName);
			if (file_exists($app_storage_path))
			{
				$utils->removeDir($app_storage_path);
			}
			
			//delete sql tables
			$dbOps=$OS->getDbOps();
			if ($tables=$dbOps->getAppTables($appName))
			{
				foreach ($tables as $table)
				{
					$db->query("DROP TABLE `".$db->dbPrefix()."{$table}`");
				}
			}
			
			$result = true;
			
			if($result)
			{
				//notify appstore of uninstall
				$appstore = $OS->getAppStoreApi();
				$appstore->uninstallApp(array('app_name'=>$appName));
				$responseData['notifications'][] = array('type'=>'success', 'message'=>_("App succesfully uninstalled !"));
				$responseData['app_action'] = 'install';
			}
		}
		
		$responseData['result'] = $result;
		
		return $responseData;
	}
	
	public function validateAppKit($appKitPath)
	{
		$OS = getOS();
		
		$result = false;
		$responseData = array('tests' => array(),'notifications' => array());
		
		//test if application kit exists
		$appPathExists = (file_exists($appKitPath));
		
		if($appPathExists) $resultType = array('type'=>'success'); 
		else $resultType = array('type'=>'error', 'message'=>_('Application Kit not found'));
		$responseData['tests'][] = array('test'=>array('message'=>_('Check if Application Kit exists')),'result'=> $resultType);
		
		if($appPathExists)
		{
			//test if application has manifest file
			$manifestFilePath = os_join_path($appKitPath, 'osManifest.ini');
			
			$appManifestPathExists = (file_exists($manifestFilePath));
			if($appManifestPathExists) $resultType = array('type'=>'success'); 
			else $resultType = array('type'=>'error', 'message'=>_('Application Manifest not found'));
			$responseData['tests'][] = array('test'=>array('message'=>_('Check if Application Manifest file exists')),'result'=> $resultType);
			
			if($appManifestPathExists)
			{
				//test if manifest file is valid
				$appInfo = $this->buildAppInfo($appKitPath);
				
				//validate app manifest file
				$validateResult = $this->validateAppManifest($appInfo);
				$appManifestIsValid = $validateResult['result'];
				
				if(!empty($validateResult['tests']))
				{
					$responseData['tests'] = array_merge($responseData['tests'], $validateResult['tests']);
				}
				
				if($appManifestIsValid) $resultType = array('type' => 'success');
				$responseData['tests'][] = array('test'=>array('message'=>_('Check if Application Manifest file is valid')),'result'=> $resultType);
				
				
				if($appManifestIsValid)
				{
					//app version compare
					if($oneApp = $this->getAppByName($appInfo['details']['name']))
					{
						if ($oneApp->requireUpdate($appInfo['details']['version']))
						{
							$resultType = array('type'=>'info','message'=>_('Installed App has an older version (it will be updated)'), 'value'=> $appInfo['details']['version']);	
						}
						else 
						{
							$resultType = array('type'=>'info','message'=>_('Installed App has the newest version'), 'value'=> $appInfo['details']['version']);
						}
					}
					else
					{
						$resultType = array('type'=>'success', 'value'=> $appInfo['details']['version']);
					}
					
					$responseData['tests'][] = array('test'=>array('message'=>_('Check App version'), 'value'=> $appInfo['details']['version']), 'result' => $resultType);
		
					$appRequirementsResult = $this->checkAppRequirements($appInfo);
					
					$responseData['tests'] = array_merge($responseData['tests'], $appRequirementsResult['tests']);
					
					if ($appRequirementsResult['result'])
					{		
						//verify signature
						$appIsSigned = false;
				
						$appstore = $OS->getAppStoreApi();
						$response = $appstore->checkAppSignature(array('app_info'=>$appInfo,'signature'=>$this->generateAppSignature($appKitPath)));
						
						if ($appstore->success)
						{
							if ($response['appSigned'])
							{
								$appIsSigned=true;
							}
						}
						
						if($appIsSigned)
						{
							$resultType = array('type'=>'success');
						} 
						else
						{
							$resultType = array('type'=>'warning','message'=>_('Application signature invalid'));
						}
						
						$responseData['tests'][] = array('test'=>array('message'=>_('Checking Application signature')),'result'=> $resultType);
						
						
						//check install path
						$appInstallPath = os_join_path($appKitPath,'manage' , 'manage.php');
						
						$app_has_manage_file = (file_exists($appInstallPath));
						
						if($app_has_manage_file)
						{
							$resultType = array('type'=>'success');
						}
						else
						{
							$resultType = array('type'=>'error','message'=>_('Management file not found'));
						}
						$responseData['tests'][] = array('test'=>array('message'=>_("Checking app install management")),'result'=> $resultType);
						
						
						if($app_has_manage_file)
						{
							include_once($appInstallPath);
							
							$installClassName = "OS_APP_".$appInfo['details']['name']."_manage";
							 
							$lowerClassName = strtolower($installClassName);
							
							$checkClassExists = (class_exists($lowerClassName));
							if($checkClassExists) $returnType = array('type'=>'success');
							else $returnType = array('type'=>'error','message'=> sprintf(_('Class %s not found in %s'), $lowerClassName, $appInstallPath));
							$responseData['tests'][] = array('test'=>array('message'=>_("Loading application install class")),'result'=> $returnType);
							
							if($checkClassExists)
							{
								$installClass = new $lowerClassName;
								
								//also check if has run method
								$checkValidMetodExists = (method_exists($installClass, 'check'));
								if($checkValidMetodExists) $returnType = array('type'=>'success');
								else $returnType = array('type'=>'error','message'=> sprintf(_('Method %s not found in %s'), 'check', $lowerClassName));
								$responseData['tests'][] = array('test'=>array('message'=>_("Running application internal tests")),'result'=> $returnType);
								
								if($checkValidMetodExists)
								{
									$installResponse = $installClass->check();
									
									$result = true;
									
									if(!empty($installResponse))
									{
										if(is_array($installResponse))
										{
											if(isset($installResponse['tests']))
											{
												foreach($installResponse['tests'] as $test)
												{
													$responseData['tests'][] = $test;
												}
											}
										}
									}
								}
							}
						}
					}
				}
			}
		}				
		
		$responseData['result'] = $result;
		
		return $responseData;		
	}
	
	
	public function checkAppRequirements($appManifest)
	{
		$OS = getOS();
		$result = true;
		$responseData = array('tests'=> array(), 'notifications' => array());

		$tmpTest = array('test'=>array('message'=>_('Check if OpenS version is valid for application'), 'value'=> sprintf(_("Required %s"), $appManifest['requirements']['os_min_version'])));
		
		//Check OpenS version
		$osVersion = $OS->getVersion(); 
		if (empty($appManifest['requirements']['os_min_version']))
		{
			$tmpTest['result'] = array('type'=>'error','message'=>_('OpenS minimum required version missing in info file'), 'value'=> sprintf(_("You have %s"), $osVersion));
			$result = false;
		}
		elseif (version_compare($osVersion,$appManifest['requirements']['os_min_version']) < 0)
		{
			$tmpTest['result'] = array('type'=>'error','message'=>_('This application requires a newer version of OpenS'), 'value'=> sprintf(_("You have %s"), $osVersion));
			$result = false;
		}
		else
		{
			$tmpTest['result'] = array('type'=>'success', 'value'=> sprintf(_("You have %s"), $osVersion));
		}
		
		$responseData['tests'][] = $tmpTest;
			
		
		//Check App dependencies
		if (!empty($appManifest['dependencies']))
		{
			//$dependenciesOK = true;
			foreach ($appManifest['dependencies'] as $dep_app_name => $details)
			{
				if(is_array($details))
				{
					$dep_app_title = $details['title'];
					$dep_app_version = $details['version'];
				}
				else
				{
					$dep_app_title = ucfirst($dep_app_name);
					$dep_app_version = $details;
				}	
				
				$tmpTest = array('test'=>array('message'=>sprintf(_("Checking if `%s` is valid"), $dep_app_title), 'value'=> sprintf(_("Required %s"), $dep_app_version)));
				
				if (!$dep_app = $this->getAppByName($dep_app_name))
				{
					$tmpTest['result'] = array('type'=>'error','message'=>_('App not installed'), 'value' => _("Not Installed"));
					$result = false;
				}
				elseif ($dep_app->requireUpdate($dep_app_version))
				{
					$tmpTest['result'] = array('type'=>'error','message'=>_('App version too old, please update'), 'value' => sprintf(_("You Have %s"), $dep_app->version));
					$result = false;
				}
				else
				{
					$tmpTest['result'] = array('type'=>'success', 'value' => sprintf(_("You Have %s"), $dep_app->version));
				}
				
				$responseData['tests'][] = $tmpTest; 
			}
		}
		
		$responseData['result'] = $result;
		
		return $responseData;
	}
	
	public function validateAppManifest($appManifest)
	{
		$result = true;
		$responseData = array('tests' => array(),'notifications' => array()); 
		
		$manifestIsParsable = (is_array($appManifest)); 
		if($manifestIsParsable) $resutType= array('type'=>'success');
		else{
			$resutType = array('type'=>'error', 'message' =>_("Manifest data could not be parsed")); 
			$result = false;
			}  
		$responseData['tests'][] = array('test' => array('message'=>_('Try to parse Manifest')), 'result'=> $resutType);
		
		if($manifestIsParsable)
		{
			$manifestHasDetails = (isset($appManifest['details'])); 
			if(!$manifestHasDetails) 
			{
				$resutType= array('type'=>'error', 'message' =>_("App Details Not Found"));
				$result = false;
			}
			else
			{
				$appDetails = array('name','description','version','title','category');
				$flag = true;
				
				foreach($appDetails as $detail)
					if($flag) if(!isset($appManifest['details'][$detail]))
					{
						$resutType= array('type'=>'error', 'message' => sprintf(_("App Detail [%s] Not Found"), $detail));
						$flag = false; $result = false;
					}

				if($flag) $resutType = array('type'=>'success');
			}
			$responseData['tests'][] = array('test' => array('message'=>_('Check Manifest details')), 'result'=> $resutType);
			
			$manifestHasReqs = (isset($appManifest['requirements'])); 
			if(!$manifestHasReqs)
			{
				$resutType= array('type'=>'error', 'message' =>_("App Details Missing"));	
			} 
			else
			{
				$appReqs = array('os_min_version');
				$flag = true;
				
				foreach($appReqs as $req)
					if($flag) if(!isset($appManifest['requirements'][$req]))
					{
						$resutType= array('type'=>'error', 'message' => sprintf(_("App Requirement [%s] Not Found"), $req));
						$flag = false;$result = false;
					}

				if($flag) $resutType = array('type'=>'success');
				
				$resutType = array('type'=>'success');  
			}
			
			$responseData['tests'][] = array('test' => array('message' => _('Check Manifest requirements')), 'result'=> $resutType);
		}

		$responseData['result'] = $result;
		
		return $responseData;
	}	
		
	public function buildAppInfo($appPath)
	{
		$result = false;
		
		$infoFilePath = os_join_path($appPath, 'osManifest.ini');
		
		if(file_exists($infoFilePath))
		{
			$osUtils = getOS()->getUtils();
			
			$confData = $osUtils->confRead($infoFilePath);
			
			if($confData !== false)
			{
				$result = $confData;
			}
		}
		
		return $result;
	}
	
	public function generateAppSignature($appKitPath)
	{
		$result = false;
		
		if(file_exists($appKitPath))
		{
			$osUtils = getOS()->getUtils();
			
			$appFiles =$osUtils->getDir($appKitPath,'*',true);
			
			$filesize = 0; $md5 = '';
			foreach ($appFiles as $file)
			{
				if (is_file($file))
				{
					$filesize += filesize($file);
					$md5 .= md5_file($file);
				}
			}
			
			$result = array('key'=>md5($md5),'size'=>$filesize);
		}
		
		return $result;
	}
	
	public function getAppFromURL($downloadUrl, $archiveName = false) 
	{
		$result = false;
		$responseData = array('tests' => array(),'notifications' => array(), 'validationResult' => false);
		
		$OS = getOS();
		
		$validator = $OS->getValidator();
		
		$url = $downloadUrl;
		
		if (!$validator->is_url($url))
		{
			$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid App Install URL"));
		}
		else
		{
			$http = $OS->getHttp();
			
			$response = $http->get($url);
			
			if (empty($response))
			{
				$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Unable to download application from the provided link"));
			}
			else
			{
				$osUtils = $OS->getUtils();
				
				if($archiveName == false)
				{
					$appKitName = strtolower(str_replace('.tar.gz','_uninstalled',basename(parse_url($url,PHP_URL_PATH))));	
				}
				else
				{
					$appKitName = strtolower($archiveName.'_uninstalled');	
				}
				
				$archive_path = $osUtils->getTempFile('tar.gz');
				
				$responseData['appKitName'] = $appKitName;
				
				$writeResult = $osUtils->fileWrite($archive_path,$response);
				
				if($writeResult === false)
				{
					$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid archive [1]"));
				}
				elseif(!file_exists($archive_path))
				{
					$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid archive [2]"));
				}
				else
				{
					//unpack application kit
					
					$extractDetails = $this->extractAppFromArchive($archive_path,$appKitName);
			
					$responseData = array_merge_recursive($responseData, $extractDetails);
					
					if($extractDetails['result'])
					{
						$result = true;
						
						//verify app manifest file
						$appKitPath = os_join_path($OS->getConfigVar('root_path'),'apps',$appKitName);
						
						$validateKitResult = $this->validateAppKit($appKitPath);
						 
						$responseData = array_merge_recursive($responseData, $validateKitResult);	
						
						//get app manifest
						$appInfo = $this->buildAppInfo($appKitPath);
						if($appInfo !== false) if(isset($appInfo['details'])) $responseData['appInfo'] = $appInfo['details'];
						
						//check tests for errors
						$flag = true;
						if(isset($responseData['tests']))
						{
							foreach($responseData['tests'] as $test)
							{
								if(isset($test['result']['type']))
								{
									if($test['result']['type'] == 'error') $flag = false;
								}
							}
						}
						
						if($flag)
						{
							$responseData['validationResult'] = true;
						} 
					}	
				}	
			}
		}
		
		$responseData['result'] = $result; 
			
		return $responseData;
	}
	
	public function getAppFromUpload($uploadObj, $archiveName = false)
	{
		$result = false;
		$responseData = array('tests' => array(),'notifications' => array(), 'validationResult' => false);
		
		$OS = getOS();
		
		//verify upload OBJ
		if(!isset($uploadObj['name']))
		{
			$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid archive - Archive not found"));
		}
		else
		{
			$fileInfo = pathinfo($uploadObj['name']);
			
			if(!isset($fileInfo['extension']))
			{
				$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid Archive - Extension missing"));
			}
			elseif($fileInfo['extension'] != 'gz')
			{
				$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid Archive - Accepted only tar.gz archives"));
			}
			elseif(strpos($uploadObj['name'],'.tar.gz') == false)
			{
				$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid Archive - Accepted only tar.gz archives"));
			}
			else
			{
				//move uploaded filed file to tmpDir
				$osUtils = $OS->getUtils();
				
				if($archiveName == false)
				{
					$appKitName = strtolower(str_replace('.tar.gz','_uninstalled', $uploadObj['name']));	
				}
				else
				{
					$appKitName = strtolower($archiveName.'_uninstalled');	
				}
				
				$archive_path = $osUtils->getTempFile('tar.gz');
				
				$responseData['appKitName'] = $appKitName;
				
				$uploadResult = move_uploaded_file($uploadObj['tmp_name'], $archive_path);
				
				if($uploadResult === false)
				{
					$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid archive - File cannot be uploaded"));
				}
				elseif(!file_exists($archive_path))
				{
					$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid archive - File cannot be uploaded"));
				}
				else
				{
					//unpack application kit
					
					$extractDetails = $this->extractAppFromArchive($archive_path,$appKitName);
			
					$responseData = array_merge($responseData, $extractDetails);
					
					if($extractDetails['result'])
					{
						$result = true; 
						
						$appKitPath = os_join_path($OS->getConfigVar('root_path'),'apps',$appKitName);
						
						//verify app manifest file
						$validateKitResult = $this->validateAppKit($appKitPath);
						 
						$responseData = array_merge($responseData, $validateKitResult);	
						
						//get app manifest
						$appInfo = $this->buildAppInfo($appKitPath);
						if($appInfo !== false) if(isset($appInfo['details'])) $responseData['appInfo'] = $appInfo['details'];
						
						//check tests for errors
						$flag = true;
						if(isset($responseData['tests']))
						{
							foreach($responseData['tests'] as $test)
							{
								if(isset($test['result']['type']))
								{
									if($test['result']['type'] == 'error') $flag = false;
								}
							}
						}
						
						if($flag)
						{
							$responseData['validationResult'] = true;
						} 
					}	
				}			
			}
		}
		
		$responseData['result'] = $result;
			
		return $responseData;	
	}
	
	public function installAppFromPath($appKitName)
	{
		$result = false;
		$responseData = array('tests' => array(),'notifications' => array());
		
		if(!empty($appKitName))
		{
			$OS = getOS();
			
			$appKitPath = os_join_path($OS->getConfigVar('root_path'),'apps',$appKitName); 
			
			$installAppResult = $this->installApp($appKitPath);
			
			$result = $installAppResult['result'];
			$responseData['tests'] = $installAppResult['tests'];
		}
		
		$responseData['result'] = $result;
		
		return $responseData;
	}		
	
}
?>