<?php
class OS_AppStoreApi
{
	private static $_instance;
	
	private $apiUrl='http://opens.org/prod/osapi/api/';
	
	private $ip;
	private $apiUser;
	private $apiKey;
	private $bulkResponse;

	private $failMessage;
	private $errData; 

	public $success;
	
	public  $status;
	
	public function __construct()
	{
		$this->setApiCredentials();
		
		$this->setInitialValues();
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_AppStoreApi();
		}
		
		return self::$_instance;
	}
	
	public function setInitialValues()
	{
		$this->bulkResponse = false;
		
		$this->status = 'FAIL';
		$this->success = false;
		$this->errData = false;
		$this->failMessage = array('message'=>_("System not available for the moment. Please try again later."),'code'=>"500");
	}
	
	public function setApiCredentials()
	{
		$OS=getOS();
		
		$this->apiUser=$OS->getSettingsVar('osc_user'); //TODO: key for os.com user
		$this->apiKey=$OS->getSettingsVar('osc_api_key'); //TODO: key for os.com apikey
	}
	
	public function __call($methodName,$arguments=false) 
	{
	    if(!$arguments)
	    {
	    	$arguments=array();
	    }
	    
	    $this->setInitialValues();
	    
		$this->ip=getOS()->getRemoteAddr();
		
		if (!isset($arguments[0]))
		{
			$arguments[0]=array();
		}
		
		$requestArr=array('method'=>$methodName,'params'=>$arguments[0]);
		$jsonRequest=json_encode($requestArr);
	 	$signature = md5(md5($jsonRequest.$this->apiKey).$this->apiKey);
		$headers=array("Content-Type: text/xml","X-Username: {$this->apiUser}","X-Signature: {$signature}","X-Remote-Ip: {$this->ip}");
		
		$http=getOS()->getHttp();
		$http->setHeaders($headers);
		
		$appstoreResponse=$http->post($this->apiUrl,gzcompress($jsonRequest,9));
		
		if(!empty($appstoreResponse))
		{
			if ($json_response = @gzuncompress($appstoreResponse))
			{
				$jsonObj = json_decode($json_response,true);
				
				if(isset($jsonObj['status']))
				{
					$this->status = $jsonObj['status']; 
					$this->bulkResponse=$jsonObj;
					
					if ($jsonObj['status']=='ERROR')
					{
						$this->setErrorMessage();
					}
					elseif ($jsonObj['status']=='OK')
					{
						$this->success=true;
						
						return $jsonObj['response'];	
					}
				}
			}
		}
		
		if($this->status == 'FAIL')
		{
			$this->setFailMessage();
		}
		else
		{
			return array('error' => $this->getError());
		}
	}
	
	private function setErrorMessage()
	{
		if (!$this->bulkResponse) return false;
		elseif ($this->bulkResponse['status']!='ERROR') return false;
		else
		{
			$this->errData = array('message'=>$this->bulkResponse['error_msg'],'code'=>$this->bulkResponse['error_code']);
			return true;
		}
	}
	
	public function setFailMessage()
	{
		if(!isset($this->failMessage)) return false;
		else
		{
			$this->errData = $this->failMessage;
			return true;
		}
	}
	
	public function getError()
	{
		return $this->errData;
	}
}
?>