<?php
class OS_AuditOperations
{
	private static $_instance;
	
	public function __construct()
	{
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_AuditOperations();
		}
		
		return self::$_instance;
	}
	
	public function getAuditByID($audit_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."audit WHERE id=?";
		$dbresult=$db->query($query,array($audit_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_Audit();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getAuditByTypeMessageHour($type,$message,$hour)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."audit WHERE type=? AND message=? AND hour=?";
		$dbresult=$db->query($query,array($type,$message,$hour));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_Audit();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getAudits($start_dt=false,$end_dt=false)
	{
		$result=false;
		
		if (!$start_dt)
		{
			$start_dt=date('Y-m-d 00:00',time());
		}
		
		if (!$end_dt)
		{
			$end_dt=date('Y-m-d 23:59',strtotime($start_dt));
		}
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."audit WHERE hour>=? AND hour<=? ORDER BY last_dt DESC";
		$dbresult=$db->query($query,array($start_dt,$end_dt));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneAudit=new OS_Audit();
			$oneAudit->set($row);
			
			$result[$row['id']]=$oneAudit;
		}
		
		return $result;
	}
	
	public function insertAudit($audit)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="INSERT INTO ".$db->dbPrefix()."audit (type,message,occurances,last_dt,`hour`) VALUES (?,?,?,?,?)";
		$dbresult=$db->query($query,array($audit->type,$audit->message,$audit->occurances,$audit->last_dt,$audit->hour));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateAudit($audit)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="UPDATE ".$db->dbPrefix()."audit SET occurances=?,last_dt=? WHERE id=?";
		$dbresult=$db->query($query,array($audit->occurances,$audit->last_dt,$audit->id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function getAuditDetails($audit)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."audit_details WHERE audit_id=? ORDER BY insert_dt DESC";
		$dbresult=$db->query($query,array($audit->id));
		while ($row=$db->fetchRow($dbresult))
		{
			$row['vars']=json_decode($row['vars'],true);
			
			$result[$row['id']]=$row;
		}
		
		return $result;
	}
	
	public function saveAuditDetails($audit,$details)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		foreach ($details as $detail)
		{
			$query="INSERT INTO ".$db->dbPrefix()."audit_details (audit_id,`vars`,insert_dt) VALUES (?,?,?)";
			
			$dbresult=$db->query($query,array($audit->id,json_encode($detail['vars']),$detail['insert_dt']));
			
			if ($dbresult===false)
			{
				$result=false;
			}
		}
		
		return $result;
	}
	
	public function logAudit($message,$vars=array())
	{
		return $this->log('A',$message,$vars);
	}
	
	public function logError($message,$vars=array())
	{
		return $this->log('E',$message,$vars);
	}
	
	public function eventAudit($params)
	{
		return $this->logAudit(_("Event")." `{$params['_event']}` "._("has been triggered"),$params);
	}
	
	private function log($type,$message,$vars=array())
	{
		$result=false;
		return false;//TODO: remove
		$path=$this->getLogPath();
		
		if (!is_dir($path['dir']))
		{
			$is_dir=@mkdir($path['dir'],0777,true);
		}
		else
		{
			$is_dir=true;
		}
		
		if ($is_dir)
		{
			$path=os_join_path($path['dir'],$path['file']);
			
			if ($file=fopen($path,'a+'))
			{
				$line="{$type}|".time()."|{$message}|".json_encode($vars)."\n";
				
				fwrite($file,$line);
				
				fclose($file);
				
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function getLogPath()
	{
		$dir=os_join_path(getOS()->getConfigVar('cache_path'),'audit_buffer');
		
		$file=floor(time()/3600).'.php';
		
		return array('dir'=>$dir,'file'=>$file);
	}
	
	public function bufferToSql()
	{
		$path=$this->getLogPath();
		
		$logs=glob(os_join_path($path['dir'],'*.php'));
		
		$current_log=floor(time()/3600);
		
		$messages=array();
		
		$db=getOS()->getDb();
		
		foreach ($logs as $log)
		{
			$logname=basename($log,'.php');
			
			if ((int)$logname<$current_log)
			{
				rename($log,$log.'.old');
				$log.='.old';
				
				if ($log_handler=fopen($log,'r'))
				{
					while (!feof($log_handler))
					{
						if ($line=fgets($log_handler))
						{
							$line=explode('|',$line);

							$message=$line[2];
							$message_hour=date('Y-m-d H:00',$line[1]);
							
							if (!isset($messages[$message_hour][$message]))
							{
								$oneAudit=$this->getAuditByTypeMessageHour($line[0],$message,$message_hour);
								
								if (!$oneAudit)
								{
									$oneAudit=new OS_Audit();
									
									$oneAudit->type=$line[0];
									$oneAudit->hour=$message_hour;
									$oneAudit->message=$message;
									$oneAudit->occurances=0;
								}
								
								$messages[$message_hour][$message]=array('object'=>$oneAudit,'details'=>array());
							}
							
							$insert_dt=date('Y-m-d H:i:s',$line[1]);
							
							$messages[$message_hour][$message]['object']->occurances++;
							$messages[$message_hour][$message]['object']->last_dt=$insert_dt;
							
							$messages[$message_hour][$message]['details'][]=array('vars'=>json_decode($line[3],true),'insert_dt'=>$insert_dt);
						}
					}
					
					fclose($log_handler);
				}
			}
		}
		
		$db->query("LOCK TABLES ".$db->dbPrefix()."audit WRITE");
		foreach ($messages as $hour=>$hour_messages)
		{
			foreach ($hour_messages as $message=>$details)
			{
				$messages[$hour][$message]['object']->save();
			}
		}
		$db->query("UNLOCK TABLES");
		
		$db->query("LOCK TABLES ".$db->dbPrefix()."audit_details WRITE");
		foreach ($messages as $hour=>$hour_messages)
		{
			foreach ($hour_messages as $message=>$details)
			{
				$messages[$hour][$message]['object']->saveDetails($details['details']);
			}
		}
		$db->query("UNLOCK TABLES");
	}
}
?>