<?php
class OS_Backlinks
{
	private static $_instance;
	
	private $engines;
	
	private $defaultCacheValidity=2592000;
	
	public function __construct()
	{
		$this->engines=array();
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_Backlinks();
		}
		
		return self::$_instance;
	}
	
	public function loadEngine($engine,$skipAuth=false)
	{
		$result=false;
		
		if (!isset($this->engines[$engine]))
		{
			$engineClass="OS_PLUGIN_Backlinks_{$engine}";
			
			$temp=call_user_func(array($engineClass,'get_instance'));	
			
			$available=true;
			
			if (!$skipAuth)
			{
				if ($temp->hasAuth)
				{
					$ops=getOS()->getBacklinksOps();
					
					if ($authData=$ops->getEngineAuthData($engine))
					{
						if (!$temp->setAuthData($authData) AND $temp->requireAuth)
						{
							$available=false;
						}
					}
					elseif ($temp->requireAuth)
					{
						$available=false;
					}
				}
			}
			
			if ($available)
			{
				$this->engines[$engine]=$temp;
				
				$result=true;
			}
		}
		else
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function getBacklinks($url,$engine)
	{
		$result=false;
		
		$engine=strtolower($engine);
		
		if (!$result=$this->getFromCache($engine,'backlinks',$url))
		{
			if ($this->loadEngine($engine))
			{
				if ($result=$this->engines[$engine]->getBacklinks($url))
				{
					$this->storeInCache($engine,'backlinks',$url,$result);
				}
			}
		}
		
		return $result;
	}
	
	public function getUrlsMetrics($urls,$engine)
	{
		$result=false;
		
		if (!is_array($urls))
		{
			$onlyOne=true;
			$urls=array($urls);
		}
		else
		{
			$onlyOne=false;
		}
		
		foreach ($urls as $key=>$url)
		{
			if ($url_metrics=$this->getFromCache($engine,'metrics',$url))
			{
				$result[$url]=$url_metrics;
				unset($urls[$key]);
			}
		}
		
		if (!empty($urls))
		{
			if ($this->loadEngine($engine))
			{
				if ($engineResult=$this->engines[$engine]->getUrlsMetrics($urls))
				{
					foreach ($engineResult as $url=>$url_metrics)
					{
						$result[$url]=$url_metrics;
						$this->storeInCache($engine,'metrics',$url,$url_metrics);
					}
				}
			}
		}
		
		if ($onlyOne)
		{
			$result=reset($result);
		}
		
		return $result;
	}
	
	private function getFromCache($engine,$requestType,$url)
	{
		$result=false;
		
		$osCache=getOS()->getCache();
		
		if ($osCache->setBucket(array('backlinks',$engine,$requestType)))
		{
			$result=$osCache->get(md5($url));
		}
		
		return $result;
	}
	
	private function storeInCache($engine,$requestType,$url,$data)
	{
		$result=false;
		
		$osCache=getOS()->getCache();
		
		if ($osCache->setBucket(array('backlinks',$engine,$requestType)))
		{
			$result=$osCache->set(md5($url),$data,$this->getCacheValidity($engine));
		}
		
		return $result;
	}
	
	private function getCacheValidity($engine)
	{
		$result=false;
		
		if ($this->loadEngine($engine))
		{
			if ($engineDetails=$this->engines[$engine]->getEngineDetails() AND isset($engineDetails['engineDetails']['cachingTime']))
			{
				$result=$engineDetails['engineDetails']['cachingTime'];
			}
			
			if (!$result)
			{
				$result=$this->defaultCacheValidity;
			}
		}
		
		return $result;
	}
	
	public function getEngines($order_by='name')
	{
		$result=false;
		
		$services=array();
		
		$plugins_path=os_join_path(getOS()->getConfigVar('root_path'),'lib','classes','plugins','backlinks');
		$plugins=glob(os_join_path($plugins_path,'*'),GLOB_ONLYDIR);
		
		foreach ($plugins as $plugin)
		{
			$plugin_name=str_replace(os_join_path($plugins_path,''),'',$plugin);
			if (file_exists(os_join_path($plugin,'class.os_plugin_backlinks_'.$plugin_name.'.php')))
			{
				$services[]=$plugin_name;
			}
		}
		
		foreach ($services as $service)
		{
			if ($this->loadEngine($service,true))
			{
				$result[$service]=$this->engines[$service]->getEngineDetails();
			}
		}
		
		if ($order_by)
		{
			$sorter=getOS()->getSorter();
			
			$sorter->setSortBy($order_by);
			$sorter->setSortType('STRING');
			
			$sorter->sort($result);
		}
		
		return $result;
	}
	
	public function getUsableEngines($order_by='name')
	{
		$result=false;
		
		$services=array();
		
		$plugins_path=os_join_path(getOS()->getConfigVar('root_path'),'lib','classes','plugins','backlinks');
		$plugins=glob(os_join_path($plugins_path,'*'),GLOB_ONLYDIR);
		
		foreach ($plugins as $plugin)
		{
			$plugin_name=str_replace(os_join_path($plugins_path,''),'',$plugin);
			if (file_exists(os_join_path($plugin,'class.os_plugin_backlinks_'.$plugin_name.'.php')))
			{
				$services[]=$plugin_name;
			}
		}
		
		foreach ($services as $service)
		{
			if ($this->loadEngine($service))
			{
				$result[$service]=$this->engines[$service]->getEngineDetails();
			}
		}
		
		if ($order_by)
		{
			$sorter=getOS()->getSorter();
			
			$sorter->setSortBy($order_by);
			$sorter->setSortType('STRING');
			
			$sorter->sort($result);
		}
		
		return $result;
	}
}
?>