<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_menu.php 2012-02-27$
 */

class OS_Charts
{
	private $chartTypes;
	
	private $requiredLibs;
		
	private static $_instance;
	
	
	function __construct()
	{
		$this->requiredLibs = array(
			'raphael' => 'raphael-min.js'
		);
		
		$this->chartTypes = array(
			'line' => array('os.raphael-line.js','popup.js'),
			'bar' => array('g.bar-min.js'),
			'pie' => array('os.raphael-pie.js'),
			'dot' => array('g.dot-min.js')
		);
	}
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_Charts();
		}
		return self::$_instance;
	}
	
	//draw a bar chart
	public function getBarChart($chartOptions)
	{
		$container_width = '350';
		$container_height = '200';
		
		$barOptions = array();
		
		if(isset($chartOptions['width']))
		{
			$container_width = $chartOptions['width']; 
		}
		
		if(isset($chartOptions['height']))
		{
			$container_height = $chartOptions['height'];
		}
		
		//set graph values
		$chartBarValues = array();  
			
		if(isset($chartOptions['values']))
		{
			$totalSeries = count($chartOptions['values']);
			
			for($i=1;$i<=$totalSeries;$i++)
			{
				$currentSerie = 'serie'.$i;
				if(isset($chartOptions['values'][$currentSerie]))
				{
					if(is_array($chartOptions['values'][$currentSerie]))
					{
						$chartBarValues[$currentSerie] = $chartOptions['values'][$currentSerie];
					}
				}
			}
		}
		
		if(isset($chartOptions['options']))
		{
			//verify with available options
			foreach($chartOptions['options'] as $option => $value)
			{
				$barOptions[$option] = $value;
			}
		}
		
		$barOptionsJson = json_encode($barOptions);
		
		
		//get barChartType 
		$barChartType = "barchart";
		if(isset($chartOptions['position']))
		{
			if($chartOptions['position'] == 'horizontal') $barChartType = "hbarchart";
			elseif($chartOptions['position'] == 'vertical') $barChartType = "barchart";
		}
		
		
		$chartHTML = "";
		$chartHTML .= "var  barChart = r.{$barChartType}(0, 0,  {$container_width}, {$container_height}, ".json_encode(array_values($chartBarValues)).", {$barOptionsJson});";
		
		
		if(isset($chartOptions['tooltips']))
		{
			if($chartOptions['tooltips'] === true)
			{
				$chartHTML .= "
					var fin = function () {this.flag = r.popup(this.bar.x, this.bar.y, this.bar.value || '0').insertBefore(this);};
					var fout = function () {this.flag.animate({opacity: 0}, 300, function () {this.remove();});};
					
					barChart.hover(fin, fout);";
			}
		}		
		
		
		return $this->buildChart('bar',$chartHTML);
	}
	
	public function getLineChart($options)
	{
		$options['width']=(empty($options['width'])?'100%':$options['width']);
		$options['height']=(empty($options['height'])?150:$options['height']);
		
		$chartLabels=array();
		$chartTooltips=array();
		$chartValues=array();
		$temp=reset($options['values']);
		if (!is_array($temp))
		{
			$options['values']=array($options['values']);
		}
		
		if (!empty($options['tooltips']))
		{
			$temp=reset($options['tooltips']);
			if (!is_array($temp))
			{
				$options['tooltips']=array($options['tooltips']);
			}
		}
		else
		{
			$options['tooltips']=array();
		}

		foreach ($options['values'] as $line=>$line_values)
		{
			$chartValues[$line]=$line_values;
			
			if (isset($options['tooltips'][$line]))
			{
				$chartTooltips[$line]=$options['tooltips'][$line];
			}
			else
			{
				$chartTooltips[$line]=false;
			}
		}
		
		$chartLabels=array_values($options['labels']);
		
		unset($options['values'],$options['labels'],$options['tooltips']);
		
		if ($options['width']=='100%')
		{
			$options['width']='containerWidth';
			$jsonOptions=str_replace('"containerWidth"','containerWidth',json_encode($options));
		}
		elseif ($options['width']=='inherit')
		{
			$jsonOptions=str_replace('"inherit"','containerWidth',json_encode($options));
		}
		else
		{
			$jsonOptions=json_encode($options);
		}
		
		$chartOptions="r.drawLineChart(".json_encode($chartValues).",".json_encode($chartLabels).",".json_encode($chartTooltips).",{$jsonOptions});";
		$chartPaperOptions=array('width'=>$options['width'],'height'=>$options['height']);
		
		return $this->buildChart('line',$chartOptions,$chartPaperOptions);
	}
	
	public function getPieChart($options)
	{
		$defaultColors=array('#3A87C4','#53B538','#E45B24','#E6F422','#4DC7E3','#5DE96F','#FF9254','#FFF45D','#65F5C2','#B2DEFF','#CCCCCC');
		
		$options['legend']=(empty($options['legend'])?array():$options['legend']);
		$options['radius']=(empty($options['radius'])?50:$options['radius']);
		$options['legend_position']=(empty($options['legend_position'])?(empty($options['legend'])?'none':'right'):$options['legend_position']);
		$options['colors']=(empty($options['colors'])?$defaultColors:$options['colors']);
		
		$chart_padding=round($options['radius']/5);

		if ($options['legend_position']=='none')
		{
			$legend_width=0;
			$legend_height=0;
		}
		else
		{
			$legend_height=count($options['legend'])*22;
			$max_length=0;
			foreach ($options['legend'] as $key=>$val)
			{
				$max_length=max($max_length,strlen($val));
			}
			$legend_width=20+($max_length+5)*7.6;
		}

		$padded_diameter=2*($options['radius']+$chart_padding);
		$width=(($options['legend_position']=='left' OR $options['legend_position']=='right')?$legend_width+$padded_diameter:max($legend_width,$padded_diameter))+20;
		$height=(($options['legend_position']=='top' OR $options['legend_position']=='bottom')?$legend_height+$padded_diameter:max($legend_height,$padded_diameter))+20;
		
		if ($options['legend_position']=='left' OR $options['legend_position']=='right')
		{
			$options['center_x']=($options['legend_position']=='left'?$legend_width+20:0)+$chart_padding+$options['radius'];
			$options['center_y']=$height/2;
			
			$options['legend_padding_left']=($options['legend_position']=='left'?10:$padded_diameter+10);
			$options['legend_padding_top']=($height-$legend_height)/2;
		}
		elseif ($options['legend_position']=='top' OR $options['legend_position']=='bottom')
		{
			$options['center_x']=$width/2;
			$options['center_y']=($options['legend_position']=='top'?$legend_height+20:0)+$chart_padding+$options['radius'];
			
			$options['legend_padding_left']=($width-$legend_width)/2;
			$options['legend_padding_top']=($options['legend_position']=='top'?10:$padded_diameter+10);;
		}
		elseif ($options['legend_position']=='none')
		{
			$options['center_x']=$width/2;
			$options['center_y']=$height/2;
		}
		
		$options['legend_width']=$legend_width;
		$options['legend_height']=$legend_height;
		
		$options['chart_padding']=$chart_padding;
		$options['strokecolor']=(empty($options['strokecolor'])?'#000':$options['strokecolor']);
		$options['strokewidth']=(empty($options['strokewidth'])?1:$options['strokewidth']);

		foreach ($options['values'] as $key=>&$val)
		{
			$val=(int)$val;
		}
		
		$chartValues=json_encode(array_values($options['values']));
		$chartLabels=json_encode(array_values($options['legend']));
	
		unset($options['values'],$options['legend']);

		$jsonOptions=json_encode($options);

		$chartOptions="r.pieChart({$chartValues},{$chartLabels},{$jsonOptions});";
		
		$chartPaperOptions=array('width'=>$width,'height'=>$height);
		
		return $this->buildChart('pie',$chartOptions,$chartPaperOptions);
	}
	
	public function buildChart($chartType,$chartOptions,$paperOptions=array())
	{
		$graphDetails = array();
	
		if(!isset($this->chartTypes[$chartType])) return false;
		else
		{
			$OS = getOS();
			
			$root_url = $OS->getConfigVar('root_url');
			
			$libs_path = $root_url.'/lib/javascript/raphael/';
			
			$requiredLibs = $this->requiredLibs;
			
			foreach ($this->chartTypes[$chartType] as $key=>$val)
			{
				$requiredLibs['raphael-'.$chartType.'-'.$key] = $val;
			}
			
			foreach($requiredLibs as $libName => $scriptName)
			{
				$graphDetails['js'][$libName] = '<script type="text/javascript" src="'.$libs_path.$scriptName.'"></script>';
			}
		
		$numericID=rand(1,10000);
		$randomChartId = 'chart-holder-'.$numericID;
			
		$graphDetails['html'] =	"
			<div id='{$randomChartId}' class='visible' style='width:100%;".(!empty($paperOptions['height'])?"height:{$paperOptions['height']}px;":'')."'></div>
			<script type='text/javascript'>function drawChart{$numericID}() { $('#{$randomChartId}').empty();
		";
			
		if ($paperOptions)
		{
			if ($paperOptions['width']=='inherit')
			{
				$paperOptions['width']='containerWidth';
			}
			
			if ($paperOptions['width']=='containerWidth')
			{
				$graphDetails['html'].="var containerWidth=$('#{$randomChartId}').width();";
			}
			
			$graphDetails['html'].="var r = Raphael('{$randomChartId}',{$paperOptions['width']},{$paperOptions['height']});";
		}
		else
		{
			$graphDetails['html'].="var r = Raphael('{$randomChartId}');";
		}
		
		$graphDetails['html'].="{$chartOptions}
				}
$(document).ready(function() {
				drawChart{$numericID}();
				var redrawChart{$numericID};
			 	$(window).on('redraw',function() { clearTimeout(redrawChart{$numericID});redrawChart{$numericID}=setTimeout('drawChart{$numericID}()',200); });
			 	$(window).on('resize',function() { clearTimeout(redrawChart{$numericID});redrawChart{$numericID}=setTimeout('drawChart{$numericID}()',200); });
});
			</script>";
		
		$graphDetails['redrawFunction']="drawChart{$numericID}";
		
		$graphDetails['html_id']=$randomChartId;
		
		return $graphDetails;	
		}
	}
	
}