<?php
class OS_ChartsImage
{
	private static $_instance;
	
	public $chartTypes;
	
	public function __construct()
	{
		$this->chartTypes=array(
			'pie'=>array('name'=>_("Pie Chart")),
			'line'=>array('name'=>_("Line Chart")),
			'bar'=>array('name'=>_("Bar Chart")),
		);
	}
	
	public function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_ChartsImage();
		}
		
		return self::$_instance;
	}
	
	public function getChartUrl($chartType,$chartData)
	{
		$result=false;
		
		if (isset($this->chartTypes[$chartType]))
		{
			$result=getOS()->getConfigVar('root_url')."/users/image_chart.php?chartType={$chartType}&chartData=".$this->encodeChartData($chartData);
		}
		
		return $result;
	}
	
	public function isValidChartType($chartType)
	{
		$result=false;
		
		if (isset($this->chartTypes[$chartType]))
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function encodeChartData($chartData)
	{
		return base64_encode(json_encode($chartData));
	}
	
	public function decodeChartData($encodedChartData)
	{
		$result=false;
		
		if ($chartData=base64_decode($encodedChartData))
		{
			if ($chartData=json_decode($chartData,true))
			{
				$result=$chartData;
			}
		}
		
		return $result;
	}
	
	public function drawChart($chartType,$chartData)
	{
		$result=false;
		
		if (isset($this->chartTypes[$chartType]))
		{
			$func="drawChart".ucwords($chartType);
			
			$result=$this->$func($chartData);
		}
		
		return $result;			
	}
	
	public function drawChartPie($chartData)
	{
		$OS=getOS();
		
		$pchart_path=os_join_path($OS->getConfigVar('root_path'),'lib','pchart');
		
		require("{$pchart_path}/pChart/pData.class");
		require("{$pchart_path}/pChart/pChart.class");
		
		$values=array();$labels=array();$colors=array();
		
		foreach ($chartData as $chunk)
		{
			$values[]=$chunk['value'];
			$labels[]=$chunk['label'];
			$colors[]=$chunk['color'];
		}
		
		$DataSet = new pData;
		$DataSet->AddPoint($values,_("Values"));
		$DataSet->AddPoint($labels,_("Labels"));
		$DataSet->AddAllSeries();
		$DataSet->SetAbsciseLabelSerie(_("Labels"));
		
		$pie = new pChart(400,200);
		
		$osUtils=$OS->getUtils();
		
		foreach ($colors as $key=>$color)
		{
			$color=$osUtils->colorHexToRgb($color);
			
			$pie->setColorPalette($key,$color['red'],$color['green'],$color['blue']);
		}
		
		$pie->setFontProperties("{$pchart_path}/Fonts/tahoma.ttf",8);
		$pie->AntialiasQuality = 0;
		$pie->drawPieGraph($DataSet->GetData(),$DataSet->GetDataDescription(),200,100,100,PIE_LABELS,FALSE,50,20,5);
		
		$pie->Stroke();
	}
	
	public function drawChartLine($chartData)
	{
		$OS=getOS();
		
		$pchart_path=os_join_path($OS->getConfigVar('root_path'),'lib','pchart');
		
		require("{$pchart_path}/pChart/pData.class");
		require("{$pchart_path}/pChart/pChart.class");
		
		$lines=array();$colors=array();
		
		$index=0;
		foreach ($chartData['lines'] as $line)
		{
			$lines[$line['name']]=$line['values'];
			
			if (isset($line['color']))
			{
				$colors[$index]=$line['color'];
			}
			
			$index++;
		}
		
		$DataSet=new pData;
		
		$counter=0;
		foreach ($lines as $name=>$values)
		{
			$counter++;
			$DataSet->AddPoint($values,"Serie".$counter);
			$DataSet->SetSerieName($name,"Serie".$counter);
		}
		
		$DataSet->AddAllSeries();
		
		if (isset($chartData['labels']))
		{
			$DataSet->AddPoint($chartData['labels'],"Abscise");
			$DataSet->SetAbsciseLabelSerie("Abscise");  
		}
		
		if (!empty($chartData['x_name']))
		{
			$DataSet->SetXAxisName($chartData['x_name']);
		}
		if (!empty($chartData['x_unit']))
		{
			$DataSet->SetXAxisUnit($chartData['x_unit']);
		}
		
		if (!empty($chartData['y_name']))
		{
			$DataSet->SetYAxisName($chartData['y_name']);
		}
		if (!empty($chartData['y_unit']))
		{
			$DataSet->SetYAxisUnit($chartData['y_unit']);
		}
		
		if (!isset($chartData['dots']))
		{
			$chartData['dots']=true;
		}
		
		$chart = new pChart(700,235);
		
		if (!empty($colors))
		{
			$osUtils=$OS->getUtils();
			
			foreach ($colors as $key=>$color)
			{
				$color=$osUtils->colorHexToRgb($color);
				
				$chart->setColorPalette($key,$color['red'],$color['green'],$color['blue']);
			}
		}
		     
		$chart->setFontProperties("{$pchart_path}/Fonts/tahoma.ttf",8);     
		$chart->setGraphArea(70,30,680,200);     
//		$chart->drawFilledRoundedRectangle(7,7,693,223,5,240,240,240);     
//		$chart->drawRoundedRectangle(5,5,695,225,5,230,230,230);     
		$chart->drawGraphArea(255,255,255,TRUE);  
		$chart->drawScale($DataSet->GetData(),$DataSet->GetDataDescription(),SCALE_NORMAL,150,150,150,TRUE,0,2);     
		$chart->drawGrid(4,TRUE,230,230,230,50);  
		   
		$chart->setFontProperties("{$pchart_path}/Fonts/tahoma.ttf",6);     
		$chart->drawTreshold(0,143,55,72,TRUE,TRUE);     
		 
		if (!empty($chartData['filled']))
		{
			$chart->drawFilledLineGraph($DataSet->GetData(),$DataSet->GetDataDescription());
		}
		else
		{  
			$chart->drawLineGraph($DataSet->GetData(),$DataSet->GetDataDescription());
		}
		
		if ($chartData['dots'])
		{     
			$chart->drawPlotGraph($DataSet->GetData(),$DataSet->GetDataDescription(),3,2,255,255,255);
		}     
		   
		$chart->setFontProperties("{$pchart_path}/Fonts/tahoma.ttf",8);     
		//$chart->drawLegend(75,35,$DataSet->GetDataDescription(),255,255,255);     
		     
		if (!empty($chartData['title']))
		{
			$chart->setFontProperties("{$pchart_path}/Fonts/tahoma.ttf",10);
			$chart->drawTitle(60,22,$chartData['title'],50,50,50,585);
		}
		
		$chart->Stroke();
	}
	
	public function drawChartBar($chartData)
	{
		$OS=getOS();
		
		$pchart_path=os_join_path($OS->getConfigVar('root_path'),'lib','pchart');
		
		require("{$pchart_path}/pChart/pData.class");
		require("{$pchart_path}/pChart/pChart.class");
		
		$bars=array();$colors=array();
		
		$index=0;
		foreach ($chartData['bars'] as $bar)
		{
			$bars[$bar['name']]=$bar['values'];
			
			if (isset($bar['color']))
			{
				$colors[$index]=$bar['color'];
			}
			
			$index++;
		}
		
		$DataSet=new pData;
		
		$counter=0;
		foreach ($bars as $name=>$values)
		{
			$counter++;
			$DataSet->AddPoint($values,"Serie".$counter);
			$DataSet->SetSerieName($name,"Serie".$counter);
		}
		
		$DataSet->AddAllSeries();
		
		if (isset($chartData['labels']))
		{
			$DataSet->AddPoint($chartData['labels'],"Abscise");
			$DataSet->SetAbsciseLabelSerie("Abscise");  
		}
		
		if (!empty($chartData['x_name']))
		{
			$DataSet->SetXAxisName($chartData['x_name']);
		}
		if (!empty($chartData['x_unit']))
		{
			$DataSet->SetXAxisUnit($chartData['x_unit']);
		}
		
		if (!empty($chartData['y_name']))
		{
			$DataSet->SetYAxisName($chartData['y_name']);
		}
		if (!empty($chartData['y_unit']))
		{
			$DataSet->SetYAxisUnit($chartData['y_unit']);
		}
		
		$chart = new pChart(700,235);
		
		if (!empty($colors))
		{
			$osUtils=$OS->getUtils();
			
			foreach ($colors as $key=>$color)
			{
				$color=$osUtils->colorHexToRgb($color);
				
				$chart->setColorPalette($key,$color['red'],$color['green'],$color['blue']);
			}
		}
		     
		$chart->setFontProperties("{$pchart_path}/Fonts/tahoma.ttf",8);     
		$chart->setGraphArea(50,30,680,200);     
//		$chart->drawFilledRoundedRectangle(7,7,693,223,5,240,240,240);     
//		$chart->drawRoundedRectangle(5,5,695,225,5,230,230,230);     
		$chart->drawGraphArea(255,255,255,TRUE);  
		$chart->drawScale($DataSet->GetData(),$DataSet->GetDataDescription(),SCALE_NORMAL,150,150,150,TRUE,0,2,TRUE);     
		$chart->drawGrid(4,TRUE,230,230,230,50);  
		   
		$chart->setFontProperties("{$pchart_path}/Fonts/tahoma.ttf",6);     
		$chart->drawTreshold(0,143,55,72,TRUE,TRUE);     
		   
		$chart->drawBarGraph($DataSet->GetData(),$DataSet->GetDataDescription(),TRUE);    
		   
		$chart->setFontProperties("{$pchart_path}/Fonts/tahoma.ttf",8);     
		//$chart->drawLegend(75,35,$DataSet->GetDataDescription(),255,255,255);     
		if (!empty($chartData['title']))
		{
			$chart->setFontProperties("{$pchart_path}/Fonts/tahoma.ttf",10);
			$chart->drawTitle(60,22,$chartData['title'],50,50,50,585);
		}
		
		$chart->Stroke();
	}
}
?>