<?php
class OS_CMSDetector
{
	private static $_instance;
	
	public function __construct()
	{
		$this->setDefaultCMSs();
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_CMSDetector();
		}
		
		return self::$_instance;
	}
	
	public function detectFromURL($url)
	{
		$result=false;
		
		$http=getOS()->getHttp();
		
		$response=$http->get($url);
		
		if ($response AND $http->success())
		{
			$result=$this->detectFromContent($response);
		}
		
		return $result;
	}
	
	public function detectFromContent($html)
	{
		$result=array();
		
		//META tags
		$found=false;
		$i=strpos($html,"<meta ");
		while ($i!==false && $found==false)
		{
			$j=strpos($html,">",$i+1);
			if ($j===false)
			{
				$j=strlen($html)-1;
			}
			$meta_tag=substr($html,$i,$j-$i+1);
			
			foreach($this->rules['meta'] as $tag=>$regex)
			{
				preg_match($regex, $meta_tag, $matches);
				if (!empty($matches))
				{
					if (!in_array($tag,$result))
					{
						array_push($result,$tag);
					}
					$found=true;
					break;
				}
			}
			
			$i=strpos($html,"<meta ",$i+1);
		}
		
		//SCRIPT tags
		$found=false;
		$i=strpos($html,"<script ");
		while ($i!==false && $found==false)
		{
			$j=strpos($html,"</script>",$i+9);
			if ($j===false)
			{
				$j=strlen($html)-1;
			}
			$meta_tag=substr($html,$i,$j-$i+9);
			foreach($this->rules['script'] as $tag=>$regex)
			{
				preg_match($regex, $meta_tag, $matches);
				if (!empty($matches))
				{
					if (!in_array($tag,$result))
					{
						array_push($result,$tag);
					}
					break;
				}
			}
			$i=strpos($html,"<script ",$i+1);
		}
		
		//Other rules
		foreach($this->rules['other'] as $tag=>$regex)
		{
			preg_match($regex, $html, $matches);
			if (!empty($matches))
			{
				if (!in_array($tag,$result))
				{
					array_push($result,$tag);
				}
			}
		}
		
		if (empty($result))
		{
			$result=false;
		}
		else
		{
			$result=reset($result);
		}
		
		return $result;
	}
	
	public function getCMSDetails($cms)
	{
		$result=false;
		
		if (isset($this->cmss[$cms]))
		{
			$result=array_merge($this->cmss[$cms],array('icon_url'=>$this->getCMSIconUrl($cms)));
		}
		
		return $result;
	}
	
	public function getCMSIconUrl($cms)
	{
		$result=false;
		
		if (isset($this->cmss[$cms]))
		{
			$OS=getOS();
			
			$result=$OS->getConfigVar('root_url').'/lib/imgs/extras/cms/'.$cms.'.png';
		}
		
		return $result;
	}
	
	public function setDefaultCMSs()
	{
		$this->rules=array(
			'meta'=>array(
				'joomla'=> '/joomla/i',
				'vbulletin'=> '/vBulletin/i',
				'wordpress'=> '/wordPress/i',
				'xoops'=> '/xoops/i',
				'plone'=> '/plone/i',
				'mediawiki'=> '/MediaWiki/i',
				'cmsms'=> '/CMS Made Simple/i',
				'silverstripe'=> '/SilverStripe/i',
				'movable_type'=> '/Movable Type/i',
				'amirocms'=> '/Amiro/i',
				'koobi'=> '/koobi/i',
				'bbpress'=> '/bbPress/i',
				'dokuwiki'=> '/dokuWiki/i',
				'typo3'=> '/TYPO3/i',
				'phpnuke'=> '/PHP-Nuke/i',
				'dotnetnuke'=> '/DotNetNuke/i',
				'sitefinity'=> '/Sitefinity\s+(.*)/i',
				'webgui'=> '/WebGUI/i',
				'ez_publish'=> '/eZ\s*Publish/i',
				'bigace'=> '/BIGACE/i',
				'typepad'=> '/typepad\.com/i',
				'blogger'=> '/blogger/i',
				'prestashop'=> '/PrestaShop/i',
				'sharepoint'=> '/SharePoint/',
				'jaliosjcms'=> '/Jalios JCMS/i',
				'zencart'=> '/zen-cart/i',
				'wpml'=> '/WPML/i',
				'pivotx'=> '/PivotX/i',
				'openacs'=> '/OpenACS/i',
				'phpbb'=> '/phpBB/i',
				'serendipity'=> '/Serendipity/i',
				'avactis'=> '/Avactis Team/i'
			),
			'script'=>array(
				'joomla'=> '/\/components\/com_/',
				'ubercart'=> '/uc_cart/i',
				'modx'=> '/\/min\/b=.*f=.*/',
				'xenforo'=> '/js\/xenforo\//i',
				'avactis'=> '/\/avactis-themes\//i',
				'volusion'=> '/a\/j\/javascripts\.js/',
				'datalife'=> "/dle_root/i",
				'drupal'=> "/Drupal\.settings/i",
				'mybb'=> "/jscripts\/general\.js\?ver=/i"
			),
			'other'=>array(
				'smf'=> "/<script .+\s+var smf_/i",
				'magento'=> "/var BLANK_URL = '[^>]+js\/blank\.html'/i",
				'tumblr'=> "/<iframe src=(\"|')http:\/\/\S+\.tumblr\.com/i",
				'wordpress'=> "/<link rel=(\"|')stylesheet(\"|') [^>]+wp-content/i",
				'liferay'=> "/<script[^>]*>.*LifeRay\.currentURL/is",
				'vbulletin'=> "/vbmenu_control/i",
				'modx'=> "/(<a[^>]+>Powered by MODx<\/a>|var el= \$\('modxhost'\);|<script type=(\"|')text\/javascript(\"|')>var MODX_MEDIA_PATH = \"media\";)/i",
				'minibb'=> "/<a href=(\"|')[^>]+minibb.+\s*<!--End of copyright link/is",
				'fatwire'=> "/\/Satellite\?|\/ContentServer\?/s",
				'contao'=> "/powered by (TYPOlight|Contao)/is",
				'moodle' => "/<link[^>]*\/theme\/standard\/styles.php\".*>/",
				'1c_bitrix' => "/<link[^>]*\/bitrix\/.*?>/i",
				'opencms' => "/<link[^>]*\.opencms\..*?>/i",
				'prostores' => "/-legacycss\/Asset\">/",
				'oscommerce'=> "/(product_info\.php\?products_id|_eof \/\/-->)/",
				'opencart'=> "/index\.php\?route=product\/product/i"
			)
		);
		
		$this->cmss=array(
			'joomla'=>array(
				'name'=>'Joomla',
				'type'=>'general',
				'url'=>'http://www.joomla.org'
			),
			'vbulletin'=>array(
				'name'=>'vBulletin',
				'type'=>'forum',
				'url'=>'http://www.vbulletin.com'
			),
			'wordpress'=>array(
				'name'=>'WordPress',
				'type'=>'blog',
				'url'=>'http://www.wordpress.org'
			),
			'xoops'=>array(
				'name'=>'XOOPS',
				'type'=>'portal',
				'url'=>'http://www.xoops.org'
			),
			'plone'=>array(
				'name'=>'Plone',
				'type'=>'portal',
				'url'=>'http://www.plone.org'
			),
			'mediawiki'=>array(
				'name'=>'MediaWiki',
				'type'=>'wiki',
				'url'=>'http://www.mediawiki.org'
			),
			'cmsms'=>array(
				'name'=>'CMSMadeSimple',
				'type'=>'general',
				'url'=>'http://www.cmsmadesimple.org'
			),
			'silverstripe'=>array(
				'name'=>'SilverStripe',
				'type'=>'general',
				'url'=>'http://www.silverstripe.org'
			),
			'movable_type'=>array(
				'name'=>'Movable Type',
				'type'=>'blog',
				'url'=>'http://www.movabletype.org'
			),
			'amirocms'=>array(
				'name'=>'Amiro.CMS',
				'type'=>'shop',
				'url'=>'http://www.amirocms.com'
			),
			'koobi'=>array(
				'name'=>'Koobi',
				'type'=>'shop',
				'url'=>'http://www.koobi.com'
			),
			'bbpress'=>array(
				'name'=>'bbPress',
				'type'=>'forum',
				'url'=>'http://www.bbpress.org'
			),
			'dokuwiki'=>array(
				'name'=>'DokuWiki',
				'type'=>'wiki',
				'url'=>'http://www.dokuwiki.org'
			),
			'typo3'=>array(
				'name'=>'TYPO3',
				'type'=>'portal',
				'url'=>'http://www.typo3.com'
			),
			'phpnuke'=>array(
				'name'=>'PHP-Nuke',
				'type'=>'general',
				'url'=>'http://phpnuke.org'
			),
			'dotnetnuke'=>array(
				'name'=>'DotNetNuke',
				'type'=>'general',
				'url'=>'http://www.dotnetnuke.com'
			),
			'sitefinity'=>array(
				'name'=>'Sitefinity',
				'type'=>'general',
				'url'=>'http://www.sitefinity.com'
			),
			'webgui'=>array(
				'name'=>'WebGUI',
				'type'=>'general',
				'url'=>'http://www.webgui.org'
			),
			'ez_publish'=>array(
				'name'=>'ez Publish',
				'type'=>'news',
				'url'=>'http://ez.no'
			),
			'bigace'=>array(
				'name'=>'BIGACE',
				'type'=>'general',
				'url'=>'http://www.bigace.de'
			),
			'typepad'=>array(
				'name'=>'TypePad',
				'type'=>'blog',
				'url'=>'http://typepad.com'
			),
			'blogger'=>array(
				'name'=>'Blogger',
				'type'=>'blog',
				'url'=>'http://blogger.com'
			),
			'prestashop'=>array(
				'name'=>'PrestaShop',
				'type'=>'shop',
				'url'=>'http://www.prestashop.com'
			),
			'sharepoint'=>array(
				'name'=>'SharePoint',
				'type'=>'collab',
				'url'=>'http://sharepoint.microsoft.com'
			),
			'jaliosjcms'=>array(
				'name'=>'JaliosJCMS',
				'type'=>'general',
				'url'=>'http://www.jalios.com'
			),
			'zencart'=>array(
				'name'=>'ZenCart',
				'type'=>'shop',
				'url'=>'http://www.zen-cart.com'
			),
			'wpml'=>array(
				'name'=>'WordPress Multilingual',
				'type'=>'blog',
				'url'=>'http://wpml.org'
			),
			'pivotx'=>array(
				'name'=>'PivotX',
				'type'=>'blog',
				'url'=>'http://pivotx.net'
			),
			'openacs'=>array(
				'name'=>'OpenACS',
				'type'=>'portal',
				'url'=>'http://openacs.org'
			),
			'phpbb'=>array(
				'name'=>'phpBB',
				'type'=>'forum',
				'url'=>'http://www.phpbb.com'
			),
			'elgg'=>array(
				'name'=>'Elgg',
				'type'=>'social',
				'url'=>'http://www.elgg.org'
			),
			'serendipity'=>array(
				'name'=>'Serendipity',
				'type'=>'blog',
				'url'=>'http://www.s9y.org'
			),
			'avactis'=>array(
				'name'=>'Avactis',
				'type'=>'shop',
				'url'=>'http://www.avactis.com'
			),
			'drupal'=>array(
				'name'=>'Drupal',
				'type'=>'general',
				'url'=>'http://www.drupal.org'
			),
			'smf'=>array(
				'name'=>'SMF',
				'type'=>'forum',
				'url'=>'http://www.simplemachines.org'
			),
			'magento'=>array(
				'name'=>'Magento',
				'type'=>'shop',
				'url'=>'http://www.magentocommerce.com'
			),
			'tumblr'=>array(
				'name'=>'Tumblr',
				'type'=>'blog',
				'url'=>'http://tumblr.com'
			),
			'liferay'=>array(
				'name'=>'Liferay',
				'type'=>'portal',
				'url'=>'http://www.liferay.com'
			),
			'minibb'=>array(
				'name'=>'miniBB',
				'type'=>'forum',
				'url'=>'http://www.minibb.com'
			),
			'fatwire'=>array(
				'name'=>'Fatwire',
				'type'=>'general',
				'url'=>'http://www.fatwire.com'
			),
			'contao'=>array(
				'name'=>'Contao',
				'type'=>'general',
				'url'=>'http://www.contao.org'
			),
			'moodle'=>array(
				'name'=>'Moodle',
				'type'=>'education',
				'url'=>'http://moodle.org'
			),
			'1c_bitrix'=>array(
				'name'=>'1c-bitrix',
				'type'=>'general',
				'url'=>'http://www.1c-bitrix.ru'
			),
			'opencms'=>array(
				'name'=>'OpenCMS',
				'type'=>'general',
				'url'=>'http://www.opencms.org'
			),
			'prostores'=>array(
				'name'=>'Prostores',
				'type'=>'shop',
				'url'=>'http://www.prostores.com'
			),
			'oscommerce'=>array(
				'name'=>'osCommerce',
				'type'=>'shop',
				'url'=>'http://www.oscommerce.com'
			),
			'opencart'=>array(
				'name'=>'OpenCart',
				'type'=>'shop',
				'url'=>'http://www.opencart.com'
			),
			'mybb'=>array(
				'name'=>'MyBB',
				'type'=>'forum',
				'url'=>'http://www.mybb.com'
			),
			'datalife'=>array(
				'name'=>'DataLife',
				'type'=>'general',
				'url'=>'http://www.datalifeengine.ir'
			),
			'ubercart'=>array(
				'name'=>'UberCart',
				'type'=>'shop',
				'url'=>'http://www.ubercart.org'
			),
			'modex'=>array(
				'name'=>'MODx',
				'type'=>'general',
				'url'=>'http://modx.com'
			),
			'xenforo'=>array(
				'name'=>'xenForo',
				'type'=>'forum',
				'url'=>'http://xenforo.com'
			),
			'volusion'=>array(
				'name'=>'Volusion',
				'type'=>'shop',
				'url'=>'http://www.volusion.com'
			)
		);
	}
}
?>