<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_Config
{
	private static $_instance;
	
	private $data = array();
	
	private $vars = array();
	
	//constructor
	function __construct()
	{
	
	}
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
    	{
			self::$_instance = new OS_Config();

      		// now load the config
      		self::$_instance->load();
    	}
    	
    	return self::$_instance;
	}
	
	
	public function save($filepath = false)
	{
	    if( !$filepath )
		{
			$filepath = $this->getParam('config_file_path');
		}
	      
	    // backup the original config.php file (just in case)
	    if( file_exists($filepath) )
		{
			@copy($filepath, os_join_path($this->getParam('cache_path'),basename($filepath).time().'.bak'));
		}
	      
		//output header to the config file.
		$OS = getOS();
		$osUtils = $OS->getUtils();
		
		$result = $osUtils->confWrite($filepath, $this->data);
		
		if($result === true)
		{
			$this->load();	
		}
		
		return ($result == false ?  false : true);
	}
	
	public function load()
	{
		$result = false;
		if(empty($this->data))
		{
	    	$configFilePath = $this->getParam('config_file_path');
	    	
			$OS = getOS();
			$osUtils = $OS->getUtils();
			
			$configData = $osUtils->confRead($configFilePath);
			
			if($configData !== false)
			{
				$this->data = $configData;
				$result = $this->data;	
			}
    	}
    	else
    	{
    		$result = $this->data;
    	}
    	
    	return $result;
	}
	
	public function getParam($key)
	{
		$result = false;
		
		if(isset($this->data[$key]))
		{
			$result = $this->data[$key];
		}
		elseif(isset($this->vars[$key]))
		{
			$result = $this->vars[$key];
		}
		else
		{
			//calculate param and add it to cache value
			switch ($key)
			{
				case 'dbms':
				case 'db_hostname':
				case 'db_username':
				case 'db_password':
				case 'db_name':
				case 'crypt_key':
				
				// these guys have to be set
				stack_trace();
				die('FATAL ERROR: Could not find database connection key '.$key.' in the config file');
				break;
				
				case 'root_path':
					$result = dirname(dirname(dirname(__FILE__)));
					break;
					
				case 'root_url':
					$part = str_replace(array(str_replace('/',DIRECTORY_SEPARATOR,$_SERVER['DOCUMENT_ROOT']),DIRECTORY_SEPARATOR),array("",'/'),$this->getParam('root_path'));
					$result = 'http://' . $_SERVER['HTTP_HOST'] . $part;
					break;
					
				case 'ssl_root_url':
					$this->vars[$key] = str_replace('http://','https://',$this->getParam('root_url'));
					$result = $this->vars[$key];
					break;

				case "config_file_path":
					$this->vars[$key] = os_join_path($this->getParam('root_path'), 'configs', 'config.php');
					$result = $this->vars[$key];
					break;
					
				case "settings_file_path":
					$this->vars[$key] = os_join_path($this->getParam('root_path'), 'configs', 'settings.php');
					$result = $this->vars[$key];
					break;
					
				case 'templates_compile_path':
					$this->vars[$key] = os_join_path($this->getParam('root_path'), 'storage', 'templates_compiled');
					$result = $this->vars[$key];
					break;
					
				case 'template_url':
					$this->vars[$key] = $this->getParam('root_url').'/themes/'. $this->getParam('theme_name');
					$result = $this->vars[$key];
					break;
					
				case 'theme_name':
					$result = 'default';
					break;
					
				case 'cache_path':
					$this->vars[$key] = os_join_path($this->getParam('root_path'), 'cache');
					$result = $this->vars[$key];
					break;
									
				case 'storage_path':
					$this->vars[$key] = os_join_path($this->getParam('root_path'),'storage');
					$result = $this->vars[$key];
					break;
					
				case 'storage_url':
					$this->vars[$key] = $this->getParam('root_url')."/storage";
					$result = $this->vars[$key];
					break;
					
				case 'admin_dir':
					$result = "admin";
					break;
					
				case 'admin_url':
					$result = $this->getParam('root_url').'/'.$this->getParam('admin_dir');
					break;	

				case 'debug':
					$result = "false";
					break;					
					
				case 'default_upload_permission':
					$result = '664';
					break;
					
				case 'max_upload_size':
					$result = $this->get_upload_size();
					break;
					
				case 'locale':
					$result = '';
					break;

				case 'default_encoding':
					$result = 'utf-8';
					break;

      			case 'wiki_url':
					return 'http://opens.org/wiki/index.php';
					break;
					
				case 'timezone':
					$result = '';
					break;
					
				default:
					$result = null;	
			}
		}
		
		return $result;
	}
	
	public function flush()
	{
		if(!empty($this->data))
		{
			$this->data = array();
		}
	}
	
	public function setParam($key, $value)
	{
		$this->data[$key] = $value;
	}
}
?>