<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */


final class OS_Core
{
	private static $_instance;
	
	
	//config Object
	private $config;
	
	//Internal error array - So functions/modules can store up debug info and spit it all out at once
	public $errorMessages;	
	
	public $infoMessages;
	
	private $systemTimezone;
	
	private $systemLanguages;
	
	//os core constructor
	protected function __construct()
	{
	
	}
	
	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_Core();
		}
		return self::$_instance;
	}
	
	//Retrieve the list of errors
	public function getErrors()
	{
		return $this->errorMessages;
	}
	
	//Add an Field error to the list
	public function addFieldError($err_str,$err_key)
	{
		$this->addError($err_str,$err_key,"F");
	}
	
	//Add an Box error to the list
	public function addBoxError($err_str,$err_key = false)
	{
		if($err_key == false) $err_key = md5($err_str);
		$this->addError($err_str,$err_key,"B");	
	}
	
	//Add an error to the list
	public function addError($err_str,$err_key,$err_type)
	{
		if( !is_array($this->errorMessages) ) $this->errorMessages = array();
		$this->errorMessages[$err_key] = array('error'=>$err_str,'type'=>$err_type);
	}

	//Add an info message to the list
	public function addInfo($info_message,$info_key = false)
	{
		if($info_key == false) $info_key = md5($info_message);
		if( !is_array($this->infoMessages) ) $this->infoMessages = array();
		$this->infoMessages[$info_key] = $info_message;
	}	
		
	//Retrieve the value of an internal variable.	
	public function getVariable($key)
	{
		if( $key != '' && isset($this->variables[$key]) )
		{
			return $this->variables[$key];
		}
	}
	
	//Set a variable for later usage.
	public function setVariable($key,$value)
	{
		$this->variables[$key] = $value;
	}
	
	public function redirectTO($path,$isFullURL=false)
	{
		$jump_url = ($isFullURL?$path:getOS()->getConfigVar('root_url').$path);
		header("Location: {$jump_url}");exit;	
	}
	
	//TODO: Temporary, only returns 0.1 so far. PS: Should we use a different way for this?
	public function getVersion()
	{
		return '0.1.0';
	}
	
	//Get a handle to the MYSQL database object.
	public function & getDb()
	{
		return OS_Database::get_instance();
	}
	
	//Get a handle to the database operations class.
	public function & getDbOps()
	{
		return OS_DatabaseOperations::get_instance();
	}
	
	//Get a handle to the global OS config. Values that are defined in config.php
	public function & getConfig()
	{
    	return OS_Config::get_instance();
	}
	
	//Get a handle to the global OS settings. Values that are defined in settings.php
	public function & getSettings()
	{
    	return OS_Settings::get_instance();
	}
	
	
	public function & getConfigVar($key)
	{
		$result = false;
		
		$param = $this->getConfig()->getParam($key);
		
		if($param !== false)
		{
			$result = $param;
		}
		
		return $result;		
	}
	
	//Handle settings
	public function getSettingsVar($key)
	{
		$result = false;
		
		$param = $this->getSettings()->getParam($key);
		
		if($param !== false)
		{
			$result = $param;
		}
		
		return $result;	
	}

	//Get a handle to the os_smarty object.
	public function & getTemplate()
	{
		return OS_Template::get_instance();
	}
	
	public function & getTemplateOps()
	{
		return OS_TemplateOperations::get_instance();
	}
	
	//Get a handle of the os_menu objest
	public function & getMenu()
	{
		return OS_Menu::get_instance();
	}
	
	public function & getValidator()
	{
		return OS_Validator::get_instance();
	}
	
	public function & getUser()
	{
		return OS_User::get_instance();
	}

	public function & getUserOps()
	{
		return OS_UserOperations::get_instance();
	}
	
	public function & getApp()
	{
		return OS_App::get_instance();
	}
	
	public function & getAppOps()
	{
		return OS_AppOperations::get_instance();
	}
	
	public function & getAppHandler($app_name=false)
	{
		$handler=OS_AppHandler::get_instance();
		
		if ($app_name AND $handler->name!=$app_name)
		{
			$handler->name=$app_name;
			$handler->unloadAppPlugin();
		}
		
		return $handler;
	}
	
	public function & getAppHandlerOps()
	{
		return OS_AppHandlerOperations::get_instance();
	}
	
	public function & getProject()
	{
		return OS_Project::get_instance();
	}
	
	public function & getProjectOps()
	{
		return OS_ProjectOperations::get_instance();
	}
	
	public function & getClient()
	{
		return OS_Client::get_instance();
	}
	
	public function & getClientOps()
	{
		return OS_ClientOperations::get_instance();
	}
	
	public function & getDepartment()
	{
		return OS_Department::get_instance();	
	}

	public function & getDepartmentOps()
	{
		return OS_DepartmentOperations::get_instance();	
	}

	public function & getPermissions()
	{
		return OS_Permissions::get_instance();
	}
	
	public function & getPermissionOps()
	{
		return OS_PermissionOperations::get_instance();
	}
	
	public function & getAjax()
	{
		return OS_Ajax::get_instance();	
	}
	
	public function & getSection()
	{
		return OS_Section::get_instance();	
	}
	
	public function & getSectionOps()
	{
		return OS_SectionOperations::get_instance();	
	}
	
	public function & getWidgetOps()
	{
		
		return OS_WidgetOperations::get_instance();	
	}
	
	public function & getWidgetHandler()
	{
		return OS_WidgetHandler::get_instance();	
	}
	
	public function & getWidgetHandlerOps()
	{
		return OS_WidgetHandlerOperations::get_instance();	
	}
	
	public function & getUtils()
	{
		return OS_Utils::get_instance();
	}
	
	public function & getCharts()
	{
		return OS_Charts::get_instance();
	}
	
	public function & getAppDeveloper()
	{
		return OS_AppDeveloper::get_instance();
	}
	
	public function & getAppDeveloperOps()
	{
		return OS_AppDeveloperOperations::get_instance();
	}
	
	public function & getAppProposed()
	{
		return OS_AppProposed::get_instance();
	}
	
	public function & getAppProposedOps()
	{
		return OS_AppProposedOperations::get_instance();
	}
	
	public function & getAppStats()
	{
		return OS_AppStats::get_instance();
	}
	
	public function & getAppStatsOps()
	{
		return OS_AppStatsOperations::get_instance();
	}
	
	public function & getWidgetStats()
	{
		return OS_WidgetStats::get_instance();
	}
	
	public function & getWidgetStatsOps()
	{
		return OS_WidgetStatsOperations::get_instance();
	}
	
	public function & getAppStoreApi()
	{
		return OS_AppStoreApi::get_instance();
	}
	
	public function & getDatasource()
	{
		return OS_Datasource::get_instance();
	}
	
	public function & getDatasourceOps()
	{
		return OS_DatasourceOperations::get_instance();
	}
	
	public function & getHttp()
	{
		return OS_Http::get_instance();
	}
	
	public function & getHttpMulti()
	{
		return OS_HttpMulti::get_instance();
	}
	
	public function & getCache()
	{
		return OS_Cache::get_instance();
	}
	
	public function & getAudit()
	{
		return OS_Audit::get_instance();
	}
	
	public function & getAuditOps()
	{
		return OS_AuditOperations::get_instance();
	}
	
	public function & getCompetitor()
	{
		return OS_Competitor::get_instance();
	}
	
	public function & getProxyOps()
	{
		return OS_ProxyOperations::get_instance();	
	}	
	
	public function & getCompetitorOps()
	{
		return OS_CompetitorOperations::get_instance();
	}
	
	public function & getTimezonesList()
	{
		if(!isset($this->systemTimezone))
		{
			$this->systemTimezone = timezone_identifiers_list();	
		}
		
		return $this->systemTimezone;
	}
	
	public function & getMailOps()
	{
		return OS_MailOperations::get_instance();
	} 
	
	public function & getSearchEngine()
	{
		return OS_SearchEngine::get_instance();
	}
	
	public function & getSearchEngineOps()
	{
		return OS_SearchEngineOperations::get_instance();
	}
	
	public function & getProjectSearchEngine()
	{
		return OS_ProjectSearchEngine::get_instance();
	}
	
	public function & getProjectSearchEngineOps()
	{
		return OS_ProjectSearchEngineOperations::get_instance();
	}
	
	public function & getProjectKeyword()
	{
		return OS_ProjectKeyword::get_instance();
	}
	
	public function & getProjectKeywordOps()
	{
		return OS_ProjectKeywordOperations::get_instance();
	}
	
	public function & getCronWrapper()
	{
		return OS_CronWrapper::get_instance();
	}
	
	public function & getJsTracker()
	{
		return OS_jsTracker::get_instance();
	}
	
	public function & getCrawler()
	{
		return OS_Crawler::get_instance();
	}
	
	public function & getProjectCrawl()
	{
		return OS_ProjectCrawl::get_instance();
	}
	
	public function & getProjectCrawlOps()
	{
		return OS_ProjectCrawlOperations::get_instance();
	}
	
	public function & getProjectCrawlHandler()
	{
		return OS_ProjectCrawlHandler::get_instance();
	}

	public function & getGeoIP()
	{
		return OS_GeoIP::get_instance();
	}
	
	public function & getForecasting()
	{
		return OS_Forecasting::get_instance();
	}
	
	public function & getSorter()
	{
		return OS_Sorter::get_instance();
	}
	
	public function & getTextualizer()
	{
		return OS_Textualizer::get_instance();
	}
	
	public function & getTimeframe()
	{
		return OS_Timeframe::get_instance();
	}
	
	public function & getSocialSignals()
	{
		return OS_SocialSignals::get_instance();
	}
	
	public function & getRankings()
	{
		return OS_Rankings::get_instance();
	}
	
	public function & getCMSDetector()
	{
		return OS_CMSDetector::get_instance();
	}
	
	public function & getStopWords()
	{
		return OS_StopWords::get_instance();
	}
	
	public function & getReport()
	{
		return OS_Report::get_instance();
	}
	
	public function & getChartsImage()
	{
		return OS_ChartsImage::get_instance();
	}
	
	public function & getPDF()
	{
		return OS_PDF::get_instance();
	}
	
	public function & getRobotsTxt()
	{
		return OS_RobotsTxt::get_instance();
	}
	
	public function & getMemory()
	{
		return OS_Memory::get_instance();
	}
	
	public function & getBacklinks()
	{
		return OS_Backlinks::get_instance();
	}
	
	public function & getBacklinksOps()
	{
		return OS_BacklinksOperations::get_instance();
	}
	
	public function & getProjectTopic()
	{
		return OS_ProjectTopic::get_instance();
	}
	
	public function & getProjectTopicOps()
	{
		return OS_ProjectTopicOperations::get_instance();
	}
	
	public function & getProjectKeywordCompetitor()
	{
		return OS_ProjectKeywordCompetitor::get_instance();
	}
	
	public function & getProjectKeywordCompetitorOps()
	{
		return OS_ProjectKeywordCompetitorOperations::get_instance();
	}
	
	public function getRemoteAddr()
	{
		return (isset($_SERVER['REMOTE_ADDR']) ? $_SERVER['REMOTE_ADDR'] : '0.0.0.0');	
	}
	
	public function & getLanguagesList()
	{
		if(!isset($this->systemLanguages))
		{
			$systemLanguages = array(
				'en' => array("name"=>_("English")),
				'es' => array("name"=>_("Spanish")),
				'fr' => array("name"=>_("French")),
				'de' => array("name"=>_("German")),
				'it' => array("name"=>_("Italian")),
				'pt' => array("name"=>_("Portuguese")),
				'ro' => array("name"=>_("Romanian")),
				'pl' => array("name"=>_("Polish")),
				'hu' => array("name"=>_("Hungarian")),
				'fi' => array("name"=>_("Finnish")),
				'se' => array("name"=>_("Swedish"))
				);
			
			$this->systemLanguages = $systemLanguages;	
		}
		
		return $this->systemLanguages;
	}
	
	public function setSessionVar($key, $val)
	{
		$result = false;
		
		if(isset($_SESSION))
		{
			$tmpVal = $val;
			
			if(isset($_SESSION[$key]))
			{
				if(is_array($val) && is_array($_SESSION[$key]))
				{
					$tmpVal = $_SESSION[$key];
					foreach($val as $subkey => $subvar)
					{
						$tmpVal[$subkey] = $subvar;
					}
				}	
			}
			
			$_SESSION[$key] = $tmpVal;
				
			$result = true;	
		}
		
		return $result;
	}
	
	public function getSessionVar($key, $val = false)
	{
		$result = false;
		
		if(isset($_SESSION))
		{
			if(isset($_SESSION[$key]))
			{
				if($val !== false)
				{
					if(is_array($val) && is_array($_SESSION[$key]))
					{
						$tmpVal = array_values($val);
						
						$tmpResult = array();
						foreach($_SESSION[$key] as $subvar => $subval)
						{
							if(in_array($subvar, $tmpVal))
							{
								$tmpResult[$subvar] = $subval;			
							}
						}
						
						if(!empty($tmpResult)) $result = $tmpResult;
					}
					elseif(isset($_SESSION[$key][$val]))
					{
						$result = $_SESSION[$key][$val];
					}
				}
				else
				{
					$result = $_SESSION[$key];	
				}
			}
		}
		
		return $result;
	}
	
	public function unsetSessionVar($key, $val = false)
	{
		$result = false;
		
		if(isset($_SESSION))
		{
			if(isset($_SESSION[$key]))
			{
				if($val !== false)
				{
					if(is_array($val) && is_array($_SESSION[$key]))
					{
						$tmpVal = array_values($val);
						
						foreach($_SESSION[$key] as $subvar => $subval)
						{
							if(in_array($subvar, $tmpVal))
							{
								unset($_SESSION[$key][$subvar]);			
								$result = true;
							}
						}
					}
					elseif(isset($_SESSION[$key][$val]))
					{
						unset($_SESSION[$key][$val]);
						$result = true;
					}
				}
				else
				{
					unset($_SESSION[$key]);
					$result = true;
				}
			}
		}
		return $result;
	}
	
	public function getCurrentTimezone()
	{
		$result=false;
		
		if ($timezone=$this->getSessionVar('os_timezone'))
		{
			$result=$timezone;
		}
		elseif ($timezone=trim($this->getConfigVar('timezone')))
		{
			$result=$timezone;
		}
		else
		{
			$result='UTC';
		}

		return $result;
	}
	
	public function setCurrentTimezone($timezone)
	{
		return $this->setSessionVar('os_timezone',$timezone);
	}
	
	public function unsetCurrentTimezone()
	{
		return $this->unsetSessionVar('os_timezone');
	}

	public function initTimezone($timezone=false)
	{
		if ($timezone==false)
		{
			$timezone=$this->getCurrentTimezone();
		}
		
		return @date_default_timezone_set($timezone);
	}
} 
?>