<?php
class OS_Crawler
{
	private static $_instance;
	
	private $maxLinks;
	private $maxDepth;
	private $maxThreads;
	private $maxRequestSize;
	private $extractionRules;
	private $sessionIds;
	private $advancedOptions;
	
	private $successCallback;
	private $errorCallback;
	
	private $rootURL;
	private $rootPath;
	
	public function __construct()
	{
		$this->setInitialValues();
	}
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_Crawler();
		}
		return self::$_instance;
	}
	
	public function setInitialValues()
	{
		$this->setMaxLinks(10000);
		
		$this->setMaxDepth(5);
		
		$this->setMaxThreads(5);
		
		$this->setMaxRequestSize(1024);
		
		$extractionRules=array(
			'a_href'=>array(
				'type'=>'xpath',
				'actual_type'=>'link',
				'query'=>'//a',
				'url'=>array(
					'location'=>'attribute',
					'attribute'=>'href'
				),
				'anchor'=>array(
					'location'=>'nodeValue'
				),
				'rel'=>array(
					'location'=>'attribute',
					'attribute'=>'rel'
				)
			)
		);
		
		$this->setExtractionRules($extractionRules);
		
		$sessionIds=array('sid','sessionid','jsessionid','phpsessid','oscsid','lsessionid','bv_sessionid','aspsessionid');
		
		$this->setSessionIds($sessionIds);
		
		$this->setSuccessCallback(false);
		
		$this->setErrorCallback(false);
	}
	
	public function crawl($urls,$depth=1)
	{
		$utils=getOS()->getUtils();
		$memory=getOS()->getMemory();
		
		if ($depth==1)
		{
			$this->actualPagesCrawled=0;
			
			if (!is_array($urls))
			{
				$urls=array($urls);
			}

			foreach ($urls as &$url)
			{
				if ($this->isRootDomain($url))
				{
					$url=$utils->appendSlash($url);
				}
			}
		}
		
		$to_crawl=array();
		
		foreach ($urls as &$url)
		{
			if (!isset($this->detectedUrls[$url]) OR (isset($this->detectedUrls[$url]) AND $this->detectedUrls[$url]>=$depth))
			{
				$this->detectedUrls[$url]=$depth;
				$to_crawl[$url]=$url;
			}
		}
		ini_set('php_error_log','/tmp/aphp-os.txt');
		if ($to_crawl)
		{
			$http=getOS()->getHttpMulti();
			
			$to_crawl=array_chunk($to_crawl,$this->getMaxThreads(),true);
			$to_crawl_new=array();
			
			$maxDepth=$this->getMaxDepth();
			$maxLinks=$this->getMaxLinks();
			
			$crawled_urls=0;
			foreach ($to_crawl as $index=>&$to_crawl_urls)
			{
				if ($maxLinks!=0 AND $this->actualPagesCrawled>=$maxLinks)
				{
					break;
				}
				else
				{
					foreach ($to_crawl_urls as &$url)
					{
						$http->addRequest($url);
					}
					$crawled_urls+=count($to_crawl[$index]);
					unset($to_crawl[$index]);
					
					if ($response=$http->execHandlers())
					{
						foreach ($response as $url=>&$url_response)
						{
							if ($url_response)
							{
								$new_internal_url=false;
								
								if ($this->isRootDomain($url_response['final_url']))
								{
									$url_response['final_url']=$utils->appendSlash($url_response['final_url']);
								}
								
								if ($url_response['final_url']==$url)
								{
									$new_internal_url=true;
								}
								elseif ($utils->areSameDomainUrls($url,$url_response['final_url']))
								{
									if (!isset($this->detectedUrls[$url_response['final_url']]) OR (isset($this->detectedUrls[$url_response['final_url']]) AND $this->detectedUrls[$url_response['final_url']]>=$depth+1))
									{
										$this->detectedUrls[$url_response['final_url']]=$depth;
										$new_internal_url=true;
									}
								}
								
								if ($url_response['redirects'])
								{
									foreach ($url_response['redirects'] as $from_url=>&$redirect_details)
									{
										if ($this->isRootDomain($redirect_details['to_url']))
										{
											$redirect_details['to_url']=$utils->appendSlash($redirect_details['to_url']);
										}
										
										if ($from_url==$url OR !isset($this->detectedUrls[$from_url]) OR (isset($this->detectedUrls[$redirect_details['to_url']]) AND $this->detectedUrls[$from_url]>=$depth+1))
										{
											$this->detectedUrls[$from_url]=$depth;
											
											$this->actualPagesCrawled++;
											
											$errorParams=array(
												'dom'=>false,
												'depth'=>$depth,
												'url'=>$from_url,
												'http_code'=>$redirect_details['http_code'],
												'bulk_headers'=>$redirect_details['bulk_headers'],
												'bulk_info'=>false,
												'content_type'=>'text/html',
												'title'=>'',
												'load_time'=>false,
												'size'=>false
											);
											$this->triggerErrorCallback($errorParams);
										}
									}
								}
								
								if ($new_internal_url)
								{
									$domLoaded=false;$dom=false;$links=false;
									
									$isActualPage=(in_array($url_response['content_type'],array('text/plain','text/html')));
									
									if ($isActualPage)
									{
										$this->actualPagesCrawled++;
										
										if (!empty($url_response['response']))
										{
											$dom=new DOMDocument();
											libxml_use_internal_errors(true);
											$domLoaded=$dom->loadHTML($url_response['response']);
											libxml_use_internal_errors(false);
											
											if ($domLoaded)
											{
												$links=$this->extractLinks($url,$dom);
											}
										}
									}
									
									$httpCode=(string)$url_response['response_code'];
									if (!empty($url_response['bulk_info']['size_download']))
									{
										$size=$url_response['bulk_info']['size_download'];
									}
									elseif (!empty($url_response['bulk_headers']['content-length']))
									{
										$size=$url_response['bulk_headers']['content-length'];
									}
									elseif (!empty($url_response['response']))
									{
										$size=strlen($url_response['response']);
									}
									else
									{
										$size=false;
									}
									
									if (!empty($url_response['bulk_info']['total_time']))
									{
										$load_time=$url_response['bulk_info']['total_time'];
									}
									else
									{
										$load_time=false;
									}
									
									if (!in_array($httpCode[0],array(1,2)))
									{
										$errorParams=array(
											'dom'=>($domLoaded?$dom:false),
											'depth'=>$depth,
											'url'=>$url_response['final_url'],
											'http_code'=>$url_response['response_code'],
											'content_type'=>$url_response['content_type'],
											'bulk_headers'=>$url_response['bulk_headers'],
											'bulk_info'=>$url_response['bulk_info'],
											'title'=>($domLoaded?$this->getTitle($dom):''),
											'load_time'=>$load_time,
											'size'=>$size
										);
										$this->triggerErrorCallback($errorParams);
									}
									else
									{
										$successParams=array(
											'url'=>$url,
											'final_url'=>$url_response['final_url'],
											'redirects'=>$url_response['redirects'],
											'http_code'=>$url_response['response_code'],
											'content_type'=>$url_response['content_type'],
											'bulk_headers'=>$url_response['bulk_headers'],
											'bulk_info'=>$url_response['bulk_info'],
											'depth'=>$depth,
											'content'=>$url_response['response'],
											'dom'=>$dom,
											'links'=>$links,
											'load_time'=>$load_time,
											'size'=>$size
										);
	
										$this->triggerSuccessCallback($successParams);
									}
									
									if ($domLoaded)
									{
										unset($dom);

										if ($depth<$maxDepth OR $maxDepth==0)
										{
											if ($links)
											{
												if (!empty($links['internal']))
												{
													foreach ($links['internal'] as $url=>&$url_links)
													{
														if ($this->isRootDomain($url))
														{
															$url=$utils->appendSlash($url);
														}
														
														if ($this->shouldCrawlLink($url))
														{
															if (($this->actualPagesCrawled<$maxLinks OR $maxLinks==0) AND ((!isset($this->detectedUrls[$url]) OR (isset($this->detectedUrls[$url]) AND $this->detectedUrls[$url]>=$depth+1))))
															{
																$this->detectedUrls[$url]=$depth+1;
																$to_crawl_new[$url]=$url;
															}
															
															if ($this->actualPagesCrawled>=$this->maxLinks AND $maxLinks!=0)
															{
																break;
															}
														}
													}
												}
											}
										}
									
										unset($links);
									}
									else
									{
										unset($dom);
									}
								}
							}
							
							unset($response[$url]);
							
							$memory->dynamicScaling();
						}
					}
				}
			}
			
			unset($to_crawl);

			if (!empty($to_crawl_new))
			{
				$this->crawl($to_crawl_new,$depth+1);
				
				unset($to_crawl_new);
			}
		}
	}
	
	public function getTitle($dom)
	{
		$result=false;
		
		$xpath=new DOMXPath($dom);
		
		$entries=$xpath->query("//title");
		
		if (!empty($entries))
		{
			$entries=$entries->item(0);
			
			if (!empty($entries))
			{
				$result=$entries->nodeValue;
			}
		}
		
		return $result;
	}
	
	public function extractRuleElement($entry,$elementDetails)
	{
		$result=false;
		
		if ($elementDetails)
		{
			if ($elementDetails['location']=='nodeValue')
			{
				$result=trim($entry->nodeValue);
			}
			elseif ($elementDetails['location']=='attribute')
			{
				$result=trim($entry->getAttribute($elementDetails['attribute']));
			}
		}
		
		return $result;
	}
	
	public function extractLinks($url,$dom)
	{
		$result=false;
		
		$utils=getOS()->getUtils();
		$validator=getOS()->getValidator();
		
		$extractionRules=$this->getExtractionRules();
				
		$xpath=new DOMXPath($dom);
		
		$allowed_schemes=array('http','https');
		
		$baseURL=$url;
		
		$entries=$xpath->query("//base");
		if (!empty($entries))
		{
			$entries=$entries->item(0);
			
			if (!empty($entries))
			{
				$href=$entries->getAttribute('href');
				if (!empty($href))
				{
					$baseURL=$href;
				}
			}
		}
		
		
		foreach ($extractionRules as $ruleName=>$rule)
		{
			if ($rule['type']=='xpath')
			{
				$entries=$xpath->query($rule['query']);
				
				foreach ($entries as $entry)
				{
					$link=str_replace(' ','%20',$this->extractRuleElement($entry,$rule['url']));
					
					if (!empty($rule['check_if_link']))
					{
						if (!$validator->is_url($link))
						{
							$link=false;
						}
					}
					
					if ($link)
					{
						if ($parsed_link=parse_url($link))
						{
							if (!empty($parsed_link['scheme']))
							{
								if (!in_array(strtolower($parsed_link['scheme']),$allowed_schemes))
								{
									$link=false;
								}
							}
						}
						else
						{
							$link=false;
						}
					}
					
					if ($link AND strlen($link)>500)
					{
						$link=false;
					}
					
					if ($link)
					{
						if ($rule['query']=='//a')
						{
							$anchor='';
							$subtype='text';							
		
							foreach ($entry->childNodes as $child)
							{
								if ($child->nodeName=='img')
								{
									$anchor.=' '.$child->getAttribute('alt');
									$subtype='image';
								}
								else
								{
									$anchor.=' '.$child->nodeValue;
								}
							}
							
							$anchor=trim($anchor);
						}
						elseif ($rule['query']=='//option')
						{
							$anchor='';
							$subtype='text';
						}
						else
						{
							$subtype=false;
							$anchor=$this->extractRuleElement($entry,$rule['anchor']);
						}
						
						$anchor=trim(preg_replace("/\s+/"," ",$anchor));
						
						$nofollow='dofollow';
						if ($rel=$this->extractRuleElement($entry,$rule['rel']))
						{
							if (false!==strpos($rel,'nofollow'))
							{
								$nofollow='nofollow';
							}
						}
						
						if ($link=$utils->makeAbsoluteUrl($baseURL,$link))
						{
							if ($this->isRootDomain($link))
							{
								$link=$utils->appendSlash($link);
							}
							
							$link=$utils->stripHash($this->discardSessionIds($link));
							
							if ($utils->areSameDomainUrls($url,$link))
							{
								$type='internal';
							}
							else
							{
								$type='external';
							}
							
							if ($subtype)
							{
								if (!isset($result[$type][$link][$rule['actual_type']][$nofollow][$subtype][$anchor]))
								{
									$result[$type][$link][$rule['actual_type']][$nofollow][$subtype][$anchor]=0;
								}
								
								$result[$type][$link][$rule['actual_type']][$nofollow][$subtype][$anchor]++;
							}
							else
							{
								if (!isset($result[$type][$link][$rule['actual_type']][$nofollow][$anchor]))
								{
									$result[$type][$link][$rule['actual_type']][$nofollow][$anchor]=0;
								}
								
								$result[$type][$link][$rule['actual_type']][$nofollow][$anchor]++;
							}
							
//							$result[$type][$link][]=array(
//								'url'=>$link,
//								'anchor'=>$anchor,
//								'nofollow'=>$nofollow,
//								'type'=>$rule['actual_type'],
//								'occurances'=>0
//							);
						}
					}
				}
			}
		}
		
		return $result;
	}
	
	public function discardSessionIds($url)
	{
		$sessionIds=$this->getSessionIds();
		
		$parsed=parse_url($url);
		
		$found=false;
		
		if (!empty($parsed['query']))
		{
			parse_str($parsed['query'],$query);
			
			foreach ($query as $key=>$val)
			{
				if (in_array(strtolower($key),$sessionIds))
				{
					unset($query[$key]);
					
					$found=true;
				}
			}
			
			$parsed['query']=http_build_query($query);
		}
		
		if ($found)
		{
			$url=$parsed['scheme'].'://'.$parsed['host'];
			
			if (!empty($parsed['path']))
			{
				$url.=$parsed['path'];
			}
			
			if (!empty($parsed['query']))
			{
				$url.='?'.$parsed['query'];
			}
			
			if (!empty($parsed['fragment']))
			{
				$url.='#'.$parsed['fragment'];
			}
		}
		
		return $url;
	}
	
	public function isRootDomain($url)
	{
		$result=false;
		
		$osUtils=getOS()->getUtils();
		$url=$osUtils->stripEndingSlash($url);
		$parsed_url=parse_url($url);
		
		if (isset($parsed_url['scheme'],$parsed_url['host']))
		{
			if ($parsed_url['scheme'].'://'.$parsed_url['host']==$url)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function triggerSuccessCallback($params)
	{
		$result=false;
		
		if ($successCallback=$this->getSuccessCallback())
		{
			$successCallback['object']->$successCallback['method']($params);
			
			$result=true;
		}
		
		return $result;
	}
	
	public function setSuccessCallback($object,$method=false)
	{
		$result=false;
		
		if ($object===false)
		{
			$this->successCallback=false;
			
			$result=true;
		}
		elseif (is_object($object) AND $method)
		{
			if (method_exists($object,$method))
			{
				$this->successCallback=array('object'=>$object,'method'=>$method);
				
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function getSuccessCallback()
	{
		$result=false;
		
		if ($this->successCallback)
		{
			$result=$this->successCallback;
		}
		
		return $result;
	}
	
	public function triggerErrorCallback($params)
	{
		$result=false;
		
		if ($errorCallback=$this->getErrorCallback())
		{
			$errorCallback['object']->$errorCallback['method']($params);
			
			$result=true;
		}
		
		return $result;
	}
	
	public function setErrorCallback($object,$method=false)
	{
		$result=false;
		
		if ($object===false)
		{
			$this->errorCallback=false;
			
			$result=true;
		}
		elseif (is_object($object) AND $method)
		{
			if (method_exists($object,$method))
			{
				$this->errorCallback=array('object'=>$object,'method'=>$method);
				
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function getErrorCallback()
	{
		$result=false;
		
		if ($this->errorCallback)
		{
			$result=$this->errorCallback;
		}
		
		return $result;
	}
	
	public function getMaxLinks()
	{
		return $this->maxLinks;
	}
	
	public function setMaxLinks($maxLinks)
	{
		$old=$this->getMaxLinks();
		
		if (is_null($old))
		{
			$old=true;
		}
		
		$this->maxLinks=$maxLinks;
		
		return $old;
	}
	
	public function getMaxDepth()
	{
		return $this->maxDepth;
	}
	
	public function setMaxDepth($maxDepth)
	{
		$old=$this->getMaxDepth();
		
		if (is_null($old))
		{
			$old=true;
		}
		
		$this->maxDepth=$maxDepth;
		
		return $old;
	}
	
	public function getMaxThreads()
	{
		return $this->maxThreads;
	}
	
	public function setMaxThreads($maxThreads)
	{
		if ($maxThreads > 0)
		{
			$result=$this->getMaxThreads();
			
			if (is_null($result))
			{
				$result=true;
			}
			
			$this->maxThreads=$maxThreads;
		}
		else
		{
			$result=false;
		}
		
		return $result;
	}
	
	public function getMaxRequestSize()
	{
		return $this->maxRequestSize;
	}
	
	public function setMaxRequestSize($maxRequestSize)
	{
		$old=$this->getMaxRequestSize();
		
		if (is_null($old))
		{
			$old=true;
		}
		
		$this->maxRequestSize=$maxRequestSize;
		
		return $old;
	}
	
	public function getExtractionRules()
	{
		return $this->extractionRules;
	}
	
	public function setExtractionRules($extractionRules)
	{
		$old=$this->getExtractionRules();
		
		if (is_null($old))
		{
			$old=true;
		}
		
		$this->extractionRules=$extractionRules;
		
		return $old;
	}
	
	public function addExtractionRule($ruleName,$rule)
	{
		$this->extractionRules[$ruleName]=$rule;
		
		return true;
	}
	
	public function addExtractionRules($rules)
	{
		foreach ($rules as $ruleName=>$rule)
		{
			$this->addExtractionRule($ruleName,$rule);
		}
		
		return true;
	}
	
	public function removeExtractionRule($ruleName)
	{
		$result=false;
		
		$rules=$this->getExtractionRules();
		
		if (isset($rules[$ruleName]))
		{
			unset($rules[$ruleName]);
			
			$result=true;
		}
		
		return $result;
	}
	
	public function getSessionIds()
	{
		return $this->sessionIds;
	}
	
	public function setSessionIds($sessionIds)
	{
		$old=$this->getSessionIds();
		
		if (is_null($old))
		{
			$old=true;
		}
		
		$this->sessionIds=$sessionIds;
		
		return $old;
	}
	
	public function getRootURL()
	{
		return $this->rootURL;
	}
	
	public function setRootURL($rootURL)
	{
		$old=$this->getRootURL();
		
		if (is_null($old))
		{
			$old=true;
		}
		
		$this->rootURL=$rootURL;
		$this->rootPath=$this->getPathFromURL($rootURL);
		
		return $old;
	}
	
	public function getAdvancedOptions()
	{
		return $this->advancedOptions;
	}
	
	public function setAdvancedOptions($advancedOptions)
	{
		$old=$this->getAdvancedOptions();
		
		if (is_null($old))
		{
			$old=true;
		}
		
		$this->advancedOptions=$advancedOptions;
		
		return $old;
	}
	
	public function shouldCrawlLink($link_url)
	{
		$parts_results=array(
			'scope'=>true,
			'blacklist'=>true
		);
		
		$advancedOptions=$this->getAdvancedOptions();
		
		if (!empty($advancedOptions['scope']))
		{
			$link_path=$this->getPathFromURL($link_url);
			
			if ($advancedOptions['scope']=='current_dir_subdirs')
			{
				if (0!==strpos($link_path,$this->rootPath))
				{
					$parts_results['scope']=false;
				}
			}
			elseif ($advancedOptions['scope']=='current_dir')
			{
				if ($link_path!=$this->rootPath)
				{
					$parts_results['scope']=false;
				}
			}
		}
		
		if (!empty($advancedOptions['blacklist']))
		{
			foreach ($advancedOptions['blacklist'] as $pattern)
			{
				if (preg_match('|'.str_replace('*','(.*)',$pattern).'|i',$link_url))
				{
					$parts_results['blacklist']=false;
					break;
				}
			}
		}
		
		$result=true;
		foreach ($parts_results as $part_result)
		{
			$result=$result&&$part_result;
		}
		
		return $result;
	}
	
	public function getPathFromURL($url)
	{
		$path=parse_url($url,PHP_URL_PATH);
		
		if (empty($path))
		{
			$path='/';
		}
		else
		{
			if ($path[strlen($path)-1]=='/')
			{
				$path=substr($path,0,-1);
			}
			else
			{
				$path=dirname($path);
			}
		}
		
		return $path;
	}
}
?>