<?php
class OS_Crons
{
	public static $intervalTypes=array(
		'm'=>array('min'=>1,'max'=>59),
		'h'=>array('min'=>1,'max'=>23),
		'd'=>array('min'=>1,'max'=>30),
		'w'=>array('min'=>1,'max'=>4),
		'M'=>array('min'=>1,'max'=>12),
		'Y'=>array('min'=>1,'max'=>1)
	);
	
	public static function getIntervalTypesHuman()
	{
		return array(
			'm'=>array('singular'=>_('minute'),'plural'=>_('minutes')),
			'h'=>array('singular'=>_('hour'),'plural'=>_('hours')),
			'd'=>array('singular'=>_('day'),'plural'=>_('days')),
			'w'=>array('singular'=>_('week'),'plural'=>_('weeks')),
			'M'=>array('singular'=>_('month'),'plural'=>_('months')),
			'Y'=>array('singular'=>_('year'),'plural'=>_('years')),
		);
	}
	
	public static function registerCron($action,$interval,$module,$module_name='',$title='')
	{
		$result=false;
		
		if (!self::getCron($action,$module,$module_name))
		{
			$interval=explode(' ',$interval);
			
			if (count($interval)==2 AND isset(self::$intervalTypes[$interval[1]]) AND self::$intervalTypes[$interval[1]]['min']<=$interval[0] AND self::$intervalTypes[$interval[1]]['max']>=$interval[0])
			{
				$db=getOS()->getDb();
				
				$time=$db->DBTimeStamp(time());
				$ip=(!empty($_SERVER['REMOTE_ADDR'])?$_SERVER['REMOTE_ADDR']:'0.0.0.0');
				
				$query="INSERT INTO ".$db->dbPrefix()."crons (module,module_name,title,action,`interval`,interval_type,status,status_dt,status_ip) VALUES (?,?,?,?,?,?,?,?,?)";
				if (false!==$db->query($query,array($module,$module_name,$title,$action,$interval[0],$interval[1],'E',$time,$ip)))
				{
					$result=true;
				}
			}
		}
		else
		{
			$result=self::updateCronInterval($action,$interval,$module,$module_name);
		}
		
		return $result;
	}
	
	public static function unregisterCron($action,$module,$module_name='')
	{
		$result=false;
		
		if ($cron_row=self::getCron($action,$module,$module_name))
		{
			$db=getOS()->getDb();
			
			$query="DELETE FROM ".$db->dbPrefix()."crons WHERE id=?";
			if (false!==$db->query($query,array($cron_row['id'])))
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public static function updateCronInterval($action,$interval,$module,$module_name='')
	{
		$result=false;
		
		if ($cron_row=self::getCron($action,$module,$module_name))
		{
			$interval=explode(' ',$interval);
			
			if (count($interval)==2 AND isset(self::$intervalTypes[$interval[1]]) AND self::$intervalTypes[$interval[1]]['min']<=$interval[0] AND self::$intervalTypes[$interval[1]]['max']>=$interval[0])
			{
				$db=getOS()->getDb();
				
				$query="UPDATE ".$db->dbPrefix()."crons SET `interval`=?,interval_type=? WHERE id=?";
				if (false!==$db->query($query,array($interval[0],$interval[1],$cron_row['id'])))
				{
					$result=true;
				}
			}
		}
		else
		{
			$result=self::registerCron($action,$interval,$module,$module_name);
		}
		
		return $result;
	}
	
	public static function unregisterCronsByModule($module,$module_name='')
	{
		$result=true;
		
		if ($crons=self::getCronsByModule($module,$module_name))
		{
			foreach ($crons as $cron_id=>$cron_details)
			{
				if (!self::unregisterCron($cron_details['action'],$module,$module_name))
				{
					$result=false;
				}
			}
		}
		
		return $result;
	}
	
	public static function enableCron($action,$module,$module_name='')
	{
		$result=false;
		
		if ($cron_row=self::getCron($action,$module,$module_name))
		{
			if ($cron_row['status']!='E')
			{
				$db=getOS()->getDb();
				
				$time=$db->DBTimeStamp(time());
				$ip=(!empty($_SERVER['REMOTE_ADDR'])?$_SERVER['REMOTE_ADDR']:'0.0.0.0');
				
				$query="UPDATE ".$db->dbPrefix()."crons SET status=?,status_dt=?,status_ip=? WHERE id=?";
				if (false!==$db->query($query,array('E',$time,$ip,$cron_row['id'])))
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public static function disableCron($action,$module,$module_name='')
	{
		$result=false;
		
		if ($cron_row=self::getCron($action,$module,$module_name))
		{
			if ($cron_row['status']!='D')
			{
				$db=getOS()->getDb();
				
				$time=$db->DBTimeStamp(time());
				$ip=(!empty($_SERVER['REMOTE_ADDR'])?$_SERVER['REMOTE_ADDR']:'0.0.0.0');
				
				$query="UPDATE ".$db->dbPrefix()."crons SET status=?,status_dt=?,status_ip=? WHERE id=?";
				if (false!==$db->query($query,array('D',$time,$ip,$cron_row['id'])))
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public static function getCronsByModule($module,$module_name='')
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."crons WHERE module=?".($module=='app'?" AND module_name=?":'');
		$query_params=($module=='app'?array($module,$module_name):array($module));
		$dbresult=$db->query($query,$query_params);
		while($row=$db->fetchRow($dbresult))
		{
			$result[$row['id']]=$row;
		}
		
		return $result;
	}
	
	public static function getCronByID($cron_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."crons WHERE id=?";
		$dbresult=$db->query($query,array($cron_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row;
		}
		
		return $result;
	}
	
	public static function getCron($action,$module,$module_name='')
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."crons WHERE module=? ".($module=='app'?" AND module_name=?":'')." AND action=?";
		$query_params=($module=='app'?array($module,$module_name,$action):array($module,$action));
		$dbresult=$db->query($query,$query_params);
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row;
		}
		
		return $result;
	}
	
	public static function getCrons()
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."crons ORDER BY module='core' DESC, module_name ASC, action ASC");
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['id']]=$row;
		}
		
		return $result;
	}
	
	public static function getScheduledCrons($time=false)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		if (!$time)
		{
			$time=time();
		}
		
		$date_arr=array('Y'=>date('Y',$time),'M'=>date('n',$time),'w'=>date('W',$time),'dow'=>date('N',$time),'d'=>date('j',$time),'h'=>date('G',$time),'m'=>(int)date('i',$time));
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."crons WHERE status=?",array('E'));
		while ($row=$db->fetchRow($dbresult))
		{
			$is_scheduled=false;
			
			if ($row['interval_type']=='Y')
			{
				if ($date_arr['M']==1 AND $date_arr['w']==1 AND $date_arr['d']==1 AND $date_arr['h']==1 AND $date_arr['m']==2)
				{
					if ($date_arr[$row['interval_type']] % $row['interval']==0)
					{
						$is_scheduled=true;
					}
				}
			}
			elseif ($row['interval_type']=='M')
			{
				if ($date_arr['w']==1 AND $date_arr['d']==1 AND $date_arr['h']==1 AND $date_arr['m']==2)
				{
					if ($date_arr[$row['interval_type']] % $row['interval']==0)
					{
						$is_scheduled=true;
					}
				}
			}
			elseif ($row['interval_type']=='w')
			{
				if ($date_arr['dow']==1 AND $date_arr['h']==1 AND $date_arr['m']==2)
				{
					if ($date_arr[$row['interval_type']] % $row['interval']==0)
					{
						$is_scheduled=true;
					}
				}
			}
			elseif ($row['interval_type']=='d')
			{
				if ($date_arr['h']==1 AND $date_arr['m']==2)
				{
					if ($date_arr[$row['interval_type']] % $row['interval']==0)
					{
						$is_scheduled=true;
					}
				}
			}
			elseif ($row['interval_type']=='h')
			{
				if ($date_arr['m']==2)
				{
					if ($date_arr[$row['interval_type']] % $row['interval']==0)
					{
						$is_scheduled=true;
					}
				}
			}
			elseif ($row['interval_type']=='m')
			{
				if ($date_arr[$row['interval_type']] % $row['interval']==0)
				{
					$is_scheduled=true;
				}
			}
			
			if ($is_scheduled)
			{
				$result[$row['id']]=$row;
			}
		}

		return $result;
	}
	
	public static function runScheduledCrons($time=false)
	{
		$result=false;
		
		if ($to_run=self::getScheduledCrons($time))
		{
			$db=getOS()->getDb();
			
			$root_path=getOS()->getConfigVar('root_path');
		
			$apps_path=os_join_path($root_path,'apps');

			foreach ($to_run as $cron_id=>$cron_details)
			{
				self::runCron($cron_id);
			}
			
			$result=true;
		}
		
		return $result;
	}
	
	public static function runCron($cron_id)
	{
		$OS=getOS();
		$osUtils=$OS->getUtils();
		
		$cron_child_lib=os_join_path($OS->getConfigVar('root_path'),'crons','cron_child.php');
		
		$command=$osUtils->getPHPCLI()." {$cron_child_lib} {$cron_id}";
		
		return $osUtils->execForked($command);
	}
	
	public static function registerCoreCrons($crons)
	{
		$result=true;
		$responseData=array('tests'=>array(),'notifications'=>array());
		
		foreach ($crons as $cron)
		{
			if (!self::registerCron($cron['action'],$cron['interval'],'core','',$cron['title']))
			{
				$returnType=array('type'=>'error','message'=>_("Unable to register cron"));
				$result=false;
			}
			else
			{
				$returnType=array('type'=>'success');
			}
			
			$responseData['tests'][]=array('test'=>array('message'=>_("Registering")." `{$cron['action']}` "._("cron")),'result'=>$returnType);
		}
		
		$responseData['result']=$result;
		
		return $responseData;
	}
	
	public static function isCLI()
	{
		$result=false;
		
		if (php_sapi_name()=='cli')
		{
			$result=true;
		}
		
		return $result;
	}
	
	public static function forceCLI()
	{
		if (!self::isCLI())
		{
			exit;
		}
	}
}
?>