<?php
class OS_Daemon
{
	public static function registerDaemon($action,$module,$module_name='',$title='')
	{
		$result=false;
		
		if (!self::getDaemon($action,$module,$module_name))
		{
			$db=getOS()->getDb();
			
			$time=$db->DBTimeStamp(time());
			$ip=(!empty($_SERVER['REMOTE_ADDR'])?$_SERVER['REMOTE_ADDR']:'0.0.0.0');
			
			$query="INSERT INTO ".$db->dbPrefix()."daemons (module,module_name,title,action,status,status_dt,status_ip) VALUES (?,?,?,?,?,?,?)";
			if (false!==$db->query($query,array($module,$module_name,$title,$action,'E',$time,$ip)))
			{
				$result=true;
			}
		}
		else
		{
			$result=true;
		}
		
		return $result;
	}
	
	public static function unregisterDaemon($action,$module,$module_name='')
	{
		$result=false;
		
		if ($daemon_row=self::getDaemon($action,$module,$module_name))
		{
			$db=getOS()->getDb();
			
			$query="DELETE FROM ".$db->dbPrefix()."daemons WHERE id=?";
			if (false!==$db->query($query,array($daemon_row['id'])))
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public static function unregisterDaemonsByModule($module,$module_name='')
	{
		$result=true;
		
		if ($daemons=self::getDaemonsByModule($module,$module_name))
		{
			foreach ($daemons as $daemon_id=>$daemon_details)
			{
				if (!self::unregisterDaemon($daemon_details['action'],$module,$module_name))
				{
					$result=false;
				}
			}
		}
		
		return $result;
	}
	
	public static function enableDaemon($action,$module,$module_name='')
	{
		$result=false;
		
		if ($daemon_row=self::getDaemon($action,$module,$module_name))
		{
			if ($daemon_row['status']!='E')
			{
				$db=getOS()->getDb();
				
				$time=$db->DBTimeStamp(time());
				$ip=(!empty($_SERVER['REMOTE_ADDR'])?$_SERVER['REMOTE_ADDR']:'0.0.0.0');
				
				$query="UPDATE ".$db->dbPrefix()."daemons SET status=?,status_dt=?,status_ip=? WHERE id=?";
				if (false!==$db->query($query,array('E',$time,$ip,$daemon_row['id'])))
				{
					$result=true;
				}
			}
			else
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public static function disableDaemon($action,$module,$module_name='')
	{
		$result=false;
		
		if ($daemon_row=self::getDaemon($action,$module,$module_name))
		{
			if ($daemon_row['status']!='D')
			{
				$db=getOS()->getDb();
				
				$time=$db->DBTimeStamp(time());
				$ip=(!empty($_SERVER['REMOTE_ADDR'])?$_SERVER['REMOTE_ADDR']:'0.0.0.0');
				
				$query="UPDATE ".$db->dbPrefix()."daemons SET status=?,status_dt=?,status_ip=? WHERE id=?";
				if (false!==$db->query($query,array('D',$time,$ip,$daemon_row['id'])))
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public static function getDaemonsByModule($module,$module_name='')
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."daemon WHERE module=?".($module=='app'?" AND module_name=?":'');
		$query_params=($module=='app'?array($module,$module_name):array($module));
		$dbresult=$db->query($query,$query_params);
		while($row=$db->fetchRow($dbresult))
		{
			$result[$row['id']]=$row;
		}
		
		return $result;
	}
	
	public static function getDaemonByID($daemon_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."daemons WHERE id=?";
		$dbresult=$db->query($query,array($daemon_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row;
		}
		
		return $result;
	}
	
	public static function getDaemon($action,$module,$module_name='')
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."daemons WHERE module=? ".($module=='app'?" AND module_name=?":'')." AND action=?";
		$query_params=($module=='app'?array($module,$module_name,$action):array($module,$action));
		$dbresult=$db->query($query,$query_params);
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row;
		}
		
		return $result;
	}
	
	public static function getDaemons()
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."daemons ORDER BY module='core' DESC, module_name ASC, action ASC");
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['id']]=$row;
		}
		
		return $result;
	}
	
	public static function getEnabledDaemons()
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."daemons WHERE status=?",array('E'));
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['id']]=$row;
		}
		
		return $result;
	}
	
	public static function startEnabledDaemons()
	{
		$result=false;
		
		if ($to_run=self::getEnabledDaemons())
		{
			$db=getOS()->getDb();
			
			foreach ($to_run as $daemon_id=>$daemon_details)
			{
				self::startDaemon($daemon_details['module'],$daemon_details['module_name'],$daemon_details['action']);
			}
			
			$result=true;
		}
		
		return $result;
	}
	
	public static function startDaemon($module,$module_name,$action)
	{
		$OS=getOS();
		$osUtils=$OS->getUtils();
		
		$fork_lib=os_join_path($OS->getConfigVar('root_path'),'daemons','daemon.php');
		
		$command=$osUtils->getPHPCLI()." {$fork_lib} {$module}";
		
		if (!empty($module_name))
		{
			$command.=" {$module_name}";
		}
		
		$command.=" {$action}";
		
		return $osUtils->execForked($command);
	}
	
	public static function markDaemonInit($module,$module_name,$action)
	{
		$result=false;
		
		if ($daemon_row=self::getDaemon($action,$module,$module_name))
		{
			$db=getOS()->getDb();
			
			$time=$db->DBTimeStamp(time());
			
			$dbresult=$db->query("UPDATE ".$db->dbPrefix()."daemons SET inits=inits+1,init_dt=? WHERE id=?",array($time,$daemon_row['id']));
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public static function getDaemonLockFile($module,$module_name,$action)
	{
		return os_join_path(getOS()->getConfigVar('storage_path'),'daemon_'.$module.(!empty($module_name)?'_'.$module_name:'').'_'.$action.'.lock');
	}
	
	public static function registerCoreDaemons($daemons)
	{
		$result=true;
		$responseData=array('tests'=>array(),'notifications'=>array());
		
		foreach ($daemons as $daemon)
		{
			if (!self::registerDaemon($daemon['action'],'core','',$daemon['title']))
			{
				$returnType=array('type'=>'error','message'=>_("Unable to register daemon"));
				$result=false;
			}
			else
			{
				$returnType=array('type'=>'success');
			}
			
			$responseData['tests'][]=array('test'=>array('message'=>_("Registering")." `{$daemon['action']}` "._("daemon")),'result'=>$returnType);
		}
		
		$responseData['result']=$result;
		
		return $responseData;
	}
	
	public static function isCLI()
	{
		$result=false;
		
		if (php_sapi_name()=='cli')
		{
			$result=true;
		}
		
		return $result;
	}
	
	public static function forceCLI()
	{
		if (!self::isCLI())
		{
			exit;
		}
	}
}
?>