<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

final class OS_Database 
{
	private static $_instance;
	
	private static $_dbConnections;
	
	private static $_currentConnection;
	
	private $_dbPrefix;

	public function __construct() {}
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
    	{
			self::$_instance = new OS_Database();
    	}
    	return self::$_instance;
	}
	
	public static function &getDBConnection()
	{
		$dbConnectionName = self::$_currentConnection;
		
		return self::$_dbConnections[$dbConnectionName];
	}
	
	public function &addDBConnection($dbConnectionName, $dbConnectionDetails)
	{
		$result = false;
		
		if(isset(self::$_dbConnections[$dbConnectionName]))
		{
			$result = true;
		}
		else
		{
			//initialize a Database for current connection
		    $db_dsn = $dbConnectionDetails['db_driver'].':dbname='.$dbConnectionDetails['db_name'].";host=".$dbConnectionDetails['db_hostname'];
		    $db_username = $dbConnectionDetails['db_username'];
		    $db_password = $dbConnectionDetails['db_password'];
		    
			try
			{
				$newDBConnection = new PDO($db_dsn, $db_username, $db_password);
				$newDBConnection->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
				
				self::$_dbConnections[$dbConnectionName] = $newDBConnection;
				
				$result = true;
			}
			catch (PDOException $e){trigger_error('DB Connection failed: '.$e->getMessage(),E_USER_ERROR);exit;}	
		}
		
		return $result;
	}
	
	public function query($query, $data = false)
	{
		//if there is no connection set the default one (change it afeter install)
		if(!isset(self::$_currentConnection))
		{
			$dbConnectionName = 'default';
			
			$OS = getOS();
			
		    //initialize a dbConnection for default Database
		    $dbConnectionDetails = array(
		    	'db_driver' => $OS->getConfigVar('db_driver'),
		    	'db_hostname' => $OS->getConfigVar('db_hostname'),
		    	'db_name' => $OS->getConfigVar('db_name'),
		    	'db_username' => $OS->getConfigVar('db_username'),
		    	'db_password' => $OS->getConfigVar('db_password')
		    	);
		    
		    $this->addDBConnection($dbConnectionName, $dbConnectionDetails);
		    $this->setCurrentDbConnection($dbConnectionName);
		}
		
		try
		{
			$osDBHandler = $this->getDBConnection();
			
			if (!is_string($query))
			{
				trigger_error(var_export($query,true));
			}
			
			$osStatementHandler = $osDBHandler->prepare($query);
			
			if($data !== false)
			{
				$osStatementHandler->execute($data);	
			}
			else
			{
				$osStatementHandler->execute();
			}
		}
		catch (PDOException $e)
		{
			self::dbClose();
			
			//stack_trace();
			
			$query = htmlspecialchars($query,ENT_QUOTES,"UTF-8");
			$pdoException = htmlspecialchars($e->getMessage(),ENT_QUOTES,"UTF-8"); 
			$error="DB Query failed: <br>\n\nPHP File: <b>".$_SERVER['SCRIPT_NAME']."</b><br>\n\n";
			$error.="The following SQL produced an error:<br>\n<b>{$query}</b><br>\n";
			if($data !== false) $error.="Query params <b>".implode("|",$data)."</b><br>\n";
			$error.="MySQL error: <b>{$pdoException}</b><br>\n\n";
			
			trigger_error($error,E_USER_ERROR);exit;
		}
		 
		return $osStatementHandler;	
	}
		
	public function fetchRow($results)
	{
		
		$result = false;
		
		try
		{
			$osDBHandler = self::getDBConnection();
			
			$result = $results->fetch(PDO::FETCH_ASSOC);	
		}
		catch (PDOException $e)
		{
			self::dbClose();
			
			$pdoException = htmlspecialchars($e->getMessage(),ENT_QUOTES,"UTF-8");
			$traceData = var_export($e->getTrace(),true);
			trigger_error('DB Connection failed: '.$pdoException ." : ". $e->getCode(),E_USER_ERROR);exit;
		}	
		
		return $result; 	
	}
	
	public function dbPrefix()
	{
	  if(!isset($this->_dbPrefix))
	  {
	  	$this->setDbPrefix(getOS()->getConfigVar('db_prefix'));
	  }
	  
	  return $this->_dbPrefix;
	}	
	
	
	public function setDbPrefix($dbPrefix)
	{
		$this->_dbPrefix = $dbPrefix;
	}

	public function DBTimeStamp($timestamp)
	{
		return date("Y-m-d H:i:s",$timestamp);
	}
	
	public function getInsertId()
	{
		$osDBHandler = self::getDBConnection();
		
		return $osDBHandler->lastInsertId();	
	}
	
	public function getAffectedRows()
	{
		$osDBHandler = self::getDBConnection();
		
		return $osDBHandler->rowCount();	
	}
	
	//kill current dbConnection
	public function dbClose($dbConnectionName = false)
	{
		if(isset(self::$_currentConnection))
		{
			if(is_object(self::$_dbConnections[self::$_currentConnection]))
			{
				self::$_dbConnections[self::$_currentConnection] = null;
			}
		}
	}
	
	public function setCurrentDbConnection($dbConnectionName)
	{
		//TODO: check if connection exists in config
		self::$_currentConnection = $dbConnectionName;
	}

	public function getCurrentDbConnection()
	{
		return self::$_currentConnection;
	}
} 
?>