<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_DatabaseOperations 
{
	private static $_instance;	
	
	public function __construct() {}

	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
    	{
			self::$_instance = new OS_DatabaseOperations();
    	}
    	return self::$_instance;
	}
	
	public function getDbTables()
	{
		$OS = getOS();
			
		$db = $OS->getDb();
		
		$dbPrefix = $db->dbPrefix();

		$result = array();
		
		$dbresult = $db->query("SHOW TABLES");
		while($row = $db->fetchRow($dbresult))
		{
			$tblName = current($row);
			
			if(strpos($tblName,$dbPrefix) === 0)
			{
				$result[] = substr($tblName,strlen($dbPrefix));	
			}
		}
		
		return $result;
	}
	
	
	public function getTableColumns($tblName)
	{
		$result = array();

		$OS = getOS();
			
		$db = $OS->getDb();
			
		$dbresult = $db->query("SHOW COLUMNS FROM {$tblName}");
		while($row = $db->fetchRow($dbresult))
		{
			if(isset($row['Field']))
			{
				$fieldName = strtolower($row['Field']);
				
				foreach($row as $field => $value)
				{
					$result[$fieldName][strtolower($field)] = $value;
				}
			}
		}
		
		return $result; 
	}
	
	public function getTableIndexes($tblName)
	{
		$result = array();

		$OS = getOS();
			
		$db = $OS->getDb();
		
		$excludeFields = array('Table', 'Key_name', 'Seq_in_index', 'Non_unique');
		
		$dbresult = $db->query("SHOW INDEXES FROM {$tblName}");
		while($row = $db->fetchRow($dbresult))
		{
			if(isset($row['Key_name'], $row['Seq_in_index'], $row['Column_name'], $row['Index_type']))
			{
				$fieldName = $row['Key_name'];
				
				$tmpArr = array();
				foreach($row as $field => $value) 
				{
					if(!in_array($field, $excludeFields))
					{
						$tmpArr[strtolower($field)] = $value;
					}
				}
				
				$result[$fieldName]['non_unique'] = $row['Non_unique'];
				$result[$fieldName]['indexes'][$row['Seq_in_index']] = $tmpArr;
			}
		}
		
		return $result; 
	}
	

	public function createTableSQL($tblname, $fields, $tblIndexes, $tableoptions = false)
	{
		if (!$tableoptions) $tableoptions = array();

		$fieldsDetails = $this->generateFieldsSQL($fields);
		
		$sql = array(); $details = array(); $flag = false;
		
		//add table primary key
		if(isset($tblIndexes['PRIMARY']))
		{
			$idxColumns = array();
			foreach($tblIndexes['PRIMARY']['indexes'] as $idxDetails) $idxColumns[] = $idxDetails['column_name'];
			$fieldsDetails["index_primary"] = "PRIMARY KEY (`".implode("`,`", $idxColumns)."`)";
		}
		
		$sqlString = "CREATE TABLE {$tblname} (".implode(", ",$fieldsDetails).")";
		
		if(isset($tableoptions['engine'])) $sqlString .=" ENGINE={$tableoptions['engine']}";
		if(isset($tableoptions['auto_increment'])) $sqlString .=" AUTO_INCREMENT={$tableoptions['auto_increment']}";
		$sqlString .=" DEFAULT CHARSET=".(isset($tableoptions['charset'])?$tableoptions['charset']:'latin1');
		
		
		$opDetails = _("Creating table").": {$tblname}";
		
		$result = array('sql' => array($sqlString), 'details' => array($opDetails));
		
		return $result;
	}
	
	
	public function addColumnSQL($tblname, $fields)
	{
		$sql = array();
		
		$fieldsDetails = $this->generateFieldsSQL($fields);
		
		$alter = 'ALTER TABLE ' . $tblname . ' ADD';
		
		foreach($fieldsDetails as $fieldString)
		{
			$sql[] = $alter . $fieldString;
		}
		return $sql;
	}
	
	public function alterColumnSQL($tblname, $fields)
	{
		$sql = array();
		
		$fieldsDetails = $this->generateFieldsSQL($fields);
		
		$alter = 'ALTER TABLE ' . $tblname . ' MODIFY COLUMN ';
		
		foreach($fieldsDetails as $fieldString)
		{
			$sql[] = $alter . $fieldString;
		}
		return $sql;
	}
	
	public function dropColumnSQL($tblname, $fields)
	{
		if (!is_array($fields)) $fields = explode(',',$fields);
		
		$sql = array();
		
		$alter = 'ALTER TABLE ' . $tblname . ' DROP COLUMN';
		
		foreach($fields as $fieldString)
		{
			$sql[] = $alter . $fieldString;
		}
		return $sql;
	}
	
	public function changeTableSQL($tblname, $schemaTblFields, $schemaTblIndexes)
	{
		// check table exists
		$originalTblColumns = $this->getTableColumns($tblname);
		
		if (empty($originalTblColumns))
		{ 
			return $this->createTableSQL($tblname, $schemaTblFields, $schemaTblIndexes);
		}

		$sql = array(); $opsDetails = array(); $has_changes = false;
		
		if (is_array($schemaTblFields))
		{
			$holdfields = array();
			foreach($schemaTblFields as $k => $v)
			{
				if ( isset($originalTblColumns[$k]) && is_array($originalTblColumns[$k]) )
				{
					$diff = array_diff($originalTblColumns[$k],$v);
					
					if(count($diff) > 0)
					{
						$holdfields[$k] = $v;	
					}
				}
				else
				{
					$holdfields[$k] = $v;
				}		
			}
			$fields = $holdfields;
		
		
			//already exists, alter table instead
			if (!empty($fields))
			{
				$tableDetails=array('alters'=>array(),'changes'=>array());
				
				foreach ($fields as $index => $field)
				{
					if ( isset($originalTblColumns[$index]) && is_array($originalTblColumns[$index]) )
					{
						$sql[] = current($this->alterColumnSQL($tblname, array($field)));
						
						$tableDetails['alters'][]=$index;
						
						$has_changes = true;
					}
					else
					{
						$sql[] = current($this->addColumnSQL($tblname, array($field)));
						
						$tableDetails['adds'][]=$index;
						
						$has_changes = true;
					}
				}	
				
				if (!empty($tableDetails['alters']))
				{
					$opsDetails[] = _("Alter column(s) in")." {$tblname}: ".implode(', ',$tableDetails['alters']);
				}
				
				if (!empty($tableDetails['adds']))
				{
					$opsDetails[] = _("Add column(s) to")." {$tblname}: ".implode(', ',$tableDetails['adds']);
				}
			}
		}
		
		$result = ($has_changes ? array('sql' => $sql, 'details' => $opsDetails) : array());
		
		return $result;
	}
	
	public function processTableIndexes($tblName, $originalTblIndexes, $schemaIndexes)
	{
		$sql = array(); $opsDetails = array(); $has_changes = false;
		
		if(!empty($schemaIndexes))
		{
			$indexData = array();
			
			foreach($schemaIndexes as $index_name => $details)
			{
				$drop_primary_index = false;
				$is_primary_index = ($index_name == 'PRIMARY' ? true : false);
				
				$src_idx_columns = array();
				foreach($details['indexes'] as $idx_details) $src_idx_columns[] = $idx_details['column_name'].(empty($idx_details['sub_part'])?'':'('.$idx_details['sub_part'].')');

				if(isset($originalTblIndexes[$index_name]))
				{
					//check if index has been changed
					$originalIndexData = $originalTblIndexes[$index_name];
					
					$local_idx_columns = array();
					foreach($originalIndexData['indexes'] as $idx_details) $local_idx_columns[] = $idx_details['column_name'].(empty($idx_details['sub_part'])?'':'('.$idx_details['sub_part'].')');
					
					$drop_index = false; 
					if($details['non_unique'] != $originalIndexData['non_unique'])
					{
						$drop_index = true;
					}
					
					$diff = array_diff($local_idx_columns, $src_idx_columns);
					
					if(count($diff) > 0)
					{
						$drop_index = true;
					}
					
					if($drop_index)
					{
						unset($originalTblIndexes[$index_name]);
						
						if($is_primary_index)
						{
							$indexData[] = "DROP PRIMARY KEY";
						}
						else
						{
							$indexData[] = "DROP INDEX {$index_name}";	
						}
						
						if($is_primary_index)
						{
							$drop_primary_index = true;	
						}
					}
				}
				
				
				//create new index (only if it not exists)
				if(!isset($originalTblIndexes[$index_name]))
				{
					if($is_primary_index)
					{
						if($drop_primary_index)
						{
							$column_name = $details['indexes'][1]['column_name'];
							$indexData[] = "ADD PRIMARY KEY {$column_name} ({$column_name})";

							$opsDetails[] = _("Process PRIMARY index for")." {$tblName}: {$column_name}";
						}
					}
					else
					{
						$is_index_unique = ($details['non_unique'] == "1" ? "": " UNIQUE");
						
						$indexData[] = "ADD{$is_index_unique} INDEX {$index_name} (".implode(",", $src_idx_columns).")";
						
						$opsDetails[] = _("Process index for")." {$tblName}: {$index_name}";
					}
				}
				else
				{
					//append fields to existing index
					$original_idx_columns = array();
					foreach($originalTblIndexes[$index_name]['indexes'] as $idx_details)
					{
						$original_idx_columns[] = $idx_details['column_name'].(empty($idx_details['sub_part'])?'':'('.$idx_details['sub_part'].')');
					} 
					
					$src_idx_diff = array_diff($src_idx_columns, $original_idx_columns);
					$original_idx_diff = array_diff($original_idx_columns, $src_idx_columns);
					
					//add the new fieds to the original index
					if((!empty($idx_diff)) || (!empty($original_idx_diff)))
					{
						$is_index_unique = ($details['non_unique'] == "1" ? "": " UNIQUE");
					
						$indexData[] = "DROP INDEX {$index_name}";
					
						$indexData[] = "ADD{$is_index_unique} INDEX {$index_name} (".implode(",", $src_idx_columns).")";
					
						$opsDetails[] = _("Process index for")." {$tblName}: {$index_name}";
					}
				}
			}
			
			if(!empty($indexData))
			{
				$sql[] = "ALTER TABLE {$tblName} ".implode(", ",$indexData);
				$has_changes = true;	
			}
		}
		
		$result = ($has_changes ? array('sql' => $sql, 'details' => $opsDetails) : array());
		 
		return $result;
	}
	
	public function renameTableSQL($oldTblName, $newTblName)
	{
		return array(sprintf('RENAME TABLE %s TO %s', $oldTblName, $newTblName));
	}
	

	public function executeSQLBatch($batchQueriesData)
	{
		$result = false;
		$responseData = array('tests'=> array(), 'notifications'=> array());
		
		if(!empty($batchQueriesData))
		{
			//use custom DB connection
			$OS = getOS();
			
			$db = $OS->getDb();
			
			$dbPrefix = $db->dbPrefix();   
			
			foreach($batchQueriesData as $tblName => $operationTypes)
			{
				$fullTblName = $dbPrefix.$tblName;
				
				foreach($operationTypes as $operationType => $operations)
				{
					if(!empty($operations['sql']))
					{
						foreach($operations['sql'] as $index => $queryString)
						{
							$db->query($queryString);
							
							$operationResult = true;
							//check affected rows
							//$result[$tblName][$operationType] = $queryString;
						}
						
						foreach($operations['details'] as $index => $testText)
						{
							$operationResult = true;
							$responseData['tests'][] = array('test'=>array('message' => $testText),'result'=>array('type'=>($operationResult ? 'success' : 'error'))); 
						}
						
						$result = true;	
					}
				}
			}
		}
		
		$responseData['result'] = $result;
		
		return $responseData;
	}
	
	
	public function testDBConnection($dbConnectionDetails)
	{
		$responseData = array();
		
		$db_dsn = $dbConnectionDetails['db_driver'].':dbname='.$dbConnectionDetails['db_name'].";host=".$dbConnectionDetails['db_hostname'];
	    $db_username = $dbConnectionDetails['db_username'];
	    $db_password = $dbConnectionDetails['db_password'];
		
		try
		{
			$newDBConnection = new PDO($db_dsn, $db_username, $db_password);
			$newDBConnection->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
			
			$responseData['result'] = true;
		}
		catch (PDOException $e)
		{
			$responseData['result'] = false;
			$responseData['error'] = $this->pdoDbException($e,'message');
		}
			
		return $responseData;
	}
	
	public function testDBPrivileges($dbConnectionDetails)
	{
		$responseData = array();
		
		$OS = getOS();
		
		$db = $OS->getDB();
		
		$db->addDBConnection('installTest',$dbConnectionDetails);
			
		$db->setCurrentDbConnection('installTest');
		
		$dbresult = $db->query("SHOW GRANTS FOR CURRENT_USER");
		while($row = $db->fetchRow($dbresult))
		{
			print_r($row);
		}
		
		exit;
			
		return $responseData;
	}
	
	
	public function pdoDbException($PDOException ,$responseType = false)
	{
		$eMessage = $PDOException->getMessage();
		
		if($responseType == 'message') 
		{
			if(strstr($eMessage, 'SQLSTATE['))
			{
				preg_match('/SQLSTATE\[(\w+)\] \[(\w+)\] (.*)/', $eMessage, $matches);
            	$code = ($matches[1] == 'HT000' ? $matches[2] : $matches[1]);
            	$eMessage = $matches[3];
			}
		}
		elseif($responseType == 'code')
		{
			$eMessage = $PDOException->getCode();
		}
		
		return $eMessage;
	}

	private function generateFieldsSQL($fields)
	{
		$fieldsDetails = array();
		
		foreach($fields as $cfield => $values)
		{
			$tmpString = '';
			
			if(!empty($values['field'])) $tmpString .= "`{$values['field']}`";
			
			if(!empty($values['type'])) $tmpString .= " {$values['type']}";
			
			$tmpString .= " ".(strtolower($values['null']) == 'no' ? "NOT NULL" : "NULL");
			
			if(!empty($values['default'])) $tmpString .= " DEFAULT '{$values['default']}'";
			
			if(!empty($values['extra'])) $tmpString .= " ".strtoupper($values['extra']);
			
			$fieldsDetails[$cfield] = $tmpString;
		}
		
		return $fieldsDetails;
	}
	
	public function getAppTables($appName)
	{
		$result = array();
		
		$OS = getOS();
			
		$db = $OS->getDb();
		
		$dbPrefix = $db->dbPrefix();
		
		$os_db_tables = $this->getDbTables();
		
		foreach($os_db_tables as $tblName)
		{
			//get only OS core tables
			if(strpos($tblName,"app_{$appName}") === 0)
			{
				$result[] = $tblName;
			}			
		}
		
		return $result;
	}
	
	public function getAppTablesFull($appName)
	{
		$result = array();
		
		$db_app_tables = $this->getAppTables($appName);
		
		$db_app_tables = array_flip($db_app_tables);
		
		$dbPrefix = getOS()->getDB()->dbPrefix();
		
		if(!empty($db_app_tables))
		{
			ksort($db_app_tables);
			
			//get tables fields info
			foreach($db_app_tables as $tblName => $index)
			{
				$fullTblName = $dbPrefix.$tblName;
				
				//get table columns
				$result[$tblName]['columns'] = $this->getTableColumns($fullTblName);
				
				//get table indexes
				$result[$tblName]['indexes'] = $this->getTableIndexes($fullTblName);
			}
		}
		
		return $result;
	}
	

	public function getDbTablesFull($options = array())
	{
		$result = array();
		
		$dbPrefix = getOS()->getDb()->dbPrefix();
		
		$dbTables = $this->getDbTables();
		
		$include_apps = (in_array('apps', $options) ? true : false);
		
		$include_columns = (in_array('columns', $options) ? true : false);
		
		$include_indexes = (in_array('indexes', $options) ? true : false);
		
		if(!empty($dbTables))
		{
			$dbTables = array_flip($dbTables);
			
			ksort($dbTables);
			
			//get tables fields info
			$db_os_tables = array();
			foreach($dbTables as $tblName => $fields)
			{
				//get only OS core tables (exclude app related tables)
				$add_table = true;
				if(!$include_apps) if(strpos($tblName,"app_") !== false) $add_table = false;
				
				if($add_table)
				{
					$fullTblName = $dbPrefix.$tblName;
					
					//get table columns
					$db_os_tables[$tblName]['columns'] = ($include_columns? $this->getTableColumns($fullTblName) : array());
					
					//get table indexes
					$db_os_tables[$tblName]['indexes'] = ($include_indexes ? $this->getTableIndexes($fullTblName) : array());
				}
			}
			
			$result =  $db_os_tables;
		}
		
		return $result;
	}

	public function compareTablesBySchema($schemaPath, $tblDetails)
	{
		$sqlSyncDetails = array();
		
		if(file_exists($schemaPath))
		{
			$OS = getOS();
			$osUtils = $OS->getUtils();
			$dbPrefix = $OS->getDb()->dbPrefix();
			
			//get schema sql info
			$schemaSqlArray = $osUtils->jsonRead($schemaPath);
			
			//compare local database with provided SQL schema
			if((!empty($schemaSqlArray)))
			{
				foreach($schemaSqlArray as $tblName => $schemTblDetails)
				{
					$fullTblName = $dbPrefix.$tblName;
					
					if(!isset($tblDetails[$tblName]))
					{//if schema table does not exists
						$sqlSyncDetails[$tblName]['create'] = $this->createTableSQL($fullTblName, $schemTblDetails['columns'], $schemTblDetails['indexes']);
					}
					else
					{//if schema table exists make alters
						$alterData = $this->changeTableSQL($fullTblName, $schemTblDetails['columns'], $schemTblDetails['indexes']);
						
						if(!empty($alterData)) $sqlSyncDetails[$tblName]['alter'] = $alterData;
					}
					
					//create or change table indexes
					$localTblIndexes = (isset($tblDetails[$tblName]) ? $tblDetails[$tblName]['indexes'] : array());
					  
					$idxData = $this->processTableIndexes($fullTblName, $localTblIndexes, $schemTblDetails['indexes']);
					
					if(!empty($idxData)) $sqlSyncDetails[$tblName]['indexes'] = $idxData;
				}
			}
		}
		
		return $sqlSyncDetails;
	}
	
	public function compareCoreTablesBySchema($schemaPath)
	{
		$tblDetails = $this->getDbTablesFull(array('columns','indexes'));
		return $this->compareTablesBySchema($schemaPath, $tblDetails);
	}
	
	public function compareAppTablesBySchema($schemaPath, $appName)
	{
		$tblDetails = $this->getAppTablesFull($appName);
		return $this->compareTablesBySchema($schemaPath, $tblDetails);
	}
	
	
	public function syncCoreTablesBySchema($schemaPath)
	{
		$result = false; $tmpTests = array();
		$responseData = array('tests'=> array(), 'notifications'=> array());
		
		$sqlSyncDetails = $this->compareCoreTablesBySchema($schemaPath);
		
		if(empty($sqlSyncDetails)) 
		{
			$result = true;
		}
		else
		{
			$sqlBatchResponse = $this->executeSQLBatch($sqlSyncDetails);
			$result = $sqlBatchResponse['result'];
			$tmpTests = $sqlBatchResponse['tests'];
		}
		
		$responseData['tests'][] = array('test'=>array('message'=> _('Syncing Core SQL Tables')),'result'=> array('type'=> ($result? 'success' : 'error')));
		if(!empty($tmpTests)) $responseData['tests'] = array_merge_recursive($responseData['tests'], $tmpTests);
		
		$responseData['result'] = $result;
		
		return $responseData;
	}
	
	public function syncAppTablesBySchema($schemaPath, $appName)
	{
		$result = false; $tmpTests = array();
		$responseData = array('tests'=> array(), 'notifications'=> array());
		
		$sqlSyncDetails = $this->compareAppTablesBySchema($schemaPath, $appName);
		
		if(empty($sqlSyncDetails)) 
		{
			$result = true;
		}
		else
		{
			$sqlBatchResponse = $this->executeSQLBatch($sqlSyncDetails);
			
			$result = $sqlBatchResponse['result'];
			$tmpTests = $sqlBatchResponse['tests'];
		}
		
		$responseData['tests'][] = array('test'=>array('message'=> _('Syncing App SQL Tables')),'result'=> array('type'=> ($result? 'success' : 'error')));
		if(!empty($tmpTests)) $responseData['tests'] = array_merge_recursive($responseData['tests'], $tmpTests);
		
		$responseData['result'] = $result;
		
		return $responseData;
	}
}