<?php
class OS_Datasource
{
	private static $_instance;
	
	public $id;
	public $name;
	public $module;
	public $module_name;
	public $table;
	public $fields;
	public $extra_conditions;
	public $status;
	
	private $isConnected;
	
	public function __construct()
	{
		$this->setInitialValues();
	}
	
	public static function &get_instance($datasource_name=false)
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_Datasource();
		}
		if ($datasource_name)
		{
			self::$_instance->name=$datasource_name;
			self::$_instance->load();
		}
		return self::$_instance;
	}
	
	public function setInitialValues()
	{
		$this->id=false;
		$this->name='';
		$this->module='';
		$this->module_name='';
		$this->table='';
		$this->fields=array();
		$this->extra_conditions=array();
		$this->status='';
		
		$this->isConnected=false;
	}
	
	public function register()
	{
		$result=false;
		
		if (!$this->id)
		{
			$datasourceOps=getOS()->getDatasourceOps();
			
			$result=$datasourceOps->registerDatasource($this);
		}
		
		return $result;
	}
	
	public function unregister()
	{
		$result=false;
		
		if ($this->id)
		{
			$datasourceOps=getOS()->getDatasourceOps();
			
			$result=$datasourceOps->unregisterDatasource($this);
		}
		
		return $result;
	}
	
	public function enable()
	{
		$result=false;
		
		if ($this->id AND $this->status=='D')
		{
			$datasourceOps=getOS()->getDatasourceOps();
			
			if ($result=$datasourceOps->enableDatasource($this))
			{
				$this->status='E';
			}
		}
		
		return $result;
	}
	
	public function disable()
	{
		$result=false;
		
		if ($this->id AND $this->status=='E')
		{
			$datasourceOps=getOS()->getDatasourceOps();
			
			if ($result=$datasourceOps->disableDatasource($this))
			{
				$this->status='D';
			}
		}
		
		return $result;
	}
	
	public function connect($module,$module_name='')
	{
		$result=false;
		
		$datasourceOps=getOS()->getDatasourceOps();
		
		if ($this->id)
		{
			if (!$datasourceOps->getDatasourceConnetion($this,$module,$module_name))
			{
				$result=$datasourceOps->connectDatasource($this,$module,$module_name);
			}
			else
			{
				$result=true;
			}
			
			if ($result)
			{
				$this->isConnected=true;
			}
		}
		
		return $result;
	}
	
	public function disconnect($module,$module_name='')
	{
		$result=false;
		
		$datasourceOps=getOS()->getDatasourceOps();
		
		if ($this->id AND $datasourceOps->getDatasourceConnetion($this,$module,$module_name))
		{
			$result=$datasourceOps->disconnectDatasource($this,$module,$module_name);
		}
		
		return $result;
	}
	
	public function set($datasource_data)
	{
		$result = false;
		
		$objVars = get_object_vars($this);
		
		foreach($objVars as $key=>$val)
		{
			if(isset($datasource_data[$key]))
			{
				$this->$key = $datasource_data[$key];
				$result = true;
			}
		}
		
		return $result;
	}
	
	public function load()
	{
		$result = false;
		
		if ($this->name)
		{
			$ops=getOS()->getDatasourceOps();
			
			if ($datasource_data=$ops->getDatasourceByName($this->name))
			{
				$this->set(get_object_vars($datasource_data));
				
				$this->isConnected=false;
			}
		}
		
		return $result;
	}
	
	public function getData($conditions,$order=array(),$paging=array())
	{
		$result=false;
		
		if ($this->id AND $this->status=='E' AND $this->isConnected)
		{
			$db=getOS()->getDb();
			
			if ($this->module=='core')
			{
				$table=$db->dbPrefix.$this->table;
			}
			elseif ($this->module=='app')
			{
				$appHandler=getOS()->getAppHandler();
				$appHandler->name=$this->module_name;
				
				$table=$appHandler->dbPrefix.$this->table;
			}
			
			$query_params=array();
			$query="SELECT `".implode('`,`',$this->fields)."` FROM {$table} WHERE ";
			$first_condition=true;
			foreach ($conditions as $field=>$value)
			{
				$query_params[]=$value;
				$query.=($first_condition?'':' AND ').'`'.$field.'`=? ';
				$first_condition=false;
			}
			if (!empty($this->extra_conditions))
			{
				$query.=" AND `".implode('`=? AND `',array_keys($this->extra_conditions))."`=?";
				foreach ($this->extra_conditions as $value)
				{
					$query_params[]=$value;
				}
			}
			
			if (!empty($order))
			{
				$query.=" ORDER BY ";
				$first_order=true;
				
				foreach ($order as $order_field=>$order_type)
				{
					$query.=($first_order?'':', ').$order_field.' '.$order_type;
				}
			}
			
			if (!empty($paging))
			{
				if (empty($paging['offset']))
				{
					$paging['offset']=0;
				}
				
				$query.=" LIMIT {$paging['offset']},{$paging['items']}";
			}
			
			$dbresult=$db->query($query,$query_params);
			
			while ($row=$db->fetchRow($dbresult))
			{
				$result[]=$row;
			}
		}
		
		return $result;
	}
	
	public function toTemplate()
	{
		if (!$this->id) return false;
		
		$datasource_array=array(
			'name'=>$this->name,
			'module'=>$this->module,
			'module_name'=>$this->module_name,
			'table'=>$this->table,
			'fields'=>$this->fields,
			'extra_conditions'=>$this->extra_conditions,
			'status'=>$this->status
		);
		
		return $datasource_array;
	}
}
?>