<?php
class OS_DatasourceOperations
{
	private static $_instance;
	
	protected function __construct()
	{
	}
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_DatasourceOperations();
		}
		return self::$_instance;
	}
	
	public function registerDatasource($datasource)
	{
		$result=false;
		
		if (!$row=$this->getDatasourceByName($datasource->name))
		{
			$db=getOS()->getDb();
			$time = $db->DBTimeStamp(time());
			$ip=(!empty($_SERVER['REMOTE_ADDR'])?$_SERVER['REMOTE_ADDR']:'0.0.0.0');
			
			$query="INSERT INTO ".$db->dbPrefix()."datasources (module,module_name,name,`table`,fields,extra_conditions,insert_dt,insert_ip,insert_by,status,status_dt,status_ip,status_by) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?)";
			$dbresult=$db->query($query,array($datasource->module,$datasource->module_name,$datasource->name,$datasource->table,json_encode($datasource->fields),json_encode($datasource->extra_conditions),$time,$ip,-1,'E',$time,$ip,-1));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function unregisterDatasource($datasource)
	{
		$result=false;
		
		if ($row=$this->getDatasourceByName($datasource->name))
		{
			$db=getOS()->getDb();
			
			$query="DELETE FROM ".$db->dbPrefix()."datasources WHERE id=?";
			$dbresult=$db->query($query,array($datasource->id));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function unregisterDatasourcesByModule($module,$module_name='')
	{
		$result=false;
		
		if ($datasources=$this->getDatasourcesByModule($module,$module_name))
		{
			foreach ($datasources as $datasource)
			{
				$datasource->unregister();
			}
			$result=true;
		}
		
		return $result;
	}
	
	public function enableDatasource($datasource)
	{
		$result=false;
		
		if ($osDatasource = $this->getDatasourceByName($datasource->name))
		{
			$db=getOS()->getDb();
			$time=$db->DBTimeStamp(time());
			$ip=(!empty($_SERVER['REMOTE_ADDR'])?$_SERVER['REMOTE_ADDR']:'0.0.0.0');
			
			$query="UPDATE ".$db->dbPrefix()."datasources SET status=?,status_dt=?,status_ip=?,status_by=? WHERE id=?";
			$dbresult=$db->query($query,array('E',$time,$ip,-1,$osDatasource->id));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function disableDatasource($datasource)
	{
		$result=false;
		
		if ($osDatasource = $this->getDatasourceByName($datasource->name))
		{
			$db=getOS()->getDb();
			$time=$db->DBTimeStamp(time());
			$ip=(!empty($_SERVER['REMOTE_ADDR'])?$_SERVER['REMOTE_ADDR']:'0.0.0.0');
			
			$query="UPDATE ".$db->dbPrefix()."datasources SET status=?,status_dt=?,status_ip=?,status_by=? WHERE id=?";
			$dbresult=$db->query($query,array('D',$time,$ip,-1,$osDatasource->id));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function enableDatasourcesByModule($module,$module_name='')
	{
		$result=false;
		
		if ($datasources=$this->getDatasourceByModule($module,$module_name))
		{
			foreach ($datasources as $datasource)
			{
				$datasource->enable();
			}
			$result=true;
		}
		
		return $result;
	}
	
	public function disableDatasourcesByModule($module,$module_name='')
	{
		$result=false;
		
		if ($datasources=$this->getDatasourceByModule($module,$module_name))
		{
			foreach ($datasources as $datasource)
			{
				$datasource->disable();
			}
			$result=true;
		}
		
		return $result;
	}
	
	public function getDatasourceByName($datasource)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."datasources WHERE name=?";
		$dbresult=$db->query($query,array($datasource));
		if ($row=$db->fetchRow($dbresult))
		{
			$row['fields']=json_decode($row['fields'],true);
			$row['extra_conditions']=(empty($row['extra_conditions'])?array():json_decode($row['extra_conditions'],true));
			$result=new OS_Datasource();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getDatasourcesByModule($module,$module_name='')
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."datasources WHERE module=?".($module=='app'?" AND module_name=?":'');
		$query_params=array($module);
		if ($module=='app')
		{
			$query_params[]=$module_name;
		}
		$dbresult=$db->query($query,$query_params);
		while ($row=$db->fetchRow($dbresult))
		{
			$row['fields']=json_decode($row['fields'],true);
			$row['extra_conditions']=(empty($row['extra_conditions'])?array():json_decode($row['extra_conditions'],true));
			$oneDatasource=new OS_Datasource();
			$oneDatasource->set($row);
			$result[]=$oneDatasource;
		}
		
		return $result;
	}
	
	public function getDatasources()
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."datasources");
		while ($row=$db->fetchRow($dbresult))
		{
			$row['fields']=json_decode($row['fields'],true);
			$row['extra_conditions']=(empty($row['extra_conditions'])?array():json_decode($row['extra_conditions'],true));
			$oneDatasource=new OS_Datasource();
			$oneDatasource->set($row);
			$result[$row['id']]=$oneDatasource;
		}
		
		return $result;
	}
	
	public function getDatasourceConnection($datasource,$module,$module_name='')
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."datasources_connections WHERE datasource=? AND module=?".($module_name?" AND module_name=?":'');
		$query_params=array($datasource->name,$module);
		if ($module_name) $query_params[]=$module_name;
		$dbresult=$db->query($query,$query_params);
		
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row;
		}
		
		return $result;
	}
	
	public function getDatasourceConnections($datasource)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."datasources_connections WHERE datasource=?",array($datasource->name));
		
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['id']]=$row;
		}
		
		return $result;
	}
	
	public function getDatasourceConnectionsByModule($module,$module_name='')
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."datasources_connections WHERE module=?".($module_name?" AND module_name=?":'');
		$query_params=array($module);
		if ($module_name) $query_params[]=$module_name;
		$dbresult=$db->query($query,$query_params);
		
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['id']]=$row;
		}
		
		return $result;
	}
	
	public function connectDatasource($datasource,$module,$module_name='')
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		if (!$this->getDarasourceConnection($datasource,$module,$module_name))
		{
			$user=getOS()->getUser();
			$time = $db->DBTimeStamp(time());
			
			$query="INSERT INTO ".$db->dbPrefix()."datasources_connections (datasource,module,module_name,insert_dt,insert_ip,insert_by) VALUES (?,?,?,?,?,?)";
			$dbresult=$db->query($query,array($datasource->name,$module,$module_name,$time,$_SERVER['REMOTE_ADDR'],$user->id));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function disconnectDatasource($datasource,$module,$module_name='')
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		if ($this->getDarasourceConnection($datasource,$module,$module_name))
		{
			$query="DELETE FROM ".$db->dbPrefix()."datasources_connections WHERE datasource=? AND module=?".($module_name?" AND module_name=?":'');
			$query_params=array($datasource->name,$module);
			if ($module_name) $query_params[]=$module_name;
			$dbresult=$db->query($query,$query_params);
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
}
?>