<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_Department
{
	//department ID
	var $id;
	
	//department name
	var $name;
	
	//department status
	var $status;
	
	//department permissions
	var $permissions;
	
	var $insert_dt;
	
	
	private static $_instance;
	
	//constructor
	function __construct()
	{
		$this->setInitialValues();
	}
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_Department();
		}
		return self::$_instance;
	}
	
	
	//sets object to some sane initial values
	public function setInitialValues()
	{
		$this->id = -1;
		$this->name = '';
		$this->status = '';
		$this->permissions = array();
	}
	
	//set permissions  to the current department object (from the database)
	public function loadPerms()
	{
		$OS = getOS();
		
		$osPermissionsOps = $OS->getPermissionOps();
		
		$departmentPermissions = $osPermissionsOps->getPermissionsByDepartmentID($this->id);
		
		if($departmentPermissions !== false)
		{
			$this->permissions = $departmentPermissions;
		}
	}

	//get department permissions by module
	public function getPerm($module = false)
	{
		$result = false;
		
		$project=getOS()->getProject();
		if ($project->id>-1)
		{
			$project_id=$project->id;
		}
		else
		{
			$project_id=0;
		}
		
		if($module !== false)
		{
			if(isset($this->permissions[$project_id][$module]))
			{
				$result = ($this->permissions[$project_id][$module]=='R'?false:true);	
			}
			elseif (isset($this->permissions[0][$module]))
			{
				$result = true;
			}
		}
		
		return $result;
	}
	
	
	//get all department's current permissions
	public function getPerms()
	{
		$result = false;
		
		if(!empty($this->permissions))
		{
			$result = $this->permissions;	
		}

		return $result;
	}
	
	
	//check if current department object has a permission
	public function checkPerm($module,$permission,$project_id=false)
	{
		if(empty($this->permissions))
		{
			return (false);
		}
		else
		{
			if ($project_id===false)
			{
				$project=getOS()->getProject();
				if ($project->id>-1)
				{
					$project_id=$project->id;
				}
				else
				{
					$project_id=0;
				}
			}
			
			if(!isset($this->permissions[$project_id][$module][$permission]))
			{
				if (!isset($this->permissions[0][$module][$permission]))
				{
					return (false);
				}
				else
				{
					return (true);
				}	
			}
			else
			{
				if ($this->permissions[$project_id][$module][$permission]=='R')
				{
					return (false);
				}
				else
				{
					return (true);
				}
			} 
		}
	}

	//add department permission
	public function addPerm($project_id,$module,$permission)
	{
		$result = false;
		
		if( $this->id > -1)
		{
			$osPermissionOps = getOS()->getPermissionOps();
			
			$permResult = $osPermissionOps->addPermissionRecord($project_id,$this->id,"D","A",$module,$permission);
			
			if($permResult === true)
			{
				$this->permissions[$module][$permission] = true;
				
				$result = true;
			}
		}
		
		return $result;
	}

	//remove department permission
	public function removePerm($project_id,$module,$permission)
	{
		$result = false;
		
		if( $this->id > -1)
		{
			$osPermissionOps = getOS()->getPermissionOps();
			
			$permResult = $osPermissionOps->removePermissionRecord($project_id,$this->id,"D",$module,$permission);
			
			if($permResult === true)
			{
				
				if(isset($this->permissions[$module][$permission])) 
				{
					unset($this->permissions[$module][$permission]);	
				}	
	
				$result = true;
			}
		}
		
		return $result;	
	}
	
	//save department permissions
	public function savePerms()
	{
		$result = false;
		
		$osPermissionOps = getOS()->getPermissionOps();
		
		$permsData = array();
		foreach ($this->permissions as $project_id=>$modules)
		{
			foreach( $modules as $module => $modulePermssions )
			{
				foreach( $modulePermssions as $permission => $dummy )
				{
					$result = $osPermissionOps->addPermissionRecord($project_id,$this->id, "D", "A", $module, $permission);
				}
			}
		}
		
		return $result;	

	}

	public function getAvailableApps($project_id=false)
	{
		$result=false;

		$OS=getOS();
		$availableApps=$OS->getAppOps()->getAvailableAppsNames();
		
		foreach ($availableApps as $app_id=>$app_name)
		{
			if ($this->checkPerm($app_name,'view',$project_id))
			{
				$result[$app_id]=$app_name;
			}
		}
		
		return $result;
	}
	
	public function set($dep_data)
	{
		$result = false;
		
		$objVars = get_object_vars($this);
		
		foreach($objVars as $key=>$val)
		{
			if(isset($dep_data[$key]))
			{
				$this->$key = $dep_data[$key];
				$result = true;
			}
		}
		
		return $result;
	}
	
	//Save the current department Object to the database
	public function save()
	{
		$result = false;
		
		$departmentOps = getOS()->getDepartmentOps();
		
		if ($this->id > -1)
		{
			$result = $departmentOps->updateDepartment($this);
		}
		else
		{
			$newid = $departmentOps->insertDepartment($this);
			
			if ($newid > -1)
			{
				$this->id = $newid;
				$result = true;
			}

		}

		return $result;
	}
	
	//Delete the department from the database and empty the current osDepartment object
	public function delete()
	{
		$result = false;
		
		if ($this->id > -1)
		{
			$OS = getOS();
			$osDepartmentOps = $OS->getDepartmentOps();
			
			$osPermissionOps = $OS->getPermissionOps();
			
			$osAppOps = $OS->getAppOps();
			
			//mark department for deletition
			
			//Remove department permissions
			$departmentPermissions = $osPermissionOps->getPermissionsByDepartmentID($this->id);
			if(!empty($departmentPermissions))
			{
				foreach($departmentPermissions as $project_id=>$modules)
				{
					foreach ($modules as $module=>$moduleData)
					{
						foreach($moduleData as $permission=>$op)
						{
							$osPermissionOps->removePermissionRecord($project_id,$this->id,"D",$module,$permission);		
						}
					}
				}
			}
	
			//Remove users linked to this department
			$departmentUsers = $osDepartmentOps->getUsersByDepartmentID($this->id);
			
			if(!empty($departmentUsers))
			{
				foreach($departmentUsers as $user_id)
				{
					$osDepartmentOps->removeDepartmentUserLink($user_id,$this->id);		
				}
			}
			
			$result = $osDepartmentOps->deleteDepartmentByID($this->id);
			if ($result !== false)
			{
				$this->setInitialValues();
			}
		}

		return $result;
	}
	
	//check if current department is active
	public function isActive()
	{
		$result = false;
		
		if($this->status == 'A')
		{
			$result = true;	
		}
		
		return $result;
	}
}
?>