<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_DepartmentOperations
{
	private static $_instance;

	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_DepartmentOperations();
		}
		return self::$_instance;
	}
	
	public function __construct() {}

	//Get a list of all users` departments
	public function &getDepartments()
	{
		$db = getOS()->getDb();
	
		$result = array();
	
		$query = "SELECT * FROM ".$db->dbPrefix()."departments ORDER BY `id` ASC";
		$dbresult = $db->query($query);
		while ($row = $db->fetchRow($dbresult))
		{
			$osDepartment = new OS_Department();
			$osDepartment->id = $row['id'];
			$osDepartment->name = $row['name'];
			$osDepartment->status = $row['status'];
			$osDepartment->insert_dt = $row['insert_dt'];

			$result[$row['id']] = $osDepartment;
		}
	
		return $result;
	}
	
	//Get a list with department's statuses
	public function & getStatuses()
	{
		$statuses = array(
			'A' => _("Active"),
			'D' => _("Disabled"),
			'P' => _("Pending"),
			'S' => _("Suspended"),
			'R' => _("Removed")
			);
		
		return $statuses; 	
	}

	//Get a department by id.
	public function &getDepartmentByID($id)
	{
		return $this->getDepartmentByDetail(array('id'=>$id));
	}

	//Get a department by name.
	public function &getDepartmentByName($name)
	{
		return $this->getDepartmentByDetail(array('name'=>$name));
	}

	public function &getDepartmentByDetail($details)
	{

		$result = false;
		$query  = false;

		$db = getOS()->getDb();

		if(isset($details['id']))  $query = "SELECT * FROM ".$db->dbPrefix()."departments WHERE id = ?";	
		elseif(isset($details['name'])) $query = "SELECT * FROM ".$db->dbPrefix()."departments WHERE name = ?";

		if($query)
		{
			$dbresult = $db->query($query, array_values($details));
			
			while ($row = $db->fetchRow($dbresult))
			{
				$osDepartment = new OS_Department();
				$osDepartment->id = $row['id'];
				$osDepartment->name = $row['name'];
				$osDepartment->status = $row['status'];

				$result = $osDepartment;
			}
				
		}
		return $result;
	}
	
	//Saves a new user to the database.
	public function insertDepartment($osDepartment)
	{
		$result = -1; 
		
		$OS = getOS();

		$db = $OS->getDb();
		
		//check for department name conflict
		$query = "SELECT id FROM ".$db->dbPrefix()."departments WHERE `name` = ?";
		$results =  $db->query($query,array($osDepartment->name));
		if( $db->fetchRow($results) ) return $result;

		//get current user Data (for status_by)
		$user_id = $OS->getUser()->id;
		
		if(is_null($user_id)) $user_id = -1;
		
		$time = $db->DBTimeStamp(time());
		$query = "INSERT INTO ".$db->dbPrefix()."departments (`insert_dt`,`insert_ip`, `name`, `status`, `status_dt`, `status_ip`, `status_by`) VALUES (?,?,?,?,?,?,?)";
		$dbresult = $db->query($query, array($time,$_SERVER['REMOTE_ADDR'],$osDepartment->name,$osDepartment->status,$time,$_SERVER['REMOTE_ADDR'],$user_id)); 
		
		if ($dbresult !== false)
		{
			$result = $db->getInsertId();
		}

		return $result;
	}

	//Updates an existing department in the database.
	public function updateDepartment($osDepartment)
	{
		$result = false; 
		if( $osDepartment->id >= 1 ) 
		{
			$OS = getOS();
	
			$db = $OS->getDb();
			
			//check id department exists
			$query = "SELECT id FROM ".$db->dbPrefix()."departments WHERE `id` = ?";
			$results =  $db->query($query,array($osDepartment->id));
			if(!$db->fetchRow($results) ) return $result;
			
			//get current user Data (for status_by)
			$user_id = $OS->getUser()->id;
			
			if(is_null($user_id)) $user_id = -1;
	
			$time = $db->DBTimeStamp(time());
			$query = "UPDATE ".$db->dbPrefix()."departments SET `name` = ?, `status` = ?, `status_dt` = ?, `status_ip` = ?, `status_by` = ?, `update_dt` = ?, `update_ip` = ?, `updates` = updates+1 WHERE `id` = ?";
			$dbresult = $db->query($query, array($osDepartment->name, $osDepartment->status, $time, $_SERVER['REMOTE_ADDR'], $user_id, $time, $_SERVER['REMOTE_ADDR'],$osDepartment->id));
			if ($dbresult !== false)
			{
				$result = true;
			}
		}

		return $result;
	}

	//Deletes an existing department from the database.
	public function deleteDepartmentByID($id)
	{
 		$result = false;
		if( $id >= 1 ) 
		{
	 		//check is current user can delete departments
	 		
	 		$result = false;
	
			$db = getOS()->getDb();
			
			//Delete the department from the database
			$query = "DELETE FROM ".$db->dbPrefix()."departments WHERE `id` = ?";
			$dbresult = $db->query($query, array($id));
			
			if($dbresult !== false)
			{
				$result = true;
			}
		}
		
		return $result;
	}	
	
	//get users ids links by department id 
	public function getUsersByDepartmentID($department_id)
	{
		$result =  false;
		
		if($department_id >= 1)
		{
			$db = getOS()->getDb();
			
			$query = "SELECT * FROM ".$db->dbPrefix()."departments_users WHERE `department_id`= ?";
			$dbresult = $db->query($query,array($department_id));
			while($row = $db->fetchRow($dbresult))
			{
				$result[] = $row['user_id'];
			}
		}
		
		return $result;		
	}
	
	//get department ids links by user ID
	public function getDepartmentsByUserID($user_id)
	{
		$result =  false;
		
		if($user_id >= 1)
		{
			$db = getOS()->getDb();
			
			$query = "SELECT * FROM ".$db->dbPrefix()."departments_users WHERE `user_id`= ?";
			$dbresult = $db->query($query,array($user_id));
			while($row = $db->fetchRow($dbresult))
			{
				$result[] = $row['department_id'];
			}
		}
		
		return $result;		
	}
	
	//get department ids links by project ID
	public function getDepartmentsByProjectID($project_id)
	{
		$result =  false;
		
		if($project_id >= 1)
		{
			$db = getOS()->getDb();
			
			$query = "SELECT * FROM ".$db->dbPrefix()."departments_projects WHERE `project_id`= ?";
			$dbresult = $db->query($query,array($project_id));
			while($row = $db->fetchRow($dbresult))
			{
				$result[] = $row['department_id'];
			}
		}
		
		return $result;		
	}
	
	//get department ids links by project ID
	public function getProjectsByDepartmentID($department_id)
	{
		$result =  false;
		
		if($department_id >= 1)
		{
			$db = getOS()->getDb();
			
			$query = "SELECT * FROM ".$db->dbPrefix()."departments_projects WHERE `department_id`= ?";
			$dbresult = $db->query($query,array($department_id));
			while($row = $db->fetchRow($dbresult))
			{
				$result[] = $row['project_id'];
			}
		}
		
		return $result;		
	}
	
	//create the link between a user and a department (assign user to department)
	public function createDepartmentUserLink($user_id,$department_id)
	{
		$result =  false;
		
		if( ($user_id >= 1) && ($department_id  >= 1))
		{
			$db = getOS()->getDb();
			
			$time = $db->DBTimeStamp(time());
			
			$query = "SELECT * FROM ".$db->dbPrefix()."departments_users WHERE `user_id`= ? AND `department_id` = ?";
			$dbresult = $db->query($query,array($user_id,$department_id));
			if(!$row = $db->fetchRow($dbresult))
			{
				$query = "INSERT INTO ".$db->dbPrefix()."departments_users (`user_id`,`department_id`,`insert_dt`,`insert_ip`) VALUES (?,?,?,?)";
				$dbresult = $db->query($query, array($user_id, $department_id, $time, $_SERVER['REMOTE_ADDR']));
				
				if ($dbresult !== false)
				{
					$result = true;
				}
			}
		}

		return $result;
	}
	
	//remove the link between a user and a department (unassign user from department)
	public function removeDepartmentUserLink($user_id,$department_id)
	{
		$result =  false;
		
		if( ($user_id >= 1) && ($department_id  >= 1))
		{
			$db = getOS()->getDb();
			
			$time = $db->DBTimeStamp(time());
			
			$query = "SELECT * FROM ".$db->dbPrefix()."departments_users WHERE `user_id`= ? AND `department_id` = ?";
			$dbresult = $db->query($query,array($user_id,$department_id));
			if($row = $db->fetchRow($dbresult))
			{
				$query = "DELETE FROM ".$db->dbPrefix()."departments_users WHERE `user_id`= ? AND `department_id` = ?";
				$dbresult = $db->query($query, array($user_id, $department_id));
				
				if ($dbresult !== false)
				{
					$result = true;
				}
			}
		}
		return $result;
	}


	//create the link between a department and a project (assign department to project)
	public function createDepartmentProjectLink($project,$department_id)
	{
		$result =  false;
		
		$db = getOS()->getDb();
		
		$time = $db->DBTimeStamp(time());
		
		$query = "SELECT * FROM ".$db->dbPrefix()."departments_projects WHERE `project_id`= ? AND `department_id` = ?";
		$dbresult = $db->query($query,array($project->id,$department_id));
		if(!$row = $db->fetchRow($dbresult))
		{
			 
			$query = "INSERT INTO ".$db->dbPrefix()."departments_projects (`project_id`,`department_id`,`insert_dt`,`insert_ip`) VALUES (?,?,?,?)";
			$dbresult = $db->query($query, array($project->id, $department_id, $time, $_SERVER['REMOTE_ADDR']));
			
			if ($dbresult !== false)
			{
				if ($users=$this->getUsersByDepartmentID($department_id))
				{
					foreach ($users as $user_id)
					{
						$oneUser=new OS_User();
						
						$oneUser->id=$user_id;

						if ($oneUser->load())
						{
							if ($userProjectApps=$oneUser->getAvailableAppsDetails($project->id))
							{
								foreach ($userProjectApps as $app_id=>$app_details)
								{
									$oneAppHandler=new OS_AppHandler();
									
									$oneAppHandler->app_id=$app_id;
									$oneAppHandler->name=$app_details['name'];
									$oneAppHandler->title=$app_details['title'];
									
									$oneAppHandler->start($project->id,$user_id);
								}
							}
						}
					}
				}
				
				$result = true;
			}
		}
		return $result;
	}
	
	//remove the link between a project and a department (unassign department from project)
	public function removeDepartmentProjectLink($project,$department_id)
	{
		$result =  false;
		
		$db = getOS()->getDb();
		
		$time = $db->DBTimeStamp(time());
		
		$query = "SELECT * FROM ".$db->dbPrefix()."departments_projects WHERE `project_id`= ? AND `department_id` = ?";
		$dbresult = $db->query($query,array($project->id,$department_id));
		if($row = $db->fetchRow($dbresult))
		{
			$query = "DELETE FROM ".$db->dbPrefix()."departments_projects WHERE `project_id`= ? AND `department_id` = ?";
			$dbresult = $db->query($query,array($project->id, $department_id));
			
			if ($dbresult !== false)
			{
				$result = true;
			}
		}
		return $result;
	}	
}

?>