<?php
class OS_Forecasting
{
	private static $_instance;
	
	private $sampleData;
	private $seasonLength;
	
	public function __construct()
	{
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_Forecasting();
		}
		
		return self::$_instance;
	}
	
	public function setSampleData($data)
	{
		if (is_array($data))
		{
			$result=$this->getSampleData();
			
			if (is_null($result))
			{
				$result=true;
			}
			
			$this->sampleData=$data;
		}
		else
		{
			$result=false;
		}
		
		return $result;
	}
	
	public function getSampleData()
	{
		return $this->sampleData;
	}
	
	public function setSeasonLength($length)
	{
		if ($length>0)
		{
			$result=$this->getSeasonLength();
			
			if (is_null($result))
			{
				$result=true;
			}
			
			$this->seasonLength=$length;	
		}
		else
		{
			$result=false;
		}
		
		return $result;
	}
	
	public function getSeasonLength()
	{
		return $this->seasonLength;
	}
	
	private function calculateLinearRegression($values)
	{
		$n = count($values);
		
		$vSumXX = $vSumXY = $vSumX = $vSumY = 0;

		$vCnt = 0;
		
		foreach ($values AS $vOne)
		{
			if (is_array($vOne))
			{
				list($x,$y) = $vOne;
			}
			else
			{
				$x = $vCnt; $y = $vOne;
			}
			$vSumXY += $x*$y;
			$vSumXX += $x*$x;
			$vSumX += $x;
			$vSumY += $y;
			$vCnt++;
		}
		
		$vTop = ($n*$vSumXY-$vSumX*$vSumY);
		$vBottom = ($n*$vSumXX-$vSumX*$vSumX);
		$a = $vBottom!=0?$vTop/$vBottom:0;
		$b = ($vSumY-$a*$vSumX)/$n;
		
		return array($a,$b);
	}
	
	private function computeSMA()
	{
		$result=array();
		
		for ($i=0;$i<count($this->sampleData);$i++)
		{
			if ($i+$this->seasonLength-1>=count($this->sampleData))
			{
				break;
			}
		
			$vSum = 0;
		
			for ($j=0;$j<$this->seasonLength;$j++)
			{
				$vSum += $this->sampleData[$i+$j];
			}
		
			$result[] = $vSum/$this->seasonLength;
		}
		
		return $result;
	}
	
	private function computeCMA($SMA)
	{
		$result = array();
		
		for ($i=0;$i<count($SMA);$i++)
		{
			if ($i+1>=count($SMA))
			{
				break;
			}
			
			$result[] = ($SMA[$i]+$SMA[$i+1])/2;
		}
		
		return $result;
	}
	
	private function computeNoises($CMA)
	{
		$result = array();
		
		for ($i=0;$i<count($CMA);$i++)
		{
			$vStarting = floor($this->seasonLength/2);
			
			$result[] = $this->sampleData[$i+$vStarting]/$CMA[$i];
		}
		
		return $result;
	}
	
	private function computeSeasonIndices($noises)
	{
		$result = array();
		
		for ($i=0;$i<$this->seasonLength;$i++)
		{
			$vSum = array();
			
			for ($j=$i;$j<count($noises);$j+=$this->seasonLength)
			{
				$vSum[] = $noises[$j];
			}
			
			$vStarting = (floor($this->seasonLength/2)+$i)%$this->seasonLength;
			$result[$vStarting] = array_sum($vSum)/count($vSum);
		}
		
		ksort($result);
		$vSum = array_sum($result);
		
		for ($i=0;$i<count($result);$i++)
		{
			$result[$i] = $result[$i]*$this->seasonLength/$vSum;
		}
		
		return $result;
	}
	
	private function computeDeSeasonalized($seasonIndices)
	{
		$result = array();
		
		for ($i=0;$i<count($this->sampleData);$i++)
		{
			$result[] = $this->sampleData[$i]/$seasonIndices[$i%$this->seasonLength];
		}
		
		return $result;
	}
	
	public function predict($futurePeriods)
	{
		$SMA = $this->computeSMA();
		
		if ($this->seasonLength%2==0)
		{
			$CMA = $this->computeCMA($SMA);
		}
		else
		{
			$CMA = $SMA;
		}
		
		$noises = $this->computeNoises($CMA);
		$seasonIndices = $this->computeSeasonIndices($noises);
		$deSeasonalized = $this->computeDeSeasonalized($seasonIndices);
		
		list($vXVar,$vIntercept) = $this->calculateLinearRegression($deSeasonalized);
		
		$result = array();
		
		for ($i=0;$i<$futurePeriods;$i++)
		{
			$result[] = $vIntercept + $vXVar*(count($this->sampleData)+$i);
		}
		
		for ($i=0;$i<count($result);$i++)
		{
			$result[$i] = $result[$i]*$seasonIndices[(count($this->sampleData)+$i)%$this->seasonLength];
		}
		
		return $result;
	}
}
?>