<?php
class OS_GeoIP
{
	private static $_instance;
	
	private $continentNames;
	
	public function __construct()
	{
		$this->continentNames=array('AS'=>_('Asia'),'EU'=>_('Europe'),'AF'=>_('Africa'),'OC'=>_('Oceania'),'NA'=>_('North America'),'SA'=>_('South America'),'AN'=>_('Antarctica'),'--'=>'n/a');
		
		$cacheEngine=getOS()->getSettingsVar('geoip_library');

		if ($cacheEngine)
		{
			$geoClass="OS_PLUGIN_GeoIP_{$cacheEngine}";
			
			$this->engine=call_user_func(array($geoClass,'get_instance'));
//			$this->engine=$geoClass::get_instance();
		}
		else
		{
			$this->engine=false;
		}
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_GeoIP();
		}
		
		return self::$_instance;
	}
	
	public function getLocation($host,$option=false)
	{
		$result=false;
		
		if ($this->engine)
		{
			if ($option)
			{
				$canReturn=false;
				$possibleDetails=$this->getPossibleDetails();
				
				if (isset($possibleDetails[$option]))
				{
					$canReturn=true;
				}
			}
			else
			{
				$canReturn=true;
			}
			
			if ($canReturn)
			{
				$engineResponse=$this->engine->getLocation($host);
				
				if (!empty($engineResponse['continent_code']) AND isset($this->continentNames[$engineResponse['continent_code']]))
				{
					$engineResponse['continent_name']=$this->continentNames[$engineResponse['continent_code']];
				}
				
				if ($option)
				{
					if (isset($engineResponse[$option]))
					{
						$result=$engineResponse[$option];
					}
				}
				else
				{
					$result=$this->processEngineResponse($engineResponse);
				}
			}
		}
		
		return $result;
	}
	
	private function processEngineResponse($engineResponse)
	{
		$result=false;

		if ($engineResponse)
		{
			$result=array_merge($this->getPossibleDetails(),$engineResponse);
		}
		
		return $result;
	}
	
	private function getPossibleDetails()
	{
		return array(
			'continent_code'=>false,
			'continent_name'=>false,
			'country_code'=>false,
			'country_code3'=>false,
			'country_name'=>false,
			'region_code'=>false,
			'region_name'=>false,
			'city'=>false,
			'postal_code'=>false,
			'latitude'=>false,
			'longitude'=>false,
			'dma_code'=>false,
			'area_code'=>false
		);
	}
	
	public function getGeoCountries()
	{
		if(!isset($this->GeoCountries))
		{
			$pluginName = "OS_PLUGIN_GeoIP_Countries";
			
			$this->GeoCountries=call_user_func(array($pluginName,'get_instance'));
//			$this->GeoCountries = $pluginName::get_instance();
		}
		
		return $this->GeoCountries;
	}	
}
?>