<?php
class OS_Http
{
	private static $_instance;
	private $useragents;
	public $curl;
	public $response;
	public $responseCode;
	
	public $requestTime;
	
	private $cookiesFile;
	
	private $proxy;
	
	public function __construct()
	{
		$this->defineUserAgents();
		$this->init();
		$this->setDefaultOptions();
	}
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_Http();
		}
		return self::$_instance;
	}
	
	public function init()
	{
		$this->curl=curl_init();
	}
	
	public function setFollowRedirect($follow)
	{
		$result=false;
		
		if ($this->curl AND is_bool($follow))
		{
			$result=curl_setopt($this->curl, CURLOPT_FOLLOWLOCATION, $follow);
		}
		
		return $result;
	}
	
	public function setTimeout($timeout)
	{
		$result=false;
		
		if ($this->curl AND is_int($timeout) AND $timeout>=0)
		{
			$result=curl_setopt($this->curl, CURLOPT_TIMEOUT, $timeout);
		}
		
		return $result;
	}
	
	public function setOption($option,$value)
	{
		$result=false;
		
		if ($this->curl)
		{
			$result=curl_setopt($this->curl,$option,$value);
		}
		
		return $result;
	}
	
	public function setOptions($options)
	{
		foreach ($options as $option=>$value)
		{
			$this->setOption($option,$value);
		}
	}
	
	public function setHeaders($headers)
	{
		$result=false;
		
		if ($this->curl)
		{
			$result=curl_setopt($this->curl,CURLOPT_HTTPHEADER,$headers);
		}
		
		return $result;
	}
	
	public function setProxy($ip,$port)
	{
		$result=false;
		
		if ($this->curl)
		{
			if ($this->setOption(CURLOPT_PROXY, $ip))
			{
				if ($this->setOption(CURLOPT_PROXYPORT, $port))
				{
					if ($this->setOption(CURLOPT_PROXYTYPE, 'HTTP'))
					{
						$result=true;
					}
				}
			}
		}
		
		return $result;
	}
	
	public function useCookies($useCookies=true)
	{
		$result=false;
		
		if ($useCookies)
		{
			$canUse=true;
			
			if (!$this->cookiesFile)
			{
				if ($this->resetCookies())
				{
					$canUse=true;
				}
			}
			else
			{
				$canUse=true;
			}
			
			if ($canUse)
			{
				if ($this->setOption(CURLOPT_COOKIEFILE,$this->cookiesFile))
				{
					if ($this->setOption(CURLOPT_COOKIEJAR,$this->cookiesFile))
					{
						$result=true;
					}
				}
			}
		}
		else
		{
			if ($this->setOption(CURLOPT_COOKIEFILE,false))
			{
				if ($this->setOption(CURLOPT_COOKIEJAR,false))
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public function resetCookies()
	{
		$result=false;
		
		if ($this->cookiesFile=$this->generateCookiesFile())
		{
			$result=true;
		}
		
		return $result;
	}
	
	private function generateCookiesFile()
	{
		$result=false;
		
		$cookies_path=os_join_path(getOS()->getConfig()->getParam('cache_path'),'cookies');

		do
		{
			$cookies_file=time().'_'.rand(1000,9999).'.cookies';
			
			$cookies_full_path=os_join_path($cookies_path,$cookies_file);
		}
		while (file_exists($cookies_full_path));
		
		$osUtils=getOS()->getUtils();
		
		$result=$osUtils->fileWrite($cookies_full_path,'');
		
		return $result;
	}
	
	public function getInfo($info=false)
	{
		$result=false;
		
		if ($this->curl)
		{
			if ($info)
			{
				$result=curl_getinfo($this->curl,$info);
			}
			else
			{
				$result=curl_getinfo($this->curl);
			}
		}
		
		return $result;
	}
	
	public function getResponseCode()
	{
		$result=false;
		
		if ($this->responseCode)
		{
			$result=$this->responseCode;
		}
		
		return $result;
	}
	
	public function getRequestTime()
	{
		$result=false;
		
		if ($this->requestTime)
		{
			$result=$this->requestTime;
		}
		
		return $result;
	}
	
	public function get($url)
	{
		$this->response=false;
		$this->responseCode=false;
		$this->responseTime=false;
		
		if ($this->curl)
		{
			$this->setOption(CURLOPT_URL, $url);
			$this->setOption(CURLOPT_NOBODY, FALSE);
			$this->setOption(CURLOPT_HEADER, FALSE);
			$this->setOption(CURLOPT_POST, FALSE);
			$this->setOption(CURLOPT_HTTPGET, TRUE);
			$start=microtime(true);
			$this->response=curl_exec($this->curl);
			$this->requestTime=round((microtime(true)-$start)*1000);
			$this->responseCode=$this->getInfo(CURLINFO_HTTP_CODE);
		}
		
		return $this->response;
	}
	
	public function post($url,$params=array())
	{
		$this->response=false;
		$this->responseCode=false;
		$this->responseTime=false;
		
		if ($this->curl)
		{
			$this->setOption(CURLOPT_URL, $url);
			$this->setOption(CURLOPT_NOBODY, FALSE);
			$this->setOption(CURLOPT_HEADER, FALSE);
			$this->setOption(CURLOPT_POST,TRUE);
			$this->setOption(CURLOPT_POSTFIELDS, $params);
			$start=microtime(true);
			$this->response=curl_exec($this->curl);
			$this->requestTime=round((microtime(true)-$start)*1000);
			$this->responseCode=$this->getInfo(CURLINFO_HTTP_CODE);
		}
		
		return $this->response;
	}
	
	public function head($url)
	{
		$this->response=false;
		$this->responseCode=false;
		$this->responseTime=false;
		
		if ($this->curl)
		{
			$this->setOption(CURLOPT_URL, $url);
			$this->setOption(CURLOPT_NOBODY, TRUE);
			$this->setOption(CURLOPT_HEADER, TRUE);
			$start=microtime(true);
			$this->response=curl_exec($this->curl);
			$this->requestTime=round((microtime(true)-$start)*1000);
			$this->responseCode=$this->getInfo(CURLINFO_HTTP_CODE);
		}
		
		return $this->response;
	}
	
	public function parseHeaders($headers)
	{
	    $result=array();
	    
	    $headers=explode("\n",$headers);
	    
	    foreach ($headers as $line)
	    {
	    	$line = trim($line);
	    	
	    	if (0===strpos($line,'HTTP'))
	    	{
	    		$line=explode(' ',$line);
	    		
	    		$result['http_code']=$line[1];
	    	}
	    	elseif (strpos($line, ':') !== false)
			{
	    		list($headerName, $headerValue) = explode(':', $line, 2);
	    		
	    		$headerValue = ltrim($headerValue);
	    		$headerName = strtolower(rtrim($headerName));
	    		
	    		if (isset($result[$headerName]))
	    		{
	    			if (is_array($result[$headerName]))
	    			{
	    				$result[$headerName][] = $headerValue;
	    			}
	    			else
	    			{
	    				$result[$headerName] = array($result[$headerName],$headerValue);
	    			}
	    		}
	    		else
	    		{
	    			$result[$headerName] = $headerValue;
	    		}
	    	}
	    }
	    
	    return $result;
	}
	
	public function success($hasContent=false)
	{
		$result=(200==$this->getResponseCode());
		
		if ($result AND $hasContent)
		{
			$result=(!empty($hasContent));
		}
		
		return $result;
	}
	
	private function setDefaultOptions()
	{
		$this->cookiesFile=false;
		
		if ($this->curl)
		{
			$this->setOption(CURLOPT_FOLLOWLOCATION, TRUE);
			$this->setOption(CURLOPT_SSL_VERIFYPEER, FALSE);
			$this->setOption(CURLOPT_RETURNTRANSFER, TRUE);
			$this->setOption(CURLOPT_TIMEOUT, 10);
			$this->setOption(CURLOPT_USERAGENT, $this->useragents[rand(0,count($this->useragents)-1)]);
		}
	}
	
	private function defineUserAgents()
	{
		$this->useragents=array(
			"Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 ( .NET CLR 3.5.30729)",
			"Mozilla/5.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; SLCC1; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 1.1.4322)",
			"Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.9.2.8) Gecko/20100722 Firefox/3.6.8",
			"Mozilla/5.0 (Windows; U; Windows NT 5.1; cs; rv:1.9.2.4) Gecko/20100611 Firefox/3.6.4"
		);
	}
}
?>