<?php
class OS_HttpMulti
{
	private static $_instance;
	
	private $handler;
	private $requestHandlers;
	
	public $requestUrls;
	
	private $handlerOptions;
	private $handlerHeaders;
	
	public $responses;
	
	public function __construct()
	{
		$this->defineUserAgents();
		
		$this->setInitialValues();
	}
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_HttpMulti();
		}
		return self::$_instance;
	}
	
	private function setInitialValues()
	{
		$this->handler=false;
		
		$this->requestHandlers=array();
		
		$this->requestUrls=array();
		
		$this->handlerOptions=array();
		$this->handlerHeaders=array();
	}
	
	public function setGlobalHeaders($headers)
	{
		$this->handlerHeaders=$headers;
	}
	
	public function getGlobalHeaders()
	{
		return $this->handlerHeaders;
	}
	
	public function setGlobalOptions($options)
	{
		$this->handlerOptions=$options;
	}
	
	public function getGlobalOptions()
	{
		return $this->handlerOptions;
	}
	
	public function addRequest($url,$request_type='get',$request_params=array(),$request_headers=array(),$request_options=array())
	{
		$request_headers=(empty($request_headers)?$this->handlerHeaders:$request_headers);
		$request_options=(empty($request_options)?$this->handlerOptions:$request_options);
		
		$handler=curl_init();
		
		$this->setDefaultOptions($handler);
		
		if ($request_headers)
		{
			curl_setopt($handler,CURLOPT_HTTPHEADER,$request_headers);
		}
		
		if ($request_options)
		{
			foreach ($request_options as $option=>$value)
			{
				curl_setopt($handler,$option,$value);
			}
		}
		
		$request_type=strtolower($request_type);
		if ($request_type=='get')
		{
			curl_setopt($handler,CURLOPT_POST, FALSE);
			curl_setopt($handler,CURLOPT_HTTPGET, TRUE);
		}
		elseif ($request_type=='post')
		{
			curl_setopt($handler,CURLOPT_POST, TRUE);
			curl_setopt($handler,CURLOPT_POSTFIELDS, $request_params);
		}
		
		curl_setopt($handler,CURLOPT_URL, $url);
		
		curl_setopt($handler,CURLOPT_HEADER, TRUE);
		
		$handler_id=count($this->requestHandlers)+1;
		
		$this->requestHandlers[$handler_id]=$handler;
		$this->requestUrls[$handler_id]=$url;
		unset($handler);
	}
	
	public function removeRequestHandler($handler_id)
	{
		$result=false;
		
		if (isset($this->requestHandlers[$handler_id]))
		{
			if ($this->handler)
			{
				curl_multi_remove_handle($this->handler,$this->requestHandlers[$handler_id]);
			}
			
			curl_close($this->requestHandlers[$handler_id]);
			
			unset($this->requestHandlers[$handler_id]);
			
			$result=true;
		}
		
		return $result;
	}
	
	public function removeRequestHandlerByUrl($url)
	{
		$result=false;
		
		foreach ($this->requestUrls as $handler_id=>$handler_url)
		{
			if ($handler_url==$url)
			{
				$result=$this->removeRequestHandler($handler_id);
			}
		}
		
		return $result;
	}
	
	public function execHandlers()
	{
		$result=false;
		
		$this->responses=array();
		
		if (!empty($this->requestHandlers))
		{
			$this->handler=curl_multi_init();
			
			foreach ($this->requestHandlers as $handler)
			{
				curl_multi_add_handle($this->handler,$handler);
			}
			
			$stillRunning=null;

			do
			{
				curl_multi_exec($this->handler,$stillRunning);
			}
			while ($stillRunning > 0);
			
			foreach ($this->requestHandlers as $handler_id=>$handler)
			{
				$response_bulk=curl_multi_getcontent($handler);
				
				
				if ($response_bulk)
				{
					$response_info=curl_getinfo($handler);
					
					$response_headers=trim(substr($response_bulk,0,$response_info['header_size']));
					if (false===strpos($response_headers,"\n"))
					{
						$replace_with="\n";
					}
					else
					{
						$replace_with='';
					}
					$response_headers=str_replace("\r",$replace_with,$response_headers);
					$response_headers=explode("\n\n",$response_headers);
					$final_headers=array_pop($response_headers);					
					$response_info['content_type']=explode(';',$response_info['content_type']);
					$response_info['content_type']=strtolower(trim($response_info['content_type'][0]));
					
					$this->responses[$handler_id]=array(
						'response'=>substr($response_bulk,$response_info['header_size']),
						'response_code'=>$response_info['http_code'],
						'bulk_info'=>$response_info,
						'bulk_headers'=>$this->parseHeaders($final_headers),
						'final_url'=>$response_info['url'],
						'content_type'=>$response_info['content_type'],
						'redirects'=>$this->extractRedirects($this->requestUrls[$handler_id],$response_headers)
					);
				}
				else
				{
					$this->responses[$handler_id]=false;
				}
				
				$this->removeRequestHandler($handler_id);
				unset($handler);
			}
			
			$result=array();
			
			foreach ($this->requestUrls as $handler_id=>$handler_url)
			{
				if (isset($this->responses[$handler_id]))
				{
					$result[$handler_url]=$this->responses[$handler_id];
				}
			}
			
			unset($this->responses);
			$this->requestUrls=array();
			$this->responses=array();
			
			curl_multi_close($this->handler);
			$this->handler=false;
		}

		return $result;
	}
	
	public function extractRedirects($initial_url,$headers)
	{
		$result=false;
		
		if (!empty($headers))
		{
			$osUtils=getOS()->getUtils();
			$current_url=$initial_url;
			
			foreach ($headers as $position=>$header)
			{
				$header=$this->parseHeaders($header);

				$to_url=$osUtils->makeAbsoluteUrl($current_url,$header['location']);

				$result[$current_url]=array('http_code'=>$header['http_code'],'to_url'=>$to_url,'bulk_headers'=>$header);

				$current_url=$to_url;
			}
		}
		
		return $result;
	}
	
	public function parseHeaders($headers)
	{
	    $result=array();
	    
	    $headers=explode("\n",$headers);
	    
	    foreach ($headers as $line)
	    {
	    	$line = trim($line);
	    	
	    	if (0===strpos($line,'HTTP'))
	    	{
	    		$line=explode(' ',$line);
	    		
	    		$result['http_code']=$line[1];
	    	}
	    	elseif (strpos($line, ':') !== false)
			{
	    		list($headerName, $headerValue) = explode(':', $line, 2);
	    		
	    		$headerValue = ltrim($headerValue);
	    		$headerName = strtolower(rtrim($headerName));
	    		
	    		if (isset($result[$headerName]))
	    		{
	    			if (is_array($result[$headerName]))
	    			{
	    				$result[$headerName][] = $headerValue;
	    			}
	    			else
	    			{
	    				$result[$headerName] = array($result[$headerName],$headerValue);
	    			}
	    		}
	    		else
	    		{
	    			$result[$headerName] = $headerValue;
	    		}
	    	}
	    }
	    
	    return $result;
	}
	
	private function setDefaultOptions($handler)
	{
		curl_setopt($handler,CURLOPT_FOLLOWLOCATION, TRUE);
		curl_setopt($handler,CURLOPT_SSL_VERIFYPEER, FALSE);
		curl_setopt($handler,CURLOPT_RETURNTRANSFER, TRUE);
		curl_setopt($handler,CURLOPT_TIMEOUT, 10);
		curl_setopt($handler,CURLOPT_USERAGENT, $this->useragents[rand(0,count($this->useragents)-1)]);
	}
	
	private function defineUserAgents()
	{
		$this->useragents=array(
			"Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.2.12) Gecko/20101026 Firefox/3.6.12 ( .NET CLR 3.5.30729)",
			"Mozilla/5.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; SLCC1; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 1.1.4322)",
			"Mozilla/5.0 (Windows; U; Windows NT 5.1; ro; rv:1.9.2.8) Gecko/20100722 Firefox/3.6.8",
			"Mozilla/5.0 (Windows; U; Windows NT 5.1; cs; rv:1.9.2.4) Gecko/20100611 Firefox/3.6.4"
		);
	}
}
?>