<?php
class OS_Interactions
{
	public static function getInteractions($type,$action)
	{
		$result=false;
		
		$userAvailableApps=false;
		$available=true;
		
		if ($type=='receiver')
		{
			$osUser=getOS()->getUser();
			
			if (!$osUser->isUserLogged())
			{
				$available=false;
			}
			else
			{
				$osProject=getOS()->getProject();
				
				if (!$osProject->selectedProject())
				{
					$available=false;
				}
				else
				{
					$userAvailableApps=array_flip($osUser->getAvailableApps($osProject->id));
				}
			}
		}
		
		if ($available)
		{
			$db=getOS()->getDb();
			
			$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."interactions WHERE type=? AND action=?",array($type,$action));
			while ($row=$db->fetchRow($dbresult))
			{
				if (self::availableInteraction($row,$userAvailableApps))
				{
					$result[$row['id']]=$row;
				}
			}
		}
		
		return $result;
	}
	
	public static function getAllInteractions()
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."interactions",array());
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['id']]=$row;
		}
		
		return $result;
	}
	
	public static function getInteractionsByModule($module,$module_name=false)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."interactions WHERE module=?".($module_name?" AND module_name=?":'');
		$query_params=($module_name?array($module,$module_name):array($module));
		$dbresult=$db->query($query,$query_params);
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['id']]=$row;
		}
		
		return $result;
	}
	
	public static function getInteraction($interaction_id,$check_availability=true)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."interactions WHERE id=?",array($interaction_id));
		if ($row=$db->fetchRow($dbresult))
		{
			if (!$check_availability)
			{
				$result=$row;
			}
			elseif (self::availableInteraction($row))
			{
				$result=$row;
			}
		}
		
		return $result;
	}
	
	public static function availableInteraction($interaction,$userAvailableApps=false)
	{
		$result=false;
		
		if ($interaction['type']=='worker')
		{
			if ($interaction['status']=='A')
			{
				$result=true;
			}
		}
		elseif ($interaction['type']=='receiver')
		{
			if ($interaction['status']=='A')
			{
				if ($interaction['module']=='app')
				{
					$can_test=true;
					
					if ($userAvailableApps===false)
					{
						$osUser=getOS()->getUser();
				
						if (!$osUser->isUserLogged())
						{
							$can_test=false;
						}
						else
						{
							$osProject=getOS()->getProject();
							
							if (!$osProject->selectedProject())
							{
								$can_test=false;
							}
							else
							{
								$userAvailableApps=array_flip($osUser->getAvailableApps($osProject->id));
							}
						}
					}
					
					if ($can_test)
					{
						if (isset($userAvailableApps[$interaction['module_name']]))
						{
							$result=true;
						}
					}
				}
				else
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public static function registerInteraction($type,$action,$action_title,$module,$module_name,$module_title,$method)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$time=$db->DBTimeStamp(time());
		$ip=getOS()->getRemoteAddr();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."interactions WHERE type=? AND action=? AND module=? AND module_name=? AND method=?",array($type,$action,$module,$module_name,$method));
		if (!$row=$db->fetchRow($dbresult))
		{
			$dbresult=$db->query("INSERT INTO ".$db->dbPrefix()."interactions (type,action,action_title,module,module_name,module_title,method,insert_dt,insert_ip,status,status_dt,status_ip) VALUES (?,?,?,?,?,?,?,?,?,?,?,?)",array($type,$action,$action_title,$module,$module_name,$module_title,$method,$time,$ip,'A',$time,$ip));
			
			if ($dbresult!==false)
			{
				$result=$db->getInsertId();
			}
		}
		else
		{
			$result=true;
		}
		
		return $result;
	}
	
	public static function disableInteraction($interaction_id)
	{
		$result=false;
		
		if ($interaction=self::getInteraction($interaction_id,false))
		{
			if ($interaction['status']=='A')
			{
				$db=getOS()->getDb();
				
				$time=$db->DBTimeStamp(time());
				$ip=getOS()->getRemoteAddr();
				
				$dbresult=$db->query("UPDATE ".$db->dbPrefix()."interactions SET status=?,status_dt=?,status_ip=? WHERE id=?",array('D',$time,$ip,$interaction_id));
				
				if ($dbresult!==false)
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public static function enableInteraction($interaction_id)
	{
		$result=false;
		
		if ($interaction=self::getInteraction($interaction_id,false))
		{
			if ($interaction['status']=='D')
			{
				$db=getOS()->getDb();
				
				$time=$db->DBTimeStamp(time());
				$ip=getOS()->getRemoteAddr();
				
				$dbresult=$db->query("UPDATE ".$db->dbPrefix()."interactions SET status=?,status_dt=?,status_ip=? WHERE id=?",array('A',$time,$ip,$interaction_id));
				
				if ($dbresult!==false)
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public static function unregisterInteractionsByModule($module,$module_name=false)
	{
		$result=false;
		
		if ($interactions=self::getInteractionsByModule($module,$module_name))
		{
			$query="DELETE FROM ".$db->dbPrefix()."interactions WHERE module=?".($module_name?" AND module_name=?":'');
			$query_params=($module_name?array($module,$module_name):array($module));
			$dbresult=$db->query($query,$query_params);
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public static function performInteraction($interaction_id,$params)
	{
		$result=false;
		
		$calledBy=getOS()->getAppHandler()->name;
		
		if ($interaction=self::getInteraction($interaction_id))
		{
			if ($interaction['module']=='core')
			{
				$interactionObj=new $interaction['module_name'];
				
				if ($interactionObj)
				{
					if (method_exists($interactionObj,$interaction['method']))
					{
						$result=$interactionObj->$interaction['method']($params);
					}
				}
			}
			elseif ($interaction['module']=='app')
			{
				if ($interaction['type']=='receiver')
				{
					$result=self::performAppReceiverInteraction($interaction,$params);
				}
				else
				{
					$appHandler = getOS()->getAppHandler($interaction['module_name']);
					$appHandler->name=$interaction['module_name'];
				
					$interactionObj=$appHandler->getAppPlugin();
					
					if ($interactionObj)
					{
						if (method_exists($interactionObj,$interaction['method']))
						{
							$result=$interactionObj->$interaction['method']($params);
						}
					}
				}
			}
		}
		
		if ($calledBy)
		{
			getOS()->getAppHandler($calledBy);
		}
		
		return $result;
	}
	
	private static function performAppReceiverInteraction($interaction,$params)
	{
		$result=false;
		
		if ($interaction['module']=='app')
		{
			$OS=getOS();
			
			if ($appHandler=$OS->getAppHandler($interaction['module_name']))
			{
				if ($interactionURL=$appHandler->getAppPlugin()->getAppActionUrl($interaction['method']))
				{
					$OS->setSessionVar('_interactions',array($interaction['module_name']=>$params));
					
//					$OS->redirectTO($interactionURL,true);
					$result=$interactionURL;
				}
			}
		}
		
		return $result;
	}
}
?>