<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_jstracker.php 2012-11-01$
 */

class OS_jsTracker
{
	private static $_instance;
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_jsTracker();
		}
		return self::$_instance;
	}
	
	function __construct() {}
	
	private function parseRequest($requestParams)
	{
		$OS = getOS();
		
		$osUtils = $OS->getUtils();
		
		$tmpData = var_export($requestParams, true);
		
		$log=false;
		
		if(isset($requestParams['pa']))
		{
			$codeData = $osUtils->codeUnpack($requestParams['pa']);
			
			if(count($codeData) == 2)
			{
				$project_id = $codeData[1];
				
				if(isset($requestParams['apps']))
				{
					$appsEvents = array();
					foreach($requestParams['apps'] as $evtName => $evtDetails)
					{
						if (!isset($evtDetails['appName']))
						{
							$log=true;
						}
						else
						{
							$appsEvents[strtolower($evtDetails['appName'])][$evtName] = $evtDetails;
						}
					}
				
					//get project apps
					$osAppHandlerOps = $OS->getAppHandlerOps();
					
					$osProjectAppHandlers = $osAppHandlerOps->getAppHandlersByProjectID($project_id);
					
					if(!empty($osProjectAppHandlers))
					{
						foreach($osProjectAppHandlers as $app_id => $oneAppHandler)
						{
							if(isset($appsEvents[$oneAppHandler->name]))	
							{
								$eventData = array(
									'project_id' => $project_id,
									'events' => $appsEvents[$oneAppHandler->name]
								);
								
								if(isset($requestParams['extra']))
								{
									if(isset($requestParams['extra']['url']))
									{
										$requestParams['extra']['url_hash'] = md5($requestParams['extra']['url']);
									}
									
									$eventData['extra'] = $requestParams['extra'];
								}
								
								$oneAppHandler->trackEvent($eventData);
							}
						}
					}
				}
			}
		}
		
		if ($log)
		{
			$fpath = os_join_path($OS->getConfigVar('cache_path'), 'tmp', 'trk_endpoint_ers.log');
			$osUtils->fileWrite($fpath, var_export($requestParams, true)."\n");
		}
	}
	
	
	public function buildTrackerFile($project_id)
	{
		$result = false;
		
		if($project_id >= 1)
		{
			//get js tracker registered apps from db
			$OS = getOS();
			$osUtils = $OS->getUtils();
			
			$osTrackerRegisteredApps = array();
			$osTrackerLinks = $this->getTrackerLinksByProjectId($project_id);
			
			if(!empty($osTrackerLinks))
			{
				foreach($osTrackerLinks as $linkDetails)
				{
					if($linkDetails['status'] == 'E')
					{
						$osTrackerRegisteredApps[] = $linkDetails['app_name'];	
					}
				}
			}
			
			
			$appsBulkContainers = array();
			
			foreach($osTrackerRegisteredApps as $appName)
			{
				//check if has valid tracker.js file
				
				$trackerPath = os_join_path($OS->getConfigVar('root_path'), 'apps', $appName, 'resources', 'js', 'tracker.js');
				
				if(file_exists($trackerPath))
				{
					$jsTrackerFileContents = $osUtils->fileRead($trackerPath);
					
					if(!empty($jsTrackerFileContents))
					{
						$appCodeDetails = $this->getAppContainer($appName, $jsTrackerFileContents);
						
						$appsBulkContainers[] = $appCodeDetails; 
					}
				}
			}
			
			$allContent = $this->getAppsCoreContainer($appsBulkContainers, $project_id);
			
			
			//get core tracker file
			$mainTrackerPath = os_join_path($OS->getConfigVar('root_path'), 'tracker', 'tracker.js');
			
			if(file_exists($mainTrackerPath))
			{
				$jsTrackerFileContents = $osUtils->fileRead($mainTrackerPath);
			
				$allJsFile = $allContent."\n\n\n".$jsTrackerFileContents;
				
				$result = $allJsFile;
			}
		}
		
		return $result;
	}
	
	private function getAppContainer($appName, $appCode)
	{
		$OS = getOS();
		$osUtils = $OS->getUtils();
		
		$result = false;
		
		$app_code_container_path = os_join_path($OS->getConfigVar('root_path'), 'tracker', 'app_core_container.js');
		if(file_exists($app_code_container_path))
		{
			$app_code_bulk = $osUtils->fileRead($app_code_container_path);
			
			$tmpArr = array('[%app_name%]' => $appName, '[%app_core_code%]' => $appCode);
			
			$app_code_bulk = str_replace(array_keys($tmpArr), array_values($tmpArr), $app_code_bulk);
			
			$result = $app_code_bulk;
		}

		return $result;
	}
	
	private function getAppsCoreContainer($appsBulkContainers, $project_id)
	{
		$OS = getOS();
		$osUtils = $OS->getUtils(); 
		
		$result = false;
		
		$app_code_container_path = os_join_path($OS->getConfigVar('root_path'), 'tracker', 'apps_container.js');
		
		if(file_exists($app_code_container_path))
		{
			$app_code_bulk = $osUtils->fileRead($app_code_container_path);
			
			$obfuscated_project_id = $osUtils->codePack($project_id, $project_id);
			
			$http_root_url = $osUtils->stripHTTP($OS->getConfigVar('root_url'));
			
			$tmpArr = array('[%project_account%]' => $obfuscated_project_id, '[%http_root_url%]' => $http_root_url, '[%apps_bulk_containers%]' => implode(",\n", $appsBulkContainers));
			
			$app_code_bulk = str_replace(array_keys($tmpArr), array_values($tmpArr), $app_code_bulk);
			
			$result = $app_code_bulk;
		}

		return $result;
	}
	
	public function writeTrackerFile($project_id)
	{
		$OS = getOS();
		
		$osUtils = $OS->getUtils();
		
		$obfuscated_project_id = $osUtils->codePack($project_id, $project_id);
		
		$completeTrackeFileContents = $this->buildTrackerFile($project_id);
		
		$obfuscated_project_id = str_replace(".", "-", $obfuscated_project_id);
		
		//destination tracker js path
		$jsTrackerPath = os_join_path($OS->getConfigVar('storage_path'), 'tracker', $obfuscated_project_id.'.js');
		
		$osUtils->fileWrite($jsTrackerPath, $completeTrackeFileContents);
	}
	
	public function getTrackerLinksByProjectId($project_id)
	{
		$result =  array();
		
		if($project_id >= 1)
		{
			$OS = getOS();
			
			$db = $OS->getDb();
			
			$query = "SELECT * FROM ".$db->dbPrefix()."project_jstracker WHERE `project_id` = ?";
			$dbresult = $db->query($query, array($project_id));
			while($row = $db->fetchRow($dbresult))
			{
				$result[$row['id']] = $row;
			}	
		}
		
		return $result;
	}	
	
	public function changeTrackerLinkStatus($status, $app_id, $project_id)
	{
		$result =  false;
		
		if( ($app_id >= 1) && ($project_id  >= 1) && in_array($status, array('E','D')))
		{
			$OS = getOS();
			
			$db = $OS->getDb();
			
			$time = $db->DBTimeStamp(time());
			$remoteAddr = $OS->getRemoteAddr();
			$oneUser = $OS->getUser();
			
			$status_id = (isset($oneUser->id) ? $oneUser->id : -1);
			
			$query = "SELECT * FROM ".$db->dbPrefix()."project_jstracker WHERE `app_id`= ? AND `project_id` = ?";
			$dbresult = $db->query($query,array($app_id, $project_id));
			if($row = $db->fetchRow($dbresult))
			{
				$query = "UPDATE ".$db->dbPrefix()."project_jstracker SET `status`= ?, `status_dt` = ?, `status_ip` = ?, `status_by` = ? WHERE `id` = ?";
				$dbresult = $db->query($query, array($status, $time, $remoteAddr, $status_id, $row['id']));
				
				if ($dbresult !== false)
				{
					$result = true;
					
					//update tracker js file
					$this->writeTrackerFile($project_id);
				}
			}
		}

		return $result;
	}
	
	public function createTrackerLink($oneApp, $project_id)
	{
		$result =  false;
		
		if( ($oneApp->id >= 1) && ($project_id  >= 1))
		{
			$OS = getOS();
			
			$db = $OS->getDb();
			
			$time = $db->DBTimeStamp(time());
			$remoteAddr = $OS->getRemoteAddr();
			
			$query = "SELECT * FROM ".$db->dbPrefix()."project_jstracker WHERE `app_id`= ? AND `project_id` = ?";
			$dbresult = $db->query($query,array($oneApp->id, $project_id));
			if(!$row = $db->fetchRow($dbresult))
			{
				$query = "INSERT INTO ".$db->dbPrefix()."project_jstracker (`app_id`,`app_name`,`project_id`,`insert_dt`,`insert_ip`,`status`,`status_dt`,`status_ip`,`status_by`) VALUES (?,?,?,?,?,?,?,?,?)";
				$dbresult = $db->query($query, array($oneApp->id, $oneApp->name,  $project_id, $time, $remoteAddr, 'E', $time, $remoteAddr, '-1', ));
				
				if ($dbresult !== false)
				{
					$result = true;
				}
			}
		}

		return $result;
	}
	
	public function removeTrackerLink($app_id, $project_id)
	{
		$result =  false;
		
		if( ($app_id >= 1) && ($project_id  >= 1))
		{
			$db = getOS()->getDb();
			
			$query = "SELECT * FROM ".$db->dbPrefix()."project_jstracker WHERE `app_id`= ? AND `project_id` = ?";
			$dbresult = $db->query($query,array($app_id, $project_id));
			if($row = $db->fetchRow($dbresult))
			{
				$query = "DELETE FROM ".$db->dbPrefix()."project_jstracker WHERE `app_id`= ? AND `project_id` = ?";
				$dbresult = $db->query($query, array($app_id, $project_id));
				
				if ($dbresult !== false)
				{
					$result = true;
				}
			}
		}
		return $result;
		
	}
	
	public function handle()
	{
		$requestParams = array();
		
		if(!empty($_GET))
		{
		 	foreach($_GET as $key => $val)
		 	{
		 		$requestParams[$key] = $val;
		 	}
		}
		
		if(!empty($requestParams))
		{
			$this->parseRequest($requestParams);	
		}
	}
}	
?>