<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_mailoperations.php 2012-01-09$
 */

require_once(dirname(dirname(__FILE__)).'/phpmailer/class.phpmailer.php');

class OS_MailOperations
{
	private static $_instance;
	
	//constructor
	function __construct(){}
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_MailOperations();
		}
		return self::$_instance;
	}
	
	public function pushMail($email_data)
	{
		$result = false; $flag = true;
		
		//check required fields
		$required_fields = array('to_email','to_name','subject','message');
		foreach($required_fields as $item) if(empty($email_data[$item])) $flag = false;

		if($flag)
		{
			//Add Do Not Reply
			if(!empty($email_data['from_name'])) $email_data['from_name'].=" - Do Not Reply";
			
			if(!isset($email_data['type'])) $email_data['type'] = 'T';
			elseif(!in_array($email_data['type'], array('T','H'))) $email_data['type'] = 'T';
			
			$OS =  getOS(); 
	
			$db = $OS->getDb();
			$time = $db->DBTimeStamp(time());
			$ip =  $OS->getRemoteAddr();

			$osRootUrlDetails = parse_url($OS->getConfigVar('root_url'));
			$os_instance_host = (isset($osRootUrlDetails['host']) ? $osRootUrlDetails['host'] : $osRootUrlDetails);  
									
			$default_data = array(
				'insert_dt' => $time,
				'insert_ip' => $ip,	
				'sender' => (isset($email_data['sender']) ? $email_data['sender'] : 'error-user@'.$os_instance_host),
				'from_name' => (isset($email_data['from_name']) ? $email_data['from_name'] : 'Do Not Reply'),
				'from_email' => (isset($email_data['from_email']) ? $email_data['from_email'] : 'Do-Not-Reply@'.$os_instance_host),
				'to_name' => $email_data['to_name'],
				'to_email' => $email_data['to_email'],
				'subject' => $email_data['subject'],
				'message' => $email_data['message'],
				'priority' =>  (isset($email_data['priority']) ? $email_data['priority'] : '11'),
				'type' =>  $email_data['type'],
				'status' => 'W',
				'status_dt' => $time,
				'status_ip' => $ip,
				'status_by' => '-1',
				'statuses' => 1
				);
			
			$query = "INSERT INTO ".$db->dbPrefix()."emails (`insert_dt`, `insert_ip`, `sender`, `from_name`, `from_email`, `to_name`, `to_email`, `subject`, `message`, `priority`, `type`, `status`, `status_dt`, `status_ip`, `status_by`, `statuses`) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
			$dbresult = $db->query($query, array_values($default_data));
			
			if ($dbresult !== false)
			{
				$result = $db->getInsertId();
			}
		}
		
		return $result;
	}
	
	public function sendMail($email_data)
	{
		$mailInsertId = $this->pushMail($email_data);
		
		if($mailInsertId !== false)
		{
			$db = getOS()->getDb();
			
			$query = "SELECT * FROM ".$db->dbPrefix()."emails WHERE `id` = ? AND `status` = ?";
			$dbresult =  $db->query($query,array($mailInsertId,"W"));
			if($row = $db->fetchRow($dbresult))
			{
				$result = $this->fetchMail($row);
			}
		}
	
		return $result;
	}	
	
	public function fetchQueuedMails()
	{
		$db = getOS()->getDb();
		$time = $db->DBTimeStamp(time());
		$bulkEmails = array();
		
		$query = "SELECT * FROM ".$db->dbPrefix()."emails WHERE `status` = ? ORDER BY id ASC LIMIT 10";
		$dbresult =  $db->query($query,array("W"));
		while ($row = $db->fetchRow($dbresult)) $bulkEmails[$row['id']] = $row;
		
		if(!empty($bulkEmails))
		{
			foreach($bulkEmails as $email_data)
			{
				$this->fetchMail($email_data);
				sleep(2);
			}
		}
	}
	
	private function fetchMail($email_data)
	{
		$result =  false;
		
		$db = getOS()->getDb();
		$time = $db->DBTimeStamp(time());

		$message = html_entity_decode($email_data['message'],ENT_QUOTES,"UTF-8");
		
		$mail = new PHPMailer(true); 
		
		$mail->IsSendmail();
		
		//$mail->IsMail();
		
		//$mail->IsSMTP();
		
		$sent_ok = false;
		
		try {
		  	$mail->AddAddress($email_data['to_email'], $email_data['to_name']);
		  	$mail->SetFrom($email_data['from_email'], $email_data['from_name']);
		  	$mail->AddReplyTo($email_data['from_email'], $email_data['from_name']);
		  	$mail->Subject = $email_data['subject'];
		  	
		  	if($email_data['type']=='T') $mail->Body = $message;
		  	elseif($email_data['type']=='H') $mail->MsgHTML($message);
		  	
		  	$mail->IsHTML(($email_data['type'] == 'H'));
		  	
		  	$mail->Send();
		  	$sent_ok = true;
			} 
		catch (phpmailerException $e) {$sent_ok=false;trigger_error("Mail Error:".$e->errorMessage(),E_USER_WARNING);}
		catch (Exception $e) {$sent_ok=false;trigger_error("Mail Error:".$e->getMessage(),E_USER_WARNING);}
		
		if($sent_ok) 
		{
			$query = "DELETE FROM ".$db->dbPrefix()."emails WHERE `id` = ?";
			$results =  $db->query($query,array($email_data['id']));
			$result =  true;
		}
		else
		{
			$query = "UPDATE ".$db->dbPrefix()."emails SET `status`= B, `status_dt` = ?, statuses = statuses+1 WHERE id = ?";
			$results =  $db->query($query,array("B", $time, $email_data['id']));
		}
		
		return $result;
	}
}
?>