<?php
class OS_Memory
{
	private static $_instance;
	
	private $currentLimit;
	private $canSetLimit;
	private $events;
	
	public function __construct()
	{
		$this->setInitialValues();
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_Memory();
		}
		
		return self::$_instance;
	}
	
	public function setInitialValues()
	{
		$this->currentLimit=$this->getLimit();
		$this->canSetLimit=$this->canSetLimit();
		$this->events=array();
	}
	
	public function getLimit()
	{
		$limit=ini_get('memory_limit');
		
		if ($limit>-1)
		{
			$multipliers=array('K'=>1024,'M'=>1024*1024,'G'=>1024*1024*1024);
			
			$temp=substr("{$limit}",-1);
			
			if (!is_numeric($temp) AND isset($multipliers[$temp]))
			{
				$limit=substr("{$limit}",0,-1)*$multipliers[$temp];
			}
		}
		
		return $limit;
	}
	
	public function setLimit($new_limit)
	{
		$result=false;
		
		if (ini_set('memory_limit',$new_limit)!==false)
		{
			$this->currentLimit=$this->getLimit();
			
			$result=true;
		}
		
		return $result;
	}
	
	public function canSetLimit()
	{
		$result=false;
		
		if ($ini_details=ini_get_all())
		{
			if (isset($ini_details['memory_limit']))
			{
				if ($ini_details['memory_limit']['access'] & INI_USER)
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public function getCurrentUsage($real=true)
	{
		return memory_get_usage($real);
	}
	
	public function getPeakUsage($real=true)
	{
		return memory_get_peak_usage($real);
	}
	
	public function dynamicScaling($based_on='peak',$max_usage=60,$step=20)
	{
		$result=false;
		
		if ($this->currentLimit==-1)
		{
			return true;
		}
		
		if ($this->canSetLimit)
		{
			$usage=($based_on=='peak'?$this->getPeakUsage():$this->getCurrentUsage());
			
			if ($usage*100/$this->currentLimit>$max_usage)
			{
				$new_limit=$this->currentLimit*(100+$step)/100;
				
				$result=$this->setLimit($new_limit);
			}
		}
		
		return $result;
	}
	
	public function logEvent($event_name,$based_on='current',$real=true)
	{
		$event_details=array();
		
		if ($based_on=='current' OR $based_on=='both')
		{
			$event_details['current']=$this->getCurrentUsage($real);
		}
		
		if ($based_on=='peak' OR $based_on=='both')
		{
			$event_details['peak']=$this->getPeakUsage($real);
		}
		
		$this->events[$event_name][time()]=$event_details;
	}
	
	public function getEvents($event_name=false)
	{
		if ($event_name)
		{
			if (!isset($this->events[$event_name]))
			{
				return false;
			}
			else
			{
				return $this->events[$event_name];
			}
		}
		else
		{
			return $this->events;
		}
	}
}
?>