<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_menu.php 2012-02-27$
 */
class OS_Menu
{
	private $menuItems;
	
	private $menuItemsBulk;
	
	private $optionsMenuItems;
	
	private $settingsMenuItems;
	
	private $perms;
	
	private static $_instance;
	
	private $osProject;
	
	private $osUser;
	
	private $osRootUrl;
    
	//os menu constructor
	public function __construct()
	{
    	$OS = getOS();
    	
    	$this->osUser = $OS->getUser();
    	
    	$this->osRootUrl = $OS->getConfigVar('root_url');
    	
    	if($this->osUser->isUserLogged())
    	{
    		$this->osProject = $OS->getProject();	
    	}
	}

	public static function &get_instance()
	{
		if( !self::$_instance  )
		{
			self::$_instance = new OS_Menu();
		}
		return self::$_instance;
	}
	
	
	public function getParentItems($parent_name)
	{
		$parent_items = array();
		
		$menu_items = $this->getMenuItems();
		
		if(!empty($this->menuItemsBulk))
		{
			foreach($this->menuItemsBulk as $itemName => $itemDetails)
			{
				if($itemDetails['parent'] == $parent_name)
				{
					$parent_items[$itemName] = $itemDetails;
				}
			}
		}
		
		return $parent_items;
	}
	
	public function getItemsByType($type_name)
	{
		$type_items = array();
		
		if(!empty($this->menuItemsBulk))
		{
			foreach($this->menuItemsBulk as $itemName => $itemDetails)
			{
				if($itemDetails['type'] == $type_name)
				{
					$type_items[$itemName] = $itemDetails;
				}
			}
		}
		
		return $type_items;
	}	
		
	public function getMenuItems()
	{
    	if(!isset($this->menuItems))
    	{
			$this->buildMenuItems();
    	}
    	
		return $this->menuItems;
	}
	
	public function buildMenuItems()
	{
        if (count($this->menuItems) > 0)
		{
            return;
		}
            
    	//initialize the menu array
    	$this->menuCreate();
    	
    	$OS = getOS();
    	
    	$osUser = $this->osUser;
    	
    	$os_root_url = $this->osRootUrl;
    	
    	if($osUser->isUserLogged())
    	{
			$osProject = $this->osProject;
			
			$this->addMenuItem('logo_about',array('url'=>$os_root_url.'/users/about.php', 'name'=>_("About"), 'show_in_menu'=>false));
			
	    	//base main menu [user logged]---------------------------------------------------------

			if($osProject->selectedProject())
				{
			    	$this->addMenuItem('widgetsview',array('url'=>$os_root_url.'/livedash/index.php#widgets','name'=>_("Widgets"), 'menu_icon' => 'Y'));
			    	
			        // base apps menu ---------------------------------------------------------
			    	$this->addMenuItem('appsview',array('url'=>$os_root_url.'/livedash/index.php#apps','name'=>_("Apps"), 'menu_icon' => 'R','title'=>_("AppBoard")));
			    	
			    	$this->addMenuItem('marketview',array('url'=>$os_root_url.'/livedash/index.php#market','name'=>_("Market"), 'menu_icon' => '$','title'=>_("AppStore")));
			    	
			    	//add timeframe handler
//			    	$this->addTimeframe();
			    	
			    	//load projects list
			    	$this->addProjectsList();
				}
			else{
		    		//show only if can manage projects
		    		if($osUser->checkPerm('projects_management','view_projects'))
		    		{
	    				$this->addMenuItem('projects_list',array('url'=>$os_root_url.'/users/projects_list.php','name'=>_("Projects"), 'menu_icon' => 'Y'));
	    				
	    				$this->addMenuItem('projects_list_sub',array('url'=>$os_root_url.'/users/projects_list.php','name'=>_("Projects"), 'parent'=>'projects_list', 'menu_icon' => 'Y'));
	    				
						if($osUser->checkPerm('projects_management','add_project'))
						{
							$this->addMenuItem('project_add',array('url'=>$os_root_url.'/users/project_manage.php?op=add','name'=>_("New Project"), 'menu_icon' => '+', 'menu_icon_color' => 'green', 'title'=>_("Add New Project"), 'parent'=>'projects_list'));	
						}	    				
		    		}
					
					if ($osUser->checkPerm('clients_management','view_clients'))
					{
						$this->addMenuItem('clients_list',array('url'=>$os_root_url.'/users/clients_list.php','name'=>_("Clients"), 'menu_icon' => 'U'));
	    				
	    				$this->addMenuItem('clients_list_sub',array('url'=>$os_root_url.'/users/clients_list.php','name'=>_("Clients"), 'parent'=>'clients_list', 'menu_icon' => 'U'));
	    				
						if($osUser->checkPerm('clients_management','manage_clients'))
						{
							$this->addMenuItem('client_add',array('url'=>$os_root_url.'/users/client_ae.php?op=add','name'=>_("New Client"), 'menu_icon' => '+', 'menu_icon_color' => 'green', 'title'=>_("Add New Client"), 'parent'=>'clients_list'));	
						}
					}
					
					//show only if can manage users
					if($osUser->checkPerm('users_management','view_users'))
					{
						$this->addMenuItem('users_list',array('url'=>$os_root_url.'/users/users_list.php', 'name'=>_("Users"), 'menu_icon' => 'U'));
						
						$this->addMenuItem('users_list_sub',array('url'=>$os_root_url.'/users/users_list.php', 'name'=>_("Users"), 'menu_icon' => 'U', 'parent'=>'users_list'));
	
						if($osUser->checkPerm('users_management','add_user'))
						{
							$this->addMenuItem('user_add',array('url'=>$os_root_url.'/users/user_manage.php?op=add','name'=>_("New User"), 'menu_icon' => '+', 'menu_icon_color' => 'green', 'title'=>_("Add New User"), 'parent'=>'users_list'));
						}
					}
					
					
					if($osUser->checkPerm('departments_management','view_departments'))
					{
						$this->addMenuItem('departments',array('url'=>$os_root_url.'/users/departments.php','name'=>_("Departments"), 'menu_icon' => 'S', 'parent'=>'users_list'));

						if($osUser->checkPerm('departments_management','add_department'))
						{
							$this->addMenuItem('department_add',array('url'=>$os_root_url.'/users/department_manage.php?op=add', 'name'=>_("New Department"), 'menu_icon' => '+', 'menu_icon_color' => 'green', 'title'=>_("Add New Department"), 'parent'=>'users_list'));
						}
					}
					
					//developer zone options
					if($osUser->checkPerm('developers','is_developer'))
					{
						$this->addMenuItem('developers',array('url'=>$os_root_url.'/developers/index.php','name'=>_("Developers"), 'menu_icon' => 'Z'));
						
						$this->addMenuItem('developers_apps_list',array('url'=>$os_root_url.'/developers/index.php','name'=>_("My Apps"), 'menu_icon' => 'Y', 'parent'=>'developers'));
						
						$this->addMenuItem('developers_add_app',array('url'=>$os_root_url.'/developers/apps_add.php','name'=>_("New App"), 'menu_icon' => '+', 'menu_icon_color' => 'green', 'parent'=>'developers'));
					}
				}

			//admin zone options
			if($osUser->isUserAdmin())
			{
				$this->addMenuItem('admin_list',array('url'=>$os_root_url.'/livedash/admin.php#apps_manager','name'=>_("Admin"), 'menu_icon' => 'g'));
				
				$this->addMenuItem('admin_apps_manager',array('url'=>$os_root_url.'/livedash/admin.php#apps_manager','name'=>_("Manager"), 'menu_icon' => '=', 'parent'=>'admin_list'));
				
				$this->addMenuItem('admin_market',array('url'=>$os_root_url.'/livedash/admin.php#admin_market','name'=>_("Market"), 'menu_icon' => '$', 'parent'=>'admin_list'));
				
				$this->addMenuItem('admin_settings',array('url'=>$os_root_url.'/livedash/admin.php#admin_settings','name'=>_("System Settings"), 'menu_icon' => 'g', 'parent'=>'admin_list'));
				
				
				//Admin managers
				$this->addMenuItem('apps_manager',array('url'=>$os_root_url.'/livedash/admin.php#apps_manager', 'name'=>_("Apps"), 'title'=>_("Apps"), 'parent'=>'admin_apps_manager', 'show_in_menu'=>false, 'type'=>'tab_menu'));
				
				$this->addMenuItem('widgets_manager',array('url'=>$os_root_url.'/livedash/admin.php#widgets_manager', 'name'=>_("Widgets"), 'title'=>_("Widgets"), 'parent'=>'admin_apps_manager', 'show_in_menu'=>false ,'type'=>'tab_menu'));
				
				$this->addMenuItem('connectors_manager',array('url'=>$os_root_url.'/livedash/admin.php#connectors_manager', 'name'=>_("Connectors"), 'title'=>_("Connectors"), 'parent'=>'admin_apps_manager' ,'show_in_menu'=>false ,'type'=>'tab_menu'));
				
				$this->addMenuItem('crons_manager',array('url'=>$os_root_url.'/livedash/admin.php#crons_manager', 'name'=>_("Crons"), 'title'=>_("Crons"), 'parent'=>'admin_apps_manager' ,'show_in_menu'=>false ,'type'=>'tab_menu'));
				
				$this->addMenuItem('interactions_manager',array('url'=>$os_root_url.'/livedash/admin.php#interactions_manager', 'name'=>_("Interactions"), 'title'=>_("Interactions"), 'parent'=>'admin_apps_manager' ,'show_in_menu'=>false ,'type'=>'tab_menu'));
				
				$this->addMenuItem('events_manager',array('url'=>$os_root_url.'/livedash/admin.php#events_manager', 'name'=>_("Events"), 'title'=>_("Events"), 'parent'=>'admin_apps_manager' ,'show_in_menu'=>false ,'type'=>'tab_menu'));
				
				$this->addMenuItem('proxies_manager',array('url'=>$os_root_url.'/livedash/admin.php#proxies_manager', 'name'=>_("Proxies"), 'title'=>_("Proxies"), 'parent'=>'admin_apps_manager' ,'show_in_menu'=>false ,'type'=>'tab_menu'));
				
				$this->addMenuItem('datasources_manager',array('url'=>$os_root_url.'/livedash/admin.php#datasources_manager', 'name'=>_("Datasources"), 'title'=>_("Datasources"), 'parent'=>'admin_apps_manager' ,'show_in_menu'=>false ,'type'=>'tab_menu'));
			}
	    	
	            
			//base user preferences menu ---------------------------------------------------------
			
			//get user name 
			$currentUserAccount = $osUser->name;
			$this->addMenuItem('settings',array('url'=>$os_root_url.'/users/my_account.php', 'name'=>$currentUserAccount, 'menu_icon' => 'u', 'type'=>'settings_menu'));
				
			$this->addMenuItem('settings_account',array('url'=>$os_root_url.'/users/my_account.php', 'name'=>_("Account"), 'title'=>_("Account Overview"), 'menu_icon' => 'g', 'parent'=>'settings', 'type'=>'settings_menu'));

			//$this->addMenuItem('settings_preferences',array('url'=>$os_root_url.'/users/my_account_preferences.php','name'=>_("Preferences"),'title'=>_("Preferences"),'parent'=>'settings', 'type'=>'settings_menu'));
			
			$this->addMenuItem('settings_about',array('url'=>$os_root_url.'/users/about.php','name'=>_("About"), 'parent'=>'settings', 'menu_icon' => 'i', 'type'=>'settings_menu'));
			
	    	$this->addMenuItem('logout',array('url'=>$os_root_url.'/users/logout.php','name'=>_("Logout"), 'parent'=>'settings', 'menu_icon' => 'Q', 'menu_icon_color'=>'red', 'type'=>'settings_menu'));
    	}
    	else
    	{
			//base main menu [user not logged]---------------------------------------------------------
    		
//    		$this->addMenuItem('login',array('url'=>$os_root_url.'/users/login.php','name'=>_("Login"), 'menu_icon' => 'O'));
//    		
//    		$this->addMenuItem('about',array('url'=>$os_root_url.'/users/about.php','name'=>_("About"), 'menu_icon' => 'i'));
    	}
    	
    	$this->getParentItems("admin_apps_manager");
	}
	
	//add element to menu
	public function addMenuItem($itemName, $itemData)
	{
		//check if order is valid
		if(empty($this->menuItems)) $this->menuItems = array();
		
		if(isset($itemData['before'])) {$order_option = $itemData['before']; $order_type = 'before';}
		elseif(isset($itemData['after'])) {$order_option = $itemData['after']; $order_type = 'after';}
		else $order_option = false;
		
		$builtItemData = $this->buildMenuItem($itemName, $itemData);
		
		//add to menu bulk data
		$this->menuItemsBulk[$itemName] = $builtItemData;		
		
		//get temp menu
		$tmpMenuData = $this->menuItems; $has_parent = false;
		if(isset($itemData['parent']))
		{
			if(isset($this->menuItems[$itemData['parent']]))
			{
				$has_parent = true;
				$tmpMenuData = (empty($this->menuItems[$itemData['parent']]['suboptions'])?array():$this->menuItems[$itemData['parent']]['suboptions']);
			}
		}
		
		if($order_option)
		{
			$tmpArray = array();
			foreach($tmpMenuData as $currentItem => $menuData)
			{
				if($currentItem == $order_option)
				{
					if($order_type == 'before') $tmpArray[$itemName] = $builtItemData;
						
					$tmpArray[$currentItem] = $menuData;
						
					if($order_type == 'after') $tmpArray[$itemName] = $builtItemData;
				}
				else
				{
					$tmpArray[$currentItem] = $menuData;
				}
			}
			
			//if the item was not added , put it at the end of the menu
			if(!isset($tmpArray[$itemName])) $tmpArray[$itemName] = $builtItemData;

			if($has_parent)
			{
				$this->menuItems[$itemData['parent']]['suboptions'] = $tmpArray;
				
				foreach($tmpArray as $items => $details)
				{
					if($details['show_in_menu'])
					{
						$this->menuItems[$itemData['parent']]['visible_suboptions']++;	
					}
				}
			}
			else
			{
				$this->menuItems = $tmpArray;
			}
		}
		elseif($has_parent)
		{
			$this->menuItems[$itemData['parent']]['suboptions'][$itemName] = $builtItemData;
			if($builtItemData['show_in_menu'])
			{
				$this->menuItems[$itemData['parent']]['visible_suboptions']++;
			}
		}		
		else
		{
			$this->menuItems[$itemName] = $builtItemData;
		}
		
		return true;
	}

	private function buildMenuItem($itemName, $itemData)
	{
		$menuData = array(
			'url' => "#", 
			'title' => "", 
			'name' => "", 
			'parent' => false,
			"show_in_menu" => true, 
			"visible_suboptions" => 0,
			"type" => 'options_menu',
			"selected" => false,
			"menu_icon" => false,
			"menu_icon_color" => "white"
			);
		
		foreach($menuData as $key => $val)
		{
			if(isset($itemData[$key])) $menuData[$key] = $itemData[$key];
		}
		
		if((empty($menuData['title'])) && (!empty($menuData['name'])))
		{
			$menuData['title'] = $menuData['name']; 
		}
		
		return $menuData;
	}

	//remove element from menu
	public function removeMenuItem($menuItem)
	{
		//change this to work with sub-menus
		if(isset($this->menuItems[$menuItem]))
		{
			unset($this->menuItems[$menuItem]);
		}
	}
	
	public function setSelectedItem($selectedItem)
	{
		if(isset($this->menuItems))
		{
			if(isset($this->menuItems[$selectedItem]))
			{
				$this->menuItems[$selectedItem]['selected'] = true;
			}
			else
			{
				foreach($this->menuItems as $coption => $details)
				{
					if(isset($details['suboptions']))
					{
						$suboptions_actions = array_keys($details['suboptions']);
						
						$cSubOption = array_search($selectedItem, $suboptions_actions);
						
						if($cSubOption !== false)
						{
							$this->menuItems[$coption]['selected'] = true;
							$this->menuItems[$coption]['suboptions'][$cSubOption]['selected'] = true;
						}
					}
				}
			}
		}
	}
	
	//Check if the user has one of the aggregate permissions
    public function hasPerm($permission)
    {
    	$result = false;
    	
    	if (isset($this->perms[$permission]))
    		{
    			if ($this->perms[$permission])
    			{
    				$result = true;
    			} 
    		}
    	return $result;	
    }

    //get settings menu items (right side)
    public function getSettingsMenu()
    {
    	if(!isset($this->settingsMenuItems))
    	{
    		$this->settingsMenuItems = array();
    		
    		$menuItems = $this->getMenuItems();
    		
    		foreach($menuItems as $itemName => $itemData)
    		{
				if(isset($itemData['type']))
				{
					if($itemData['type'] == 'settings_menu')
					{
						$this->settingsMenuItems[$itemName] = $itemData;
					}
				}
    		}
    	}
    	
    	return $this->settingsMenuItems;	
    }
    
    //get options menu items (left side) 
    public function getOptionsMenu()
    {
    	if(!isset($this->optionsMenuItems))
    	{
    		$this->optionsMenuItems =  array();
    		
    		$menuItems = $this->getMenuItems();
    		
    		foreach($menuItems as $itemName => $itemData)
    		{
    			if(isset($itemData['type']))
				{
					if($itemData['type'] == 'options_menu')
					{
						$this->optionsMenuItems[$itemName] = $itemData;
					}
				}
    		}
    	}
    	
    	return $this->optionsMenuItems;
    }

	//empty current menu
	public function menuCreate()
	{
		$this->menuItems = array();
	}
	
	private function addProjectsList()
	{
	    $osProject = $this->osProject;
	    
	    $os_root_url = $this->osRootUrl;
	    
		if(!empty($_SESSION['project']['projects_list']))
	    {
			$userProjects = array();
	    	foreach($_SESSION['project']['projects_list'] as $project_id => $projectDetails)
			{
				$tmpParams = array('url'=> $os_root_url.'/livedash/index.php#change_project/'.$project_id, 'name'=>$projectDetails['name'], 'parent'=>'projects_list', 'type' => 'settings_menu');
				
				if($project_id == $osProject->id)
	    		{
	    			$this->addMenuItem('projects_list', array('url'=>'#widgets', 'name'=> $osProject->name, 'menu_icon' => 'a', 'type' => 'settings_menu'));
	    			$tmpParams['selected'] = true;	
	    		}
	    			
    			$userProjects[$project_id] = $tmpParams;
			}
	    		
	    	foreach($userProjects as $project_id => $menuParams)
	    	{
	    		$this->addMenuItem('projects_'.$project_id, $menuParams);	
	    	}

			$this->addMenuItem('close_project',array('url'=>$os_root_url.'/users/projects_list.php?op=close_project','name'=>_("Close Project"), 'parent'=>'projects_list', 'menu_icon'=>':', 'menu_icon_color'=>'red', 'type' => 'settings_menu'));	    	
		}
	}
	
	private function addTimeframe()
	{
		$OS=getOS();
		
		$osTimeframe=$OS->getTimeframe();
				
		if ($osTimeframe->isTimeframePossible())
		{
			if ($timeframe=$osTimeframe->getTimeframe())
			{
				if (date('Y',strtotime($timeframe['first']))==date('Y',strtotime($timeframe['last'])))
				{
					if (date('M',strtotime($timeframe['first']))==date('M',strtotime($timeframe['last'])))
					{
						$timeframeName=date('d',strtotime($timeframe['first'])).' - '.date('d M Y',strtotime($timeframe['last']));
					}
					else
					{
						$timeframeName=date('d M',strtotime($timeframe['first'])).' - '.date('d M Y',strtotime($timeframe['last']));
					}
				}
				else
				{
					$timeframeName=date('d M Y',strtotime($timeframe['first'])).' - '.date('d M Y',strtotime($timeframe['last']));
				}
				
				$this->addMenuItem('timeframe_handler',array('url'=>'#','name'=>$timeframeName,'menu_icon'=>'6','title'=>_("Change stats timeframe")));
			}
		}
	}
}
?>