<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_PermissionOperations
{
	private static $_instance;
	
	protected function __construct() {}

	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_PermissionOperations();
		}
		return self::$_instance;
	}
	
	
	//add a permission record to database
	public function addPermissionRecord($project_id,$object_id,$object_type,$permission_op,$module,$permission)
	{
		$result = false;
		
		if( $object_id > -1 && in_array($object_type,array('U','D')))
		{
			$db = getOS()->getDb();
			
			$time = $db->DBTimeStamp(time());
			
			//check permission record 
			$query = "SELECT id FROM ".$db->dbPrefix()."permissions WHERE `project_id`=? AND `object_id` = ? AND `object_type` = ? AND `module` = ? AND `permission` = ?";
			$results =  $db->query($query,array($project_id,$object_id,$object_type,$module,$permission));
			if( !$row = $db->fetchRow($results))
			{
				//insert new permission
				$query = "INSERT INTO ".$db->dbPrefix()."permissions (`project_id`,`object_id`,`object_type`,`op`,`module`,`permission`,`insert_dt`,`insert_ip`) VALUES (?,?,?,?,?,?,?,?)";
				$dbresult = $db->query($query, array($project_id,$object_id,$object_type,$permission_op,$module,$permission,$time,$_SERVER['REMOTE_ADDR']));
			
				if ($dbresult !== false)
				{
					$result = true;
				}
			}
			else
			{

				$time = $db->DBTimeStamp(time());
				$query = "UPDATE ".$db->dbPrefix()."permissions SET `op` = ?, `update_dt` = ?, `update_ip` = ?, `updates` = updates+1 WHERE `id` = ?";
				$dbresult = $db->query($query, array($permission_op, $time, $_SERVER['REMOTE_ADDR'], $row['id']));
				
				if ($dbresult !== false)
				{
					$result = true;
				}
			}
		}
		
		return $result;
	}
	
	//remove a permission record from database
	public function removePermissionRecord($project_id,$object_id,$object_type,$module,$permission)
	{
		$result = false;
		
		if( $object_id > -1 && in_array($object_type,array('U','D')))
		{
			$db =  getOS()->getDb();
			
			//check permission record
			$query = "SELECT id,object_id FROM ".$db->dbPrefix()."permissions WHERE `project_id`=? AND `object_id` = ? AND `object_type` = ? AND `module` = ? AND `permission` = ?";
			$results =  $db->query($query,array($project_id,$object_id,$object_type,$module,$permission));
			if( $row = $db->fetchRow($results))
			{
				//delete current row
				$query = "DELETE FROM ".$db->dbPrefix()."permissions WHERE `object_id`= ? AND `id` = ? ";
				$dbresult =  $db->query($query,array($row['object_id'],$row['id']));
				
				$result =  true;
			}
		}
		
		return $result;		
	}
	
	public function removePermissionsByModule($module)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="SELECT id FROM ".$db->dbPrefix()."permissions WHERE module=? LIMIT 1";
		$dbresult=$db->query($query,array($module));
		if ($row=$db->fetchRow($dbresult))
		{
			$query="DELETE FROM ".$db->dbPrefix()."permissions WHERE module=?";
			$dbresult=$db->query($query,array($module));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		else
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function removePermissionsByProjectID($project_id)
	{
		$result=false;
		
		$db =  getOS()->getDb();
		
		$dbresult=$db->query("DELETE FROM ".$db->dbPrefix()."permissions WHERE project_id=?",array($project_id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	//get one user`s permissions 
	public function getPermissionsByUserID($user_id)
	{
		$result = array();
		
		$db = getOS()->getDb();
		
		if($user_id > -1)
		{
			$query = "SELECT * FROM ".$db->dbPrefix()."permissions WHERE `object_type`= ? AND `object_id` = ?";
			$dbresult = $db->query($query,array("U",$user_id));
			while ($row = $db->fetchRow($dbresult))
			{
				$result[$row['project_id']][$row['module']][$row['permission']] = $row['op'];
			}
		}
		
		return $result;
	}

	//get one department`s permissions
	public function getPermissionsByDepartmentID($department_id)
	{
		$result = array();
		
		$db = getOS()->getDb();
		
		if($department_id > -1)
		{
			$query = "SELECT * FROM ".$db->dbPrefix()."permissions WHERE `object_type`= ? AND `object_id` = ?";
			$dbresult = $db->query($query,array("D",$department_id));
			while ($row = $db->fetchRow($dbresult))
			{
				$result[$row['project_id']][$row['module']][$row['permission']] = $row['op'];
			}
		}
		
		return $result;
	}
}

?>