<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_Permissions
{
	private $permissions;
	
	private static $_instance;
	
	protected function __construct() 
	{
		$this->setInitialValues();
	}

	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_Permissions();
		}
		return self::$_instance;
	}
	
	//sets object to some sane initial values
	public function setInitialValues()
	{
		//default permissions (hackin' for the moment)
		
		//users management rules
		$this->addPermission('core','users_management',array('name'=>_("View Users"),'perm'=>"view_users"));
		$this->addPermission('core','users_management',array('name'=>_("Add User"),'perm'=>"add_user"));
		$this->addPermission('core','users_management',array('name'=>_("Edit User"),'perm'=>"edit_user"));
		$this->addPermission('core','users_management',array('name'=>_("Delete User"),'perm'=>"delete_user"));
		
		//department management rules
		$this->addPermission('core','departments_management',array('name'=>_("View Departments"),'perm'=>"view_departments"));
		$this->addPermission('core','departments_management',array('name'=>_("Add Department"),'perm'=>"add_department"));
		$this->addPermission('core','departments_management',array('name'=>_("Edit Department"),'perm'=>"edit_department"));
		$this->addPermission('core','departments_management',array('name'=>_("Delete Department"),'perm'=>"delete_department"));
		
		//websites managements rules
		$this->addPermission('core','projects_management',array('name'=>_("View Projects"),'perm'=>"view_projects"));
		$this->addPermission('core','projects_management',array('name'=>_("Add Project"),'perm'=>"add_project"));
		$this->addPermission('core','projects_management',array('name'=>_("Edit Projects"),'perm'=>"edit_project"));
		$this->addPermission('core','projects_management',array('name'=>_("Delete Projects"),'perm'=>"delete_project"));
		
		//clients management rules
		$this->addPermission('core','clients_management',array('name'=>_("View Clients"),'perm'=>"view_clients"));
		$this->addPermission('core','clients_management',array('name'=>_("Manage Clients"),'perm'=>"manage_clients"));
		
		//developer permissions
		$this->addPermission('core','developer',array('name'=>_("Access Developer Area"),'perm'=>"is_developer"));
		
		//apps permissions
		$availableApps = getOS()->getAppOps()->getAvailableApps();
		$appHandler = getOS()->getAppHandler();
		
		if(!empty($availableApps))
		{
			foreach ($availableApps as $availableApp)
			{
				$appHandler->name=$availableApp->name;
				
				$appHandler->unloadAppPlugin();
				$appPlugin = $appHandler->getAppPlugin();
				
				if($appPerms = $appPlugin->getPerms())
				{
					foreach($appPerms as $group => $groupData)
					{
						foreach($groupData as $perm => $permData)
						{
							if(isset($permData['name']))
							{
								$tmpPerms = array('name' => $permData['name'],'perm' => $perm);
								if(isset($permData['scope']))
								{
									$tmpPerms['scope'] = $permData['scope'];
								}
								
								$this->addPermission('apps',$group,$tmpPerms);	
							}
						}
					}	
				}
			}
		}
	}
	
	public function getCorePermissions()
	{
		if(empty($this->permissions['core']))
		{
			return (false);	
		}
		else
		{
			return $this->permissions['core'];
		}
	}
	
	public function getAppsPermissions()
	{
		if(empty($this->permissions['apps']))
		{
			return (false);	
		}
		else
		{
			return $this->permissions['apps'];
		}
	}
	
	public function getAllPermissions()
	{
		if(empty($this->permissions))
		{
			return (false);	
		}
		else
		{
			$perms=array();
			
			foreach ($this->permissions as $side=>$sidePerms)
			{
				$perms=array_merge($perms,$sidePerms);
			}
			
			return $perms;	
		}
	}

	public function getPermission($perm)
	{
		$result = false;
		
		if(isset($this->permissions[$perm]))
		{
			$result - $this->permissions[$perm];
		}
		
		return $result;	
	}
	
	public function addPermission($side,$perm_name,$perm_data)
	{
		$this->permissions[$side][$perm_name][$perm_data['perm']] = $perm_data;
	}

	public function removePermission($side,$perm_name,$perm = false)
	{
		$result = false;
		
		if($perm !== false)
		{
			if(isset($this->permissions[$side][$perm_name][$perm]))
			{
				unset($this->permissions[$side][$perm_name][$perm]);
				$result = true;
			}
		}
		elseif(isset($this->permissions[$side][$perm_name]))
		{
			unset($this->permissions[$side][$perm_name]);
			$result = true;	
		} 
		
		return $result;
	}
}	
?>