<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_Project
{
	//project ID
	var $id;
	
	//project`s user_id
	var $user_id;

	//project`s user
	var $user;
	
	//client_id
	var $client_id;
	
	//project Name
	var $name;
	
	//project url
	var $url;
	
	//project timezone
	var $timezone;
	
	//project timezone
	var $language;
	
	//project status
	var $status;

	//status changed date
	var $status_dt;

	//status changed ip
	var $status_ip;
	
	//status changed by user_id
	var $status_by;
	
	//insert_dt
	var $insert_dt;
	
	public $js_tracking;
	
	public $crawl_freq;
	public $crawl_depth;
	public $crawl_max_links;
	public $crawl_threads;
	public $crawl_adv_options;
	public $crawl_dt;
	
	//project departments
	private $departments;
	
	private static $_instance;
	
	//constructor
	function __construct($check_project = false)
	{
		if(($check_project === true) && ($this->selectedProject()))
		{
			$this->syncDetails();
		}
	}
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_Project(true);
		}
		return self::$_instance;
	}
	
	//Load a project in session
	public function load()
	{
		$result = false;
		
		if($this->isValid())
		{
			$projectOps = getOS()->getProjectOps();
			
			$oneProject = $projectOps->getProjectByID($this->id);
			
			if($oneProject !== false)
			{
				$this->set($oneProject);
				
				$result = true;
			}
		}
		
		return $result;
	}
	
	public function set($projectDetails)
	{
		$result = false;
		
		$objVars = get_object_vars($this);
		
		if(is_object($projectDetails))
		{
			$projectDetails = get_object_vars($projectDetails);
		}
		
		foreach($objVars as $field=>$val)
		{
			if(isset($projectDetails[$field]))
			{
				$this->$field = $projectDetails[$field];
				$result = true;
			}
		}
		
		return $result;
	}
	
	//Load and open a new project
	public function open()
	{
		$result = false;
		
		if($this->isValid())	
		{
			$osUser = new OS_User();
			$osUser->id = $this->user_id;
			$osUser->load();
			
			$checkResult = $this->checkProjectPermissions($osUser);
			
			if($checkResult === true)
			{
				$loadResult = $this->load();
				
				$this->loadDepartments();
				
				if($loadResult === true)
				{
					$this->syncDetails();
					
					getOS()->setCurrentTimezone($this->timezone);
					
					$this->syncProjects();
					
					$result = true;	
				}
			}
		}
		return $result;
	}
	
	//Saves the project to the database. 
	public function save()
	{
		$result = false;
		$OS = getOS();
		
		$projectOps = $OS->getProjectOps();

		if ($this->id > -1)
		{
			$result = $projectOps->updateProject($this);
		}
		else
		{
			$newid = $projectOps->insertProject($this);
			if ($newid > -1)
			{
				$this->id = $newid;
				
				//Add jsTracker apps linked to this project
				$trackerResult = $projectOps->checkProjectJsTrackerApps($this->id);
				
				if($trackerResult)
				{
					$OS->getJsTracker()->writeTrackerFile($this->id);
				}
				
				$result = true;
			}

		}

		return $result;
	}
	
	//Delete current project and empty the Project object
	public function delete()
	{
		$result = false;
		
		if ($this->id > -1)
		{
			$OS = getOS();
			
			$projectOps = $OS->getProjectOps();
			
			$osAppOps = $OS->getAppOps();
			
			//Remove departments linked to this project
			$projectDepartments = $this->getDepartments();
			
			if(!empty($projectDepartments))
			{
				foreach($projectDepartments as $department_id)
				{
					$this->removeDepartment($department_id);		
				}
			}
			
			//Remove project keywords
			$osProjectKeywordsOps = $OS->getProjectKeywordOps();
			$osProjectKeywordsOps->deleteKeywordsByProjectID($this->id);
			
			//Remove project search engines
			$osProjectSearchEnginesOps = $OS->getProjectSearchEngineOps();
			$osProjectSearchEnginesOps->deleteSearchEnginesByProjectID($this->id);
			
			//Remove project competitors
			$osCompetitorsOps = $OS->getCompetitorOps();
			$osCompetitorsOps->deleteCompetitorsByProjectID($this->id);
			
			//Remove project-speciffic permissions
			$osPermissionsOps = $OS->getPermissionOps();
			$osPermissionsOps->removePermissionsByProjectID($this->id);
			
			//Remove project sections and widgets within
			$osSectionsOps = $OS->getSectionOps();
			$osSectionsOps->deleteSectionsByProjectID($this->id);
			
			//Remove project crawls
			$osProjectCrawlsOps = $OS->getProjectCrawlOps();
			$osProjectCrawlsOps->deleteCrawlsByProjectID($this->id);
			
			//Remove jsTracker apps linked to this project
			$result = $projectOps->checkProjectJsTrackerApps($this->id, 'remove');
			
			if($result)
			{
				$osUtils = $OS->getUtils();
				
				$obfuscated_project_id = str_replace(".", "-", $osUtils->codePack($this->id, $this->id));
				
				//destination tracker js path
				$jsTrackerPath = os_join_path($OS->getConfigVar('storage_path'), 'tracker', $obfuscated_project_id.'.js');
				if(file_exists($jsTrackerPath))
				{
					unlink($jsTrackerPath);
				}
			}
			
			//Remove user record from the database	
			$result = $projectOps->deleteProjectByID($this->id);
			if ($result)
			{
				$this->reset();
			}
		}

		return $result;
	}
	
	public function markForDeletion()
	{
		$this->status='X';
		
		return $this->save();
	}
	
	public function selectedProject()
	{
		$result = true;
	
		if(!isset($_SESSION['project']['attrs'])) 
		{
			$result = false;
		}
		else  
		{
			$p = array('id','name');
			foreach($p as $v) if (!isset($_SESSION['project']['attrs'][$v])) $result = false;	
		}
		
		return $result;
	}
	
	//Force selected project
	public function forceProjectSelected($jump_to = false)
	{
	if (!$this->selectedProject())
		{
		if (!$jump_to) $jump_to = urlencode($_SERVER['REQUEST_URI']);
		
		getOS()->redirectTO("/users/projects_list.php");
		}
	}
	
	public function close()
	{
		$result = false;
		if($this->id > -1)
		{
			$this->reset();
			
			$clearData = $this->clearSession();
			
			if($clearData === true)
			{
				getOS()->unsetCurrentTimezone();
				
				$result = true;
			}
		}
		return $result;
	}
	
	public function reset()
	{
		if($this->isValid())
		{
			$details = get_object_vars($this);
			
			if($details)
			{
				foreach($details as $field => $value)
				{
					if($field !== '_instance')
					{
						$this->$field = NULL; 
					}
				}
			}
		}
	}
	
	//Clear Project data from SESSION (used when changing projects)
	public function clearSession()
	{
		$result = false;
		if(isset($_SESSION['project']))
		{
			unset($_SESSION['project']);
			$result = true;
		}
		
		return $result;
	}
	
	//check if current project is active
	public function isActive()
	{
		$result = false;
		
		if($this->status == 'A')
		{
			$result = true;	
		}
		
		return $result;
	}

	//get all departments that are linked with the current project
	public function loadDepartments()
	{
		$result = false;
		
		if($this->isValid())
		{
			if(!isset($this->departments))
			{
				$osDepartmentOps = getOS()->getDepartmentOps();
				
				$departmentsResult = $osDepartmentOps->getDepartmentsByProjectID($this->id);
		
				$this->departments = $departmentsResult;
				
				$result = true;
			}
		}	
		
		return $result;
	}
	
	public function getDepartments()
	{
		$result = false;
		
		if($this->isValid())
		{
			if(!isset($this->departments))
			{
				$this->loadDepartments();
			}
			
			$result = $this->departments;
		}
		
		return $result;
	}
	
	//link current user with with a new department
	public function addDepartment($department_id)
	{
		$result = false;
		
		if($this->isValid())
		{
			$osDepartmentOps = getOS()->getDepartmentOps();
			
			$addResult = $osDepartmentOps->createDepartmentProjectLink($this,$department_id);
			
			if($addResult !== false)
			{
				$result = true;
			}
		}
		
		return $result;
	}
	
	//remove current user from a department
	public function removeDepartment($department_id)
	{
		$result = false;
		
		if($this->isValid())
		{
			$osDepartmentOps = getOS()->getDepartmentOps();
			
			$removeResult = $osDepartmentOps->removeDepartmentProjectLink($this,$department_id);
			
			if($removeResult !== false)
			{
				$result = true;
			}
		}
		
		return $result;
	}
	
	public function checkProjectPermissions($osUser)
	{
		$result = true;
		$projectOps = getOS()->getProjectOps();
			
		$checkResult = $projectOps->checkProjectPermissionsByUser($this,$osUser);
		
		if($checkResult === true)
		{
			$result = true;	
		} 
		
		return $result;
	}
	
	public function syncDetails()
	{
		$projectDetails = get_object_vars($this);

		$invalidValues = array("_intance","departments");
		
		//check if user is valid
		if($this->isValid())
		{
			//push project object in SESSION
			foreach($projectDetails as $field => $value)
			{
				if(!in_array($field, $invalidValues))
				{
					$_SESSION['project']['attrs'][$field] = $value;	
				}
			}
			
			if(isset($this->departments))
			{
				$_SESSION['project']['departments'] = $this->departments;
			}
		}
		else
		{
			if($this->selectedProject()) 
			{
				//populate project object from SESSION
				$tmpDetails =  array();
				foreach($projectDetails as $field => $value)
				{
					if(!in_array($field, $invalidValues))
					{
						if(isset($_SESSION['project']['attrs'][$field]))
						{
							$tmpDetails[$field] = $_SESSION['project']['attrs'][$field];	
						}
					}
				}
				
				$this->set($tmpDetails);
				
				if(isset($_SESSION['project']['departments']))
				{
					$this->departments = $_SESSION['project']['departments'];	
				}
			}
		}
	}
	
	private function syncProjects()
	{
		if(!isset($_SESSION['project']['projects_list']))
		{
			$OS = getOS();
			
			//load user project into session
			$osProjectOps = $OS->getProjectOps();
			
			$projects = $osProjectOps->getProjects();
			
			//for now load all projects, later check for permissions
			if(!empty($projects))
			{
				$osUser = $OS->getUser();
				
				//get user's departments
				$osUserDepartments = $osUser->getDepartments();
				
				foreach($projects as $project_id => $oneProject)
				{
					$show_project = false;
					
					if($osUser->isUserAdmin()) $show_project = true;
					else{
							$osProjectDepartments = $oneProject->getDepartments();//checkDepartmentACL($osUser)
							
							if($osProjectDepartments !== false && $osUserDepartments !== false)
							{
								$arrInt = array_intersect($osProjectDepartments,$osUserDepartments);
								
								if($arrInt)
								{
									$show_project =  true;
								}
							}
						}
					
					if($show_project)
					{
						$_SESSION['project']['projects_list'][$project_id] = array(
							'name' => $oneProject->name
							);		
					}
				}
			}			
		}
	}	
	
	//verify if osProject contains valid project details
	public function isValid()
	{
		$result = false;
		
		if(isset($this->id, $this->user_id))
		{
			if($this->id >= 1 && $this->user_id >= 1)
			{
				$result  = true;		
			}
		}
		
		return $result;
	}	
}
?>