<?php
class OS_ProjectCrawlHandler
{
	private static $_instance;
	
	private $crawl;
	private $project;
	private $requestedBy;
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_ProjectCrawlHandler();
		}
		
		return self::$_instance;
	}
	
	public function shouldCrawlProject($project)
	{
		$result=false;
		
		$OS=getOS();
		
		if ($project->crawl_freq>0)
		{
			$OS->initTimezone($project->timezone);

			if (time()-strtotime($project->crawl_dt)>$project->crawl_freq*86400)
			{
				if ($projectCrawlEvents=OS_Events::getEventsByModule('core','os_projectcrawlhandler'))
				{
					$linkedApps=array();
					
					foreach ($projectCrawlEvents as $projectCrawlEvent)
					{
						if ($eventHandlers=OS_Events::getEventHandlers($projectCrawlEvent['name']))
						{
							foreach ($eventHandlers as $eventHandler)
							{
								if ($eventHandler['module']=='core' AND $eventHandler['module_name']!='os_auditoperations')
								{
									$result=true;
									
									break;
								}
								elseif ($eventHandler['module']=='app')
								{
									$linkedApps[$eventHandler['module_name']]=true;
								}
							}
							
							if (!$result)
							{
								$appOps=$OS->getAppOps();
								
								foreach ($linkedApps as $linkedApp=>$dummy)
								{
									$availableApp=$appOps->getAppByName($linkedApp);
									
									if ($appOps->isProjectApp($project->id,$availableApp->id))
									{
										$result=true;
										
										break;
									}
								}
							}
						}
						
						if ($result)
						{
							break;
						}
					}
				}
				else
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public function crawlProject($project,$requestedBy=false)
	{
		$result=false;
		
		$OS=getOS();
		
		$this->project=$project;
		$this->requestedBy=$requestedBy;
		$this->crawl=$OS->getProjectCrawl();
		
		$OS->initTimezone($project->timezone);
		
		$this->crawl->setInitialValues();
		
		$db=$OS->getDb();
		$dt=$db->DBTimeStamp(time());
		
		$this->crawl->project_id=$project->id;
		$this->crawl->start_dt=$dt;
		$this->crawl->status='R';
		$this->crawl->status_dt=$dt;
		
		if ($this->crawl->save())
		{
			OS_Events::triggerEvent('projectCrawlStart',array('project_id'=>$project->id,'start_dt'=>$dt),$this->getEventsScope());

			$osCrawler=getOS()->getCrawler();
			
			$osCrawler->setMaxLinks($project->crawl_max_links);
			$osCrawler->setMaxDepth($project->crawl_depth);
			$osCrawler->setMaxThreads($project->crawl_threads);
			
			$extractionRules=array(
				'select_filters'=>array(
					'type'=>'xpath',
					'actual_type'=>'link',
					'query'=>'//option',
					'url'=>array(
						'location'=>'attribute',
						'attribute'=>'value'
					),
					'anchor'=>false,
					'rel'=>false,
					'check_if_link'=>true
				),
				'img_src'=>array(
					'type'=>'xpath',
					'actual_type'=>'image',
					'query'=>'//img',
					'url'=>array(
						'location'=>'attribute',
						'attribute'=>'src'
					),
					'anchor'=>false,
					'rel'=>false
				),
				'script_src'=>array(
					'type'=>'xpath',
					'actual_type'=>'js',
					'query'=>'//script',
					'url'=>array(
						'location'=>'attribute',
						'attribute'=>'src',
					),
					'anchor'=>false,
					'rel'=>false
				),
				'css'=>array(
					'type'=>'xpath',
					'actual_type'=>'css',
					'query'=>'//link[@rel="stylesheet"]',
					'url'=>array(
						'location'=>'attribute',
						'attribute'=>'href',
					),
					'anchor'=>false,
					'rel'=>false
				),
			);
			
			if (empty($project->crawl_adv_options['images']))
			{
				unset($extractionRules['img_src']);
			}
			if (empty($project->crawl_adv_options['css']))
			{
				unset($extractionRules['css']);
			}
			if (empty($project->crawl_adv_options['js']))
			{
				unset($extractionRules['script_src']);
			}
			
			
			$osCrawler->addExtractionRules($extractionRules);
			
			$osCrawler->setSuccessCallback($this,'projectPageCrawledSuccess');
			$osCrawler->setErrorCallback($this,'projectPageCrawledError');
			
			$osCrawler->setRootURL($project->url);
			$osCrawler->setAdvancedOptions($project->crawl_adv_options);
			
			$osCrawler->crawl($project->url);
			
			$obsolete_urls=array();
			
			$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."projects_urls WHERE project_id=? AND seen_dt<?",array($project->id,$dt));
			while ($row=$db->fetchRow($dbresult))
			{
				$obsolete_urls[$row['id']]=array(
					'url'=>$row['url'],
					'url_hash'=>$row['url_hash']
				);
			}
			
			if ($obsolete_urls)
			{
				$dbresult=$db->query("DELETE FROM ".$db->dbPrefix()."projects_urls WHERE project_id=? AND seen_dt<?",array($project->id,$dt));
				
				foreach ($obsolete_urls as $url_id=>$url_details)
				{
					$db->query("DELETE FROM ".$db->dbPrefix()."projects_urls_links WHERE project_id=? AND from_url_hash=?",array($project->id,$url_details['url_hash']));
					$db->query("DELETE FROM ".$db->dbPrefix()."projects_urls_links WHERE project_id=? AND to_url_hash=?",array($project->id,$url_details['url_hash']));
					$db->query("DELETE FROM ".$db->dbPrefix()."projects_urls_links_external WHERE project_id=? AND from_url_hash=?",array($project->id,$url_details['url_hash']));
				}
				
				OS_Events::triggerEvent('projectUrlsObsolete',array('project_id'=>$project->id,'urls'=>$obsolete_urls));
			}
			
			$dbresult=$db->query("SELECT url_hash,depth,(links_internal_dofollow+links_internal_nofollow) AS links_internal,(links_external_dofollow+links_external_nofollow) AS links_external FROM ".$db->dbPrefix()."projects_urls WHERE project_id=?",array($project->id));
			while ($row=$db->fetchRow($dbresult))
			{
				$db->query("UPDATE ".$db->dbPrefix()."projects_urls_links SET to_depth=? WHERE project_id=? AND to_url_hash=?",array($row['depth'],$project->id,$row['url_hash']));
				
				if ($row['links_internal']>0)
				{
					$db->query("UPDATE ".$db->dbPrefix()."projects_urls_links SET from_depth=? WHERE project_id=? AND from_url_hash=?",array($row['depth'],$project->id,$row['url_hash']));
				}
				
				if ($row['links_external']>0)
				{
					$db->query("UPDATE ".$db->dbPrefix()."projects_urls_links_external SET from_depth=? WHERE project_id=? AND from_url_hash=?",array($row['depth'],$project->id,$row['url_hash']));
				}
			}
			
			OS_Events::triggerEvent('projectCrawlEnd',array('project_id'=>$project->id,'start_dt'=>$dt),$this->getEventsScope());
			
			$dt=date('Y-m-d H:i:s');
			
			if (!$this->getEventsScope())
			{
				$project->crawl_dt=$dt;
				$project->save();
			}
			
			$this->crawl->status='D';
			$this->crawl->status_dt=$dt;
			$this->crawl->end_dt=$dt;
			
			if ($this->crawl->save())
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	private function getEventsScope()
	{
		return $this->requestedBy;
	}
	
	public function projectPageCrawledSuccess($params)
	{
		$this->crawl->urls_2xx++;
		$this->crawl->urls++;
		
		$eventParams=array(
			'project_id'=>$this->project->id,
			'crawl_id'=>$this->crawl->id,
			'url'=>$params['url'],
			'url_hash'=>md5($params['url']),
			'final_url'=>$params['final_url'],
			'redirects'=>$params['redirects'],
			'http_code'=>$params['http_code'],
			'content_type'=>$params['content_type'],
			'file_type'=>$this->typeFromMime($params['content_type']),
			'bulk_headers'=>$params['bulk_headers'],
			'depth'=>$params['depth'],
			'load_time'=>$params['load_time'],
			'size'=>$params['size'],
			'content'=>$params['content'],
			'dom'=>$params['dom'],
			'links'=>$params['links']
		);
		
		$urlCategory='urls_'.$eventParams['file_type'];
		
		$this->crawl->$urlCategory++;
		
		$eventParams['url_id']=$this->logProjectUrl($eventParams);
		
		OS_Events::triggerEvent('projectPageCrawled',$eventParams,$this->getEventsScope());
		
		$this->logCrawlProgress();
	}
	
	public function projectPageCrawledError($params)
	{
		$httpCode=(string)$params['http_code'];
		$urlsCountGroup='urls_'.$httpCode[0].'xx';
		
		$this->crawl->$urlsCountGroup++;
		$this->crawl->urls++;
		
		$eventParams=array(
			'project_id'=>$this->project->id,
			'crawl_id'=>$this->crawl->id,
			'url'=>$params['url'],
			'url_hash'=>md5($params['url']),
			'http_code'=>$params['http_code'],
			'content_type'=>$params['content_type'],
			'file_type'=>$this->typeFromMime($params['content_type']),
			'bulk_headers'=>$params['bulk_headers'],
			'depth'=>$params['depth'],
			'load_time'=>$params['load_time'],
			'size'=>$params['size'],
			'dom'=>$params['dom']
		);
		
		$this->crawl->logUrlError($params['depth'],$params['url'],$params['http_code'],$params['title'],$params['size'],$eventParams['file_type']);
		
		$urlCategory='urls_'.$eventParams['file_type'];
		
		$this->crawl->$urlCategory++;
		
		$eventParams['url_id']=$this->logProjectUrl($eventParams);
		
		OS_Events::triggerEvent('projectPageCrawledError',$eventParams,$this->getEventsScope());
		
		$this->logCrawlProgress();
	}
	
	private function logProjectUrl($params)
	{
		$result=false;
		
		$OS=getOS();
		$utils=$OS->getUtils();
		$db=$OS->getDb();
		
		$query_params=array(
			'project_id'=>$params['project_id'],
			'url'=>$params['url'],
			'url_hash'=>$params['url_hash'],
			'depth'=>$params['depth'],
			'content_type'=>$params['content_type'],
			'file_type'=>$params['file_type'],
			'http_code'=>$params['http_code'],
			'title'=>'',
			'description'=>'',
			'canonical_url'=>'',
			'size'=>0,
			'load_time'=>0,
			'links_internal_nofollow'=>0,
			'links_internal_dofollow'=>0,
			'links_external_nofollow'=>0,
			'links_external_dofollow'=>0,
		);
		
		if (!empty($params['size']))
		{
			$query_params['size']=$params['size'];
		}
		
		if (!empty($params['load_time']))
		{
			$query_params['load_time']=$params['load_time'];
		}
		
		if ($params['dom'])
		{
			$xpath=new DOMXPath($params['dom']);
			
			$title=$xpath->query('//title');
			if ($title->item(0))
			{
				$title=$title->item(0);
				if ($title->nodeValue)
				{
					$query_params['title']=$title->nodeValue;
				}					
			}
			
			$description=$xpath->query('//meta[@name="description"]');
			if ($description->item(0))
			{
				$description=$description->item(0);
				if ($description->getAttribute('content'))
				{
					$query_params['description']=$description->getAttribute('content');
				}
			}
			
			$canonical=$xpath->query("//link[@rel='canonical']");
			if ($canonical->item(0))
			{
				$canonical=$canonical->item(0);
				if ($canonical=$canonical->getAttribute('href'))
				{
					$query_params['canonical_url']=getOS()->getUtils()->makeAbsoluteUrl($params['url'],$canonical);
				}
			}
		}
		
		$old_links=array();
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."projects_urls_links WHERE project_id=? AND from_url_hash=?",array($params['project_id'],$params['url_hash']));
		while ($row=$db->fetchRow($dbresult))
		{
			$follow_type=(empty($row['nofollow'])?'dofollow':'nofollow');
			
			$old_links[$row['to_url']][$follow_type][$row['type']][$row['anchor']]=array('id'=>$row['id'],'occurances'=>$row['occurances']);
		}
		
		$old_links_external=array();
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."projects_urls_links_external WHERE project_id=? AND from_url_hash=?",array($params['project_id'],$params['url_hash']));
		while ($row=$db->fetchRow($dbresult))
		{
			$follow_type=(empty($row['nofollow'])?'dofollow':'nofollow');
			
			$old_links_external[$row['to_url']][$follow_type][$row['type']][$row['anchor']]=array('id'=>$row['id'],'occurances'=>$row['occurances']);
		}
		
		if (!empty($params['links']))
		{
			foreach ($params['links'] as $type=>$actual_urls)
			{
				foreach ($actual_urls as $url=>$types)
				{
					if (!empty($types['link']))
					{
						foreach ($types['link'] as $follow_type=>$subtypes)
						{
							foreach ($subtypes as $subtype=>$anchors)
							{
								foreach ($anchors as $anchor=>$occurances)
								{
									$query_params["links_{$type}_{$follow_type}"]++;
									
									if ($type=='internal')
									{
										if (!isset($old_links[$url][$follow_type][$subtype][$anchor]))
										{
											$to_url_hash=md5($url);
											
											$nofollow=($follow_type=='nofollow'?'Y':'');
											
											$db->query("INSERT INTO ".$db->dbPrefix()."projects_urls_links (project_id,from_url,from_url_hash,to_url,to_url_hash,type,anchor,nofollow,occurances) VALUES (?,?,?,?,?,?,?,?,?)",array($params['project_id'],$params['url'],$params['url_hash'],$url,$to_url_hash,$subtype,$anchor,$nofollow,$occurances));
										}
										else
										{
											if ($old_links[$url][$follow_type][$subtype][$anchor]['occurances']!=$occurances)
											{
												$db->query("UPDATE ".$db->dbPrefix()."projects_urls_links SET occurances=? WHERE id=?",array($occurances,$old_links[$url][$follow_type][$subtype][$anchor]['id']));
											}
											
											unset($old_links[$url][$follow_type][$subtype][$anchor]);
										}
									}
									
									if ($type=='external')
									{
										if (!isset($old_links_external[$url][$follow_type][$subtype][$anchor]))
										{
											$to_url_hash=md5($url);
											
											$nofollow=($follow_type=='nofollow'?'Y':'');
											
											$db->query("INSERT INTO ".$db->dbPrefix()."projects_urls_links_external (project_id,from_url,from_url_hash,to_url,to_url_hash,type,anchor,nofollow,occurances) VALUES (?,?,?,?,?,?,?,?,?)",array($params['project_id'],$params['url'],$params['url_hash'],$url,$to_url_hash,$subtype,$anchor,$nofollow,$occurances));
										}
										else
										{
											if ($old_links_external[$url][$follow_type][$subtype][$anchor]['occurances']!=$occurances)
											{
												$db->query("UPDATE ".$db->dbPrefix()."projects_urls_links_external SET occurances=? WHERE id=?",array($occurances,$old_links_external[$url][$follow_type][$subtype][$anchor]['id']));
											}
											
											unset($old_links_external[$url][$follow_type][$subtype][$anchor]);
										}
									}
								}
							}
						}
					}
				}
			}
		}
		
		foreach ($old_links as $url=>$types)
		{
			foreach ($types as $type=>$subtypes)
			{
				foreach ($subtypes as $subtype=>$anchors)
				{
					foreach ($anchors as $anchor=>$details)
					{
						$db->query("DELETE FROM ".$db->dbPrefix()."projects_urls_links WHERE id=?",array($details['id']));
					}
				}
			}
		}
		
		foreach ($old_links_external as $url=>$types)
		{
			foreach ($types as $type=>$subtypes)
			{
				foreach ($subtypes as $subtype=>$anchors)
				{
					foreach ($anchors as $anchor=>$details)
					{
						$db->query("DELETE FROM ".$db->dbPrefix()."projects_urls_links_external WHERE id=?",array($details['id']));
					}
				}
			}
		}
		
		$dt=$db->DBTimeStamp(time());
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."projects_urls WHERE project_id=? AND url_hash=?",array($params['project_id'],$params['url_hash']));
		if ($row=$db->fetchRow($dbresult))
		{
			$changed_query_params=array();
			
			foreach ($query_params as $field=>$value)
			{
				if ($value!=$row[$field])
				{
					$changed_query_params[$field]=$value;
				}
			}
			
			if (!empty($changed_query_params))
			{
				$changed_query_params['update_dt']=$dt;
			}
			
			$changed_query_params['seen_dt']=$dt;
			
			$set='';
			
			foreach ($changed_query_params as $field=>$value)
			{
				$set.=(empty($set)?'':',')."`{$field}`=?";
				$actual_query_params[]=$value;
			}
			
			$changed_query_params[]=$row['id'];
			
			$dbresult=$db->query("UPDATE ".$db->dbPrefix()."projects_urls SET {$set} WHERE id=?",array_values($changed_query_params));
			
			$result=$row['id'];
		}
		else
		{
			$query_params['insert_dt']=$dt;
			$query_params['update_dt']=$dt;
			$query_params['seen_dt']=$dt;
			
			$query="INSERT INTO ".$db->dbPrefix()."projects_urls (`".implode('`,`',array_keys($query_params))."`) VALUES (".substr(str_repeat("?,",count($query_params)),0,-1).")";
			$dbresult=$db->query($query,array_values($query_params));
			
			if ($dbresult!==false)
			{
				$result=$db->getInsertId();
			}
		}
		
		return $result;
	}
	
	public function typeFromMime($content_type)
	{
		$result=false;
		
		$known_types=array('application/javascript'=>'js','text/css'=>'css','text/html'=>'html','text/xml'=>'xml','text/plain'=>'txt','image/'=>'img');
		
		foreach ($known_types as $mime=>$type)
		{
			if (0===strpos($content_type,$mime))
			{
				$result=$type;
				
				break;
			}
		}
		
		if (!$result)
		{
			$result='other';
		}
		
		return $result;
	}
	
	private function logCrawlProgress($urls_step=100)
	{
		$result=false;
		
		if ($this->crawl->urls % $urls_step==0)
		{
			$this->crawl->status_dt=getOS()->getDb()->DBTimeStamp(time());
			
			$result=$this->crawl->save();
		}
		
		return $result;
	}
}
?>