<?php
class OS_ProjectCrawlOperations
{
	private static $_instance;
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_ProjectCrawlOperations();
		}
		
		return self::$_instance;
	}
	
	public function getProjectCrawlByID($project_id,$crawl_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."project_crawls WHERE id=? AND project_id=?",array($crawl_id,$project_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_ProjectCrawl();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getProjectCrawls($params)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$project_id = $params['project_id'];
		$status = (isset($params['status']) ? $params['status'] : false);

		//use operations function here
		$current_set = (isset($params['set']) ? $params['set'] : 1);
		$max_rows =  (isset($params['max_rows']) ? $params['max_rows'] : 10);
		
		$limit = (($current_set * $max_rows) - $max_rows);
		
		$query="SELECT * FROM ".$db->dbPrefix()."project_crawls WHERE project_id=? ".($status?" AND status=?":'')." ORDER BY status_dt DESC LIMIT {$limit},{$max_rows}";
		$query_params=array($project_id);
		if ($status)
		{
			$query_params[]=$status;
		}

		$dbresult=$db->query($query,$query_params);
		while ($row=$db->fetchRow($dbresult))
		{
			$oneCrawl=new OS_ProjectCrawl();
			$oneCrawl->set($row);
			
			$result[$oneCrawl->id]=$oneCrawl;
		}
		
		return $result;
	}
	
	public function getAllProjectCrawls($project_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."project_crawls WHERE project_id=?",array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneCrawl=new OS_ProjectCrawl();
			$oneCrawl->set($row);
			
			$result[$oneCrawl->id]=$oneCrawl;
		}
		
		return $result;
	}
	
	public function insertProjectCrawl($crawl)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$query="INSERT INTO ".$db->dbPrefix()."project_crawls (project_id,urls,urls_2xx,urls_3xx,urls_4xx,urls_5xx,urls_html,urls_xml,urls_txt,urls_css,urls_js,urls_img,urls_other,start_dt,end_dt,status,status_dt) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		$dbresult=$db->query($query,array($crawl->project_id,$crawl->urls,$crawl->urls_2xx,$crawl->urls_3xx,$crawl->urls_4xx,$crawl->urls_5xx,$crawl->urls_html,$crawl->urls_xml,$crawl->urls_txt,$crawl->urls_css,$crawl->urls_js,$crawl->urls_img,$crawl->urls_other,$crawl->start_dt,$crawl->end_dt,$crawl->status,$crawl->status_dt));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateProjectCrawl($crawl)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		if ($oneCrawl=$this->getProjectCrawlByID($crawl->project_id,$crawl->id))
		{
			$query="UPDATE ".$db->dbPrefix()."project_crawls SET urls=?,urls_2xx=?,urls_3xx=?,urls_4xx=?,urls_5xx=?,urls_html=?,urls_xml=?,urls_txt=?,urls_css=?,urls_js=?,urls_img=?,urls_other=?,start_dt=?,end_dt=?,status=?,status_dt=? WHERE id=?";
			$dbresult=$db->query($query,array($crawl->urls,$crawl->urls_2xx,$crawl->urls_3xx,$crawl->urls_4xx,$crawl->urls_5xx,$crawl->urls_html,$crawl->urls_xml,$crawl->urls_txt,$crawl->urls_css,$crawl->urls_js,$crawl->urls_img,$crawl->urls_other,$crawl->start_dt,$crawl->end_dt,$crawl->status,$crawl->status_dt,$crawl->id));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function deleteProjectCrawlByID($crawl_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("DELETE FROM ".$db->dbPrefix()."project_crawls WHERE id=?",array($crawl_id));
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteCrawlsByProjectID($project_id)
	{
		$result=true;
		
		if ($crawls=$this->getAllProjectCrawls($project_id))
		{
			foreach ($crawls as $crawl_id=>$crawl)
			{
				if (!$crawl->delete())
				{
					$result=false;
					break;
				}
			}
		}
		
		return $result;
	}
	
	public function deleteProjectCrawlUrlErrors($crawl)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("DELETE FROM ".$db->dbPrefix()."project_crawls_urlerrors WHERE project_id=? AND crawl_id=?",array($crawl->project_id,$crawl->id));
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function getProjectCrawlUrlErrors($crawl,$http_code_group=false)
	{
		$result=($http_code_group?array():array(3=>array(),4=>array(),5=>array()));
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."project_crawls_urlerrors WHERE project_id=? AND crawl_id=? ".($http_code_group?" AND http_code_group=?":'')." ORDER BY depth ASC";
		$query_params=array($crawl->project_id,$crawl->id);
		if ($http_code_group)
		{
			$query_params[]=$http_code_group;
		}
		$dbresult=$db->query($query,$query_params);
		while ($row=$db->fetchRow($dbresult))
		{
			if ($http_code_group)
			{
				$result[$row['id']]=$row;
			}
			else
			{
				$result[$row['http_code_group']][$row['id']]=$row;
			}
		}
		
		return $result;
	}
	
	public function insertProjectCrawlUrlError($crawl,$depth,$url,$http_code,$title='',$size=0,$file_type='')
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$http_code_group=(string)$http_code;
		$http_code_group=$http_code_group[0];
		
		$query="INSERT INTO ".$db->dbPrefix()."project_crawls_urlerrors (project_id,crawl_id,http_code_group,file_type,url,title,size,depth,http_code) VALUES (?,?,?,?,?,?,?,?,?)";
		$dbresult=$db->query($query,array($crawl->project_id,$crawl->id,$http_code_group,$file_type,$url,$title,$size,$depth,$http_code));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
}
?>