<?php
class OS_ProjectKeywordOperations
{
	private static $_instance;
	
	public function __construct()
	{
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_ProjectKeywordOperations();
		}
		
		return self::$_instance;
	}
	
	public function getProjectKeywordByID($keyword_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."project_keywords WHERE id=?",array($keyword_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_ProjectKeyword();
			
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getProjectKeywordByKeyword($project_id,$keyword)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."project_keywords WHERE project_id=? AND keyword=?",array($project_id,$keyword));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_ProjectKeyword();
			
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getProjectKeywordsByTopicID($topic_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."project_keywords WHERE topic_id=?",array($topic_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneKeyword=new OS_ProjectKeyword();
			
			$oneKeyword->set($row);
			
			$result[$row['id']]=$oneKeyword;
		}
		
		return $result;
	}
	
	public function getProjectKeywords($project_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."project_keywords WHERE project_id=?",array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneKeyword=new OS_ProjectKeyword();
			
			$oneKeyword->set($row);
			
			$result[$row['id']]=$oneKeyword;
		}
		
		return $result;
	}
	
	public function getProjectKeywordsCountByTopicID($topic_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT COUNT(*) AS topic_keywords FROM ".$db->dbPrefix()."project_keywords WHERE topic_id=?",array($topic_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row['topic_keywords'];
		}
		
		return $result;
	}
	
	public function getProjectKeywordsCountGroupedByTopicID($project_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT topic_id,COUNT(*) AS topic_keywords FROM ".$db->dbPrefix()."project_keywords WHERE project_id=? GROUP BY topic_id",array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['topic_id']]=$row['topic_keywords'];
		}
		
		return $result;
	}
	
	public function getProjectKeywordsCount($project_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT COUNT(*) AS project_keywords FROM ".$db->dbPrefix()."project_keywords WHERE project_id=?",array($project_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row['project_keywords'];
		}
		
		return $result;
	}
	
	public function getProjectKeywordsPendingCompetitors($offset=0,$count=1)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."project_keywords WHERE competitors=? ORDER BY id ASC LIMIT {$offset},{$count}",array(''));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneKeyword=new OS_ProjectKeyword();
			
			$oneKeyword->set($row);
			
			$result[$row['id']]=$oneKeyword;
		}
		
		return $result;
	}
	
	public function getProjectKeywordsPendingCompetitorsCountByTopicID($topic_id)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT COUNT(*) AS kws_pending_competitors FROM ".$db->dbPrefix()."project_keywords WHERE topic_id=? AND competitors=?",array($topic_id,''));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=(int)$row['kws_pending_competitors'];
		}
		
		return $result;
	}
	
	public function deleteProjectKeywordByID($keyword_id)
	{
		$result=false;
		
		if ($keyword=$this->getProjectKeywordByID($keyword_id))
		{
			$db=getOS()->getDb();
			
			$dbresult=$db->query("DELETE FROM ".$db->dbPrefix()."project_keywords WHERE id=?",array($keyword_id));
			
			if ($dbresult!==false)
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function deleteProjectKeywordsByTopicID($topic_id)
	{
		$result=true;
		
		if ($keywords=$this->getProjectKeywordsByTopicID($topic_id))
		{
			foreach ($keywords as $keyword)
			{
				if (!$keyword->delete())
				{
					$result=false;
					break;
				}
			}
		}
		
		return $result;
	}
	
	public function deleteKeywordsByProjectID($project_id)
	{
		$result=true;
		
		if ($keywords=$this->getProjectKeywords($project_id))
		{
			foreach ($keywords as $keyword)
			{
				if (!$keyword->delete())
				{
					$result=false;
					break;
				}
			}
		}
		
		return $result;
	}
	
	public function insertProjectKeyword($keyword)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		$query="INSERT INTO ".$db->dbPrefix()."project_keywords (project_id,topic_id,keyword,competitors) VALUES (?,?,?,?)";
		$dbresult=$db->query($query,array($keyword->project_id,$keyword->topic_id,$keyword->keyword,$keyword->competitors));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateProjectKeyword($keyword)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		$dbresult=$db->query("UPDATE ".$db->dbPrefix()."project_keywords SET competitors=? WHERE id=?",array($keyword->competitors,$keyword->id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function fetchCompetitors($keyword,$engine=false,$locale=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$engine)
		{
			$projectTopicOps=$OS->getProjectTopicOps();
			
			if ($topic=$projectTopicOps->getProjectTopicByID($keyword->topic_id))
			{
				$projectSEOps=$OS->getProjectSearchEngineOps();
				
				if ($se=$projectSEOps->getProjectSearchEngineByID($topic->se_id))
				{
					$engine=$se->engine;
					$locale=(empty($se->locale)?false:$se->locale);
				}
			}
		}
		
		if ($engine)
		{
			$osSearchEngine=$OS->getSearchEngine();
			
			if ($competitors=$osSearchEngine->getResults($keyword->keyword,$engine,$locale))
			{
				if ($competitors['status']=='done')
				{
					$result=$this->saveCompetitors($keyword,$competitors['data']);
				}
				elseif ($competitors['status']=='queued')
				{
					$result=$this->queueKeyword($keyword->id,$competitors['queue_id']);
				}
			}
		}
		
		return $result;
	}
	
	public function saveCompetitors($keyword,$competitors)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		$position=0;
		foreach ($competitors as $competitor)
		{
			$position++;
			
			$oneCompetitor=new OS_ProjectKeywordCompetitor();
			
			$competitor_data=array(
				'project_id'=>$keyword->project_id,
				'keyword_id'=>$keyword->id,
				'url'=>$competitor['url'],
				'position'=>$position
			);
			
			$oneCompetitor->set($competitor_data);
			
			$oneCompetitor->save();
		}
		
		$keyword->competitors='Y';
		
		if ($keyword->save())
		{
			$result=true;
			
			$projectKeywordOps=$OS->getProjectKeywordOps();
			
			if (0===$projectKeywordOps->getProjectKeywordsPendingCompetitorsCountByTopicID($keyword->topic_id))
			{
				$projectTopicOps=$OS->getProjectTopicOps();
				$projectTopicOps->processCompetitors($keyword->topic_id);
			}
		}
		
		return $result;
	}
	
	public function queueKeyword($keyword_id,$queue_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		$dbresult=$db->query("INSERT INTO ".$db->dbPrefix()."project_keywords_queue (keyword_id,queue_id) VALUES (?,?)",array($keyword_id,$queue_id));
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function eventSearchEngineQueried($params)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		$keyword_ids=array();
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."project_keywords_queue WHERE queue_id=?",array($params['queue_id']));
		while ($row=$db->fetchRow($dbresult))
		{
			$keyword_ids[]=$row['keyword_id'];
		}
		
		if (!empty($keyword_ids))
		{
			$db->query("DELETE FROM ".$db->dbPrefix()."project_keywords_queue WHERE queue_id=?",array($params['queue_id']));
			
			foreach ($keyword_ids as $keyword_id)
			{
				if ($oneKeyword=$this->getProjectKeywordByID($keyword_id))
				{
					if ($params['status']=='done')
					{
						$this->saveCompetitors($oneKeyword,$params['data']['getResults']);
					}
					elseif ($params['status']=='failed')
					{
						$this->fetchCompetitors($oneKeyword);
					}
				}
			}
			
			$result=true;
		}
		
		return $result;
	}
}
?>