<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */
 
require_once(dirname(__FILE__)."/class.os_project.php"); 
 
class OS_ProjectOperations
{
	private static $_instance;
	
	protected function __construct() {}

	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_ProjectOperations();
		}
		return self::$_instance;
	}
	
	//Get a list with projects's statuses
	public function & getStatuses()
	{
		$statuses = array(
			'A' => _("Active"),
			'D' => _("Disabled"),
			'P' => _("Pending"),
			'S' => _("Suspended"),
			'R' => _("Removed")
			);
		
		return $statuses; 	
	}

	//Get a list of all projects
	public function &getProjects()
	{
		$db = getOS()->getDb();

		$result = array();

		$query = "SELECT * FROM ".$db->dbPrefix()."projects WHERE status<>? ORDER BY id DESC";
		$dbresult = $db->query($query,array('X'));
		while ($row = $db->fetchRow($dbresult))
		{
			$project = new OS_Project();
			$project->id = $row['id'];
			$project->user_id = $row['user_id'];
			$project->user = $row['user'];
			$project->client_id = $row['client_id'];
			$project->name = $row['name'];
			$project->url = $row['url'];
			$project->timezone = $row['timezone'];
			$project->language = $row['language'];
			$project->status = $row['status'];
			$project->status_dt = $row['status_dt'];
			$project->status_ip = $row['status_ip'];
			$project->status_by = $row['status_by'];
			$project->insert_dt = $row['insert_dt'];
			$project->js_tracking = $row['js_tracking'];
			$project->crawl_freq = $row['crawl_freq'];
			$project->crawl_depth = $row['crawl_depth'];
			$project->crawl_max_links = $row['crawl_max_links'];
			$project->crawl_threads = $row['crawl_threads'];
			if (empty($row['crawl_adv_options']))
			{
				$project->crawl_adv_options=array();
			}
			else
			{
				$project->crawl_adv_options=json_decode($row['crawl_adv_options'],true);
			}
			$project->crawl_dt = $row['crawl_dt'];
			$result[$row['id']] = $project;
		}

		return $result;
	}
	
	public function &getProjectsByClientID($client_id)
	{
		$db = getOS()->getDb();

		$result = array();

		$query = "SELECT * FROM ".$db->dbPrefix()."projects WHERE client_id=? AND status<>? ORDER BY id DESC";
		$dbresult = $db->query($query,array($client_id,'X'));
		while ($row = $db->fetchRow($dbresult))
		{
			$project = new OS_Project();
			$project->id = $row['id'];
			$project->user_id = $row['user_id'];
			$project->user = $row['user'];
			$project->client_id = $row['client_id'];
			$project->name = $row['name'];
			$project->url = $row['url'];
			$project->timezone = $row['timezone'];
			$project->language = $row['language'];
			$project->status = $row['status'];
			$project->status_dt = $row['status_dt'];
			$project->status_ip = $row['status_ip'];
			$project->status_by = $row['status_by'];
			$project->insert_dt = $row['insert_dt'];
			$project->js_tracking = $row['js_tracking'];
			$project->crawl_freq = $row['crawl_freq'];
			$project->crawl_depth = $row['crawl_depth'];
			$project->crawl_max_links = $row['crawl_max_links'];
			$project->crawl_threads = $row['crawl_threads'];
			if (empty($row['crawl_adv_options']))
			{
				$project->crawl_adv_options=array();
			}
			else
			{
				$project->crawl_adv_options=json_decode($row['crawl_adv_options'],true);
			}
			$project->crawl_dt = $row['crawl_dt'];
			$result[$row['id']] = $project;
		}

		return $result;
	}
	
	public function &getProjectsCountByClientID($client_id)
	{
		$db = getOS()->getDb();

		$result = array();

		$query = "SELECT COUNT(*) AS client_projects FROM ".$db->dbPrefix()."projects WHERE client_id=? AND status<>? ORDER BY id DESC";
		$dbresult=$db->query($query,array($client_id,'X'));
		$row=$db->fetchRow($dbresult);
		
		return $row['client_projects'];
	}
	
	//Get a project by id.
	public function &getProjectByID($id)
	{
		return $this->getProjectByDetail(array('id'=>$id));
	}

	//Get a project by url.
	public function &getProjectByUrl($url)
	{
		return $this->getProjectByDetail(array('url'=>$url));
	}

	public function &getProjectByDetail($details)
	{
		$result = false;
		$query  = false;

		$db = getOS()->getDb();

		if(isset($details['id']))  $query = "SELECT * FROM ".$db->dbPrefix()."projects WHERE id = ?";	
		elseif(isset($details['url'])) $query = "SELECT * FROM ".$db->dbPrefix()."projects WHERE url = ?";
		
		if($query)
		{
			$dbresult = $db->query($query, array_values($details));
			
			if ($row = $db->fetchRow($dbresult))
			{
				$project = new OS_Project();
				$project->id = $row['id'];
				$project->user_id = $row['user_id'];
				$project->user = $row['user'];
				$project->client_id = $row['client_id'];
				$project->name = $row['name'];
				$project->url = $row['url'];
				$project->timezone = $row['timezone'];
				$project->language = $row['language'];
				$project->status = $row['status'];
				$project->status_dt = $row['status_dt'];
				$project->status_ip = $row['status_ip'];
				$project->status_by = $row['status_by'];
				$project->insert_dt = $row['insert_dt'];
				$project->js_tracking = $row['js_tracking'];
				$project->crawl_freq = $row['crawl_freq'];
				$project->crawl_depth = $row['crawl_depth'];
				$project->crawl_max_links = $row['crawl_max_links'];
				$project->crawl_threads = $row['crawl_threads'];
				if (empty($row['crawl_adv_options']))
				{
					$project->crawl_adv_options=array();
				}
				else
				{
					$project->crawl_adv_options=json_decode($row['crawl_adv_options'],true);
				}
				$project->crawl_dt = $row['crawl_dt'];
				$result = $project;
			}
				
		}
		return $result;
	}

	//Saves a new project to the database.
	public function insertProject($project)
	{
		$result = -1; 
		
		$OS = getOS();
		
		$db = $OS->getDb();
		
		//check for project conflict (is it necessary in this case ?)
		$query = "SELECT id FROM ".$db->dbPrefix()."projects WHERE `url` = ?";
		$results =  $db->query($query,array($project->url));
		if( $db->fetchRow($results) !== false) return $result;
		
		$time = $db->DBTimeStamp(time());

		//get current user's data (needed for status_by)
		$user_id = $OS->getUser()->id;
		if(is_null($user_id)) $user_id = -1;
				
		//add status additional data
		$project->status_dt = $time;
		$project->status_ip = $OS->getRemoteAddr();
		$project->status_by = $user_id;
		
		$project->crawl_dt=$time;
		
		$query = "INSERT INTO ".$db->dbPrefix()."projects (`user_id`,`user`,`client_id`,`name`,`url`,`timezone`, `language`,`status`,`status_dt`,`status_ip`,`status_by`,`insert_dt`,`insert_ip`,`js_tracking`,`crawl_freq`,`crawl_max_links`,`crawl_depth`,`crawl_threads`,`crawl_adv_options`,`crawl_dt`) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		$dbresult = $db->query($query, array($project->user_id,$project->user,$project->client_id,$project->name, $project->url, $project->timezone, $project->language, $project->status, $project->status_dt, $project->status_ip, $project->status_by, $time, $OS->getRemoteAddr(),$project->js_tracking,$project->crawl_freq,$project->crawl_max_links,$project->crawl_depth,$project->crawl_threads,json_encode($project->crawl_adv_options),$project->crawl_dt));  
		
		if ($dbresult !== false)
		{
			$result = $db->getInsertId();
		}

		return $result;
	}

	//Updates an existing project in the database.
	public function updateProject($project)
	{
		$result = false;
		
		$OS = getOS(); 

		$db = $OS->getDb();
		
		//check for project conflict
		$query = "SELECT id FROM ".$db->dbPrefix()."projects WHERE `url` = ? AND `id` != ?";
		$results =  $db->query($query,array($project->url,$project->id));
		if( $db->fetchRow($results) !== false) return $result;
		
		//get old project from the database
		$time = $db->DBTimeStamp(time());
		$oldProject = $this->getProjectByID($project->id);
		
		if($oldProject !== false)
		{
			$oldProject->client_id = $project->client_id;
			
			$oldProject->name =  $project->name; 
			$oldProject->url =  $project->url;
			$oldProject->timezone =  $project->timezone;
			$oldProject->language =  $project->language;
			
			$oldProject->js_tracking = $project->js_tracking;
			
			$oldProject->crawl_freq = $project->crawl_freq;
			$oldProject->crawl_max_links = $project->crawl_max_links;
			$oldProject->crawl_depth = $project->crawl_depth;
			$oldProject->crawl_threads = $project->crawl_threads;
			$oldProject->crawl_adv_options = $project->crawl_adv_options;
			$oldProject->crawl_dt = $project->crawl_dt;
			
			if($project->status != $oldProject->status)
			{
				//get current user's data (needed for status_by)
				$user_id = $OS->getUser()->id;
				if(is_null($user_id)) $user_id = -1;
				
				$oldProject->status = $project->status; 
				$oldProject->status_dt = $time;
				$oldProject->status_ip = $OS->getRemoteAddr();  
				$oldProject->status_by = $user_id;
			}

			//execute the update query
			$query = "UPDATE ".$db->dbPrefix()."projects SET `client_id`=?, `name` = ?, `url` = ?, `timezone` = ?, `language` = ?, `status` = ?, `status_dt` = ?, `status_ip` = ?, `status_by` = ?, `update_dt` = ?, `update_ip` = ?, `js_tracking` = ?, `crawl_freq` = ?, `crawl_max_links` = ?, `crawl_depth` = ?, `crawl_threads` = ?, `crawl_adv_options` = ?, `crawl_dt` = ? WHERE `id` = ?";
			$dbresult = $db->query($query, array($oldProject->client_id,$oldProject->name, $oldProject->url, $oldProject->timezone, $oldProject->language, $oldProject->status, $oldProject->status_dt, $oldProject->status_ip, $oldProject->status_by, $time, $OS->getRemoteAddr(), $oldProject->js_tracking, $oldProject->crawl_freq, $oldProject->crawl_max_links, $oldProject->crawl_depth, $oldProject->crawl_threads, json_encode($oldProject->crawl_adv_options), $oldProject->crawl_dt, $oldProject->id));
			if ($dbresult !== false)
			{
				$result = true;
			}
		}  
		return $result;
	}
	
	
	//checks used has permissions to access the project
	public function checkProjectPermissionsByUser($project,$user)
	{
		$result = false;
		
		//get project's departments
		if($user->isUserAdmin()) $result = true;
		else
		{
			$osProjectDepartments = $project->getDepartments();
			
			$osUserDepartments = $user->getDepartments();
			
			if($osProjectDepartments !== false  && $osUserDepartments !== false)
			{
				//check for common departments
				$arrInt = array_intersect($osProjectDepartments,$osUserDepartments);
				
				if($arrInt !== false)
				{
					$result = true;
				}
			}
		} 
		
		return $result;
	}

	//Deletes an existing project from the database.
	public function deleteProjectByID($id)
	{
 		$result = false;

		$db = getOS()->getDb();
 		
 		$dbresult=$db->query("DELETE FROM ".$db->dbPrefix()."projects_urls WHERE project_id=?",array($id));
 		
 		if ($dbresult!==false)
 		{
 			$dbresult=$db->query("DELETE FROM ".$db->dbPrefix()."projects_urls_links WHERE project_id=?",array($id));
 			
 			if ($dbresult!==false)
 			{
 				$dbresult=$db->query("DELETE FROM ".$db->dbPrefix()."projects_urls_links_external WHERE project_id=?",array($id));
 				
 				if ($dbresult!==false)
 				{
 					$dbresult=$db->query("DELETE FROM ".$db->dbPrefix()."projects WHERE id=?",array($id));
 					
 					if ($dbresult!==false)
 					{
 						$result=true;
 						
 						OS_Events::triggerEvent('projectDeleted',array('project_id'=>$id));
 					}
 				}
 			}
 		}

		return $result;
	}
	
	public function getProjectTagCode($project_id)
	{
		$OS = getOS();
		$osUtils = $OS->getUtils();
		
		$obfuscated_project_id = $osUtils->codePack($project_id, $project_id);
		
		$obfuscated_project_id = str_replace(".", "-", $obfuscated_project_id); 
		
		$http_root_url = $osUtils->stripHttp($OS->getConfigVar('root_url'));
		
		$jsTrackerPath =  'storage/tracker/'.$obfuscated_project_id.'.js';
		
		$jsTrackerEndpoint = '';
		
		$tagCode = "<script type='text/javascript'>\n";
		$tagCode .= "var _osaq = _osaq || [];\n";
		$tagCode .= "(function(){ \n";
		$tagCode .= "var u=(('https:' == document.location.protocol) ? 'https' : 'http') + '://{$http_root_url}/'\n";
		$tagCode .= "_osaq.push(['enableAppsTracker']);\n";
		$tagCode .= "var d=document, g=d.createElement('script'), s=d.getElementsByTagName('script')[0]; g.type='text/javascript'; g.defer=true; g.async=true; g.src=u+'{$jsTrackerPath}';\n";
		$tagCode .= "s.parentNode.insertBefore(g,s); })();\n";
		$tagCode .= "</script>";
		
		return $tagCode;	
	}
	
	public function createProjectDetailsBySchema($oneProject, $schemaFilepath)
	{
		
	}
	
	public function createDefaultProjectDetails($oneProject)
	{
		//verify project
		
		//store it in a file (json format)
		$defaultProjectSchema = array(
			
			'sections' => array(
				'opens' => array(
					'name' => "OpenS",
					'layout' => 2,
					'position' => 1,
					'widgets'=> array(
						)
					)	
				),
			'departments' => array('administrators')	
		);
			
		$OS = getOS();
		
		if(!empty($defaultProjectSchema['sections']))
		{
			$osWidgetOps = $OS->getWidgetOps();
			
			$osSectionOps = $OS->getSectionOps();
			
			//get all project sections
			$osProjectSectionsNames = array();
			$osProjectSections = $osSectionOps->getSectionsByProjectID($oneProject->id);
			
			if(!empty($osProjectSections))
			{
				foreach($osProjectSections as $currentSection)
				{
					$osProjectSectionsNames[$currentSection->name] = $currentSection->id;
				}	
			}
			
			foreach($defaultProjectSchema['sections'] as $sname => $sectionOptions)
			{
				$buildWidgets = true;
				
				$sectionDetails = array(
					'project_id' => $oneProject->id,
					'user_id' => $oneProject->user_id,
					'name' => $sectionOptions['name'],
					'position' => $sectionOptions['position'],
					//'icon' => $sectionOptions['icon'],
					'layout' => $sectionOptions['layout']
					);
				
				//if section already exists in the system
				if(isset($osProjectSectionsNames[$sectionOptions['name']] ))
				{
					$sectionDetails['id'] = $osProjectSectionsNames[$sectionOptions['name']];
					$buildWidgets = false; 
				}
				
				//create new section
				$oneSection = new OS_Section();
				$oneSection->set($sectionDetails);
				$sectionResponse = $oneSection->save();
				
				if($sectionResponse !== false)
				{
					$sectionOps=$OS->getSectionOps();
					
					//if section has widgets add them
					if((isset($sectionOptions['widgets'])) && ($buildWidgets === true))
					{
						foreach($sectionOptions['widgets'] as $wname => $widgetOptions)
						{
							$oneWidget = $osWidgetOps->getWidgetByName($wname);
							
							if($oneWidget !== false)
							{ 	
								$widgetDetails = array(
									'main_widget_id' => $oneWidget->id,
									'project_id' => $oneProject->id,
									'user_id' => $oneProject->user_id,
									'section_id' => $oneSection->id,
//									'column_id' => $widgetOptions['column_id'],
									'column_id' => $sectionOps->getEmptiestColumn($oneSection->id,$oneProject->user_id,$oneProject->id),
									'position' => $widgetOptions['position'],
									'background_color' => $widgetOptions['background_color'],
									'name' => $wname,
									'title' => $oneWidget->title
								);
								
								$osWidgetHandler = new OS_WidgetHandler();
								$osWidgetHandler->set($widgetDetails);
								$widgetResponse = $osWidgetHandler->save();
								
								if($widgetResponse !== false)
								{
									
								}
								else
								{
									
								}
							}
						}
					}
				}
				else
				{
					
				}
			}	
		}

		//Add project departments
		if(!empty($defaultProjectSchema['departments']))
		{
			$osDepartmentOps = $OS->getDepartmentOps();
			
			foreach($defaultProjectSchema['departments'] as $depName)
			{
				$oneDepartment = $osDepartmentOps->getDepartmentByName($depName);
				
				if($oneDepartment !== false)
				{
					$depResult = $oneProject->addDepartment($oneDepartment->id);
				}
			}
		}
		
		
		$this->checkProjectJsTrackerApps($oneProject->id);
		
		return true;
	}

	public function checkProjectJsTrackerApps($project_id, $type = 'add')
	{
		$result = false;
		
		//Add project js tracker details
		$OS = getOS();
		
		$osAppOps = $OS->getAppOps();
		
		$osAvailableApps = $osAppOps->getAvailableApps();
		
		$trackerApps = array();
		if(!empty($osAvailableApps))
		{
			foreach($osAvailableApps as $app_id => $oneApp)
			{
				$appManifest = $oneApp->getManifest();
				
				if(isset($appManifest['details']['useJsTracker']))
				{
					if($appManifest['details']['useJsTracker'] == 1)
					{
						$trackerApps[$oneApp->name] = $oneApp;						
					}
				}
			}
		}
		
		if(!empty($trackerApps))
		{
			$osAppHandlerOps = $OS->getAppHandlerOps();
			$osJsTracker = $OS->getJsTracker();
			
			/*
			$osProjectAppHandlers = $osAppHandlerOps->getAppHandlersByProjectID($project_id);
			if(!empty($osProjectAppHandlers))
			*/
			foreach($trackerApps as $oneApp)
			{
				if($type == 'add')
				{
					$osJsTracker->createTrackerLink($oneApp, $project_id);	
				}
				elseif($type == 'remove')
				{
					$osJsTracker->removeTrackerLink($oneApp->id, $project_id);
				}
				
				$result = true;
			}
		}

		return $result;
	} 
	
}	
?>