<?php
class OS_ProjectTopicOperations
{
	private static $_instance;
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_ProjectTopicOperations();
		}
		
		return self::$_instance;
	}
	
	public function getProjectTopicByID($topic_id)
	{
		$result=false;
		
		$OS=getOS();
		
		$db=$OS->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."project_topics WHERE id=?",array($topic_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=new OS_ProjectTopic();
			$result->set($row);
		}
		
		return $result;
	}
	
	public function getProjectTopicsBySearchEngineID($se_id,$project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."project_topics WHERE se_id=? AND project_id=?",array($se_id,$project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneTopic=new OS_ProjectTopic();
			$oneTopic->set($row);
			
			$result[$row['id']]=$oneTopic;
		}
		
		return $result;
	}
	
	public function getProjectTopicsCountBySearchEngineID($se_id,$project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		
		$dbresult=$db->query("SELECT COUNT(*) AS se_topics FROM ".$db->dbPrefix()."project_topics WHERE se_id=? AND project_id=?",array($se_id,$project_id));
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row['se_topics'];
		}
		
		return $result;
	}
	
	public function getProjectTopics($project_id=false)
	{
		$result=false;
		
		$OS=getOS();
		
		if (!$project_id)
		{
			$osProject=$OS->getProject();
			
			if (empty($osProject->id))
			{
				return false;
			}
			
			$project_id=$osProject->id;
		}
		
		$db=$OS->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."project_topics WHERE project_id=?",array($project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$oneTopic=new OS_ProjectTopic();
			$oneTopic->set($row);
			
			$result[$row['id']]=$oneTopic;
		}
		
		return $result;
	}
	
	public function insertProjectTopic($topic)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		$dbresult=$db->query("INSERT INTO ".$db->dbPrefix()."project_topics (project_id,se_id,topic,competitors) VALUES (?,?,?,?)",array($topic->project_id,$topic->se_id,$topic->topic,$topic->competitors));
		
		if ($dbresult!==false)
		{
			$result=$db->getInsertId();
		}
		
		return $result;
	}
	
	public function updateProjectTopic($topic)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		$dbresult=$db->query("UPDATE ".$db->dbPrefix()."project_topics SET competitors=? WHERE id=?",array($topic->competitors,$topic->id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteProjectTopicByID($topic_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		$kwOps=$OS->getProjectKeywordOps();
		
		if ($kwOps->deleteProjectKeywordsByTopicID($topic_id))
		{
			$osCompetitorOps=$OS->getCompetitorOps();
			
			if ($osCompetitorOps->deleteCompetitorsByTopicID($topic_id))
			{
				$dbresult=$db->query("DELETE FROM ".$db->dbPrefix()."project_topics WHERE id=?",array($topic_id));
				
				if ($dbresult!==false)
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public function deleteProjectTopicsByProjectID($project_id)
	{
		$result=true;
		
		if ($topics=$this->getProjectTopics($project_id))
		{
			foreach ($topics as $topic)
			{
				if (!$topic->delete())
				{
					$result=false;
					break;
				}
			}
		}
		
		return $result;
	}
	
	public function processCompetitors($topic_id)
	{
		$result=false;
		
		if ($topic=$this->getProjectTopicByID($topic_id))
		{
			$OS=getOS();
			$projectKeywordOps=$OS->getProjectKeywordOps();
			$projectKwCompetitorOps=$OS->getProjectKeywordCompetitorOps();
									
			if ($topicKeywords=$projectKeywordOps->getProjectKeywordsByTopicID($topic_id))
			{
				$topicCompetitors=array();
				
				foreach ($topicKeywords as $topicKeyword)
				{
					if ($topicKeywordCompetitors=$projectKwCompetitorOps->getProjectKeywordCompetitorsByKeywordID($topicKeyword->id))
					{
						foreach ($topicKeywordCompetitors as $topicKeywordCompetitor)
						{
							if ($topicKeywordCompetitorHost=parse_url($topicKeywordCompetitor->url,PHP_URL_HOST))
							{
								if (!isset($topicCompetitors[$topicKeywordCompetitorHost]))
								{
									$topicCompetitors[$topicKeywordCompetitorHost]=array('occurances'=>0,'position'=>0);
								}
								
								$topicCompetitors[$topicKeywordCompetitorHost]['occurances']++;
								$topicCompetitors[$topicKeywordCompetitorHost]['position']+=$topicKeywordCompetitor->position;
							}
						}
					}
				}
				
				foreach ($topicCompetitors as $topicCompetitorHost=>$details)
				{
					$topicCompetitors[$topicCompetitorHost]['position']=$details['position']/$details['occurances'];
				}
				
				$topicCompetitors=$this->orderCompetitors($topicCompetitors,'occurances',SORT_DESC,'position',SORT_ASC);
				if ($topicCompetitors=array_slice($topicCompetitors,0,10,true))
				{
					$osCompetitorOps=$OS->getCompetitorOps();
					
					$osCompetitorOps->deleteCompetitorsByTopicID($topic->id,false);
					
					foreach ($topicCompetitors as $topicCompetitorHost=>$dummy)
					{
						$oneCompetitor=new OS_Competitor();
						
						$competitor_data=array(
							'project_id'=>$topic->project_id,
							'topic_id'=>$topic->id,
							'host'=>$topicCompetitorHost
						);
						
						$oneCompetitor->set($competitor_data);
						
						$oneCompetitor->save();
					}
					
					$topic->competitors='Y';
					
					$topic->save();
					
					$eventParams=array(
						'project_id'=>$topic->project_id,
						'competitors'=>array_keys($topicCompetitors)
					);
					
					OS_Events::triggerEvent('projectCompetitorsDetected',$eventParams);
					
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	private function orderCompetitors()
	{
		$args = func_get_args();
		$data = array_shift($args);
		
	    foreach ($args as $n => $field)
		{
			if (is_string($field))
			{
				$tmp = array();
				
				foreach ($data as $key => $row)
				{
					$tmp[$key] = $row[$field];
				}
				
				$args[$n] = $tmp;
			}
		}
		
		$args[] = &$data;
		call_user_func_array('array_multisort', $args);
		
	    return array_pop($args);
	}
}
?>