<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */
class OS_Proxy
{
	
	public $id;
	
	public $proxy_ip;
	
	public $proxy_port;
	
	public $status;
	
	public $request_time;
	
	public $status_reason;
	
	public $status_dt;
	
	public $status_ip;
	
	public $status_by;
	
	
	public function __construct($options = array()) 
	{
		if(!empty($options) && (is_array($options)))
		{
			$this->set($options);
		}		
	}
	
	
	//save proxy data
	public function save()
	{
		$result = false;
		
		$OS = getOS();
		
		$osProxyOps = $OS->getProxyOps();
		
		if ($this->id > -1)
		{
			$result = $osProxyOps->updateProxy($this);
		}
		else
		{
			$newid = $osProxyOps->insertProxy($this);
			
			if ($newid > -1)
			{
				$this->id = $newid;
				$result = true;
			}
		}

		return $result;
	}	
	
	public function set($widgetData)
	{
		$result = false;
		
		$objVars = get_object_vars($this);
		
		foreach($objVars as $key=>$val)
		{
			if(isset($widgetData[$key]))
			{
				$this->$key = $widgetData[$key];
				$result = true;
			}
		}
		return $result;
	}
	
	public function get($key)
	{
		$result = false;
		
		$objVars = get_object_vars($this);
		
		if(isset($objVars[$key]))
		{
			$result = $objVars[$key];
		}
		
		return $result;
	}
	
	
	public function delete()
	{
		$result = false;
		
		if ($this->id > -1)
		{
			$OS = getOS();
			
			$osProxyOps = $OS->getProxyOps();
			
			//Remove widget record from the database
			$result = $osProxyOps->deleteProxyByID($this->id);
			if ($result)
			{
				$this->destroy();
			}
		}

		return $result;		
	}
	
	public function destroy()
	{
		$result = false;
		
		$objVars = get_object_vars($this);
		
		foreach($objVars as $key=>$val)
		{
			$this->$key = null;
			$result = true;
		}
		
		return $result;
	}
	
	public function isValid()
	{
		$result = false;
		if(isset($this->id))
		{
			if($this->id > 0)
			{
				$result  = true;		
			}
		}
		
		return $result;
	}
	
	public function checkProxy()
	{
		$resultDetails = array('result'=> false);
		
		if($this->isValid())
		{
			$OS = getOS();
			$osHttp = $OS->getHttp();
			
			$setProxyResult = $osHttp->setProxy($this->proxy_ip,$this->proxy_port);
			
			if($setProxyResult)
			{
				$proxy_check_path = os_join_path($OS->getConfigVar('root_url'), 'int', 'proxy_check.php');
				
				//calculate request time
				$checkResponse = $osHttp->get($proxy_check_path);
				
				$resultDetails['request_time'] = $osHttp->getRequestTime();

				if((!empty($checkResponse)) && ($osHttp->getResponseCode() == '200'))
				{
					$resultDetails['checkProxy_checkResponse'] = $checkResponse;
					
					$proxyCheckDetails = json_decode($checkResponse, true);
					
					if(!is_null($proxyCheckDetails))
					{
						if($proxyCheckDetails['actionData']['remote_addr'] == $this->proxy_ip)
						{
							$flag = true;
							foreach($proxyCheckDetails['actionData'] as $action => $action_result)
							{
								if($action_result === true)	$flag = false;
							}

							$flag = true;
							$resultDetails['result'] = $flag;
						}
					}
				}
			}
		}
		
		return $resultDetails;
	}
	
	public function checkUrl($url)
	{
		$resultDetails = array('result' =>false);
		
		if($this->isValid())
		{
			$osHttp = getOS()->getHttp();
			
			$setProxyResult = $osHttp->setProxy($this->proxy_ip,$this->proxy_port);
			
			if($setProxyResult)
			{
				$checkResponse = $osHttp->get($url);
				$resultDetails['request_time'] = $osHttp->getRequestTime();

				if(!empty($checkResponse))
				{
					if($osHttp->getResponseCode() == '200')
					{
						$resultDetails['result'] = true;						
					}
				}
			}
		}
		
		return $resultDetails;
	}
	
	public function addLabel($label_name)
	{
		$result = false;
		
		return $result;
	}
	
	public function removeLabel($label_name)
	{
		$result = false;
		
		return $result;
	}
}	
?>