<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_proxyoperations.php 2012-01-09$
 */

class OS_ProxyOperations
{
	private static $_instance;
	
	protected function __construct() {}

	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_ProxyOperations();
		}
		return self::$_instance;
	}
	
	//Get a list of all proxies
	public function &getProxies()
	{
		$db = getOS()->getDb();

		$result = array();

		$query = "SELECT * FROM ".$db->dbPrefix()."proxies ORDER BY `id` DESC";
		$dbresult = $db->query($query);
		while ($row = $db->fetchRow($dbresult))
		{
			$result[$row['id']] = new OS_Proxy($row);
		}

		return $result;
	}

	//Get a proxy by id
	public function &getProxyByID($id)
	{
		return $this->getProxyByDetail(array('id'=>$id));
	}
	
	//Get a proxy by proxy_ip.
	public function &getProxyByIp($proxy_ip)
	{
		return $this->getProxyByDetail(array('proxy_ip'=>$proxy_ip));
	}
	
	public function &getProxyByDetail($details)
	{
		$result = false;
		$query  = false;

		$db = getOS()->getDb();

		if(isset($details['id']))  $query = "SELECT * FROM ".$db->dbPrefix()."proxies WHERE id = ?";	
		elseif(isset($details['proxy_ip']))  $query = "SELECT * FROM ".$db->dbPrefix()."proxies WHERE proxy_ip = ?";
		
		if($query)
		{
			$dbresult = $db->query($query, array_values($details));
			
			if ($row = $db->fetchRow($dbresult))
			{
				$result = new OS_Proxy($row);
			}
				
		}
		return $result;
	}

	//Get a list with proxies statuses
	public function & getStatuses()
	{
		$statuses = array(
			'A' => _("Active"),
			'D' => _("Disabled"),
			'P' => _("Pending"),
			'S' => _("Suspended"),
			'R' => _("Removed")
		);
		
		return $statuses; 	
	}	
	
	//Saves a new proxy to the database.
	public function insertProxy($proxy)
	{
		$result = false; 
		
		$OS = getOS();

		$db = $OS->getDb();
		
		//check for ip conflict
		$query = "SELECT id FROM ".$db->dbPrefix()."proxies WHERE `proxy_ip` = ?";
		$results =  $db->query($query,array($proxy->proxy_ip));
		if( $db->fetchRow($results) !== false) return $result;
		
		//get current user's data (needed for status_by)
		$user_id = $OS->getUser()->id;
		if(is_null($user_id)) $user_id = -1;
		
		$time = $db->DBTimeStamp(time());
		
		$proxyDetails = array(
			'status' => (isset($proxy->status)? $proxy->status : "E"),
			'status_dt' => $time,
			'status_ip' => $_SERVER['REMOTE_ADDR'],
			'status_by' => $user_id,
			);
			
		$proxy->set($proxyDetails);	
		
		$query = "INSERT INTO ".$db->dbPrefix()."proxies (`insert_dt`, `insert_ip`, `insert_by`, `proxy_ip`, `proxy_port`, `status`, `status_dt`, `status_ip`, `status_by`) VALUES (?,?,?,?,?,?,?,?,?)";
		$dbresult = $db->query($query, array($time, $_SERVER['REMOTE_ADDR'], $user_id, $proxy->proxy_ip, $proxy->proxy_port, $proxy->status, $proxy->status_dt, $proxy->status_ip, $proxy->status_by));
		
		if ($dbresult !== false)
		{
			$result = $db->getInsertId();
		}
		return $result;
	}

	//Updates an existing proxy in the database.
	public function updateProxy($proxy)
	{
		$result = false;
		
		$OS =  getOS(); 

		$db = $OS->getDb();
		
		//check for proxy conflict
		$query = "SELECT id FROM ".$db->dbPrefix()."proxies WHERE `proxy_ip` = ? AND `id` != ?";
		$results =  $db->query($query,array($proxy->proxy_ip,$proxy->id));
		if( $db->fetchRow($results) !== false) return $result;
		
		//get proxy data from database
		$time = $db->DBTimeStamp(time());
		$oneProxy = $this->getProxyByID($proxy->id);
		
		if($oneProxy !== false)
		{
			$proxyDetails = array(
				'proxy_ip' => (isset($proxy->proxy_ip) ? $proxy->proxy_ip : $oneProxy->proxy_ip),
				'proxy_port' =>  (isset($proxy->proxy_port) ? $proxy->proxy_port : $oneProxy->proxy_port),
				'request_time' =>  (isset($proxy->request_time) ? $proxy->request_time : $oneProxy->request_time),
				);

			if($proxy->status != $oneProxy->status)
			{
				//get current user's data (needed for status_by)
				$user_id = $OS->getUser()->id;
				if(is_null($user_id)) $user_id = -1;
				
				$proxyDetails['status'] = $proxy->status;
				$proxyDetails['status_reason'] = (isset($proxy->status_reason) ? $proxy->status_reason : '');
				$proxyDetails['status_dt'] = $time;
				$proxyDetails['status_ip'] = $_SERVER['REMOTE_ADDR'];  
				$proxyDetails['status_by'] = $user_id;
			}	
			
			$oneProxy->set($proxyDetails);

			//execute the update query
			$query = "UPDATE ".$db->dbPrefix()."proxies SET `proxy_ip` = ?, `proxy_port` = ?, `request_time` = ?, `status` = ?,`status_dt` = ?,`status_ip` = ?,`status_by` = ?, `status_reason` = ?, `update_dt` = ?, `update_ip` = ?, `updates` = updates+1 WHERE `id` = ?";
			$dbresult = $db->query($query, array($oneProxy->proxy_ip, $oneProxy->proxy_port, $oneProxy->request_time, $oneProxy->status, $oneProxy->status_dt, $oneProxy->status_ip, $oneProxy->status_by, $oneProxy->status_reason, $time, $_SERVER['REMOTE_ADDR'], $oneProxy->id));
			if ($dbresult !== false)
			{
				$result = true;
			}
		}  

		return $result;
	}

	//Deletes an existing proxy from the database.
	public function deleteProxyByID($id)
	{
 		if( $id <= 1 ) return false;
 		
 		//check if current user can delete proxies
 		
 		
 		$result = false;

		$db = getOS()->getDb();
 		
		$query = "DELETE FROM ".$db->dbPrefix()."proxies WHERE `id` = ?";
		$dbresult = $db->query($query, array($id));

		if ($dbresult !== false)
		{
			$result = true;
		}

		return $result;
	}	
	

}	
?>	