<?php
class OS_Report
{
	private static $_instance;
	
	private $pdfTemplateFiles;
	
	public function __construct()
	{
		$this->pdfTemplateFiles=false;
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_Report();
		}
		
		return self::$_instance;
	}
	
	public function generateReport($reportData,$format='pdf',$segmented=false,$noExtraText=false,$returnBulk=false)
	{
		$result=false;
		
		if ($format=='pdf')
		{
			$OS=getOS();
		
			$result=$this->generateReportPDF($reportData,$noExtraText,$returnBulk);
		}
		elseif ($format=='html')
		{
			$result=$this->generateReportHTML($reportData,$segmented,$noExtraText,$returnBulk);
		}
		elseif ($format=='json')
		{
			$result=$this->generateReportJSON($reportData);
		}
		
		return $result;
	}
	
	public function generateReportHTML($reportData,$segmented=false,$noExtraText=false,$returnBulk=false,$cssClasses=false)
	{
		$result=false;
		
		$OS=getOS();
		
		$osUtils=$OS->getUtils();
		
		if (empty($reportData['main_sections']))
		{
			$file=$reportData['filename'];
			$reportData['main_sections']=array($reportData);
			$reportData['filename']=$file;
		}
		$first_main_section=true;
		foreach ($reportData['main_sections'] as $ms=>$main_section)
		{
			$result[$ms]['html']="<div id='mainSection_{$ms}' ".($cssClasses?"class='mainSectionTitle'":"style='text-align:center;font-size:20px;font-family:Arial;font-weight:bold;color:#fff;background-color:#c8c8c8;padding:5px;margin-bottom:30px;".(!$first_main_section?'margin-top:50px;':'')."'").">{$main_section['title']}</div>";
			$first_main_section=false;
					
			foreach ($main_section['sections'] as $section=>$sectionData)
			{
				$color=(empty($sectionData['title_color'])?'#000000':$sectionData['title_color']);
				
				$result[$ms]['sections'][$section]['html']="<div id='section_{$section}' class='section'><div id='sectionTitle_{$section}' ".($cssClasses?"class='sectionTitle' style='color:{$color}'":"style='font-size:16px;font-family:Arial;font-weight:bold;color:{$color};border-bottom:1px solid #c8c8c8;margin-bottom:5px;'").">".($sectionData['icon']?"<img src='data:image/png;base64,".base64_encode(file_get_contents($sectionData['icon']))."' ".($cssClasses?"class='sectionIcon'":"style='width:24px;margin:2px;' align='absmiddle'").">":'')."<span>{$sectionData['title']}</span></div>";
				
				if (!empty($sectionData['sectionChart']))
				{
					$sectionContentsWidth=100-$sectionData['sectionChartWidth']/2;
				}
				else
				{
					$sectionContentsWidth=100;
				}
				
				$result[$ms]['sections'][$section]['html'].="<div id='sectionContents_{$section}' ".($cssClasses?"class='sectionContents'":'')." style='width:100%;margin-bottom:20px;'><div ".($cssClasses?"class='sectionTextualContents' style='width:{$sectionContentsWidth}%;'":"style='width:{$sectionContentsWidth}%;display:inline-block;vertical-align:top;'").">";
				
				if ($sectionData['type']=='bulk_text')
				{
					$color=(empty($sectionData['text_color'])?'#000000':$sectionData['text_color']);
					
					$result[$ms]['sections'][$section]['html'].="<div ".($cssClasses?"class='sectionTextualContentsBulk'":"style='font-size:14px;font-family:Arial;color:{$color};padding-left:20px;'").">".nl2br($sectionData['text'])."</div>";
				}
				elseif ($sectionData['type']=='messages')
				{
					foreach ($sectionData['messages'] as $message)
					{
						if ($message['type']=='label_value')
						{
							$label_color=(empty($message['label']['color'])?'#000000':$message['label']['color']);
							$value_color=(empty($message['value']['color'])?'#000000':$message['value']['color']);
							
							$result[$ms]['sections'][$section]['html'].="<div ".($cssClasses?"class='sectionTextualContentsMessage'":"style='font-size:14px;font-family:Arial;padding-left:20px;'")."><span ".($cssClasses?"class='sectionTextualContentsMessageLabel'":'')." style='font-weight:bold;color:{$label_color}'>{$message['label']['text']}".(empty($message['separator'])?': ':$message['separator'])."</span><span ".($cssClasses?"class='sectionTextualContentsMessageValue'":'')." style='color:{$value_color}'>{$message['value']['text']}</span></div>";
						}
						elseif ($message['type']=='blank')
						{
							$result[$ms]['sections'][$section]['html'].="<br>";
						}
					}
				}
				elseif ($sectionData['type']=='image')
				{
					$result[$ms]['sections'][$section]['html'].="<img ".($cssClasses?"class='sectionTextualContentsImage'":'')." src='data:image/png;base64,".base64_encode(file_get_contents($sectionData['image_url']))."' width='100%'><br>";
				}
				
				$result[$ms]['sections'][$section]['html'].="</div>";
				
				if (!empty($sectionData['sectionChart']))
				{
					$result[$ms]['sections'][$section]['html'].="<div ".($cssClasses?"class='sectionChartContents' style='width:".($sectionData['sectionChartWidth']/2)."%;'":"style='width:".($sectionData['sectionChartWidth']/2)."%;display:inline-block;vertical-align:top;'")."><img src='data:image/png;base64,".base64_encode(file_get_contents($sectionData['sectionChart']))."' width='100%'></div>";
				}
				
				if (!empty($sectionData['extraText']) AND !$noExtraText)
				{
					$result[$ms]['sections'][$section]['html'].="<div ".($cssClasses?"class='sectionExtraInfo'":"style='font-size:12px;font-family:Arial;padding-left:40px;padding-right:40px;color:#000;margin-top:10px;'")."><em>".nl2br($sectionData['extraText'])."</em></div>";
				}
				
				$result[$ms]['sections'][$section]['html'].="</div></div>";
			}
		}
		
		if (!$segmented)
		{
			$html="<html><head><title>{$reportData['title']}</title><body style='background-color:white;'>";
			
			foreach ($result as $main_section=>$details)
			{
				$html.=$details['html'];
				
				foreach ($details['sections'] as $section=>$section_details)
				{
					$html.=$section_details['html'];
				}
			}
			
			$html.="</body></html>";

			$result=$html;
		}
		
		return $result;
	}
	
	public function generateReportJSON($reportData)
	{
		return json_encode($reportData);
	}
	
	public function generateReportPDF($reportData,$noExtraText,$returnBulk=false)
	{
		$OS=getOS();
		
		$this->pdf=new OS_PDF();
		
		if ($this->pdfTemplateFiles===false)
		{
			$osProject=$OS->getProject();
			
			if (!empty($osProject->id))
			{
				$appOps=$OS->getAppOps();
				if ($app=$appOps->getAppByName('reporting'))
				{
					if ($appOps->isProjectApp($osProject->id,$app->id))
					{
						$currentApp=$OS->getAppHandler()->name;
						$appHandler=$OS->getAppHandler('reporting');
						
						$reportingTemplateOps=OS_APP_Reporting_TemplateOperations::get_instance();
						
						if ($defaultTemplate=$reportingTemplateOps->getDefaultTemplate($osProject->id))
						{
							$this->pdfTemplateFiles=$reportingTemplateOps->getTemplateFilesFull($defaultTemplate,true);
						}
						
						$OS->getAppHandler($currentApp);
					}
				}
			}
		}
		
		$this->pdf->setTemplateFiles($this->pdfTemplateFiles);
		
		$osUtils=$OS->getUtils();
		
		if (empty($reportData['main_sections']))
		{
			$file=$reportData['filename'];
			$reportData['main_sections']=array($reportData);
			$reportData['filename']=$file;
		}
		
		$this->pdf->SetMargins(10,48);
		$this->pdf->SetAutoPageBreak(true,26);
		
		foreach ($reportData['main_sections'] as $main_section)
		{
			$this->pdf->SetFont('Arial','B','18');
			$this->pdf->AddPage();
			
			$this->pdf->SetTextColor(255,255,255);
			$this->pdf->SetFillColor(200,200,200);
			$this->pdf->Cell(190,10,$main_section['title'],0,1,'C',true);
			
			$this->pdf->SetY($this->pdf->GetY()+8);
					
			foreach ($main_section['sections'] as $section=>$sectionData)
			{
				if ($this->pdf->GetY()>255)
				{
					$this->pdf->AddPage();
				}
				
				$y=$this->pdf->GetY();
				if (!empty($sectionData['icon']))
				{
					$this->pdf->Image($sectionData['icon'],null,null,5,0,'png');
				}
				$this->pdf->SetY($y);
				
				$this->pdf->SetFont('Arial','B','14');
				$color=(empty($sectionData['title_color'])?'#000000':$sectionData['title_color']);
				if (!$color=$osUtils->colorHexToRgb($color))
				{
					$color=array('red'=>0,'green'=>0,'blue'=>0);
				}
				$this->pdf->SetTextColor($color['red'],$color['green'],$color['blue']);
				$this->pdf->SetDrawColor(200,200,200);
				$this->pdf->SetLineWidth(0.5);
				$this->pdf->Cell(0,6,($sectionData['icon']?'    ':'').$sectionData['title'],'B',1,'L');
				$this->pdf->SetY($this->pdf->GetY()+2);
				
				$sectionStartY=$this->pdf->GetY();
				
				if ($sectionData['type']=='bulk_text')
				{
					$this->pdf->SetFont('Arial','','12');
					$this->pdf->SetX(15);
					$color=(empty($sectionData['text_color'])?'#000000':$sectionData['text_color']);
					if (!$color=$osUtils->colorHexToRgb($color))
					{
						$color=array('red'=>0,'green'=>0,'blue'=>0);
					}
					$this->pdf->SetTextColor($color['red'],$color['green'],$color['blue']);
					$this->pdf->MultiCell(180,5,$sectionData['text'],0,'L');
				}
				elseif ($sectionData['type']=='messages')
				{
					foreach ($sectionData['messages'] as $message)
					{
						if ($message['type']=='label_value')
						{
							$this->pdf->SetX(15);
							
							//label
							$this->pdf->SetFont('Arial','B','12');
							$color=(empty($message['label']['color'])?'#000000':$message['label']['color']);
							if (!$color=$osUtils->colorHexToRgb($color))
							{
								$color=array('red'=>0,'green'=>0,'blue'=>0);
							}
							$this->pdf->SetTextColor($color['red'],$color['green'],$color['blue']);
							$this->pdf->Write(5,$message['label']['text']);
							
							//separator
							if (!empty($message['separator']))
							{
								$this->pdf->Write(5,$message['separator']);
							}
							else
							{
								$this->pdf->Write(5,': ');
							}
							
							//value
							$this->pdf->SetFont('Arial','','12');
							$color=(empty($message['value']['color'])?'#000000':$message['value']['color']);
							if (!$color=$osUtils->colorHexToRgb($color))
							{
								$color=array('red'=>0,'green'=>0,'blue'=>0);
							}
							$this->pdf->SetTextColor($color['red'],$color['green'],$color['blue']);
							$this->pdf->Write(5,$message['value']['text']);
							
							$this->pdf->Ln();
						}
						elseif ($message['type']=='blank')
						{
							$this->pdf->Ln();
						}
					}
				}
				elseif ($sectionData['type']=='image')
				{
					$this->pdf->Image($sectionData['image_url'],null,null,0,0,'png');
				}
				
				if (!empty($sectionData['sectionChart']))
				{
					$this->pdf->Image($sectionData['sectionChart'],200-$sectionData['sectionChartWidth'],$sectionStartY,$sectionData['sectionChartWidth'],0,'png');
				}
				
				if (!empty($sectionData['extraText']) AND !$noExtraText)
				{
					$this->pdf->Ln();
					$this->pdf->SetFont('Arial','I','10');
					$this->pdf->SetX(25);
					$this->pdf->SetTextColor(0,0,0);
					$this->pdf->MultiCell(160,4,$sectionData['extraText'],0,'L');
				}
				
				$this->pdf->SetY($this->pdf->GetY()+10);
			}
		}
		
		if ($returnBulk)
		{
			return $this->pdf->Output($reportData['filename'],'S');
		}
		else
		{
			$this->pdf->Output($reportData['filename'],'D');
		}
	}
	
	public function setTemplateFiles($templateFiles)
	{
		$this->pdfTemplateFiles=$templateFiles;
	}
}
?>