<?php
class OS_RobotsTxt
{
	private static $_instance;
	
	private $parsedFiles;
	
	public function __construct()
	{
		$this->parsedFiles=array();
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_RobotsTxt();
		}
		
		return self::$_instance;
	}
	
	public function extractHost($url)
	{
		return parse_url($url,PHP_URL_HOST);
	}
	
	public function canVisit($url,$useragent=false)
	{
		$result=true;
		
		if (!$host=$this->extractHost($url))
		{
			$result=false;
		}
		else
		{
			if (!isset($this->parsedFiles[$host]))
			{
				$this->parseFile($host);
			}
			
			if ($this->parsedFiles[$host]['rules'])
			{
				if (!$current_path=parse_url($url,PHP_URL_PATH))
				{
					$current_path='/';
				}
				
				$useragents=array('(.*)');
				if ($useragent)
				{
					$useragents[]=preg_quote($useragent);
				}
				$useragents=implode('|',$useragents);
				
				foreach ($this->parsedFiles[$host]['rules'] as $ua=>$paths)
				{
					if (preg_match("/{$useragents}/i",$ua))
					{
						foreach ($paths as $path=>$canVisit)
						{
							if (preg_match("/^".preg_quote($path,'/')."/",$current_path))
							{
								$result=$canVisit;
								
								break 2;
							}
						}
					}
				}
			}
		}
		
		return $result;
	}
	
	public function getSitemap($url)
	{
		$result=false;
		
		if (!$host=$this->extractHost($url))
		{
			$result=false;
		}
		else
		{
			if (!isset($this->parsedFiles[$host]))
			{
				$this->parseFile($host);
			}
			
			if ($this->parsedFiles[$host]['sitemap'])
			{
				$result=(count($this->parsedFiles[$host]['sitemap'])==1?$this->parsedFiles[$host]['sitemap'][0]:$this->parsedFiles[$host]['sitemap']);
			}
		}
		
		return $result;
	}
	
	public function parseFile($host)
	{
		$http=getOS()->getHttp();
		
		$robots_url="http://{$host}/robots.txt";
		
		$this->parsedFiles[$host]=array('rules'=>false,'sitemap'=>false);
		
		if ($robots=$http->get($robots_url) AND $http->success())
		{
			$robots=explode("\n",$robots);
			
			$current_ua=false;
			
			foreach ($robots as $line)
			{
				$line=trim($line);
				
				if (!empty($line))
				{
					if (0===stripos($line,'Sitemap:'))
					{
						$line=explode(':',$line);
						unset($line[0]);
						$line=trim(implode(':',$line));
						
						if (!empty($line))
						{
							if (empty($this->parsedFiles[$host]['sitemap']))
							{
								$this->parsedFiles[$host]['sitemap']=array();
							}
							
							$this->parsedFiles[$host]['sitemap'][]=$line;
						}
					}
					elseif (0===stripos($line,'User-agent:'))
					{
						$line=explode(':',$line);
						unset($line[0]);
						$line=trim(implode(':',$line));
						
						if (!empty($line))
						{
							$current_ua=$line;
						}
						else
						{
							$current_ua=false;
						}
					}
					elseif ($current_ua)
					{
						$line=explode(':',$line);
						$action=strtolower(trim($line[0]));
						unset($line[0]);
						$line=trim(implode(':',$line));
						
						if ($action=='allow')
						{
							$this->parsedFiles[$host]['rules'][$current_ua][$line]=true;
						}
						elseif ($action=='disallow')
						{
							if (!isset($this->parsedFiles[$host]['rules'][$current_ua][$line]))
							{
								$this->parsedFiles[$host]['rules'][$current_ua][$line]=false;
							}
						}
					}
				}
			}
			
			if ($this->parsedFiles[$host]['rules'])
			{
				foreach ($this->parsedFiles[$host]['rules'] as $ua=>$paths)
				{
					uksort($this->parsedFiles[$host]['rules'][$ua],array($this,'sortByLength'));
				}
			}
		}
	}
	
	public function sortByLength($a,$b)
	{
		return strlen($b)-strlen($a);
	}
}
?>