<?php
class OS_SearchEngine
{
	private static $_instance;
	
	public $skipQueue=false;
	
	private $engines;
	
	public function __construct()
	{
		$this->engines=array();
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_SearchEngine();
		}
		
		return self::$_instance;
	}
	
	public function loadEngine($engine,$checkAvailability=true)
	{
		$result=false;
		
		if (!isset($this->engines[$engine]))
		{
			//TODO: uncomment when using the availability thing
//			$seOps=getOS()->getSearchEngineOps();
//			
//			if ($seOps->isAvailableSearchEngine($engine))
//			{
				$engineClass="OS_PLUGIN_SearchEngine_{$engine}";
					
				$this->engines[$engine]=call_user_func(array($engineClass,'get_instance'));
//				$this->engines[$engine]=$engineClass::get_instance();
				
				$result=true;
//			}
		}
		elseif (is_object($this->engines[$engine]))
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function getEngineDetails($engine)
	{
		$result=false;
		
		$engine=strtolower($engine);
		
		if ($this->loadEngine($engine,false))
		{
			$result=array(
				'title'=>$this->engines[$engine]->title,
				'hasLocales'=>$this->engines[$engine]->hasLocales,
				'searchUrlPattern'=>(isset($this->engines[$engine]->searchUrlPattern)?$this->engines[$engine]->searchUrlPattern:false),
				'serpReferral'=>(isset($this->engines[$engine]->serpReferral)?$this->engines[$engine]->serpReferral:false),
				'domain'=>(isset($this->engines[$engine]->domain)?$this->engines[$engine]->domain:false),
			);
		}
		
		return $result;
	}
	
	public function hasLocales($engine)
	{
		$result=false;
		
		$engine=strtolower($engine);
		
		if ($this->loadEngine($engine,false))
		{
			$result=$this->engines[$engine]->hasLocales;
		}
		
		return $result;
	}
	
	public function getEngineLocaleDetails($engine,$locale)
	{
		$result=false;
		
		if ($this->hasLocales($engine))
		{
			$result=$this->engines[$engine]->getLocaleDetails($locale);
		}
		
		return $result;
	}
	
	public function getSearchUrl($query,$engine,$locale=false,$offset=false,$results_per_page=false)
	{
		$result=false;
		
		$engine=strtolower($engine);
		
		if ($this->loadEngine($engine))
		{
			if ($this->engines[$engine]->hasLocales)
			{
				$result=$this->engines[$engine]->getSearchUrl($query,$locale,$offset,$results_per_page);
			}
			else
			{
				$result=$this->engines[$engine]->getSearchUrl($query,$offset,$results_per_page);
			}
		}
		
		return $result;
	}
	
	public function getDomain($engine,$locale=false)
	{
		$result=false;
		
		$engine=strtolower($engine);
		
		if ($this->loadEngine($engine))
		{
			$result=$this->engines[$engine]->getDomain($locale);
		}
		
		return $result;
	}
	
	public function getResults($query,$engine,$locale=false)
	{
		$result=false;
		
		$engine=strtolower($engine);
		
		if ($this->loadEngine($engine))
		{
			if ($searchURL=$this->getSearchUrl($query,$engine,$locale))
			{
				if ($fromCache=$this->getFromCache($searchURL,$engine,$locale))
				{
					$result=array('status'=>'done','data'=>$this->engines[$engine]->getResults($fromCache,$locale));
				}
				else
				{
					$ops=OS_SearchEngineOperations::get_instance();
					
					$queue_id=$ops->queueRequest($searchURL,$query,$engine,$locale,'getResults');
					
					$result=array('status'=>'queued','queue_id'=>$queue_id);
				}
			}
		}
		
		$this->setOffset(0,$engine,$locale);
		$this->setResultsPerPage(10,$engine,$locale);
		
		return $result;
	}
	
	public function getResultsNumber($query,$engine,$locale=false)
	{
		$result=false;
		
		$engine=strtolower($engine);
		
		if ($this->loadEngine($engine))
		{
			if ($searchURL=$this->getSearchUrl($query,$engine,$locale))
			{
				if ($fromCache=$this->getFromCache($searchURL,$engine,$locale))
				{
					$result=array('status'=>'done','data'=>$this->engines[$engine]->getResultsNumber($fromCache,$locale));
				}
				else
				{
					$ops=OS_SearchEngineOperations::get_instance();
					
					$queue_id=$ops->queueRequest($searchURL,$query,$engine,$locale,'getResultsNumber');
					
					$result=array('status'=>'queued','queue_id'=>$queue_id);
				}
			}
		}
		
		$this->setOffset(0,$engine,$locale);
		$this->setResultsPerPage(10,$engine,$locale);
		
		return $result;
	}
	
	public function getSerp($query,$engine,$locale=false)
	{
		$result=false;
		
		$engine=strtolower($engine);
		
		if ($this->loadEngine($engine))
		{
			if ($searchURL=$this->getSearchUrl($query,$engine,$locale))
			{
				if ($fromCache=$this->getFromCache($searchURL,$engine,$locale))
				{
					$result=array('status'=>'done','data'=>$fromCache);
				}
				else
				{
					$ops=OS_SearchEngineOperations::get_instance();
					
					$queue_id=$ops->queueRequest($searchURL,$query,$engine,$locale,'getSerp');

					$result=array('status'=>'queued','queue_id'=>$queue_id);
				}
			}
		}
		
		$this->setOffset(0,$engine,$locale);
		$this->setResultsPerPage(10,$engine,$locale);
		
		return $result;
	}
	
	public function setResultsPerPage($results_per_page,$engine=false,$locale=false)
	{
		$result=false;
		
		if ($engine)
		{
			$engine=strtolower($engine);
			
			if ($this->loadEngine($engine))
			{
				$result=$this->engines[$engine]->setResultsPerPage($results_per_page,$locale);
			}
		}
		elseif (!empty($this->engines))
		{
			foreach ($this->engines as $engine_name=>$engine)
			{
				$result[$engine_name]=$engine->setResultsPerPage($results_per_page);
			}
		}
		
		return $result;
	}
	
	public function setOffset($offset,$engine=false,$locale=false)
	{
		$result=false;
		
		if ($engine)
		{
			$engine=strtolower($engine);
			
			if ($this->loadEngine($engine))
			{
				$result=$this->engines[$engine]->setOffset($offset,$locale);
			}
		}
		elseif (!empty($this->engines))
		{
			foreach ($this->engines as $engine_name=>$engine)
			{
				$result[$engine_name]=$engine->setOffset($offset);
			}
		}
		
		return $result;
	}
	
	public function setOption($option,$value,$engine=false,$locale=false)
	{
		$result=false;
		
		if ($engine)
		{
			$engine=strtolower($engine);
			
			if ($this->loadEngine($engine))
			{
				if (method_exists($this->engines[$engine],'setOption'))
				{
					$result=$this->engines[$engine]->setOption($option,$value,$locale);
				}
			}
		}
		elseif (!empty($this->engines))
		{
			foreach ($this->engines as $engine_name=>$engine)
			{
				if (method_exists($engine,'setOption'))
				{
					$result[$engine_name]=$engine->setOption($option,$value);
				}
			}
		}
		
		return $result;
	}
	
	public function getFromCache($url,$engine,$locale)
	{
		$result=false;
		
		$osCache=getOS()->getCache();
		
		$bucket=array('searchengines',$engine);
		if ($locale)
		{
			$bucket[]=$locale;
		}
		
		if ($osCache->setBucket($bucket))
		{
			if ($result=$osCache->get(md5($url)))
			{
				$result=reset($result);
			}
		}
		
		return $result;
	}
	
	public function storeInCache($url,$data,$engine,$locale)
	{
		$result=false;
		
		$osCache=getOS()->getCache();
		
		$bucket=array('searchengines',$engine);
		if ($locale)
		{
			$bucket[]=$locale;
		}
		
		if ($osCache->setBucket($bucket))
		{
			$result=$osCache->set(md5($url),array($data),86400);
		}
		
		return $result;
	}
}
?>