<?php
class OS_SearchEngineOperations
{
	private static $_instance;
	
	public function __construct()
	{
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_SearchEngineOperations();
		}
		
		return self::$_instance;
	}
	
	public function queueRequest($url,$query,$engine,$locale,$processingMethod)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."search_engines_queue WHERE url=?",array($url));
		if ($row=$db->fetchRow($dbresult))
		{
			$processingMethods=json_decode($row['processing_methods'],true);
			
			if (!in_array($processingMethod,$processingMethods))
			{
				$processingMethods[]=$processingMethod;
				
				$processingMethods=json_encode($processingMethods);
				
				$dbresult=$db->query("UPDATE ".$db->dbPrefix()."search_engines_queue SET processing_methods=? WHERE id=?",array($processingMethods,$row['id']));
			}
			
			$result=$row['id'];
		}
		else
		{
			$processingMethods=json_encode(array($processingMethod));
			
			$dbresult=$db->query("INSERT INTO ".$db->dbPrefix()."search_engines_queue (url,query,engine,locale,processing_methods) VALUES (?,?,?,?,?)",array($url,$query,$engine,$locale,$processingMethods));
			
			if ($dbresult!==false)
			{
				$result=$db->getInsertId();
			}
		}
		
		return $result;
	}
	
	public function getQueuedItem($engines=false)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		$condition='';
		$query_params=array();
		if (!empty($engines))
		{
			foreach ($engines as $engine)
			{
				$condition.=(empty($condition)?'':',').'?';
				$query_params[]=$engine;
			}
			
			$condition="WHERE `engine` IN ({$condition})";
		}
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."search_engines_queue {$condition} ORDER BY id ASC LIMIT 1",$query_params);
		if ($row=$db->fetchRow($dbresult))
		{
			$result=$row;
		}
		
		return $result;
	}
	
	public function markQueueItemAsFailed($queue_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		$time=$db->DBTimeStamp(time());
		
		$dbresult=$db->query("UPDATE ".$db->dbPrefix()."search_engines_queue SET fails=fails+1,fail_dt=? WHERE id=?",array($time,$queue_id));
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function deleteQueueItem($queue_id)
	{
		$result=false;
		
		$OS=getOS();
		$db=$OS->getDb();
		
		$dbresult=$db->query("DELETE FROM ".$db->dbPrefix()."search_engines_queue WHERE id=?",array($queue_id));
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function getAvailableSearchEngines()
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."search_engines WHERE status=?",array('A'));
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['engine']]=$row;
		}
		
		return $result;
	}
	
	public function getAvailableSearchEnginesFull()
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."search_engines WHERE status=?",array('A'));
		while ($row=$db->fetchRow($dbresult))
		{
			if ($row['has_locales'])
			{
				$row['_locales']=$this->getAvailableSearchEngineLocales($row['engine']);
			}
			
			$result[$row['engine']]=$row;
		}
		
		return $result;
	}
	
	public function isAvailableSearchEngine($engine)
	{
		$result=false;
		
		$engines=$this->getAvailableSearchEngines();
		
		if (isset($engines[$engine]))
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function getAvailableSearchEngineLocales($engine)
	{
		$result=false;
		
		$db=getOS()->getDb();
		
		$dbresult=$db->query("SELECT * FROM ".$db->dbPrefix()."search_engines_locales WHERE engine=? AND status=?",array($engine,'A'));
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['locale']]=$row;
		}
		
		return $result;
	}
	
	public function isAvailableSearchEngineLocale($engine,$locale)
	{
		$result=false;
		
		$locales=$this->getAvailableSearchEngineLocales($engine);
		
		if (isset($locales[$locale]))
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function installSearchEngine($engine)
	{
		$result=false;
		
		if ($this->isUnsintalledSearchEngine($engine))
		{
			$osSearchEngine=getOS()->getSearchEngine();
			
			if ($engineDetails=$osSearchEngine->getEngineDetails($engine))
			{
				$db=getOS()->getDb();
				
				$ip=getOS()->getRemoteAddr();
				$time=$db->DBTimeStamp(time());
				
				if ($engineDetails['hasLocales'])
				{
					$query="INSERT INTO ".$db->dbPrefix()."search_engines (engine,title,has_locales,insert_dt,insert_ip,status,status_dt,status_ip) VALUES (?,?,?,?,?,?,?,?)";
					$query_params=array($engine,$engineDetails['title'],'Y',$time,$ip,'A',$time,$ip);
				}
				else
				{
					$query="INSERT INTO ".$db->dbPrefix()."search_engines (engine,title,has_locales,search_url_pattern,serp_referral,insert_dt,insert_ip,status,status_dt,status_ip) VALUES (?,?,?,?,?,?,?,?,?,?)";
					$query_params=array($engine,$engineDetails['title'],'',$engineDetails['searchUrlPattern'],json_encode($engineDetails['serpReferral']),$time,$ip,'A',$time,$ip);
				}
				
				$dbresult=$db->query($query,$query_params);
				
				if ($dbresult!==false)
				{
					$engine_id=$db->getInsertId();
					
					if ($engineDetails['hasLocales'])
					{
						$locales=$this->getUninstalledSearchEngineLocales($engine);
						
						foreach ($locales as $locale)
						{
							if ($localeDetails=$osSearchEngine->getEngineLocaleDetails($engine,$locale))
							{
								$query="INSERT INTO ".$db->dbPrefix()."search_engines_locales (engine_id,engine,locale,title,search_url_pattern,serp_referral,insert_dt,insert_ip,status,status_dt,status_ip) VALUES (?,?,?,?,?,?,?,?,?,?,?)";
								$query_params=array($engine_id,$engine,$locale,$localeDetails['title'],$localeDetails['searchUrlPattern'],json_encode($localeDetails['serpReferral']),$time,$ip,'A',$time,$ip);
								
								$dbresult=$db->query($query,$query_params);
							}
						}
					}
					
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public function uninstallSearchEngine($engine)
	{
		$result=false;
		
		if ($this->isAvailableSearchEngine($engine))
		{
			$db=getOS()->getDb();
			
			$dbresult=$db->query("DELETE FROM ".$db->dbPrefix()."search_engines WHERE engine=?",array($engine));
			
			if ($dbresult!==false)
			{
				$dbresult=$db->query("DELETE FROM ".$db->dbPrefix()."search_engines_locales WHERE engine=?",array($engine));
				
				if ($dbresult!==false)
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public function enableSearchEngine($engine)
	{
		$result=false;
		
		if ($this->isAvailableSearchEngine($engine))
		{
			//TODO: status='A'
		}
		
		return $result;
	}
	
	public function disableSearchEngine($engine)
	{
		$result=false;
		
		if ($this->isAvailableSearchEngine($engine))
		{
			//TODO: status='D'
		}
		
		return $result;
	}
	
	public function getUninstalledSearchEngines()
	{
		$result=false;
		
		$plugins_path=os_join_path(getOS()->getConfigVar('root_path'),'lib','classes','plugins','searchengine','');
		
		$installed_plugins=$this->getAvailableSearchEngines();
		
		$all_plugins=glob(os_join_path($plugins_path.'*'),GLOB_ONLYDIR);
		
		foreach ($all_plugins as $plugin)
		{
			$plugin=str_replace($plugins_path,'',$plugin);
			
			if (!isset($installed_plugins[$plugin]))
			{
				$result[]=$plugin;
			}
		}
		
		return $result;
	}
	
	public function getUninstalledSearchEngineLocales($engine)
	{
		$result=false;
		
		$plugins_path=os_join_path(getOS()->getConfigVar('root_path'),'lib','classes','plugins','searchengine',$engine,'lib');
		
		$replace=array(os_join_path($plugins_path,'class.os_plugin_searchengine_'.$engine.'_'),'.php');
		
		$all_locales=glob(os_join_path($plugins_path,'*'));
		
		foreach ($all_locales as $locale)
		{
			$locale=str_replace($replace,'',$locale);
			
			if ($locale!='base')
			{
				$result[]=$locale;
			}
		}
		
		return $result;
	}
	
	public function installAllSearchEngines()
	{
		$result=false;
		
		if ($uninstalledSearchEngines=$this->getUninstalledSearchEngines())
		{
			foreach ($uninstalledSearchEngines as $engine)
			{
				$result[$engine]=$this->installSearchEngine($engine);
			}
		}
		
		return $result;
	}
	
	public function isUnsintalledSearchEngine($engine)
	{
		$result=false;
		
		$uninstalled=$this->getUninstalledSearchEngines();
		
		if (in_array($engine,$uninstalled))
		{
			$result=true;
		}
		
		return $result;
	}
}
?>