<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_Section
{
	//section ID
	var $id;
	
	//section`s project ID
	var $project_id;
	
	//section`s user ID
	var $user_id;
	
	//section name
	var $name;
	
	//section position in stack
	var $position;
	
	//section icon
	var $icon;
	
	//section layout
	var $layout;
	
	//section class instance
	private static $_instance;
	
	//constructor
	function __construct()
	{
		$this->setInitialValues();
	}
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_Section(true);
		}
		return self::$_instance;
	}
	
	//sets object to some sane initial values
	public function setInitialValues()
	{
		$initialValues = array(
			'id' => -1,
			'project_id' => -1,
			'user_id' => -1,
			'name' => '',
			'position' => 0,
			'icon' => '',
			'layout' => ''
			);
			
		$this->set($initialValues);	
	}
	
	
	public function save()
	{
		$result = false;
		
		$osSectionOps = getOS()->getSectionOps();
		
		if ($this->id > -1)
		{
			$result = $osSectionOps->updateSection($this);
		}
		else
		{
			$newid = $osSectionOps->insertSection($this);
			if ($newid > -1)
			{
				$this->id = $newid;
				$result = true;
			}

		}

		return $result;
	}
	
	public function delete()
	{
		$result = false;
		
		if ($this->id > -1)
		{
			$OS = getOS();
			
			//remove other dependencies linked with current section
			
			//remove all widgets connected to current section
			$osWidgetHandlerOps = $OS->getWidgetHandlerOps();
			$osSectionWidgets = $osWidgetHandlerOps->getWidgetsBySectionID($this->id);
			
			if(!empty($osSectionWidgets))
			{
				foreach($osSectionWidgets as $oneWidgetHandler)
				{
					$oneWidgetHandler->delete();
				}
			}
			
			
			//Remove user record from the database
			$osSectionOps = $OS->getSectionOps();
			
			$result = $osSectionOps->deleteSectionByID($this->id);
			if ($result)
			{
				$this->setInitialValues();
			}
		}

		return $result;
	}

	public function set($data)
	{
		$result = false;
		
		$objVars = get_object_vars($this);
		
		if(is_object($data))
		{
			$data = get_object_vars($data);
		}
		
		foreach($objVars as $key=>$val)
		{
			if(isset($data[$key]))
			{
				$this->$key = $data[$key];
				$result = true;
			}
		}
		
		return $result;
	}

	//verify if osSection contains valid section details
	public function isValid()
	{
		$result = false;
		if(isset($this->id))
		{
			if($this->id > 0)
			{
				$result  = true;		
			}
		}
		
		return $result;
	}
	
	
	public function load()
	{
		$result = false;
		
		if($this->isValid())
		{
			$osSectionOps = getOS()->getSectionOps();
			
			$oneSection = $osSectionOps->getUserByID($this->id);
			
			if($oneSection !== false)
			{
				$this->set($oneSection);
				
				$result = false;	
			}
		}
		
		return $result;
	}
	}
