<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_SectionOperations
{
	
	private static $_instance;
	
	public function __construct() {}

	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_SectionOperations();
		}
		return self::$_instance;
	}
	
	//Get a section by id.
	public function &getSectionByID($id)
	{
		if( $id < 1 ) return false;
		else return $this->getSectionByDetail(array('id'=>$id));
	}

	//Get a section by name
	public function &getSectionByName($name)
	{
		return $this->getSectionByDetail(array('name'=>$name));
	}

	public function &getSectionByDetail($details)
	{
		$result = false;
		$query  = false;

		$db = getOS()->getDb();

		if(isset($details['id']))  $query = "SELECT * FROM ".$db->dbPrefix()."sections WHERE `id` = ?";	
		elseif(isset($details['name'])) $query = "SELECT * FROM ".$db->dbPrefix()."sections WHERE `name` = ?";
		
		if($query)
		{
			$dbresult = $db->query($query, array_values($details));
			
			if ($row = $db->fetchRow($dbresult))
			{
				$oneSection = new OS_Section();
				$oneSection->set($row);
							
				$result = $oneSection;
			}
				
		}
		return $result;
	}
	
	
	//get a list of all sections linked to a project 
	public function &getSectionsByProjectID($project_id)
	{
		if( $project_id < 1 ) return false;
		
		$db = getOS()->getDb();

		$result = array();

		$query = "SELECT * FROM ".$db->dbPrefix()."sections WHERE `project_id` = ?  ORDER BY `position` ASC";
		$dbresult = $db->query($query,array($project_id));
		while ($row = $db->fetchRow($dbresult))
		{
			$oneSection = new OS_Section();
			$oneSection->set($row);
			
			$result[$row['id']] = $oneSection;
		}

		return $result;
	}

	//get a list of all sections linked to a user 
	public function &getSectionsByUserID($user_id)
	{
		
		if( $user_id < 1 ) return false;
		
		$db = getOS()->getDb();

		$result = array();

		$query = "SELECT * FROM ".$db->dbPrefix()."sections WHERE `user_id` = ?  ORDER BY `position` ASC";
		$dbresult = $db->query($query,array($user_id));
		while ($row = $db->fetchRow($dbresult))
		{
			$oneSection = new OS_Section();
			$oneSection->set($row);
			
			$result[$row['id']] = $oneSection;
		}

		return $result;
	}

	//Saves a new section to the database.
	public function insertSection($section)
	{
		$result = -1; 
		
		$OS = getOS();

		$db = $OS->getDb();

		//get current user's data (needed for status_by)
		$user_id = $OS->getUser()->id;
		if(is_null($user_id)) $user_id = -1;
				
		$time = $db->DBTimeStamp(time());
		$query = "INSERT INTO ".$db->dbPrefix()."sections (`user_id`,`project_id`,`name`,`position`,`icon`,`layout`,`insert_dt`,`insert_ip`,`insert_by`) VALUES (?,?,?,?,?,?,?,?,?)";
		$dbresult = $db->query($query, array($section->user_id, $section->project_id, $section->name, $section->position, $section->icon, $section->layout, $time, $_SERVER['REMOTE_ADDR'], $user_id ));
		
		if ($dbresult !== false)
		{
			$result = $db->getInsertId();
		}
		return $result;
	}
	
	//Updates an existing section in the database.
	public function updateSection($section)
	{
		$result = false;
		
		$OS =  getOS(); 

		$db = $OS->getDb();
		
		//execute the update query
		$time = $db->DBTimeStamp(time());
		
		$query = "UPDATE ".$db->dbPrefix()."sections SET `name` = ?,`position` = ?, `layout` = ?, `update_dt` = ?, `update_ip` = ?, `updates` = updates+1 WHERE `user_id` = ? AND `project_id` = ? AND `id` = ?";
		$dbresult = $db->query($query, array($section->name, $section->position,$section->layout, $time, $_SERVER['REMOTE_ADDR'], $section->user_id, $section->project_id, $section->id));
		if ($dbresult !== false)
		{
			$result = true;
		}

		return $result;
	}
	
	//Deletes an existing section from the database.
	public function deleteSectionByID($id)
	{
		if( $id < 1 ) return false;

 		$result = false;

		$db = getOS()->getDb();
 		
		$query = "DELETE FROM ".$db->dbPrefix()."sections WHERE `id` = ?";
		$dbresult = $db->query($query, array($id));

		if ($dbresult !== false)
		{
			$result = true;
		}

		return $result;
	}
	
	public function deleteSectionsByProjectID($project_id)
	{
		$result=true;
		
		if ($sections=$this->getSectionsByProjectID($project_id))
		{
			foreach ($sections as $section)
			{
				if (!$section->delete())
				{
					$result=false;
					break;
				}
			}
		}
		
		return $result;
	}
	
	public function getEmptiestColumn($section_id,$user_id=false,$project_id=false)
	{
		$result=false;
		
		if ($section=$this->getSectionByID($section_id))
		{
			if ($section->layout==1)
			{
				$result=1;
			}
			elseif ($section->layout==2 OR $section->layout==3)
			{
				$columns=($section->layout==2?array(1=>0,2=>0,3=>0):array(1=>0,2=>0));
				
				$OS=getOS();
				
				if (!$user_id)
				{
					$user_id=$OS->getUser()->id;
				}
				
				if (!$project_id)
				{
					$project_id=$OS->getProject()->id;
				}
				
				$db=$OS->getDb();
				
				$dbresult=$db->query("SELECT column_id FROM ".$db->dbPrefix()."widgets_users WHERE user_id=? AND project_id=? AND section_id=?",array($user_id,$project_id,$section->id));
				while ($row=$db->fetchRow($dbresult))
				{
					if (isset($columns[$row['column_id']]))
					{
						$columns[$row['column_id']]++;
					}
				}
				
				//TODO: take widget height into acct
				
				$result=array_search(min($columns),$columns);
			}
		}
		
		return $result;		
	}
	
	public function getNextPosition($section_id,$column_id)
	{
		$result=false;
		
		if ($section=$this->getSectionByID($section_id))
		{
			$db=getOS()->getDb();
			
			$dbresult=$db->query("SELECT MAX(position) AS max_position FROM ".$db->dbPrefix()."widgets_users WHERE section_id=? AND column_id=?",array($section_id,$column_id));
			if ($row=$db->fetchRow($dbresult))
			{
				$result=$row['max_position']+1;
			}
			else
			{
				$result=1;
			}
		}
		
		return $result;
	}
}	