<?php
class OS_Sorter
{
	private static $_instance;
	
	private $sortBy;
	private $sortType;
	private $sortOrder;
	
	private $allowedTypes=array('NUMERIC','STRING','DATE');
	private $allowedOrders=array('ASC','DESC');
	
	public function __construct($by=false,$type=false,$order=false)
	{
		$this->setInitialValues();
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_Sorter();
		}
		
		return self::$_instance;
	}
	
	public function setInitialValues()
	{
		$this->setSortType('NUMERIC');
		$this->setSortOrder('ASC');
	}
	
	public function setSortBy($by)
	{
		if ($this->sortBy)
		{
			$old=$this->sortBy;
		}
		else
		{
			$old=true;
		}
		
		$this->sortBy=$by;
		
		return $old;
	}
	
	public function setSortType($type)
	{
		$type=strtoupper($type);
		
		if (!in_array($type,$this->allowedTypes))
		{
			return false;
		}
		
		if ($this->sortType)
		{
			$old=$this->sortType;
		}
		else
		{
			$old=true;
		}
		
		$this->sortType=$type;
		
		return $old;
	}
	
	public function setSortOrder($order)
	{
		$order=strtoupper($order);
		
		if (!in_array($order,$this->allowedOrders))
		{
			return false;
		}
		
		if ($this->sortOrder)
		{
			$old=$this->sortOrder;
		}
		else
		{
			$old=true;
		}
		
		$this->sortOrder=$order;
		
		return $old;
	}
	
	public function sort(&$array,$keepOriginal=false)
	{
		if (!$this->sortBy OR !is_array($array))
		{
			return false;
		}
		
		if ($keepOriginal)
		{
			$this->tempArray=$array;
			
			if (uasort($this->tempArray,array($this,'_actualSort')))
			{
				return $this->tempArray;
			}
			else
			{
				return false;
			}
		}
		else
		{
			return uasort($array,array($this,'_actualSort'));
		}
	}
	
	private function _actualSort($a, $b)
	{
		if (!$this->sortBy)
		{
			return 0;
		}
		
		if (!isset($a[$this->sortBy]) OR !isset($b[$this->sortBy]))
		{
			return 0;
		}

		if ($this->sortType=='NUMERIC')
		{
			if ($a[$this->sortBy]==$b[$this->sortBy])
			{
				return 0;
			}
			
			$cmp_result=($a[$this->sortBy]<$b[$this->sortBy]);
		}
		elseif ($this->sortType=='STRING')
		{
			if ($a[$this->sortBy]==$b[$this->sortBy])
			{
				return 0;
			}

			$cmp=strcasecmp($a[$this->sortBy],$b[$this->sortBy]);
			$cmp_result=($cmp<0);
		}
		elseif ($this->sortType=='DATE')
		{
			if (strtotime($a[$this->sortBy])==strtotime($b[$this->sortBy]))
			{
				return 0;
			}
			
			$cmp_result=(strtotime($a[$this->sortBy])<strtotime($b[$this->sortBy]));
		}
		
		return ($cmp_result?($this->sortOrder=='ASC'?-1:1):($this->sortOrder=='ASC'?1:-1));
	}
}
?>