<?php

/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

require_once(dirname(dirname(__FILE__)).'/smarty/Smarty.class.php');

class OS_Template
{	
	//Page Title 
	protected $title;

	//Current page url
	protected $url;
	
	protected $query;
	
	public $template_name;
	
	private $template_path;
	
	//opens root url
	protected $root_url;
	
    //All menu items
    protected $menuItems;
    
    //menu options part (left)
    protected $optionsMenuItems;
    
    //menu setting part (right)
    protected $settingsMenuItems;
    
    //Theme Name
    protected $themeName;

    //selectec menu item
    public $selectedMenuItem;
    
	private static $_instance;
	
	//contains data for top section of the page (page title,page options)
	public $topSection;
	
	//container for top menu html
	private $topMenuContents;
	
	public $headContents;
	
	private $headContentsData;
	
	public $bodyBeginContents;
	
	public $bodyTemplateName;
	
	public $bodyContents;
	
	public $bodyEndContents;
	
	public $footerContents;
	
	//smarty object template vars
	private $tVars;
	
	private $Smarty;

	public function __construct()
	{
		//parent::__construct();
		
		$this->Smarty = new Smarty();
		
		$OS = getOS();
		$os_root_path = $OS->getConfigVar('root_path');

		//put initial values
		$this->setInitialValues();
		
		//Smarty Init
		$this->setTemplateDir(os_join_path($os_root_path,"themes", $OS->getConfigVar('theme_name')));
		$this->setConfigDir(os_join_path($OS->getConfigVar('cache_path'), "configs"));
		$this->setCompileDir($OS->getConfigVar('templates_compile_path'));
		$this->setCacheDir(os_join_path($OS->getConfigVar('cache_path')));
		$this->setPluginsDir(array(os_join_path($os_root_path,"lib", "smarty", "plugins")));
		
    	$this->Smarty->error_reporting = E_ALL;
    	
    	if ($OS->getConfigVar("debug") == true)
    	{	
			$this->Smarty->force_compile = true;
			$this->Smarty->debugging = true;
    	}
	}

	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
    	{
			self::$_instance = new OS_Template();
    	}
    	return self::$_instance;
	}


	private function initMenu()
	{
		$osMenu = OS_Menu::get_instance();
		
		if(empty($this->selectedMenuItem))
			{
				if(!empty($this->bodyTemplateName))
				{
					$this->selectedMenuItem = $this->bodyTemplateName;
				}
			}
		
		//use a osMenu method here
		$osMenu->setSelectedItem($this->selectedMenuItem);
		
		$this->menuItems = $osMenu->getMenuItems();
		
		$this->settingsMenuItems = $osMenu->getSettingsMenu();
		
		$this->optionsMenuItems = $osMenu->getOptionsMenu();
	}
	
	//Sets object to some sane initial values
	private function setInitialValues()
	{
		$OS = getOS();
 		
 		//assign root_url
    	$this->root_url = $OS->getConfigVar('root_url');
    	
 		//assign template_url
    	$this->template_url = $OS->getConfigVar('template_url');

		$this->url = $_SERVER['SCRIPT_NAME'];
		
		$this->query = (isset($_SERVER['QUERY_STRING']) ? $_SERVER['QUERY_STRING'] : '');
		
		$this->template_name = "";
		
		$this->menuItems = array();
		$this->settingsMenuItems = array();
		$this->optionsMenuItems = array();
		$this->headContentsData = array();
		$this->headContents = "";
		
        if (strpos( $this->url, '/' ) === false)
            {
            $this->script = $this->url;
            }
        else{
			$toam_tmp = explode('/',$this->url);
			$toam_tmp2 = array_pop($toam_tmp);
			$this->script = $toam_tmp2;
            //$this->script = array_pop(@explode('/',$this->url));
    	    }

	}
	
	public function setTemplateDir($dirname)
	{
		$this->Smarty->template_dir = $dirname;
	}
	
	public function setConfigDir($dirname)
	{
		$this->Smarty->config_dir = $dirname;
	}
	
	public function setCompileDir($dirname)
	{
		//check if compile dir exists
		$check_compile_dir = true;
		if(isset($_SESSION['ui']['file_exists']['templates_c']))
		{
			$check_compile_dir = ($_SESSION['ui']['file_exists']['templates_c'] ? false : true);	
		}

		if($check_compile_dir)
		{
			if(@is_writable($dirname)) {$dir_is_writable = true;}
			else
			{
				$osUtils = getOS()->getUtils(); $mode = 0777;
				if(file_exists($dirname))
				{
					$dir_is_writable = $osUtils->chmodDir($dirname, $mode);
				}
				else
				{
					$dir_is_writable = $osUtils->createDir($dirname, $mode);
				}
			}
				
			if($dir_is_writable) $_SESSION['ui']['file_exists']['templates_c'] = true; 
			else {die("Apache does not have permissions to write (777) in ". $dirname);}
		}
		
		$this->Smarty->compile_dir = $dirname;	
	}
	
	public function setCacheDir($dirname)
	{
		$this->Smarty->cache_dir = $dirname;
	}
	
	public function setPluginsDir($dirname)
	{
		$this->Smarty->plugins_dir = $dirname;
	}


	//Add smarty variable
	public function setVar($var,$val)
	{
		if(!isset($this->tVars)) $this->tVars = array();
		$this->tVars[$var] = $val;	
	}

	//Remove smarty variable	
	public function unsetVar($var)
	{
		if(isset($this->tVars[$var])) unset($this->tVars[$var]);	
	}
	
	private function buildTemplateVars($requiredData = false)
	{
		$restrictedVars = array('tVars','force_compile','debugging');
		
		$templateProperties = get_object_vars($this);
		
		if(!empty($templateProperties))
		{
			$OS = getOS();
			
			$osUser = $OS->getUser();
			
			//put is_logged variable
			$this->setVar('is_logged',$osUser->isUserLogged());
			
			$hasRequired = false;
			
			if($requiredData !== false)
			{
				if(!is_array($requiredData)) {$requiredData = array($requiredData); $hasRequired = true;}	
			}
			
			if(!$hasRequired) $requiredData = array_keys($templateProperties);
			
			foreach($templateProperties as $var => $val)
			{
				if(!in_array($var, $restrictedVars) && in_array($var, $requiredData))
				{
					$this->setVar($var,$val);	
				}
			}
		}
		
		$this->Smarty->assign('tvars',$this->tVars);
	}

	public function mainTemplateRender($mainTemplate = false, $cache_tpl = false)
	{
		if($mainTemplate == false)  $mainTemplate  = 'main';
		
		$this->template_name = $mainTemplate;
		
		$valid_cache = false;
		if($cache_tpl)
		{
			if($this->cacheValid())
			{
				$valid_cache = true;	
			}
		}
		
		if($valid_cache)
		{
			$html_output = $this->cacheRead();
		}
		else	
		{
			$OS = getOS();
			
			//Build menu 
			$this->initMenu();
			
			//refresh vars
			$this->buildTemplateVars();
			
			//get Top Menu Template
			$this->topMenuContents = $this->getTopMenuTemplate();
			
			if(isset($this->bodyTemplateName))
			{
				$bodyContents = $this->getTemplateBody($this->bodyTemplateName);
				$this->setBodyContents($bodyContents);
			}
			
			//fetch errors/info messages
			if(!empty($this->tVars['errors']))
			{
				$content = "
					<script type='text/javascript'>
						$(function() {
							
							if(osKernel)
							{
								var	errData = eval(".json_encode($this->tVars['errors']).");
								
								osKernel.setErrorsData(errData);
								osKernel.loadErrorMessages();
							} 
						});					
					</script>";
				
				$this->setHeadContents($content);
			}
			
			if(!empty($this->tVars['info']))
			{
				$content = "
				<script type='text/javascript'>
					$(function() {	
						if(osKernel)
						{
							var infoData = eval(".json_encode($this->tVars['info']).");
						
							osKernel.setInfoMessagesData(infoData);
							osKernel.loadInfoMessages();
						}	
					
					});					
				</script>";
				
				$this->setHeadContents($content);	
			}
			
			//Build HeadContents
			$this->minifyHeadContents();
			
			$this->headContents = implode("\n", $this->headContentsData);
			
			$this->buildTemplateVars(array('topMenuContents','bodyContents','headContents'));
			
			$this->Smarty->assign('rootURL',$OS->getConfigVar('root_url'));
			
			$html_output = $this->Smarty->fetch("{$this->template_name}.tpl");
			
			if($cache_tpl)
			{
				$this->cacheWrite($html_output);	
			}
		}
	
		return $html_output;	
	}

	//Given a page template, return the body portion of a page template.
	public function getTemplateBody($bodyTemplate)
	{
		$this->buildTemplateVars('topSection');
		
		$template_path = $this->getTemplatePath($bodyTemplate);
		
		return $this->Smarty->fetch($template_path);	
	}
	
	public function setBodyContents($contents)
	{
		$this->bodyContents = $contents;  
	}
	
	//Given a page template name, return it's entire contents.
	public function getTemplate($template_name)
	{
		$result = false;
		
		$this->Smarty->assign('tvars',$this->tVars);
		
		$tpl_path = os_join_path($this->Smarty->template_dir, "{$template_name}.tpl");
		
		if(file_exists($tpl_path))
		{
			$this->template_name = $template_name;
			$result = $this->Smarty->fetch($tpl_path);	
		}
		
		return $result;	
	}
	
	//Given a page template name, return it's entire contents.
	public function fetchTemplate($template_name, $template_vars = array(), $cache_tpl = false)
	{
		$html_output = false;
		
		$this->template_name = $template_name;
		$tpl_path = os_join_path($this->Smarty->template_dir, "{$this->template_name}.tpl");
		
		if(file_exists($tpl_path))
		{
			$valid_cache = false;
			if($cache_tpl)
			{
				if($this->cacheValid())
				{
					$valid_cache = true;	
				}
			}
			
			if($valid_cache)
			{
				$html_output = $this->cacheRead();
			}
			else
			{
				$this->Smarty->assign('tvars', $template_vars);
				
				$html_output = $this->Smarty->fetch($tpl_path);
				if($cache_tpl)
				{
					$this->cacheWrite($html_output);
				}
			}
		}
		
		return $html_output;	
	}	
	
	public function getAppTemplate($app_name, $template_name)
	{
		$result = false;
		
		$this->Smarty->assign('tvars',$this->tVars);
		
		$tpl_path = getOS()->getConfigVar('root_path')."/apps/{$app_name}/templates/{$template_name}.tpl";
		if(file_exists($tpl_path))
		{
			$result = $this->Smarty->fetch($tpl_path);	
		}
		
		return $result;	
	}
	
	public function getWidgetTemplate($widget_name, $template_name)
	{
		$result = false;
		
		$this->Smarty->assign('tvars',$this->tVars);
		
		$tpl_path = getOS()->getConfigVar('root_path')."/widgets/{$widget_name}/templates/{$template_name}.tpl";
		if(file_exists($tpl_path))
		{
			$result = $this->Smarty->fetch($tpl_path);	
		}
		
		return $result;	
	}
	
	public function getInstallTemplate($template_name)
	{
		$result = false;
		
		$this->Smarty->assign('tvars',$this->tVars);
		
		$tpl_path = getOS()->getConfigVar('root_path')."/install/templates/{$template_name}.tpl";
		if(file_exists($tpl_path))
		{
			$result = $this->Smarty->fetch($tpl_path);	
		}
		
		return $result;	
	}

	//Output Top Menu data
	public function getTopMenuTemplate()
	{
		//Build Page menu
		if(empty($this->menuItems))
		{
			$this->initMenu();
		}
		
		$template_path = $this->getTemplatePath('top_menu');
		
		return $this->Smarty->fetch($template_path);
	}

	//get valid template path
	private function getTemplatePath($template_filename)
	{
		$template_file = "{$template_filename}.tpl";
		
		$template_path = $this->Smarty->template_dir.'/'.$template_file;
		
		if(!file_exists($template_path))
		{
			$template_path = getOS()->getConfigVar('root_path').'/themes/default/'.$template_file;
		}
		
		return $template_path;
	}
	
	
	//add an item to the top section options bar
	public function addTopSectionOption($item,$itemData)
	{
		$result = false; $add_item = false; 
		
		if(!isset($itemData['type'], $itemData['name']))
		{
			$result = false;
		}	
		elseif(!in_array($itemData['type'], array('link','submit')))
		{
			$result = false;
		}	
		else
		{
			if(!isset($itemData['title']))
			{
				$itemData['title'] = $itemData['name'];
			}
			
			if($itemData['type'] == 'submit')
			{
				$add_item = true;
			}
			elseif($itemData['type'] == 'link')
			{
				if(!isset($itemData['url']))
				{
					$result = false;	
				}
				else
				{
					$add_item = true;	
				}
			}
			
			if($add_item)
			{
				$this->topSection['options'][$item] = $itemData;
			}	
		}
	
		return $result;	
	}

	//set the top section title
	public function setTopSectionTitle($title)
	{
		$this->topSection['ptitle'] = $title;	
	}
	
	public function setHeadContents($content)
	{
		if(!empty($content))
		{
			if(is_array($content))
			{
				if(isset($content['js']))
				{
					foreach($content['js'] as $item => $val)
					{
						$this->headContentsData['js'][$item] = $val; 
					}
					unset($content['js']);
				}
				
				if(isset($content['css']))
				{
					foreach($content['css'] as $item => $val)
					{
						$this->headContentsData['css'][$item] = $val; 
					}
					unset($content['css']);
				}
				
				foreach($content as $item => $val)
				{
					$this->headContentsData[$item] = $val; 
				}
			}
			else
			{
				$this->headContentsData[] = $content; 
			}	
		}
	}
	
	//Cache functions
	public function cacheValid($cache_time = false)
	{
		$cachePath =  $this->cachePath();
		
		if(!$cache_time) $cache_time = (15*60);
		
		$valid_cache =  true;
		if(!file_exists($cachePath)) $valid_cache = false;
		elseif(time() - filemtime($cachePath) > $cache_time) $valid_cache = false;
		elseif($_SERVER['REQUEST_METHOD'] == "POST")  $valid_cache = false;
		
		return $valid_cache;
	}
	
	public function cacheRead()
	{
		$cachePath =  $this->cachePath();
		return file_get_contents($cachePath);
	}
	
	public function cacheWrite($output)
	{
		$cachePath =  $this->cachePath();
		return file_put_contents($cachePath, $output);	
	}
	
	public function cachePath()
	{
		$cache_ext = "html";
		$cache_key = md5($this->url.$this->query.$this->template_name);
		
		return os_join_path(getOS()->getConfigVar('cache_path'), "{$cache_key}.{$cache_ext}");
	}
	
	

	public function getHeadFilesPath($cache_key, $cache_ext)
	{
		return os_join_path(getOS()->getConfigVar('cache_path'), "{$cache_key}.{$cache_ext}");
	}
	
	
	private function minifyHeadContents()
	{
		$OS = getOS();
		$root_url = $OS->getConfigVar('root_url');
		
		$tmpData = array();
		
		if(isset($this->headContentsData['css']))
		{
			$cache_key = md5(json_encode($this->headContentsData['css']));
			$fpath = $this->getHeadFilesPath($cache_key, 'css');
			$script_path = $root_url."/cache/{$cache_key}.css";
			$add_file = false;
						
			if(file_exists($fpath))
			{
				$add_file = true;
			}
			else
			{
				$data = $this->compressExternalFiles($this->headContentsData, 'css');
				
				if(!empty($data))
				{
					$writeResult = $OS->getUtils()->fileWrite($fpath, $data);
					
					if($writeResult)
					{
						$add_file = true;	
					}
				}
			}
			
			if($add_file)
			{
				$tmpData[$cache_key] = '<link rel="stylesheet" type="text/css" href="'.$script_path.'"/>';
			}
						
			unset($this->headContentsData['css']);
		}
		
		if(isset($this->headContentsData['js']))
		{
			$cache_key = md5(json_encode($this->headContentsData['js']));
			$fpath = $this->getHeadFilesPath($cache_key, 'js');
			$script_path = $root_url."/cache/{$cache_key}.js";
			$add_file = false;
			
			if(file_exists($fpath))
			{
				$add_file = true;	
			}
			else
			{
				$data = $this->compressExternalFiles($this->headContentsData,'js');
				
				if(!empty($data))
				{
					file_put_contents($fpath, $data);
					$add_file = true;
				}
			}
			
			if($add_file)
			{
				$tmpData[$cache_key] = '<script type="text/javascript" src="'.$script_path.'"></script>';
			}
			
			unset($this->headContentsData['js']);
		}
		
		$this->headContentsData = array_merge($tmpData, $this->headContentsData);
	}
	
	private function compressExternalFiles($headContentsFiles, $type)
	{
		$data = "";
		$OS = getOS();
		$osHttp = $OS->getHttp();
		$root_url = $OS->getConfigVar("root_url");
		$root_path = $OS->getConfigVar("root_path");
		
		$osTemplateCssRewrite = new OS_TemplateCSSUrlRewriter();
		
		//setup load order
		$buffer= array();
		foreach($headContentsFiles[$type] as $item => $filename)
		{
			$bulkData = $osHttp->get($filename);
			
			if(($osHttp->success()) && (!empty($bulkData)))
			{
				if($type == 'css')
				{
					//Rename URLs
					$css_file_path =  str_replace($root_url,$root_path, $filename);
					$bulkData = $osTemplateCssRewrite->rewrite($bulkData, dirname($css_file_path));
					
					//Compress Data
					$bulkData = OS_TemplateCSSCompressor::process($bulkData);
				}
				
				$buffer[] = $bulkData;		
			}
		}
		
		if(!empty($buffer))
		{
			$data =  implode("\n\n", $buffer);
		}
		
		return $data;
	}	
}
?>