<?php
class OS_TemplateOperations
{
	private static $_instance;
	
	private $cacheBasePath;
	
	public function __construct()
	{
		$this->cacheBasePath = "images"; 	
	}
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
    	{
			self::$_instance = new OS_TemplateOperations();
    	}
    	return self::$_instance;
	}
	
	public function getCachedImagePath($image_url, $params = array())
	{
		$OS = getOS();
		
		$validImage = false;
		$resizeImage = false;
		
		if(isset($params['width'],$params['width']))
		{
			$resizeImage = true;
		}
		
		if($this->cacheValid($image_url))
		{
			$validImage = true;
		}
		else
		{
			$osHttp = $OS->getHttp();
			$imageData = $osHttp->get($image_url);
			
			if($osHttp->success())
			{
				//check if image requires resizing
				if($resizeImage)
				{
					$contentType = $osHttp->getInfo(CURLINFO_CONTENT_TYPE);
					if($contentType !== false)
					{
						$imageExt = $this->imageMimeTypeToExt($contentType);
						
						if($imageExt !== false)
						{
							$imageObj = imagecreatefromstring($imageData);
							$imageWidth = imagesx($imageObj);
							$imageHeight = imagesy($imageObj);
						
							$defaultImageWidth = $params['width'];
							$defaultImageHeight = $params['height'];
							
							//check if image needs resizing
							if($imageWidth > $defaultImageWidth || $imageHeight > $defaultImageHeight)
							{
								//resize image
								$imageData = $this->imageResize($imageObj, $imageExt, $defaultImageWidth, $defaultImageHeight);
							}
						}
					}	
				}
					
				//write image to file
				$writeResult = $this->cacheWrite($image_url, $imageData);
				
				if(!empty($writeResult))
				{
					$validImage = true;
				}
			}
		}
		
		if($validImage)
		{
			return os_join_path($OS->getConfigVar('root_url'), "cache", $this->getCodedPath($image_url));
		}
		else
		{
			return false;
		}
	}
	
	public function imageResize($imageObj, $fext, $newWidth, $newHeight)
	{
		$func_suffix = ( $fext== 'jpg' ? "jpeg": $fext );
		$fimage = "image{$func_suffix}";
		
		$imageWidth = imagesx($imageObj);
		$imageHeight = imagesy($imageObj);
		
		//Keep image ratio
		$ratio = $imageWidth / $imageHeight;
		if ($newWidth/$newHeight > $ratio)
		{
			$newWidth = $newHeight*$ratio;
			$newHeight = $newHeight;
		} 
		else
		{
			$newHeight = $newWidth/$ratio;
			$newWidth = $newWidth;
		}	
		
		//create new resampled image
		$final = imagecreatetruecolor($newWidth, $newHeight);
		imagecopyresampled($final,$imageObj,0,0,0,0,$newWidth,$newHeight,$imageWidth,$imageHeight);
		
		ob_start();
		$fimage($final);
    	$finalImageObj = ob_get_clean();

    	imagedestroy($imageObj);imagedestroy($final);
		
		return $finalImageObj;
	}
	
	//Cache functions
	public function cacheValid($imgURL, $cache_time = false)
	{
		$cachePath =  $this->cachePath($imgURL);
		
		if(!$cache_time) $cache_time = (30*24*60*60);
		
		$valid_cache =  true;
		if(!file_exists($cachePath)) $valid_cache = false;
		elseif(time() - filemtime($cachePath) > $cache_time) $valid_cache = false;
		
		return $valid_cache;
	}
	
	public function cacheRead($imgURL)
	{
		$cachePath =  $this->cachePath($imgURL);
		return getOS()->getUtils()->fileRead($cachePath);
	}
	
	public function cacheWrite($imgURL, $output)
	{
		$cachePath =  $this->cachePath($imgURL);
		return getOS()->getUtils()->fileWrite($cachePath, $output);	
	}
	
	public function cachePath($imgURL)
	{
		return os_join_path(getOS()->getConfigVar('cache_path'), $this->getCodedPath($imgURL));
	}	
	
	private function getCodedPath($imgURL)
	{
		$parts = explode(".", basename($imgURL));
		
		$ext = (isset($parts[1]) ? ".{$parts[1]}":"");
		
		$coded_dir = md5($imgURL); 
		
		return os_join_path($this->cacheBasePath, $coded_dir[0], $coded_dir[1], substr($coded_dir,2,6), substr($coded_dir,8).$ext);  
	}

	public function imageMimeTypeToExt($ImageContentType)
	{
		$content_types = array(
			'image/gif' => 'gif', 	
			'image/jpeg' => 'jpg',
			'image/jpg' => 'jpg', 	
			'image/png' => 'png',	
			'application/x-shockwave-flash' => 'swf', 	
			'image/psd' => 'psd', 	
			'image/bmp' => 'bmp', 	
			'image/tiff'=> 'tiff', 	
			'image/vnd.microsoft.icon' => 'ico' 	
			);
			
		if(isset($content_types[$ImageContentType])) return $content_types[$ImageContentType];
		else return false;
	}
}
?>