<?php
class OS_Textualizer
{
	private static $_instance;
	
	private $engine;
	
	public function __construct()
	{
		$this->setInitialValues();
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_Textualizer();
		}
		
		return self::$_instance;
	}
	
	private function setInitialValues()
	{
		$this->setEngine('fullbody');
	}
	
	public function setEngine($engine)
	{
		$engineClass="OS_PLUGIN_Textualizer_{$engine}";
		
		$this->engine=call_user_func(array($engineClass,'get_instance'));	
//		$this->engine=$engineClass::get_instance();
	}
	
	public function setEngineOption($option,$value)
	{
		$result=false;
		
		if ($this->engine)
		{
			if (method_exists($this->engine,'setOption'))
			{
				$result=$this->engine->setOption($option,$value);
			}
		}
		
		return $result;
	}
	
	public function extractTextFromURL($url)
	{
		$result=false;
		
		$OS=getOS();
		
		$osHttp=$OS->getHttp();
		
		if ($response=$osHttp->get($url) AND $osHttp->success())
		{
			$result=$this->extractTextFromHTML($response);
		}
		
		return $result;
	}
	
	public function extractTextFromHTML($html)
	{
		$result=false;
		
		$dom=new DOMDocument();
		
		libxml_use_internal_errors(true);
		$loaded=$dom->loadHTML($html);
		libxml_use_internal_errors(false);
		
		if ($loaded)
		{
			$result=$this->extractTextFromDOM($dom);
		}
		
		return $result;
	}
	
	public function extractTextFromDOM($dom)
	{
		$result=false;
		
		if ($this->engine)
		{
			if ($text=$this->engine->extractText($dom))
			{
				$result=$this->cleanText($text);
			}
		}
		
		return $result;
	}
	
	public function cleanText($text)
	{
		$result=false;
		
		$result=strtolower(preg_replace("/[^\p{L}\p{N}]+/u",' ',$text));
		
		return $result;
	}
	
	public function wordCount($text)
	{
		$result=false;
		
		if (!empty($text))
		{
			$text=explode(' ',$text);
			
			$result=count($text);
		}
		
		return $result;
	}
	
	public function extractPhrases($text,$length=1,$min_word_length=0,$allow_numeric=false,$skip_words=array(),$allow_multiple_occurances=true)
	{
		$result=false;
		
		if (!empty($text))
		{
			$text=explode(' ',$text);
			
			foreach ($text as $key=>$val)
			{
				if (!$allow_numeric AND is_numeric($val))
				{
					unset($text[$key]);
					continue;
				}
				elseif ($min_word_length)
				{
					if (strlen($val)<$min_word_length)
					{
						unset($text[$key]);
						continue;
					}
				}
				
				if ($skip_words AND in_array($val,$skip_words))
				{
					unset($text[$key]);
				}
			}
			
			$text=array_values($text);
			$phrases=array();
			$count=count($text);
			
			if ($allow_multiple_occurances)
			{
				for ($i=0;$i<=$count-$length;$i++)
				{
					$phrase=implode(' ',array_slice($text,$i,$length));
					
					if (!isset($phrases[$phrase]))
					{
						$phrases[$phrase]=0;
					}
					
					$phrases[$phrase]++;
				}
			}
			else
			{
				for ($i=0;$i<=$count-$length;$i++)
				{
					$phrase=array($text[$i]=>'');
					
					$j=$i+1;
					while ($j<=$count-1 AND count($phrase)<$length)
					{
						$phrase[$text[$j]]='';
						$j++;
					}
					
					if (count($phrase)==$length)
					{
						$phrase=implode(' ',array_keys($phrase));
						
						if (!isset($phrases[$phrase]))
						{
							$phrases[$phrase]=0;
						}
						
						$phrases[$phrase]++;
					}
				}
			}
			
			if (!empty($phrases))
			{
				arsort($phrases);
				
				$result=$phrases;
			}
		}
		
		return $result;
	}
}
?>