<?php
class OS_Timeframe
{
	private static $_instance;
	
	private $firstDay;
	private $lastDay;
	
	private $minDay;
	private $maxDay;
	
	private $timeframePossible;
	
	public function __construct()
	{
		$OS=getOS();
		
		$osProject=$OS->getProject();
		$this->minDay=date('Y-m-d',strtotime($osProject->insert_dt));
		$time=time();
		$this->maxDay=date('Y-m-d',$time-86400);

		if ($this->timeframePossible=$this->validTimeframe($this->minDay,$this->maxDay))
		{
			if ($firstDay=$this->loadDay('first'))
			{
				$this->firstDay=$firstDay;
			}
			else
			{
				if ($this->validDay(date('Y-m-d',$time-30*86400)))
				{
					$this->firstDay=date('Y-m-d',$time-30*86400);
				}
				else
				{
					$this->firstDay=$this->minDay;
				}
				
				$this->saveDay($this->firstDay,'first');
			}

			if ($lastDay=$this->loadDay('last'))
			{
				$this->lastDay=$lastDay;
			}
			else
			{
				$this->lastDay=$this->maxDay;

				$this->saveDay($this->lastDay,'last');
			}
		}
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_Timeframe();
		}
		
		return self::$_instance;
	}
	
	public function setTimeframe($firstDay,$lastDay)
	{
		$result=false;
		
		if ($this->validTimeframe($firstDay,$lastDay))
		{
			$OS=getOS();
			
			$result=array('first'=>$this->firstDay,'last'=>$this->lastDay);
			
			$this->firstDay=$firstDay;
			$this->lastDay=$lastDay;
			
			$this->saveTimeframe($firstDay,$lastDay);
		}
		
		return $result;
	}
	
	public function setFirstDay($firstDay)
	{
		$result=false;
		
		if ($this->validTimeframe($firstDay,$this->lastDay))
		{
			$OS=getOS();
			
			$result=$this->firstDay;
			
			$this->firstDay=$firstDay;
			
			$this->saveDay($firstDay,'first');
		}
		
		return $result;
	}
	
	public function setLastDay($lastDay)
	{
		$result=false;
		
		if ($this->validTimeframe($this->firstDay,$lastDay))
		{
			$OS=getOS();
			
			$result=$this->lastDay;
			
			$this->lastDay=$lastDay;
			
			$this->saveDay($lastDay,'last');
		}
		
		return $result;
	}
	
	public function saveDay($day,$dayType)
	{
		$_SESSION['project']['osTimeframe'][$dayType.'Day']=$day;
	}
	
	public function saveTimeframe($firstDay,$lastDay)
	{
		$_SESSION['project']['osTimeframe']=array('firstDay'=>$firstDay,'lastDay'=>$lastDay);
	}
	
	public function loadDay($dayType)
	{
		$result=false;
		
		if (isset($_SESSION['project']['osTimeframe']))
		{
			if (isset($_SESSION['project']['osTimeframe'][$dayType.'Day']))
			{
				$result=$_SESSION['project']['osTimeframe'][$dayType.'Day'];
			}
		}
		
		return $result;
	}
	
	public function loadTimeframe()
	{
		$result=false;
		
		if (isset($_SESSION['project']['osTimeframe']))
		{
			$result=$_SESSION['project']['osTimeframe'];
		}
		
		return $result;
	}
	
	public function unsetDay($dayType)
	{
		unset($_SESSION['project']['osTimeframe'][$dayType.'Day']);
	}
	
	public function unsetTimeframe()
	{
		unset($_SESSION['project']['osTimeframe']);
	}
	
	public function getTimeframe()
	{
		$result=false;
		
		if ($this->isTimeframePossible())
		{
			$result=array('first'=>$this->firstDay,'last'=>$this->lastDay);
		}
		
		return $result;
	}
	
	public function getPreviousTimeframe()
	{
		$result=false;
		
		if ($this->isTimeframePossible())
		{
			$currentTimeframe=$this->getTimeframe();
			
			$daysInTimeframe=(strtotime($currentTimeframe['last'])-strtotime($currentTimeframe['first']))/86400;
			
			$previousTimeframe=array('first'=>date('Y-m-d',strtotime($currentTimeframe['first'])-86400*($daysInTimeframe+1)),'last'=>date('Y-m-d',strtotime($currentTimeframe['first'])-86400));
			
			if (!$this->validDay($previousTimeframe['first']))
			{
				$previousTimeframe['first']=$this->minDay;
			}
			
			if ($this->validTimeframe($previousTimeframe['first'],$previousTimeframe['last']))
			{
				$result=$previousTimeframe;
			}
		}
		
		return $result;
	}
	
	public function getFirstDay()
	{
		$result=false;
		
		if ($this->isTimeframePossible())
		{
			$result=$this->firstDay;
		}
		
		return $result;
	}
	
	public function getLastDay()
	{
		$result=false;
		
		if ($this->isTimeframePossible())
		{
			$result=$this->lastDay;
		}
		
		return $result;
	}
	
	public function getMinDay()
	{
		$result=false;
		
		if ($this->isTimeframePossible())
		{
			$result=$this->minDay;
		}
		
		return $result;
	}
	
	public function getMaxDay()
	{
		$result=false;
		
		if ($this->isTimeframePossible())
		{
			$result=$this->maxDay;
		}
		
		return $result;
	}
	
	public function isTimeframePossible()
	{
		return $this->timeframePossible;
	}
	
	public function validDay($day)
	{
		$result=false;
		
		if (strtotime($day)>=strtotime($this->minDay) AND strtotime($day)<=strtotime($this->maxDay))
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function validTimeframe($firstDay,$lastDay)
	{
		$result=false;
		
		if ($this->validDay($firstDay) AND $this->validDay($lastDay))
		{
			if (strtotime($firstDay)<=strtotime($lastDay))
			{
				$result=true;
			}
		}
		
		return $result;
	}
}
?>