<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_User
{
	//user ID
	var $id;
	
	//user
	var $user;
	
	//password (encrypted)
	var $password;
	
	//password changed date
	var $password_dt;
	
	//password changed ip
	var $password_ip;
	
	//name
	var $name;
	
	//email
	var $email;
	
	//user timezone
	var $timezone;

	//user language
	var $language;

	//flag if user is active
	var $isActive;
	
	//flag if user is admin
	var $is_admin;	
	
	//user status
	var $status;
	
	//status changed date
	var $status_dt;

	//status changed ip
	var $status_ip;
	
	//status changed by user_id
	var $status_by;
	
	//current user permissions
	private $permissions;
	
	//curent user departments
	private $departments;
	
	private static $_instance;
	
	//constructor
	function __construct($check_user = false)
	{
		if(($check_user) && ($this->isUserLogged()))
		{
			$this->syncUserDetails();
		}
	}
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_User(true);
		}
		return self::$_instance;
	}
	
	
	//encrypts and sets user password
	public function setPassword($password)
	{
		if(!empty($password))
		{
			$OS = getOS();
			$osUtils = $OS->getUtils();
			
			$this->password = $osUtils->generateHash($password,8);
			//should complete here $this->password_dt, $this->password_ip ?
		}
	}
	
	//Saves the user to the database. 
	public function save()
	{
		$result = false;
		
		$userOps = getOS()->getUserOps();
		
		if ($this->id > -1)
		{
			$result = $userOps->updateUser($this);
			
			//saving current user details ?
			if($this->isUserLogged())
			{
				if($_SESSION['user']['attrs']['id'] == $this->id)
				{
					$this->syncUserDetails();
				} 
			}
		}
		else
		{
			$newid = $userOps->insertUser($this);
			if ($newid > -1)
			{
				$this->id = $newid;
				$result = true;
			}

		}
		
		
		//update osUser details after a save operation
		/*
		if($result === true)
		{
			if($this->isValid())
			{
				$this->load();	
			}	
		}
		*/
	
		return $result;
	}
	
	public function set($userDetails)
	{
		$result = false;
		
		$objVars = get_object_vars($this);
		
		if(is_object($userDetails))
		{
			$userDetails = get_object_vars($userDetails);
		}
		
		foreach($objVars as $field=>$val)
		{
			if(isset($userDetails[$field]))
			{
				$this->$field = $userDetails[$field];
				$result = true;
			}
		}
		
		return $result;
	}
	
	
	//Delete current user and empty the User object
	public function delete()
	{
		$result = false;
		
		if ($this->id > -1)
		{
			$OS = getOS();
			
			$osUserOps = $OS->getUserOps();
			
			$osDepartmentOps = $OS->getDepartmentOps();
			
			$osPermissionOps = $OS->getPermissionOps();
			
			$osAppHandlerOps = $OS->getAppHandlerOps(); 
			
			//mark user for deletition
			
			
			//Remove user permissions
			$userPermissions = $osPermissionOps->getPermissionsByUserID($this->id);
			if(!empty($userPermissions))
			{
				foreach($userPermissions as $project_id=>$modules)
				{
					foreach ($modules as $module=>$moduleData)
					{
						foreach($moduleData as $permission=>$op)
						{
							$osPermissionOps->removePermissionRecord($project_id,$this->id,"U",$module,$permission);		
						}
					}
				}
			}
	
			//Remove links between this user and departments
			$userDepartments = $osDepartmentOps->getDepartmentsByUserID($this->id);
			if(!empty($userDepartments))
			{
				foreach($userDepartments as $department_id)
				{
					$osDepartmentOps->removeDepartmentUserLink($this->id,$department_id);		
				}
			}
			
			
			//Remove apps linked to this user
			$userApps = $osAppHandlerOps->getAppsByUserID($this->id);
			if(!empty($userApps))
			{
				foreach($userApps as $app_id=>$oneAppHandler)
				{
//					$osAppHandlerOps->removeAppUserLink($app_id,$this->id);
//					$oneAppHandler->removeApp($this->id,$project_id);		
				}
			}
			
			//Remove user record from the database
			$result = $osUserOps->deleteUserByID($this->id);
			if ($result)
			{
				$this->reset();
			}
		}

		return $result;
	}
	
	//Login current user object
	public function login()
	{
		$result = false;
		
		$userOps = getOS()->getUserOps();
		
		$oneUser = $userOps->loginUser($this->user,$this->password);
		
		if($oneUser !== false)
		{
			//operations done after user is succesfully verified
			
			//update current user data
			
			$this->set($oneUser);
			
			//get this user permissions (from database) 
			$this->loadPerms();
			
			$this->loadDepartments();
			
			$this->syncUserDetails();
			
			//update User Object
			$_SESSION["session_ip"] = $_SERVER['REMOTE_ADDR'];
			
			$_SESSION['tok'] = md5(session_id());
			
			session_write_close();
			
			$result = true;	
		}
		
		return $result;
	}
	
	
	//Checks is a user is logged
	public function isUserLogged()
	{
		$result = true;
	
		if(!isset($_SESSION['user']['attrs']))
		{
			$result = false;	
		}
		else
		{
			$p = array('id','user','password','email');
			foreach($p as $v) if (!isset($_SESSION['user']['attrs'][$v])) $result = false;	
		}
		return $result;
	}
	
	//Force login user
	public function forceUserLogin($jump_to = false)
	{
		if (!$this->isUserLogged())
		{
			$OS = getOS();
			
			//must change users with admin
			if (!$jump_to) $jump_to = urlencode($_SERVER['REQUEST_URI']);
			$OS->redirectTO("/users/login.php?msg=must_login&jumpto={$jump_to}");
		}
	}
	
	//Logout user
	public function logout()
	{
		$this->reset();
		$this->clearSession();
	}
	
	public function clearSession()
	{
		$result = false;
		if(isset($_SESSION['user']))
		{
			unset($_SESSION['user']);
			$result = true;
		}
		
		return $result;
	}
	
	//add user permission
	public function addPerm($project_id, $module, $permission, $op)
	{
		$result = false;
		
		if( $this->isValid())
		{
			$osPermissionOps = getOS()->getPermissionOps();
			
			$permResult = $osPermissionOps->addPermissionRecord($project_id,$this->id,"U",$op,$module,$permission);
	
			if($permResult === true)
			{
				$this->permissions[$project_id][$module][$permission] = $op;
				
				$result = true;
			}
		}
		
		return $result;
	}

	//remove user permission
	public function removePerm($project_id,$module,$permission)
	{
		$result = false;
		
		if( $this->isValid() )
		{
			$osPermissionOps = getOS()->getPermissionOps();
			
			$permResult = $osPermissionOps->removePermissionRecord($project_id,$this->id,"U",$module,$permission);
			
			if($permResult === true)
			{
				
				if(isset($this->permissions['U'][$project_id][$module][$permission])) 
				{
					unset($this->permissions['U'][$project_id][$module][$permission]);	
				}	
	
				$result = true;
			}
		}
		
		return $result;	
	}
	
	//check user permission
	public function checkPerm($module,$permission,$project_id=false)
	{
		$result = false;
		
		if ($project_id===false)
		{
			$project=getOS()->getProject();
			
			if ($project->id>-1)
			{
				$project_id=$project->id;
			}
			else
			{
				$project_id=0;
			}
		}
		
		if($this->isValid())
		{
			if($this->is_admin == 'Y') $result = true;
			else
			{
				if(!empty($this->permissions))
				{
					if(isset($this->permissions['D']))
					{
						foreach($this->permissions['D'] as $dep_id => $permData)
						{
							if(isset($permData[$project_id][$module][$permission]))
							{
								if($permData[$project_id][$module][$permission] == 'A' ) $result = true;
							}
							elseif (isset($permData[0][$module][$permission]))
							{
								$result = true;
							}
						}
					}
					
					if(isset($this->permissions['U']))
					{
						if(isset($this->permissions['U'][$project_id][$module][$permission]))
						{
							$permission_op = $this->permissions['U'][$project_id][$module][$permission];
						}
						elseif (isset($this->permissions['U'][0][$module][$permission]))
						{
							$permission_op = $this->permissions['U'][0][$module][$permission];
						}
						
						if (isset($permission_op))
						{
							if($permission_op == 'A' ) $result = true;
							elseif($permission_op == 'R' ) $result = false;
						}
					}
				}
			} 
		}

		return $result;
	}
	
	public function forcePerm($module,$permission, $jump_to = false)
	{
		$checkResult = $this->checkPerm($module, $permission);
		
		$OS =  getOS();
		
		if($checkResult === false) 
		{
			if (!$jump_to)
			{
				$jump_to = urlencode($_SERVER['REQUEST_URI']);
			} 
			
			$OS->redirectTO("/users/upause.php?msg=noperms&jumpto={$jump_to}");
		}
	}
	
	public function getTips($count=1)
	{
		$result = false;
		
		$userOps = getOS()->getUserOps();
		
		$result=$userOps->getUserTips($this,$count);
		
		return $result;
	}
	
	public function isUserAdmin()
	{
		$result = false;

		if($this->isValid())
		{
			if ($this->isUserLogged())
			{
				if($this->is_admin == 'Y') $result = true;				
			}
		}
			
		return $result;
	}
	
	
	public function forceUserAdmin($jump_to=false)
	{
		if(!$this->isUserAdmin())
		{
			//must change users with admin
			if (!$jump_to) $jump_to = urlencode($_SERVER['REQUEST_URI']);
			getOS()->redirectTO("/users/projects_list.php?msg=noperms");
		}
	}
	
	public function forceIn($jump_to = false)
	{
		if ($this->isUserLogged())
		{
			if (!$jump_to) $jump_to = "/users/projects_list.php?msg=welcome";
			getOS()->redirectTO($jump_to);
		}
	}

	//get user permissions by module
	public function getPerm($module = false)
	{
		$result = false;
		
		if($module !== false)
		{
			if(isset($this->permissions[$module]))
				{
					$result = $this->permissions[$module];	
				}
		}
		
		return $result;
	}
	
	
	//get all user's current permissions
	public function getPerms()
	{
		$result = array();
		
		if(!empty($this->permissions))
		{
			$result = $this->permissions;	
		}

		return $result;
	}	
	
	//save user permissions
	public function savePerms()
	{
		$result = false;
		
		$osPermissionOps = getOS()->getPermissionOps();
		
		$permsData = array();
		foreach( $this->permissions as $module => $modulePermssions )
		{
			foreach( $modulePermssions as $permission => $scope )
			{
				$result = $osPermissionOps->addPermissionRecord($this->id, "U", "A", $module, $permission, $scope );
			}
		}
		
		return $result;	
	}
	
	//load user permissions (get from SQL and push into object)
	public function loadPerms()
	{
		$result = false;
		
		if($this->id > -1)
		{
			$osUserOps = getOS()->getUserOps();
			
			$userPerms = $osUserOps->getUserPermissions($this->id);
			
			if($userPerms !== false)
			{
				$this->permissions = $userPerms;
				$result = true;
			}
		}
		return $result;
	}
	
	//check if current user is active
	public function isActive()
	{
		$result = false;
		
		if($this->status == 'A')
		{
			$result = true;	
		}
		
		return $result;
	}
	
	
	//get all departments that are linked with the current user
	public function loadDepartments()
	{
		$result = false;
		
		if($this->isValid())
		{
			if(!isset($this->departments))
			{
				$osDepartmentOps = getOS()->getUserOps();
				
				$departmentsResult = $osDepartmentOps->getDepartmentsByUserID($this->id);
		
				$this->departments = $departmentsResult;
			} 
		}
		
		return $result;
	}	
	
	public function getDepartments()
	{
		$result = false;
		
		if($this->isValid())
		{
			if(!isset($this->departments))
			{
				$this->loadDepartments();
			}
			
			$result = $this->departments;
		}
		
		return $result;
	}
	
	
	//link current user with with a new department
	public function addDepartment($department_id)
	{
		$result = false;
		
		if(($department_id >= 1) && ($this->isValid()))
		{
			$osDepartmentOps = getOS()->getDepartmentOps();
			
			$addResult = $osDepartmentOps->createDepartmentUserLink($this->id,$department_id);
			
			if($addResult !== false)
			{
				$result = true;
			}
		}
		
		return $result;
	}
	
	//remove current user from a department
	public function removeDepartment($department_id)
	{
		$result = false;
		
		if(($department_id >= 1) && ($this->isValid()))
		{
			$osDepartmentOps = getOS()->getDepartmentOps();
			
			$removeResult = $osDepartmentOps->removeDepartmentUserLink($this->id,$department_id);
			
			if($removeResult !== false)
			{
				$result = true;
			}
		}
		
		return $result;
	}

	//get current user apps (from database)
	public function getApps($project_id=false)
	{
		$result = array();
	
		$OS = getOS();
		$osApplicationsOps = $OS->getAppHandlerOps();
	
		$osUserApps = $osApplicationsOps->getAppsByUserID($this->id,$project_id);
		
		if(!empty($osUserApps))
		{
			$result = $osUserApps;
		}
	
		return $result;
	}
	
	public function getAvailableApps($project_id=false)
	{
		$result=false;
		
		if (is_null($this->permissions))
		{
			$this->loadPerms();
		}
		
		$OS=getOS();
		$availableApps=$OS->getAppOps()->getAvailableAppsNames();
		
		foreach ($availableApps as $app_id=>$app_name)
		{
			if ($this->checkPerm($app_name,'view',$project_id))
			{
				$result[$app_id]=$app_name;
			}
		}
		
		return $result;
	}
	
	public function getAvailableAppsDetails($project_id=false)
	{
		$result=false;
		
		if (is_null($this->permissions))
		{
			$this->loadPerms();
		}
		
		$OS=getOS();
		$availableApps=$OS->getAppOps()->getAvailableAppsDetails();
		
		if(!empty($availableApps))
		{
			foreach ($availableApps as $app_id=>$app_details)
			{
				if ($this->checkPerm($app_details['name'],'view',$project_id))
				{
					$result[$app_id]=$app_details;
				}
			}
		}
		
		return $result;
	}
	
	//push current user details into sesssion (for future use)
	public function syncUserDetails()
	{
		$currentUserDetails = get_object_vars($this);

		$invalidValues = array("_intance","permissions","departments");
		
		//check if user is valid
		if($this->isValid())
		{
			//push user object in SESSION
			foreach($currentUserDetails as $field => $value)
			{
				if(!in_array($field, $invalidValues))
				{
					$_SESSION['user']['attrs'][$field] = $value;	
				}
			}
			
			if(isset($this->permissions))
			{
				$_SESSION['user']['permissions'] = $this->permissions;
			}
			
			if(isset($this->departments))
			{
				$_SESSION['user']['departments'] = $this->departments;
			}
		}
		else
		{
			if($this->isUserLogged()) 
			{
				//populate user object from SESSION
				$tmpUserDetails =  array();
				foreach($currentUserDetails as $field => $value)
				{
					if(!in_array($field, $invalidValues))
					{
						if(isset($_SESSION['user']['attrs'][$field]))
						{
							$tmpUserDetails[$field] = $_SESSION['user']['attrs'][$field];	
						}
					}
				}
				
				$this->set($tmpUserDetails);
				
				if(isset($_SESSION['user']['permissions']))
				{
					$this->permissions = $_SESSION['user']['permissions'];	
				}
				
				if(isset($_SESSION['user']['departments']))
				{
					$this->departments = $_SESSION['user']['departments'];	
				}
			}
		}
	}
	
	//verify if osUser contains valid user details
	public function isValid()
	{
		$result = false;
		if(isset($this->id))
		{
			if($this->id > 0)
			{
				$result  = true;		
			}
		}
		
		return $result;
	}
	
	public function reset()
	{
		if($this->isValid())
		{
			$details = get_object_vars($this);
			
			if($details)
			{
				foreach($details as $field => $value)
				{
					if($field !== '_instance')
					{
						$this->$field = NULL; 
					}
				}
			}
		}
	}
	
	public function load()
	{
		$result = false;
		
		if($this->isValid())
		{
			$osUserOps = getOS()->getUserOps();
			
			$oneUser = $osUserOps->getUserByID($this->id);

			if($oneUser !== false)
			{
				$this->set($oneUser);
				
				$result = true;;	
			}
		}
		
		return $result;
	}
}
?>