<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

//require_once(dirname(__FILE__)."/class.os_user.php"); 

class OS_UserOperations
{
	
	private static $_instance;
	
	protected function __construct() {}

	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_UserOperations();
		}
		return self::$_instance;
	}

	//Get a list of all users
	public function &getUsers()
	{
		$db = getOS()->getDb();

		$result = array();

		$query = "SELECT * FROM ".$db->dbPrefix()."users ORDER BY `id` DESC";
		$dbresult = $db->query($query);
		while ($row = $db->fetchRow($dbresult))
		{
			$userData = new OS_User();
			$userData->set($row);
			$result[$row['id']] = $userData;
		}

		return $result;
	}
	

	//Get a user by user id.
	public function &getUserByID($id)
	{
		return $this->getUserByDetail(array('id'=>$id));
	}

	//Get a user by username.
	public function &getUserByUsername($user)
	{
		return $this->getUserByDetail(array('user'=>$user));
	}

	//Get a user by email
	public function &getUserByEmail($email)
	{
		return $this->getUserByDetail(array('email'=>$email));
	}

	
	public function &getUserByDetail($details)
	{
		$result = false;
		$query  = false;

		$db = getOS()->getDb();

		if(isset($details['id']))  $query = "SELECT * FROM ".$db->dbPrefix()."users WHERE id = ?";	
		elseif(isset($details['user'])) $query = "SELECT * FROM ".$db->dbPrefix()."users WHERE user = ?";
		elseif(isset($details['email'])) $query = "SELECT * FROM ".$db->dbPrefix()."users WHERE email = ?";
		
		if($query)
		{
			$dbresult = $db->query($query, array_values($details));
			
			if ($row = $db->fetchRow($dbresult))
			{
				$userData = new OS_User();
				$userData->set($row);
				$result = $userData;
			}
				
		}
		return $result;
	}
	
	//Get a list with user's statuses
	public function & getStatuses()
	{
		$statuses = array(
			'A' => _("Active"),
			'D' => _("Disabled"),
			'P' => _("Pending"),
			'S' => _("Suspended"),
			'R' => _("Removed")
			);
		
		return $statuses; 	
	}
	
	//Saves a new user to the database.
	public function insertUser($user)
	{
		$result = -1; 
		
		$OS = getOS();

		$db = $OS->getDb();
		
		//check for username conflict
		$query = "SELECT id FROM ".$db->dbPrefix()."users WHERE `user` = ?";
		$results =  $db->query($query,array($user->user));
		if( $db->fetchRow($results) !== false) return $result;
		
		//get current user's data (needed for status_by)
		$user_id = $OS->getUser()->id;
			
		if(is_null($user_id)) $user_id = -1;
		
		$time = $db->DBTimeStamp(time());
		
		//Set default is_admin if not already set
		if(is_null($user->is_admin))
		{
			$user->is_admin = "";
		}
		
		$userDetails = array(
			'password_dt' => $time,
			'password_ip' => $_SERVER['REMOTE_ADDR'],
			'status_dt' => $time,
			'status_ip' => $_SERVER['REMOTE_ADDR'],
			'status_by' => $user_id,
			);
			
		$user->set($userDetails);	
		
		$query = "INSERT INTO ".$db->dbPrefix()."users (`user`, `password`, `password_dt`, `password_ip`, `passwords`, `email`, `name`, `timezone`, `language`, `is_admin`, `register_dt`, `register_ip`, `status`, `status_dt`, `status_ip`, `status_by`) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		$dbresult = $db->query($query, array($user->user, $user->password, $user->password_dt , $user->password_ip, 1, $user->email, $user->name,$user->timezone,$user->language, $user->is_admin, $time,$_SERVER['REMOTE_ADDR'],$user->status,$user->status_dt,$user->status_ip,$user->status_by));
		
		if ($dbresult !== false)
		{
			$result = $db->getInsertId();
		}
		return $result;
	}

	//Updates an existing user in the database.
	public function updateUser($user)
	{
		$result = false;
		
		$OS =  getOS(); 

		$db = $OS->getDb();
		
		//check for user conflict
		$query = "SELECT id FROM ".$db->dbPrefix()."users WHERE `user` = ? AND `id` != ?";
		$results =  $db->query($query,array($user->user,$user->id));
		if( $db->fetchRow($results) !== false) return $result;
		
		//get user data from database
		$time = $db->DBTimeStamp(time());
		$oldUser = $this->getUserByID($user->id);
		
		if($oldUser !== false)
		{
			$userDetails = array(
				'name' => $user->name,
				'email' => $user->email,
				'timezone' => $user->timezone,
				'language' => $user->language,
				'is_admin' => $user->is_admin,	
				);
			
			if($user->password != $oldUser->password)
			{
				$userDetails['password'] = $user->password; 
				$userDetails['password_dt'] = $time;
				$userDetails['password_ip'] = $_SERVER['REMOTE_ADDR'];  
			}
			
			if($user->status != $oldUser->status)
			{
				//get current user's data (needed for status_by)
				$user_id = $OS->getUser()->id;
				if(is_null($user_id)) $user_id = -1;
				
				$userDetails['status'] = $user->status;
				$userDetails['status_dt'] = $time;
				$userDetails['status_ip'] = $_SERVER['REMOTE_ADDR'];  
				$userDetails['status_by'] = $user_id;
			}	
			
			$oldUser->set($userDetails);

			//execute the update query
			$query = "UPDATE ".$db->dbPrefix()."users SET `name` = ?,`email` = ?, `timezone` = ?, `language` = ?,`password` = ?,`password_dt` = ?,`password_ip` = ?,`is_admin` = ?,`status` = ?,`status_dt` = ?,`status_ip` = ?,`status_by` = ?,`update_dt` = ?, `update_ip` = ?, `updates` = updates+1 WHERE `id` = ?";
			$dbresult = $db->query($query, array($oldUser->name, $oldUser->email,$oldUser->timezone, $oldUser->language, $oldUser->password, $oldUser->password_dt, $oldUser->password_ip, $oldUser->is_admin, $oldUser->status, $oldUser->status_dt,$oldUser->status_ip,$oldUser->status_by, $time, $_SERVER['REMOTE_ADDR'], $oldUser->id));
			if ($dbresult !== false)
			{
				$result = true;
			}
		}  

		return $result;
	}
	

	public function loginUser($username,$password)
	{
		$result = false;
		
		$OS =  getOS();
		
		$db = $OS->getDb();
	
		$userOps = $OS->getUserOps();
		
		$user =  strtolower(trim($username));
		
		$userData = $userOps->getUserByUsername($user);
		
		if($userData===false) 
		{
			$OS->addBoxError(_("Wrong user/password combination !"),'error'); 
		}
		else
		{
			$user_ok = false;
			if($password == $userData->password) $user_ok = true;
			 
			if(!$user_ok)
			{
				$query = "UPDATE ".$db->dbPrefix()."users SET loginer_dt=?, loginer_ip=?, loginser=loginser+1 WHERE `id` = ? LIMIT 1"; 
				$dbresult = $db->query($query, array($db->DBTimeStamp(time()),'',$userData->id));
	
				$query = "INSERT INTO ".$db->dbPrefix()."logins (user_id,login_dt,login_ip,login_status) VALUES(?,?,?,?)";
				$dbresult = $db->query($query, array($userData->id,$db->DBTimeStamp(time()),'','R'));
				
				$OS->addBoxError(_("Wrong user/password combination !"),'error'); 
			}
			else
			{//ENTER
	
				$query = "UPDATE ".$db->dbPrefix()."users SET loginok_dt=?, loginok_ip=?, loginsok=loginsok+1 WHERE `id` = ? LIMIT 1"; 
				$dbresult = $db->query($query, array($db->DBTimeStamp(time()),'',$userData->id));
	
				$query = "INSERT INTO ".$db->dbPrefix()."logins (user_id,login_dt,login_ip,login_status) VALUES(?,?,?,?)";
				$dbresult = $db->query($query, array($userData->id,$db->DBTimeStamp(time()),'','O'));
	
				
				if ($userData->status=='D')
				{
					$OS->addBoxError(_("This User is marked for deletion. You can't login with it any more."),'error');	
				} 
				/*
				elseif($userData->status=='A')
				{
					$OS->addBoxError("This User it is not approved yet. Please wait until it will be activated !",'error');	
				}
				*/
				elseif($userData->status=='V')
				{
					$OS->addBoxError(_("This User it is not verified.").'<br>'._("You should have an email with the verification link sent at")." {$row['email']} !<br>"._("In case that is not the correct email address please <a href='/contact.php'>contact us</a>."),'error');
				} 
				elseif($userData->status=='S')
				{
					$query = "INSERT INTO ".$db->dbPrefix()."logins (user_id,login_dt,login_ip,login_status) VALUES(?,?,?,?)";
					$dbresult = $db->query($query, array($userData->id,$db->DBTimeStamp(time()),'','S'));
	
					$OS->addBoxError(_("This user is Suspended !")."<br><i>{$row['status_reason']}</i>",'error');
				}				
				else
				{
					$result = $userData;
				}
					
			} 
		}

	return $result;		
	}

	//get department object by user id
	public function getDepartmentsByUserID($user_id)
	{
		$result =  false;
		
		$db = getOS()->getDb();
		
		$time = $db->DBTimeStamp(time());
		
		$query = "SELECT * FROM ".$db->dbPrefix()."departments_users WHERE `user_id`= ?";
		$dbresult = $db->query($query,array($user_id));
		while($row = $db->fetchRow($dbresult))
		{
			$result[] = $row['department_id'];
		}
		
		return $result;		
	}
	

	//Deletes an existing user from the database.
	public function deleteUserByID($id)
	{
 		if( $id <= 1 ) return false;
 		
 		//check if current user can delete users
 		
 		
 		$result = false;

		$db = getOS()->getDb();
 		
		$query = "DELETE FROM ".$db->dbPrefix()."users WHERE `id` = ?";
		$dbresult = $db->query($query, array($id));

		if ($dbresult !== false)
		{
			$result = true;
		}

		return $result;
	}
	
	
	//get user permissions from database
	public function getUserPermissions($user_id)
	{
		$result = array(); 
		$departmentPermissions = array();
		$userPermissions = array();
		
		$OS = getOS();
		
		$db = $OS->getDb();
		
		$osPermissionOps = $OS->getPermissionOps();
		
		if($user_id > -1)
		{
			$usersDepartments = array();
			$query = "SELECT * FROM ".$db->dbPrefix()."departments_users WHERE `user_id`= ?";
			$dbresult = $db->query($query,array($user_id));
			while ($row = $db->fetchRow($dbresult)) $usersDepartments[] = $row['department_id'];
			
			if(!empty($usersDepartments))
			{
				foreach($usersDepartments as  $dep_id)
				{
					$tmpResult = $osPermissionOps->getPermissionsByDepartmentID($dep_id);
					if(!empty($tmpResult))
					{
						$result['D'][$dep_id] = $tmpResult;
					}
				}
			}
		}

		$tmpResult = $osPermissionOps->getPermissionsByUserID($user_id);
		if(!empty($tmpResult))
		{
			$result['U'] = $tmpResult;
		}
		
		return $result;
	}
	
	public function getUserTips($user,$count)
	{
		$result=false;
		
		$available_tips=array();
		
		//Admin-only tips
		if ($user->isUserAdmin())
		{
			$OS=getOS();
			
			$osConfig=$OS->getConfig();
			
			$backlinksOps=$OS->getBacklinksOps();
			
			if (!$backlinksOps->getEngineAuthData('moz'))
			{
				$available_tips['moz_auth']=array(
					'title'=>_("Get Moz data integrated in OpenS"),
					'description'=>_("Integrate the MozScape API to see more comprehensive data and metrics about your project and competitors. You will get Domain Authority, Page Authority, MozRank, MozTrust and a bunch of other metrics straight into the OpenS apps."),
					'link'=>array(
						'url'=>$osConfig->getParam('root_url').'/livedash/admin.php#connectors_manager',
						'title'=>_("Define API credentials"),
						'anchor_type'=>'text',
						'anchor_text'=>_("Define API credentials")
					)
				);
			}
		}
		
		//Average user tips
		if (!$user->isUserAdmin() OR count($available_tips)<$count)
		{
		}
		
		if ($available_tips)
		{
			$pick_tips=array_rand($available_tips,$count);
			
			if ($pick_tips!==false AND !is_array($pick_tips))
			{
				$pick_tips=array($pick_tips);
			}
			
			if ($pick_tips)
			{
				foreach ($pick_tips as $tip)
				{
					$result[$tip]=$available_tips[$tip];
				}
			}
		}
		
		return $result;
	}
	
	public function isValidUsername($username)
	{
		$userchars = "-01234567890123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";
		$bad_words = array("root","admin","administrator","www","http");
	
		$flag = true;
		for ($i=0;$i<strlen($username);$i++)
		{
			if (strpos($userchars,$username[$i])===false) $flag = false;
		} 
		
		foreach($bad_words as $idx=>$word)
		{
			if(strpos(strtolower(trim($username)),$word)!==false) $flag = false;
		}		
	
		return $flag;
	}
	
	public function isValidName($name)
	{
		$namechars=" -01234567890123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz.";
		$flag = true;
		for ($i=0;$i<strlen($name);$i++)  
		{
			if (strpos($namechars,$name[$i])===false)
			{
				$flag = false;
			} 
		}	
		return $flag;
	}
	
	public function createDefaultUserDetails($oneUser)
	{
		$OS = getOS();
		
		$defaultUserSchema = array(
			'departments' => array('administrators')
		);
		
		if(!empty($defaultUserSchema['departments']))
		{
			$osDepartmentOps = $OS->getDepartmentOps();
			
			foreach($defaultUserSchema['departments'] as $depName)
			{
				$oneDepartment = $osDepartmentOps->getDepartmentByName($depName);
				
				$depResult = $oneUser->addDepartment($oneDepartment->id);

				if($depResult === true)
				{
					
				}
				else
				{
					
				}
			}
		}
	}
}
?>