<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 */
class OS_Utils
{
	private static $_instance;
	
	private $instanceCache;
	
	function __construct()
	{
		$this->instanceCache=array();
	}
	
	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_Utils();
		}
		return self::$_instance;
	}
	
	public function getSafeURL($url)
	{
		return getOS()->getConfigVar('root_url').'/users/jump.php?url='.urlencode($url).'&key='.$this->getSafeURLKey($url);
	}
	
	public function getSafeURLKey($url)
	{
		return substr(md5($url.'os_jump_salt'),0,8);
	}
	
	public function stripHTTP($url)
	{
		return str_replace(array('http://','https://'),'',$url);
	}
	
	public function stripWWW($url)
	{
		if (strpos($url,'www.') === 0)
		{
			$url=substr($url,4);
		}
		
		return $url;
	}
	
	public function stripPort($url)
	{
		if (strpos($url,':')!==false)
		{
			$url=substr($url,0,strpos($url,':'));
		}
		
		return $url;
	}
	
	public function stripEndingSlash($url)
	{
		if ($url[strlen($url)-1]=='/')
		{
			$url=substr($url,0,-1);
		}
		
		return $url;
	}
	
	public function stripHash($url)
	{
		if (strpos($url,'#')!==false)
		{
			$url=substr($url,0,strpos($url,'#'));
		}
		
		return $url;
	}
	
	public function stripifyURL($url)
	{
		return $this->stripWWW($this->stripHTTP($this->stripEndingSlash($url)));
	}
	
	public function prependHTTP($url)
	{
		return 'http://'.$this->stripHTTP($url);
	}
	
	public function prependWWW($url)
	{
		return 'www.'.$this->stripWWW($url);
	}
	
	public function appendSlash($url)
	{
		return $this->stripEndingSlash($url).'/';
	}
	
	public function appendSlashIfNoPath($url)
	{
		$result=$url;
		
		if (!parse_url($url,PHP_URL_PATH))
		{
			$result=$url.'/';
		}
		
		return $result;
	}
	
	public function urlifyHost($host)
	{
		return $this->appendSlash($this->prependHTTP($host));
	}
	
	public function getDir($path,$pattern,$recursive=false,$flags=0)
	{
		$result=glob(os_join_path($path,$pattern), $flags);
		
		if ($recursive)
		{
		    if ($paths=glob(os_join_path($path,'*'), GLOB_ONLYDIR))
		    {
		    	foreach ($paths as $path) { $result=array_merge($result,$this->getDir($path,$pattern,true,$flags)); }
		    }
		}
		
		if ($result===false)
		{
			$result=array();
		}
		
	    return $result;
	}
	
	public function copyDir($source_path,$destination_path)
	{
		$result=true;
		
		$default_chmod = 0777;
		
		if (!file_exists($destination_path))
		{
			$this->createDir($destination_path, $default_chmod);
		}
		
		if ($src_files=glob(os_join_path($source_path,'*')))
		{
			foreach ($src_files as $src_file)
			{
				$dest_file = str_replace(os_join_path($source_path,''),os_join_path($destination_path,''),$src_file);
				
				if (is_file($src_file))
				{
					if (!@copy($src_file,$dest_file))
					{
						$result = false;
					}
					else
					{
						$this->chmodDir($dest_file, $default_chmod);
					}
				}
				else
				{
					$copy_dir=true;
					
					if (!file_exists($dest_file))
					{
						if(!$this->createDir($dest_file,$default_chmod))
						{
							$result = false;
							$copy_dir = false;
						}
					}
					
					if ($copy_dir)
					{
						$result=$this->copyDir($src_file,$dest_file);
					}
				}
			}
		}
		
		return $result;
	}
	
	public function moveDir($source_path,$destination_path)
	{
		$result=false;
		
		if ($this->copyDir($source_path,$destination_path))
		{
			if ($this->removeDir($source_path))
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function removeDir($dirname,$remove_root=true)
	{
		if(!is_dir($dirname))
		{
			return @unlink($dirname);
		}
		
		if ($items = glob(os_join_path($dirname,'*'), GLOB_NOSORT))
		{
			foreach($items as $itemPath)
			{
				if(!@is_dir($itemPath))
				{
					if(!@unlink($itemPath))
					{
						return false;
					}
				}
				else
				{
					$this->removeDir($itemPath, true);
				}
			}
			
			if ($remove_root)
			{
				if( ! @rmdir($dirname) )
				{
					return false;
				}
			}
		}
		
		return true;
	}
	
	public function isEmptyDir($dirname)
	{
		$dir_contents=glob(os_join_path($dirname,'*'));
		
		return empty($dir_contents);
	}
	
	//Recursively chmod all files and folders in a directory
	public function chmodDir( $path, $mode )
	{
		if( !is_dir( $path ) )
		{
			$old=umask(0);
			$result=@chmod( $path, $mode );
			umask($old);	
			return $result;
		} 
		
		$dh = @opendir( $path );
		if( !$dh ) return FALSE;
		
		while( $file = readdir( $dh ) )
		{
			if( $file != '.' && $file != '..' )
			{
				$p = $path.DIRECTORY_SEPARATOR.$file;
				if( is_dir( $p ) )
				{
					if( !@$this->chmodDir( $p, $mode ) )
					{
						closedir( $dh );
						return false;
					}
				}
				else if( !is_link( $p ) )
				{
					$old=umask(0);
					$result=@chmod($p,$mode);
					umask($old);
					
					if( !$result )
					{
						closedir( $dh );
						return false;
					}
				}
			}
		}
		@closedir( $dh );
		
		$old=umask(0);
		$result=@chmod( $path, $mode );
		umask($old);
		
		return $result;
	}	
	
	public function getTempFile($extension='tmp')
	{
		$tmp_path=getOS()->getConfigVar('cache_path');
		$result=os_join_path($tmp_path,time().'-'.rand(1000,9999).'.'.$extension);
		
		while (file_exists($result))
		{
			$result=os_join_path($tmp_path,time().'-'.rand(1000,9999).'.'.$extension);
		}
		
		touch($result);
		
		return $result;
	}
	
	public function getTempDir()
	{
		$tmp_path=getOS()->getConfigVar('root_path');
		$result=os_join_path($tmp_path,time().'-'.rand(1000,9999));
		
		while (file_exists($result))
		{
			$result=os_join_path($tmp_path,time().'-'.rand(1000,9999));
		}
		
		$this->createDir($result,0755);
		
		return $result;
	}
	
	public function createDir($dirpath, $mode = 0755)
	{
		$result = false;
		if(!is_dir($dirpath))
		{
			$old=umask(0);
			$result=mkdir($dirpath, $mode, true);
			umask($old);
		}
		
		return $result;
	}
	
	public function extractArchive($archive,$destination_path,$type='tar.gz')
	{
		$result=false;
		
		switch($type)
		{
			case 'tar.gz':
			{
				if (!file_exists($destination_path))
				{
					$this->createDir($destination_path);
				}
				
				$archive=new OS_ArchiverTar($archive,'gz');
				$result=$archive->extract($destination_path);

				break;
			}
		}
		
		return $result;
	}
	
	public function createArchive($source_path,$archive,$strip_from_path='',$type='tar.gz')
	{
		$result=false;
		
		switch($type)
		{
			case 'tar.gz':
			{
				$archiver=new OS_ArchiverTar($archive);
				$result=$archiver->createModify($source_path,'',$strip_from_path);
				
				break;
			}
		}
		
		return $result;
	}
	
	public function areSameDomainUrls($url_1,$url_2)
	{
		$result=false;
		
		$parsed_1=parse_url($url_1);
		$parsed_2=parse_url($url_2);
		
		if ($parsed_1 AND $parsed_2)
		{
			if (!empty($parsed_1['host']) AND !empty($parsed_2['host']))
			{
				if (strtolower($this->stripWWW($parsed_1['host']))==strtolower($this->stripWWW($parsed_2['host'])))
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public function areSameSchemeUrls($url_1,$url_2)
	{
		$result=false;
		
		$parsed_1=parse_url($url_1);
		$parsed_2=parse_url($url_2);
		
		if ($parsed_1 AND $parsed_2)
		{
			if (!empty($parsed_1['scheme']) AND !empty($parsed_2['scheme']))
			{
				if ($parsed_1['scheme']==$parsed_2['scheme'])
				{
					$result=true;
				}
			}
		}
		
		return $result;
	}
	
	public function removePathDottedSegments($path)
	{
		$inSegs=preg_split( '/\//u', $path );
		
		$outSegs=array();
		foreach ($inSegs as $seg)
		{
			if ($seg=='' OR $seg=='.')
			{
				continue;
			}
			if ($seg=='..')
			{
				array_pop($outSegs);
			}
			else
			{
				array_push($outSegs,$seg);
			}
		}
		
		$outPath=implode('/',$outSegs);
		if ($path[0]=='/')
		{
			$outPath='/'.$outPath;
		}

		if ( $outPath!='/' AND (strlen($path)-1)==strrpos($path,'/'))
		{
			$outPath.='/';
		}
		
		return $outPath;
	}
	
	public function joinUrlParts($url_parts)
	{
		$result='';
		
		if (!empty($url_parts['scheme']))
		{
			$result.=$url_parts['scheme'].':';
		}
		
		if (!empty($url_parts['host']))
		{
			$result.='//';
			
			if (!empty($url_patts['user']))
			{
				$result.=$url_parts['user'];
				
				if (!empty($url_parts['pass']))
				{
					$result.=':'.$url_parts['pass'];
				}
				
				$result.='@';
			}
			
			$result.=$url_parts['host'];
			
			if (!empty($url_parts['port']))
			{
				$result.=':'.$url_parts['port'];
			}
			
			if (!empty($url_parts['path']) AND 0!==strpos($url_parts['path'],'/'))
			{
				$result.='/';
			}
		}
			
		if (!empty($url_parts['path']))
		{
			$url_parts['path']=$this->removePathDottedSegments($url_parts['path']);
        	
			$result.=$url_parts['path'];
		}
		
		if (!empty($url_parts['query']))
		{
			$result.='?'.$url_parts['query'];
		}
		
		if (!empty($url_parts['fragment']))
		{
			$result.='#'.$url_parts['fragment'];
		}
		
		return $result;
	}
	
	public function makeAbsoluteUrl($base,$href,$allowedSchemes=array('http','https'))
	{
		if (!$base_parsed=parse_url($base))
		{
			return false;
		}
		
		if (empty($base_parsed['scheme']) OR empty($base_parsed['host']))
		{
			return false;
		}
		
		if (0===strpos($href,'//'))
		{
			return $base_parsed['scheme'].$href;
		}
		
		if (!$href_parsed=parse_url($href))
		{
			return false;
		}
		
		if (!empty($href_parsed['scheme']))
		{
			if ($allowedSchemes AND !in_array($href_parsed['scheme'],$allowedSchemes))
			{
				return false;
			}
			
			return $href;
		}
		
		$href_parsed['scheme']=$base_parsed['scheme'];
		
		if (!empty($href_parsed['host']))
		{
			return $this->joinUrlParts($href_parsed);
		}
		
		if (isset($href_parsed['port']))
		{
			unset($href_parsed['port']);
		}
		if (isset($href_parsed['user']))
		{
			unset($href_parsed['user']);
		}
		if (isset($href_parsed['pass']))
		{
			unset($href_parsed['pass']);
		}
		
		$href_parsed['host']=$base_parsed['host'];
		if (isset($base_parsed['port']))
		{
			$href_parsed['port']=$base_parsed['port'];
		}
		if (isset($base_parsed['user']))
		{
			$href_parsed['user']=$base_parsed['user'];
		}
		if (isset($base_parsed['pass']))
		{
			$href_parsed['pass']=$base_parsed['pass'];
		}
		
		if (empty($href_parsed['path']))
		{
			if (!empty($base_parsed['path']))
			{
				$href_parsed['path']=$base_parsed['path'];
			}
			if (empty($href_parsed['query']) AND !empty($base_parsed['query']))
			{
				$href_parsed['query']=$base_parsed['query'];
			}
			
			return $this->joinUrlParts($href_parsed);
		}
		
		if (0!==strpos($href_parsed['path'],'/'))
		{
			if (empty($base_parsed['path']))
			{
				$basePath='';
			}
			else
			{
				$lastSlash=strrpos($base_parsed['path'],'/');
	
				if (!$lastSlash)
				{
					$basePath='';
				}
				else
				{
					$basePath=substr($base_parsed['path'],0,$lastSlash);
				}
			}
			
			$href_parsed['path']=$basePath.'/'.$href_parsed['path'];
		}
		
		return $this->joinUrlParts($href_parsed);
	}
	
	public function extractRootDomainFromUrl($url)
	{
		$result=false;
		
		if ($host=parse_url($url,PHP_URL_HOST))
		{
			$result=$this->extractRootDomainFromHost($host);
		}
		
		return $result;
	}
	
	public function extractRootDomainFromHost($host)
	{
		$result=$host;
		
		if ($host=explode('.',$host))
		{
			$OS=getOS();
			
			$resource_path=os_join_path($OS->getConfig()->getParam('root_path'),'lib','resources','tlds_and_slds.php');
			
			if (file_exists($resource_path))
			{
				include($resource_path);
				
				if ($tlds=json_decode($tlds,true))
				{
					$host=array_reverse($host);
					
					if (isset($tlds[$host[0]]))
					{
						$root_domain='';
						
						while (count($host)>0 AND isset($tlds[$host[0]]))
						{
							$root_domain=$host[0].(empty($root_domain)?'':'.'.$root_domain);
							
							$tlds=(is_array($tlds[$host[0]])?$tlds[$host[0]]:array());
							
							array_shift($host);
						}
						
						if (!empty($host))
						{
							$root_domain=$host[0].'.'.$root_domain;
						}
						
						$result=$root_domain;
					}
				}
			}
		}
		
		return $result;
	}
	
	public function humanizeDate($date,$format='datetime')
	{
		$result=false;
		
		$formats=array(
			'datetime'=>"M d, Y \a\\t H:i",
			'date'=>"M d, Y",
			'day'=>"M d",
			'time'=>"H:i"
		);
		
		if ($date=strtotime($date))
		{
			$result=date($formats[$format],$date);
		}
		
		return $result;
	}
	
	public function humanizeYesNo($value)
	{
		$result=false;
		
		$values=array(''=>_('No'),'N'=>_('No'),'Y'=>_('Yes'));
		
		if (isset($values[$value]))
		{
			$result=$values[$value];
		}
		
		return $result;
	}
	
	public function humanizeTime($seconds)
	{
		$time=array('value'=>$seconds,'unit'=>($seconds==1?_('second'):_('seconds')));
		
		if ($time['value']/60>1)
		{
			$time=array('value'=>floor($time['value']/60),'unit'=>(floor($time['value']/60)==1?_('minute'):_('minutes')));
			
			if ($time['value']/60>1)
			{
				$time=array('value'=>floor($time['value']/60),'unit'=>(floor($time['value']/60)==1?_('hour'):_('hours')));
				
					if ($time['value']/24>1)
					{
						$time=array('value'=>floor($time['value']/24),'unit'=>(floor($time['value']/24)==1?_('day'):_('days')));
						
						if ($time['value']/30>1)
						{
							$time=array('value'=>floor($time['value']/30),'unit'=>(floor($time['value']/30)==1?_('month'):_('months')));
							
							if ($time['value']/12>1)
							{
								$time=array('value'=>floor($time['value']/12),'unit'=>(floor($time['value']/12)==1?_('year'):_('years')));
							}
						}
					}
			}
		}
		
		return $time['value'].' '.$time['unit'];
	}
	
	public function humanizeSize($bytes)
	{
		$sizes=array('B','KB','MB','GB','TB');
		
		$i=0;
		while (isset($sizes[$i]) AND $bytes/pow(1024,$i)>1)
		{
			$i++;
		}
		
		if ($i>0)
		{
			$i--;
		}
		
		return round($bytes/pow(1024,$i),2).' '.$sizes[$i];
	}
	
	public function humanizeArray($array,$max_depth=2,$depth=0,$output='html')
	{
		$result='';
		
		if ($output=='html')
		{
			$spacer="&nbsp;";
			$newline="<br>";
		}
		elseif ($output=='text')
		{
			$spacer=' ';
			$newline="\n";
		}
		
		foreach ($array as $key=>$val)
		{
			if ($output=='html')
			{
				$key="<strong>{$key}</strong>";
			}
			
			$result.=str_repeat($spacer,$depth*4).$key;
			
			if (is_array($val) AND $depth<$max_depth)
			{
				$result.=$newline.$this->humanizeArray($val,$max_depth,$depth+1,$output);
			}
			else
			{
				$result.=var_export($val,true).$newline;
			}
		}
		
		return $result;
	}
	
	public function humanizeInteger($integer,$settings=array())
	{
		if (empty($settings['decimals']))
		{
			$settings['decimals']=0;
		}
		
		if (empty($settings['decimals_separator']))
		{
			$settings['decimals_separator']='.';
		}
		
		if (empty($settings['thousands_separator']))
		{
			$settings['thousands_separator']=',';
		}
		
		return number_format($integer,$settings['decimals'],$settings['decimals_separator'],$settings['thousands_separator']);
	}
	
	public function colorHexToRgb($color)
	{
	    if ($color[0] == '#')
	    {
	    	$color = substr($color, 1);
	    }
	
	    if (strlen($color) == 6)
	    {
	        list($r, $g, $b) = array($color[0].$color[1],$color[2].$color[3],$color[4].$color[5]);
	    }
	    elseif (strlen($color) == 3)
	    {
	        list($r, $g, $b) = array($color[0].$color[0], $color[1].$color[1], $color[2].$color[2]);
	    }
	    else
		{
	        return false;
		}
	
	    $r = hexdec($r); $g = hexdec($g); $b = hexdec($b);
	
	    return array('red'=>$r, 'green'=>$g, 'blue'=>$b);
	}
	
	public function getMedianValue($values)
	{
		$result=false;
		
		if (sort($values))
		{
			$count=count($values);
			$middle=floor(($count-1)/2);
			
			if ($count%2)
			{
				$result=$values[$middle];
			}
			else
			{
				$result=($values[$middle]+$values[$middle+1])/2;
			}
		}
		
		return $result;
	}
	
	public function convertTimezone($format,$date,$to_timezone,$from_timezone='UTC')
	{
		$result=false;

		$original_timezone=date_default_timezone_get();
		$current_timezone=$original_timezone;
		
		if ($from_timezone!=false AND $original_timezone!=$from_timezone)
		{
			date_default_timezone_set($from_timezone);
			$current_timezone=$from_timezone;
		}
		
		if ($timestamp=strtotime($date))
		{
			date_default_timezone_set($to_timezone);
			$current_timezone=$to_timezone;
			
			$result=date($format,$timestamp);
		}
		
		if ($original_timezone!=$current_timezone)
		{
			date_default_timezone_set($original_timezone);
		}
		
		return $result;
	}
	
	public function serializeObject($object)
	{
		return base64_encode(json_encode($object));
	}
	
	public function unserializeObject($serialized)
	{
		return  json_decode(base64_decode($serialized),true);
	}
	
	public function confRead($filename)
	{
		$result = false;
		if(file_exists($filename))
		{
			$result = parse_ini_file($filename,true);
		}
		
		return $result;
	}
	
	public function confWrite($filename, $data)
	{
		$result = false;
		
		if(!empty($data))
		{
			if(is_array($data))
			{
				$boolArr = array('true','false');
				
				$output = ";<?php exit; ?>\n";
				
				foreach($data as $var => $val )
				{
			    	if(is_array($val))
			    	{//config file has sections 
			    		$output .= "[{$var}]\n";
			    		
			    		foreach($val as $subvar => $subval)
			    		{
			    			if((!in_array($subval,$boolArr)) && (!is_numeric($subval))) $subval = '"'.$subval.'"';
			    			
			    			$output .=  $subvar." = ".$subval."\n";	
			    		}
			    	}
			    	else
			    	{
		    			if((!in_array($val,$boolArr)) && (!is_numeric($val))) $val = '"'.$val.'"';
		    			
			    		$output .= $var." = ".$val."\n";	
			    	}
			    }
								
			    $result = $this->fileWrite($filename, $output);
			}
		}
		return $result;
	}
	
	public function jsonRead($filename)
	{
		$result = false;
		if(file_exists($filename))
		{
			$data = $this->fileRead($filename);
			
			if(!empty($data))
			{
				//remove the first line from file
				$data = substr($data, 14);
				
				$result = json_decode($data, true);
			}
		}
		
		return $result;
	}
	
	public function jsonWrite($filename, $data)
	{
		$result = false;
		
		if(!empty($data))
		{
			if(is_array($data))
			{
				$output = "<?php exit; ?>\n";
				$output .= json_encode($data);

				$result = $this->fileWrite($filename, $output);
			}
		}
		return $result;
	}
	
	public function fileRead($filename)
	{
		return file_get_contents($filename);
	}
	
	public function fileWrite($filename, $txt, $mode = 0755)
	{
		$result = false;
		
		$dirname = dirname($filename);
		
		if(!is_dir($dirname))
		{
			$this->createDir($dirname, $mode);
		}
		
		$fp = fopen($filename, 'w');
		
		if($fp)
		{
			$canWrite = false;
			while (!$canWrite)
			{
				$canWrite = flock($fp, LOCK_EX);
				if( !$canWrite ) 
				{ 
					$miliSeconds = rand(0, 20); 
					usleep(round($miliSeconds*100000));
				}
			}
			
			$result = fwrite($fp, $txt); flock($fp, LOCK_UN);
			fclose($fp);
			@chmod($filename, $mode);
		}
		
		return $result;
	} 
	
	public function jsonIndent($json)
	{
		$result = false;
		
		$pos = 0;
		$strLen = strlen($json);
		$indentStr = "\t";
		$newLine = "\n";
		
		for ($i = 0; $i < $strLen; $i++)
		{
			$char = $json[$i];
			
			if ($char == '"')
			{
				if (!preg_match('`"(\\\\\\\\|\\\\"|.)*?"`s', $json, $m, null, $i))
				{
					return $json;
				}
				
				$result .= $m[0];
				$i += strLen($m[0]) - 1;
				
				continue;
			}
			elseif ($char == '}' || $char == ']')
			{
				$result .= $newLine;
				$pos --;
				$result .= str_repeat($indentStr, $pos);
			}
			
			$result .= $char;
			
			if ($char == ',' || $char == '{' || $char == '[')
			{
				$result .= $newLine;
				
				if ($char == '{' || $char == '[')
				{
					$pos ++;
				}
				
				$result .= str_repeat($indentStr, $pos);
			}
		}
		
		return $result;
	}
	
	public function jsonify($array)
	{
		return json_encode($array);
	}	
	
	public function csvify($header,$array)
	{
		$result='';
		
		foreach ($header as $column=>$column_name)
		{
			$result.=(empty($result)?'':',').$column_name;
		}
		
		foreach ($array as $element)
		{
			$line='';
			
			foreach ($header as $column=>$column_name)
			{
				$line.=(empty($line)?'':',').$element[$column];
			}
			
			$result.="\n".$line;
		}
		
		return $result;
	}
	
	public function detectOperatingSystem()
	{
		$result=false;
		
		if (isset($this->instanceCache['os']))
		{
			return $this->instanceCache['os'];
		}
		
		if (substr(strtolower(PHP_OS),0,3)=='win')
		{
			$result='windows';
		}
		else
		{
			$result='linux';
		}
		
		$this->instanceCache['os']=$result;
		
		return $result;
	}
	
	public function guessPHPDir()
	{
		$result=false;
		
		if (isset($this->instanceCache['php_dir']))
		{
			return $this->instanceCache['php_dir'];
		}
		elseif (!$result=getOS()->getConfig()->getParam('php_dir'))
		{
			$current_os=$this->detectOperatingSystem();
			
			if ($current_os=='windows')
			{
				if (isset($_SERVER['PHPRC']))
				{
					$path=$_SERVER['PHPRC'];
				}
			}
			elseif ($current_os=='linux')
			{
				if (isset($_SERVER['_']))
				{
					$path=$_SERVER['_'];
				}
			}
	
			if (!$result)
			{
				if (defined('PHP_BINDIR'))
				{
					$path=PHP_BINDIR;
				}
			}
		}
		else
		{
			return $result;
		}
		
		if ($rpath=@realpath($path))
		{
			$path=$rpath;
		}
		
		if ($this->getPHPCLIVersion($path))
		{
			$result=$path;
		}
		
		$this->instanceCache['php_dir']=$result;
		
		return $result;
	}
	
	public function getPHPCLI($php_dir=false)
	{
		$result=false;
		
		if (isset($this->instanceCache['php_cli']))
		{
			return $this->instanceCache['php_cli'];
		}
		
		if (!$php_dir)
		{
			$php_dir=$this->guessPHPDir();
		}
		
		if ($php_dir)
		{
			$test=os_join_path($php_dir,'php-cli');
			
			exec($test.' -v',$output,$return_value);
			
			if ($return_value==0)
			{
				$result=$test;
			}
			else
			{
				$test=os_join_path($php_dir,'php');
			
				exec($test.' -v',$output,$return_value);
				
				if ($return_value==0)
				{
					$result=$test;
				}
			}
		}
		
		$this->instanceCache['php_cli']=$result;
		
		return $result;
	}
	
	public function getPHPCLIVersion($php_dir)
	{
		$result=false;
		
		if (isset($this->instanceCache['php_cli_version']))
		{
			return $this->instanceCache['php_cli_version'];
		}
		
		if ($php_cli=$this->getPHPCLI($php_dir))
		{
			$command=$php_cli.' -v';
	
			exec($command,$output,$return_value);
			
			if ($return_value==0)
			{
				if (!empty($output))
				{
					$output=explode(' ',$output[0]);
					
					if (!empty($output[1]))
					{
						$result=$output[1];
					}
				}
			}
		}
		
		$this->instanceCache['php_cli_version']=$result;
		
		return $result;
	}
	
	public function getTextDimensions($text,$size='12',$font='arial')
	{
		$result=false;
		
		$font_path=os_join_path(getOS()->getConfigVar('root_path'),'lib','fonts',$font.'.ttf');
		
		if (file_exists($font_path))
		{
			if ($bbox=imagettfbbox($size,0,$font_path,$text))
			{
				$result=array(
					'width'=>abs($bbox[4]-$bbox[0]),
					'height'=>abs($bbox[1]-$bbox[7])
				);
			}
		}
		
		return $result;
	}
	
	public function execForked($command)
	{
		$result=false;
		
		$current_os=$this->detectOperatingSystem();
 
		$to_execute=false;
		switch($current_os)
		{
			case 'linux':
			{
				$to_execute="{$command} >/dev/null 2>/dev/null &";
				break;
			}
			case 'windows':
			{
				$to_execute='start /B cmd /C "'.$command.' >NUL 2>NUL"';
				break;
			}
		}

		if ($to_execute)
		{
			if ($process=popen($to_execute,'r'))
			{
				pclose($process);
				$result=true;
			}
		}
		
		return $result;
	}
	
	// Generate a random crypt key of length $len
	public function generateCryptKey($len, $readable = false, $hash = false)
	{
		$key = '';
		if ($hash)
		{
			$key = substr(sha1(uniqid(rand(), true)), 0, $len);
		}
		elseif($readable)
		{
			$chars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
			for ($i = 0; $i < $len; ++$i)
			{
				$key .= substr($chars, (mt_rand() % strlen($chars)), 1);
			}
		}
		else
		{
			for ($i = 0; $i < $len; ++$i)
			{
				$key .= chr(mt_rand(33, 126));
			}
		}
				
		return $key;
	}
	
	public function generateHash($args, $length = false, $cryptKey = false)
	{
		$result = false;
		
		if(is_array($args))
		{
			$string = implode("",$args);
		}
		else
		{
			$string = $args;
		} 
		
		if(!empty($string))
		{
			$os_crypt_key = ($cryptKey ? $cryptKey : getOS()->getConfigVar('crypt_key'));
			
			$result = $this->generateKrypt($string, $os_crypt_key);
			
			if($length !== false) if(is_numeric($length))
			{
				$result = substr($result, 0, $length);	
			}
		}
		return $result;
	}
		
	public function stringEncode($string, $key)
	{
		if (function_exists('mcrypt_encrypt'))
		{
			return base64_encode(mcrypt_encrypt(MCRYPT_RIJNDAEL_256, md5($key), $string, MCRYPT_MODE_CBC, md5(md5($key))));
		}
		else
		{
			return base64_encode($string);
		}
	}
	
	public function stringDecode($string, $key)
	{
		if (function_exists('mcrypt_decrypt'))
		{
			return rtrim(mcrypt_decrypt(MCRYPT_RIJNDAEL_256, md5($key), base64_decode($string), MCRYPT_MODE_CBC, md5(md5($key))), "\0");
		}
		else
		{
			return trim(base64_decode($string));
		}
	}
	
	public function generateKrypt($str, $salt)
	{
		return sha1($salt.sha1($str));
	}
	
	public function generateAuthCode()
	{
		return strtoupper(substr(base64_encode(uniqid(time())), -9, 8));
	}
	
	function codePack($first_item, $second_item)
	{
		$first_item+=$second_item;
		return base_convert($this->codeChecksum($first_item*10+$this->codeChecksum($first_item)).$first_item.$this->codeChecksum($first_item),10,36).'.'.base_convert($this->codeChecksum($second_item*10+$this->codeChecksum($second_item)).$second_item.$this->codeChecksum($second_item),10,36);
	}
	
	function codeUnpack($packed)
	{
		$temp = explode('.',str_replace('_','.',$packed));
		$response = array();
		foreach ($temp as $x)
			{
			$x=base_convert($x,36,10);
			$c1=$x[0];
			$xi=$x-$c1*pow(10,strlen($x)-1);
			if ($c1!=$this->codeChecksum($xi)) return false;
			$c2=$xi%10;
			$xf=floor($xi/10);
			if ($c2!=$this->codeChecksum($xf)) return false;
			$response[]=$xf;
			}
		foreach ($response as $key=>$val) if (isset($response[$key+1])) $response[$key]=$val-$response[$key+1];
		return $response;
	}
	
	public function codeChecksum($number)
	{
		while ($number>=10)
		{
			$temp=$number;$number=0;
			while ($temp)
			{
				$number+=$temp % 10;
				$temp=floor($temp/10);
			}
		}
		return $number;
	}	
}
?>