<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_Validator
{
	private static $_instance;
	
	protected function __construct() {}
	
	public $ERROR	=	"";

	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_Validator();
		}
		return self::$_instance;
	}

	function has_html($text = "")
	{
		if(empty($text))
		{
			return false;
		}
		
		$New = htmlspecialchars($text);
		if($New == $text)
		{
			return false;
		}
		return true;
	}
	
	
	//	************************************************************
	//	Valid email format? true or false
	//	This checks the raw address, not RFC 822 addresses.

	//Looks for [something]@[valid hostname with DNS record]

	function is_email ($Email = "")
	{
	/*
		if(empty($Address))
		{
			$this->ERROR = "is_email: No email address submitted";
			return false;
		}

		if(!preg_match("@",$Address))
		{
			$this->ERROR = "is_email: Invalid, no @ symbol in string";
			return false;
		}
		
		list($User,$Host) = preg_split("/@/",$Address);

		if ( (empty($User)) or (empty($Address)) )
		{
			$this->ERROR = "is_email: missing data [$User]@[$Host]";
			return false;
		}
		if( ($this->has_space($User)) or ($this->has_space($Host)) )
		{
			$this->ERROR = "is_email: Whitespace in [$User]@[$Host]";
			return false;
		}

		// Can't look for an MX only record as that precludes
		// CNAME only records. Thanks to everyone that slapped
		// me upside the head for this glaring oversite. :)

		if(!$this->is_host($Host,"ANY"))		{ return false; }

		return true;
		*/
		
		global $HTTP_HOST; 
		if (!preg_match("/^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,4})$/i", $Email))
			{ 
			$this->ERROR = "$Email is not properly formatted"; 
			return false;
		    } 
		list ( $Username, $Domain ) = preg_split("/@/",$Email); 
		if(strtolower($Username)=='abuse')
			{ 
			$this->ERROR = "$Email is wrong"; 
			return false;
		    } 
		if(!$this->is_host($Domain,"ANY"))  return false;
		/*
		if (getmxrr($Domain, $MXHost)) $ConnectAddress = $MXHost[0]; 
		else $ConnectAddress = $Domain; 
		$errno=0; $errstr='';
		$Connect = fsockopen ( $ConnectAddress, 25, $errno, $errstr, 2 ); 
		if ($Connect)
			{ 
			if (preg_match("^220", $Out = fgets($Connect, 1024)))
				{ 
				fputs ($Connect, "HELO $HTTP_HOST\r\n"); 
				$Out = fgets ( $Connect, 1024 ); 
				fputs ($Connect, "MAIL FROM: <{$Email}>\r\n"); 
				$From = fgets ( $Connect, 1024 ); 
				fputs ($Connect, "RCPT TO: <{$Email}>\r\n"); 
				$To = fgets ($Connect, 1024); 
				fputs ($Connect, "QUIT\r\n"); 
				fclose($Connect); 
				if (!preg_match ("^250", $From) || !preg_match ( "^250", $To ))
					{ 
					$this->ERROR = "Server rejected address"; 
					return false;
					} 
				}
			else{ 
				$this->ERROR = "No response from server"; 
				return false;
				}
			}
		else{ 
			$this->ERROR = "Can not connect E-Mail server."; 
			return false;
		    } 
		*/
		$this->ERROR = "$Email appears to be valid."; 
		return true;
	}

//	************************************************************
//	Valid URL format? true or false

//	Checks format of a URL - does NOT handle query strings or
//	urlencoded data.

	function is_url ($Url = "")
	{
		if (empty($Url))
		{
			$this->ERROR = "is_url: No URL submitted";
			return false;
		}
		if (strlen($Url)<10)
		{
			$this->ERROR = "is_url: Incomplete URL submitted";
			return false;
		}
		if (strpos(strtolower($Url),'http://http://')===0)
		{
			$this->ERROR = "is_url: Bad URL submitted";
			return false;
		}
		$tmpUrl=$Url;
		if (strpos(str_replace('http:/','',$tmpUrl),'//')===0)
		{
			$this->ERROR = "is_url: Bad URL submitted";
			return false;
		}


		// Wow, the magic of parse_url!

		@$UrlElements = parse_url($Url);
		if( (empty($UrlElements)) or (!$UrlElements) )
		{
			$this->ERROR = "is_url: Parse error reading [$Url]";
			return false;
		}

		if(empty($UrlElements['scheme']))
		{
			$this->ERROR = "is_url: Missing protocol declaration";
			return false;
		}

		if(empty($UrlElements['host']))
		{
			$this->ERROR = "is_url: No hostname in URL";
			return false;
		}

		$scheme		= $UrlElements['scheme'];
		$HostName	= $UrlElements['host'];

		if (!preg_match("/^(ht|f)tp/i",$scheme))
		{
			$this->ERROR = "is_url: No http:// or ftp://";
			return false;
		}

		if(!$this->is_hostname($HostName))	{ return false; }

		return true;
	}

	function is_hostname ($hostname = "")
	{
		$web = false;

		if(empty($hostname))
		{
			$this->ERROR = "is_hostname: No hostname submitted";
			return false;
		}

		// Only a-z, 0-9, and "-" or "." are permitted in a hostname

		// Patch for POSIX regex lib by Sascha Schumann sas@schell.de
		$Bad = preg_replace("/[-A-Z0-9\.]/i","",$hostname);
		
		if(!empty($Bad))
		{
			$this->ERROR = "is_hostname: invalid chars [$Bad]";
			return false;
		}

		// See if we're doing www.hostname.tld or hostname.tld
		if(preg_match("/^www\./i",$hostname))
		{
			$web = true;
		}

		// double "." is a not permitted
		if(preg_match("/\.\./",$hostname))
		{
			$this->ERROR = "is_hostname: Double dot in [$hostname]";
			return false;
		}
		if(preg_match("/^\./",$hostname))
		{
			$this->ERROR = "is_hostname: leading dot in [$hostname]";
			return false;
		}

		$chunks = explode(".",$hostname);

		if( (gettype($chunks)) != "array")
		{
			$this->ERROR = "is_hostname: Invalid hostname, no dot seperator [$hostname]";
			return false;
		}

		$count = ( (count($chunks)) - 1);

		if($count < 1)
		{
			$this->ERROR = "is_hostname: Invalid hostname [$count] [$hostname]\n";
			return false;
		}

		// Bug that can't be killed without doing an is_host,
		// something.something will return TRUE, even if it's something
		// stupid like NS.SOMETHING (with no tld), because SOMETHING is
		// construed to BE the tld.  The is_bigfour and is_country
		// checks should help eliminate this inconsistancy. To really
		// be sure you've got a valid hostname, do an is_host() on it.

		if( ($web) and ($count < 2) )
		{
			$this->ERROR = "is_hostname: Invalid hostname [$count] [$hostname]\n";
			return false;
		}

		$tld = $chunks[$count];

		if(empty($tld))
		{
			$this->ERROR = "is_hostname: No TLD found in [$hostname]";
			return false;
		}

		if(!$this->is_bigfour($tld))
		{
			if(!$this->is_country($tld))
			{
				$this->ERROR = "is_hostname: Unrecognized TLD [$tld]";
				return false;
			}
		}
		
		return true;
	}

//	************************************************************

	function is_bigfour ($tld)
	{
		if(empty($tld))
		{
			return false;
		}
		if(preg_match("/^\./i",$tld))
		{
			$tld = preg_replace("/^\./i","",$tld);
		}
		$BigFour = array ('com'=>'com','biz'=>'biz','edu'=>'edu','net'=>'net','org'=>'org','info'=>'info','eu'=>'eu','asia'=>'asia','mobi'=>'mobi','tel'=>'tel','mil'=>'mil');
		$tld = strtolower($tld);

		if(isset($BigFour[$tld]))
		{
			return true;
		}

		return false;
	}
	
//	************************************************************
//	Hostname is a reachable internet host? true or false

	function is_host ($hostname = "", $type = "ANY")
	{
		if(empty($hostname))
		{
			$this->ERROR = "is_host: No hostname submitted";	
			return false;
		}

		if(!$this->is_hostname($hostname))	{ return false; }

		if(!checkdnsrr($hostname,$type))
		{
			$this->ERROR = "is_host: no DNS records for [$hostname].";
			return false;
		}

		return true;
	}
//	************************************************************
//	Valid, fully qualified hostname? true or false
//	Checks the -syntax- of the hostname, not it's actual
//	validity as a reachable internet host

/*	
	function is_hostname ($hostname = "")
	{
		$web = false;

		if(empty($hostname))
		{
			$this->ERROR = "is_hostname: No hostname submitted";
			return false;
		}

		// Only a-z, 0-9, and "-" or "." are permitted in a hostname

		// Patch for POSIX regex lib by Sascha Schumann sas@schell.de
		$Bad = preg_replace("/[-A-Z0-9\.]/i","",$hostname);

		if(!empty($Bad))
		{
			$this->ERROR = "is_hostname: invalid chars [$Bad]";
			return false;
		}

		// See if we're doing www.hostname.tld or hostname.tld
		if(preg_match("/^www\./i",$hostname))
		{
			$web = true;
		}

		// double "." is a not permitted
		if(preg_match("/\.\./",$hostname))
		{
			$this->ERROR = "is_hostname: Double dot in [$hostname]";
			return false;
		}
		if(preg_match("/^\./",$hostname))
		{
			$this->ERROR = "is_hostname: leading dot in [$hostname]";
			return false;
		}

		$chunks = explode(".",$hostname);

		if( (gettype($chunks)) != "array")
		{
			$this->ERROR = "is_hostname: Invalid hostname, no dot seperator [$hostname]";
			return false;
		}

		$count = ( (count($chunks)) - 1);

		if($count < 1)
		{
			$this->ERROR = "is_hostname: Invalid hostname [$count] [$hostname]\n";
			return false;
		}

		// Bug that can't be killed without doing an is_host,
		// something.something will return TRUE, even if it's something
		// stupid like NS.SOMETHING (with no tld), because SOMETHING is
		// construed to BE the tld.  The is_bigfour and is_country
		// checks should help eliminate this inconsistancy. To really
		// be sure you've got a valid hostname, do an is_host() on it.

		if( ($web) and ($count < 2) )
		{
			$this->ERROR = "is_hostname: Invalid hostname [$count] [$hostname]\n";
			return false;
		}

		$tld = $chunks[$count];

		if(empty($tld))
		{
			$this->ERROR = "is_hostname: No TLD found in [$hostname]";
			return false;
		}

		if(!$this->is_bigfour($tld))
		{
			if(!$this->is_country($tld))
			{
				$this->ERROR = "is_hostname: Unrecognized TLD [$tld]";
				return false;
			}
		}
		
		return true;
	}
*/	
	

	function is_country ($countrycode = "")
	{
		$Return = "";

		if(empty($countrycode))
		{
			$this->ERROR = "is_country: No country code submitted";
			return $Return;
		}

		$countrycode = strtolower($countrycode);

		if( (strlen($countrycode)) != 2 )
		{
			$this->ERROR = "is_country: 2 digit codes only [$countrycode]";
			return $Return;
		}

		//	Now for a really big array

		//	Dominican Republic, cc = "do" because it's a reserved
		//	word in PHP. That parse error took 10 minutes of
		//	head-scratching to figure out :)

		//	A (roughly) 3.1 Kbyte array

		$CCodes =	array (

				"do"	=>	"Dominican Republic",
				'ad'	=>	"Andorra",
				'ae'	=>	"United Arab Emirates",
				'af'	=>	"Afghanistan",
				'ag'	=>	"Antigua and Barbuda",
				'ai'	=>	"Anguilla",
				'al'	=>	"Albania",
				'am'	=>	"Armenia",
				'an'	=>	"Netherlands Antilles",
				'ao'	=>	"Angola",
				'aq'	=>	"Antarctica",
				'ar'	=>	"Argentina",
				'as'	=>	"American Samoa",
				'at'	=>	"Austria",
				'au'	=>	"Australia",
				'aw'	=>	"Aruba",
				'az'	=>	"Azerbaijan",
				'ba'	=>	"Bosnia Hercegovina",
				'bb'	=>	"Barbados",
				'bd'	=>	"Bangladesh",
				'be'	=>	"Belgium",
				'bf'	=>	"Burkina Faso",
				'bg'	=>	"Bulgaria",
				'bh'	=>	"Bahrain",
				'bi'	=>	"Burundi",
				'bj'	=>	"Benin",
				'bm'	=>	"Bermuda",
				'bn'	=>	"Brunei Darussalam",
				'bo'	=>	"Bolivia",
				'br'	=>	"Brazil",
				'bs'	=>	"Bahamas",
				'bt'	=>	"Bhutan",
				'bv'	=>	"Bouvet Island",
				'bw'	=>	"Botswana",
				'by'	=>	"Belarus (Byelorussia)",
				'bz'	=>	"Belize",
				'ca'	=>	"Canada",
				'cc'	=>	"Cocos Islands",
				'cd'	=>	'Congo, The Democratic Republic of the',
				'cf'	=>	"Central African Republic",
				'cg'	=>	"Congo",
				'ch'	=>	"Switzerland",
				'ci'	=>	"Ivory Coast",
				'ck'	=>	"Cook Islands",
				'cl'	=>	"Chile",
				'cm'	=>	"Cameroon",
				'cn'	=>	"China",
				'co'	=>	"Colombia",
				'cr'	=>	"Costa Rica",
				'cs'	=>	"Czechoslovakia",
				'cu'	=>	"Cuba",
				'cv'	=>	"Cape Verde",
				'cx'	=>	"Christmas Island",
				'cy'	=>	"Cyprus",
				'cz'	=>	'Czech Republic',
				'de'	=>	"Germany",
				'dj'	=>	"Djibouti",
				'dk'	=>	"Denmark",
				'dm'	=>	"Dominica",
				'dz'	=>	"Algeria",
				'ec'	=>	"Ecuador",
				'ee'	=>	"Estonia",
				'eg'	=>	"Egypt",
				'eh'	=>	"Western Sahara",
				'er'	=>	'Eritrea',
				'es'	=>	"Spain",
				'et'	=>	"Ethiopia",
				'fi'	=>	"Finland",
				'fj'	=>	"Fiji",
				'fk'	=>	"Falkland Islands",
				'fm'	=>	"Micronesia",
				'fo'	=>	"Faroe Islands",
				'fr'	=>	"France",
				'fx'	=>	'France, Metropolitan FX',
				'ga'	=>	"Gabon",
				'gb'	=>	'United Kingdom (Great Britain)',
				'gd'	=>	"Grenada",
				'ge'	=>	"Georgia",
				'gf'	=>	"French Guiana",
				'gh'	=>	"Ghana",
				'gi'	=>	"Gibraltar",
				'gl'	=>	"Greenland",
				'gm'	=>	"Gambia",
				'gn'	=>	"Guinea",
				'gp'	=>	"Guadeloupe",
				'gq'	=>	"Equatorial Guinea",
				'gr'	=>	"Greece",
				'gs'	=>	'South Georgia and the South Sandwich Islands',
				'gt'	=>	"Guatemala",
				'gu'	=>	"Guam",
				'gw'	=>	"Guinea-bissau",
				'gy'	=>	"Guyana",
				'hk'	=>	"Hong Kong",
				'hm'	=>	"Heard and McDonald Islands",
				'hn'	=>	"Honduras",
				'hr'	=>	"Croatia",
				'ht'	=>	"Haiti",
				'hu'	=>	"Hungary",
				'id'	=>	"Indonesia",
				'ie'	=>	"Ireland",
				'il'	=>	"Israel",
				'in'	=>	"India",
				'io'	=>	"British Indian Ocean Territory",
				'iq'	=>	"Iraq",
				'ir'	=>	"Iran",
				'is'	=>	"Iceland",
				'it'	=>	"Italy",
				'jm'	=>	"Jamaica",
				'jo'	=>	"Jordan",
				'jp'	=>	"Japan",
				'ke'	=>	"Kenya",
				'kg'	=>	"Kyrgyzstan",
				'kh'	=>	"Cambodia",
				'ki'	=>	"Kiribati",
				'km'	=>	"Comoros",
				'kn'	=>	"Saint Kitts and Nevis",
				'kp'	=>	"North Korea",
				'kr'	=>	"South Korea",
				'kw'	=>	"Kuwait",
				'ky'	=>	"Cayman Islands",
				'kz'	=>	"Kazakhstan",
				'la'	=>	"Laos",
				'lb'	=>	"Lebanon",
				'lc'	=>	"Saint Lucia",
				'li'	=>	"Lichtenstein",
				'lk'	=>	"Sri Lanka",
				'lr'	=>	"Liberia",
				'ls'	=>	"Lesotho",
				'lt'	=>	"Lithuania",
				'lu'	=>	"Luxembourg",
				'lv'	=>	"Latvia",
				'ly'	=>	"Libya",
				'ma'	=>	"Morocco",
				'mc'	=>	"Monaco",
				'md'	=>	"Moldova Republic",
				'me'	=>	"Montenegro",
				'mg'	=>	"Madagascar",
				'mh'	=>	"Marshall Islands",
				'mk'	=>	"Macedonia, The Former Yugoslav Republic of",
				'ml'	=>	"Mali",
				'mm'	=>	"Myanmar",
				'mn'	=>	"Mongolia",
				'mo'	=>	"Macau",
				'mp'	=>	"Northern Mariana Islands",
				'mq'	=>	"Martinique",
				'mr'	=>	"Mauritania",
				'ms'	=>	"Montserrat",
				'mt'	=>	"Malta",
				'mu'	=>	"Mauritius",
				'mv'	=>	"Maldives",
				'mw'	=>	"Malawi",
				'mx'	=>	"Mexico",
				'my'	=>	"Malaysia",
				'mz'	=>	"Mozambique",
				'na'	=>	"Namibia",
				'nc'	=>	"New Caledonia",
				'ne'	=>	"Niger",
				'nf'	=>	"Norfolk Island",
				'ng'	=>	"Nigeria",
				'ni'	=>	"Nicaragua",
				'nl'	=>	"Netherlands",
				'no'	=>	"Norway",
				'np'	=>	"Nepal",
				'nr'	=>	"Nauru",
				'nt'	=>	"Neutral Zone",
				'nu'	=>	"Niue",
				'nz'	=>	"New Zealand",
				'om'	=>	"Oman",
				'pa'	=>	"Panama",
				'pe'	=>	"Peru",
				'pf'	=>	"French Polynesia",
				'pg'	=>	"Papua New Guinea",
				'ph'	=>	"Philippines",
				'pk'	=>	"Pakistan",
				'pl'	=>	"Poland",
				'pm'	=>	"St. Pierre and Miquelon",
				'pn'	=>	"Pitcairn",
				'pr'	=>	"Puerto Rico",
				'pt'	=>	"Portugal",
				'pw'	=>	"Palau",
				'py'	=>	"Paraguay",
				'qa'	=>	'Qatar',
				're'	=>	"Reunion",
				'ro'	=>	"Romania",
				'ru'	=>	"Russia",
				'rw'	=>	"Rwanda",
				'sa'	=>	"Saudi Arabia",
				'sb'	=>	"Solomon Islands",
				'sc'	=>	"Seychelles",
				'sd'	=>	"Sudan",
				'se'	=>	"Sweden",
				'sg'	=>	"Singapore",
				'sh'	=>	"St. Helena",
				'si'	=>	"Slovenia",
				'sj'	=>	"Svalbard and Jan Mayen Islands",
				'sk'	=>	'Slovakia (Slovak Republic)',
				'sl'	=>	"Sierra Leone",
				'sm'	=>	"San Marino",
				'sn'	=>	"Senegal",
				'so'	=>	"Somalia",
				'sr'	=>	"Suriname",
				'st'	=>	"Sao Tome and Principe",
				'sv'	=>	"El Salvador",
				'sy'	=>	"Syria",
				'sz'	=>	"Swaziland",
				'tc'	=>	"Turks and Caicos Islands",
				'td'	=>	"Chad",
				'tf'	=>	"French Southern Territories",
				'tg'	=>	"Togo",
				'th'	=>	"Thailand",
				'tj'	=>	"Tajikistan",
				'tk'	=>	"Tokelau",
				'tm'	=>	"Turkmenistan",
				'tn'	=>	"Tunisia",
				'to'	=>	"Tonga",
				'tp'	=>	"East Timor",
				'tr'	=>	"Turkey",
				'tt'	=>	"Trinidad, Tobago",
				'tv'	=>	"Tuvalu",
				'tw'	=>	"Taiwan",
				'tz'	=>	"Tanzania",
				'ua'	=>	"Ukraine",
				'ug'	=>	"Uganda",
				'uk'	=>	"United Kingdom",
				'um'	=>	"United States Minor Islands",
				'us'	=>	"United States of America",
				'uy'	=>	"Uruguay",
				'uz'	=>	"Uzbekistan",
				'va'	=>	"Vatican City",
				'vc'	=>	"Saint Vincent, Grenadines",
				've'	=>	"Venezuela",
				'vg'	=>	"Virgin Islands (British)",
				'vi'	=>	"Virgin Islands (USA)",
				'vn'	=>	"Viet Nam",
				'vu'	=>	"Vanuatu",
				'wf'	=>	'Wallis and Futuna Islands',
				'ws'	=>	"Samoa",
				'ye'	=>	'Yemen',
				'yt'	=>	'Mayotte',
				'yu'	=>	"Yugoslavia",
				'za'	=>	"South Africa",
				'zm'	=>	"Zambia",
				'zr'	=>	"Zaire",
				'zw'	=>	"Zimbabwe"
		);


		if(isset($CCodes[$countrycode]))
		{
			$Return = $CCodes[$countrycode];
		}
		else
		{
			$this->ERROR = "is_country: Unrecognized country code [$countrycode]";
			$Return = "";
		}

		// make sure this monster is removed from memory

		unset($CCodes);

		return ($Return);

	}	// end is_country
	
	
	public function isValidIP($ip_addr)
	{
		//first of all the format of the ip address is matched
		if(preg_match("/^(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})$/",$ip_addr))
		{
			//now all the intger values are separated
			$parts = explode(".",$ip_addr);
			//now we need to check each part can range from 0-255
		
			foreach($parts as $ip_parts)
			{
				if(intval($ip_parts)>255 || intval($ip_parts)<0)
				return false; //if number is not within range of 0-255
			}
			return true;
		}
		else
		{
			return false; //if format of ip address doesn't matches	
		}
	}
	
	public function isValidPortNumber($port_number)
	{
		if(!is_numeric($port_number)) return false;
		elseif($port_number < 0)  return false;
		elseif($port_number > 65535)  return false;
		else return true;
	}
}
?>