<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */
class OS_Widget
{
	
	public $id;
	
	public $name;
	
	public $title;
	
	public $description;
	
	public $version;
	
	public $status;
	
	public $status_dt;
	
	public $status_ip;
	
	public $status_by;
	
	public $manifest;
	
	
	public function __construct()
	{
		$this->setInitialValues();
	}
	
	
	//sets object to some sane initial values
	private function setInitialValues()
	{
		$initialValues = array(
			'id' => -1,
			'name' => "",
			'title' => "",
			'description' => "",
			'version' => "",
			'status' => ""
			);
			
		$this->set($initialValues);	
	}
	
	//install widget
	public function install()
	{
		$result = false;
		
		$osWidgetOps = $OS->getWidgetOps();
		
		if ($this->id > -1)
		{
			$result = $osWidgetOps->updateWidget($this);
		}
		else
		{
			$newid = $osWidgetOps->insertWidget($this);
			if ($newid > -1)
			{
				$this->id = $newid;
				$result = true;
			}

		}

		return $result;
	}
	
	//save widget data
	public function save()
	{
		$result = false;
		
		$OS = getOS();
		
		$osWidgetOps = $OS->getWidgetOps();
		
		if ($this->id > -1)
		{
			$result = $osWidgetOps->updateWidget($this);
		}
		else
		{
			$newid = $osWidgetOps->insertWidget($this);
			
			if ($newid > -1)
			{
				$this->id = $newid;
				$result = true;
			}
		}

		return $result;
	}	
	

	//uninstall widget
	public function unistall()
	{
		$result = false;
		
		if ($this->id > -1)
		{
			$OS = getOS();
			
			//remove other dependencies linked with current section
			
			
			//Remove widget record from the database
			$osWidgetOps = $OS->getWidgetOps();
			
			$result = $osWidgetOps->deleteWidgetByID($this->id);
			if ($result)
			{
				$this->setInitialValues();
			}
		}

		return $result;		
	}
	
	public function getWidgetUrl()
	{
		if (!$this->id || !$this->name) return false;
		
		return getOS()->getConfigVar('root_url').'/widgets/'.$this->name;
	}
	
	public function set($widgetData)
	{
		$result = false;
		
		$objVars = get_object_vars($this);
		
		foreach($objVars as $key=>$val)
		{
			if(isset($widgetData[$key]))
			{
				$this->$key = $widgetData[$key];
				$result = true;
			}
		}
		return $result;
	}
	
	public function get($key)
	{
		$result = false;
		
		$objVars = get_object_vars($this);
		
		if(isset($objVars[$key]))
		{
			$result = $objVars[$key];
		}
		
		return $result;
	}
	
	
	public function delete()
	{
		$result = false;
		
		if ($this->id > -1)
		{
			$OS = getOS();
			
			$osWidgetOps = $OS->getWidgetOps();
			
			//Remove widget record from the database
			$result = $osWidgetOps->deleteWidgetByID($this->id);
			if ($result)
			{
				$this->setInitialValues();
			}
		}

		return $result;		
	}
	
	public function isValid()
	{
		$result = false;
		if(isset($this->id))
		{
			if($this->id > 0)
			{
				$result  = true;		
			}
		}
		
		return $result;
	}
	
	public function requireUpdate($newVersion)
	{
		$result = true;
		
		if((isset($this->version)) && (!empty($newVersion)))
		{
			if (version_compare($this->version, $newVersion) <= 0)
			{
				$result = false;	
			}	
		}
		
		return $result;
	}	
	
}	
?>