<?php
class OS_WidgetBase
{
	private $requestParams;
	
	private $routerOptions;
	
	public function __construct()
	{
	}
	
	public function getWidgetUrl()
	{
		return getOS()->getConfigVar('root_url').'/users/widget.php?wid='.$this->getWidgetDetail('id');
	}
	
	public function getWidgetActionUrl($view,$params=array())
	{
		return $this->getWidgetUrl()."&view={$view}".($params?"&".http_build_query($params):'');
	}
	
	public function getWidgetHomeUrl($secure=false)
	{
		$result=false;
		
		if ($secure)
		{
			$result=getOS()->getConfigVar('ssl_root_url').'/widgets/'.$this->getWidgetDetail('name');
		}
		else
		{
			$result=getOS()->getConfigVar('root_url').'/widgets/'.$this->getWidgetDetail('name');
		}
		
		return $result;
	}
	
	public function getWidgetHomePath()
	{
		return os_join_path(getOS()->getConfigVar('root_path'),'widgets',$this->getWidgetDetail('name'));
	}
	
	public function getWidgetDetail($detail_name)
	{
		$result=false;
		
		$widgetHandler=getOS()->getWidgetHandler();
		
		if (isset($widgetHandler->$detail_name))
		{
			$result=$widgetHandler->$detail_name;
		}
		
		return $result;
	}	

	public function saveWidgetSettings($settings)
	{
		//settings = array(setting=>array('value'=>value,'type'=>type));
		return $this->execHandlerMethod('saveSettings',array($settings)); 
	}
	
	public function getWidgetSetting($setting_name)
	{
		$result=false;
		
		$widgetHandler=getOS()->getWidgetHandler();
		
		if (isset($widgetHandler->settings[$setting_name]))
		{
			$result=$widgetHandler->settings[$setting_name];
		}
		
		return $result;
	}
	
	public function execHandlerMethod($method_name,$params=array())
	{
		$result=false;
		
		$widgetHandler=getOS()->getWidgetHandler();
		
		if (method_exists($widgetHandler,$method_name))
		{
			$result=call_user_func_array(array($widgetHandler,$method_name),$params);
		}
		
		return $result;
	}
	
	public function processRequest($request)
	{
		$response = false;
		
		if(!empty($request['params']))
		{
			$this->setRequestParams($request['params']);  
		}
		
		//get current View
		$currentView = 'view';
		if (!empty($request['view']))
		{
			if(!empty($this->routerOptions))
			{
				if(isset($this->routerOptions[$request['view']]))
				{
					$currentView = $request['view'];
				}
			}		
		}
		
		//check if app has an active router
		if(!empty($this->routerOptions))
		{
			if(isset($this->routerOptions[$currentView]))
			{
				//set the app template dir
				$tpl = getOS()->getTemplate();
				$tpl->setTemplateDir(os_join_path($this->getWidgetHomePath(), "templates"));
				
				$renderfcn = $this->routerOptions[$currentView];

				$response = $this->$renderfcn();
			}
		}

		return $response;
	}
	
	public function getRequestParams()
	{
		return $this->requestParams; 
	}
	
	public function setRequestParams($requestParams)
	{
		$this->requestParams = $requestParams;
		return (true);
	}

	protected function setRouterOptions($options)
	{
		$this->routerOptions = $options;
	}


	protected function setRouterOption($optionName, $optionFunction)
	{
		$this->routerOptions[$optionName] = $optionFunction;
	}

	protected function getRouterOptions()
	{
		return $this->routerOptions;
	}

	protected function getRouterOption($option)
	{
		if(!isset($this->routerOptions[$option]))
		{
			return false;
		}

		return $this->routerOptions[$option];
	}
}
?>