<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */
 
class OS_WidgetHandler
{
	private static $_instance;
	
	private $_widget;
	
	public $id;
	public $project_id;
	public $user_id;
	public $section_id;
	public $name;
	public $title;
	public $column_id;
	public $collapsed;
	public $position;
	public $background_color;
	public $main_widget_id;
	public $settings;
	
	private $widgetData;
	
	public function __construct()
	{
		$this->setInitialValues();
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_WidgetHandler();
		}
		
		return self::$_instance;
	}
	
	//sets object to some sane initial values
	private function setInitialValues()
	{
		$initialValues = array(
			'id' => -1,
			'project_id' => -1,
			'user_id' => -1,
			'section_id' => -1,
			'main_widget_id' => "-1",
			'name' => "",
			'title' => "",
			'column_id' => 1,
			'position' => 1,
			'collapsed' => "",
			'background_color' => "white",		
			);
			
		$this->set($initialValues);	
	}
		
	//add widget
	public function save()
	{
		$result = false;
		
		$OS = getOS();
		
		$osWidgetHandlerOps = $OS->getWidgetHandlerOps();
		
		if ($this->id > -1)
		{
			$result = $osWidgetHandlerOps->updateWidgetHandler($this);
		}
		else
		{
			$newid = $osWidgetHandlerOps->insertWidgetHandler($this);
			if ($newid > -1)
			{
				$this->id = $newid;
				$result = true;
			}

		}

		return $result;
	}
	
	//delete widget
	public function delete()
	{
		$result = false;
		
		if ($this->id > -1)
		{
			$OS = getOS();
			
			//Remove widget record from the database
			$osWidgetHandlerOps = $OS->getWidgetHandlerOps();
			
			$result = $osWidgetHandlerOps->deleteWidgetHandlerByID($this->id);
			
			if ($result)
			{
				$widgetStatsOps=getOS()->getWidgetStatsOps();
				$widgetStatsOps->log($this->main_widget_id,$this->name,'remove');
				
				$this->setInitialValues();
			}
		}

		return $result;		
	}
	
	
	public function set($widgetData)
	{
		$result = false;
		
		$objVars = get_object_vars($this);
		
		foreach($objVars as $key=>$val)
		{
			if(isset($widgetData[$key]))
			{
				$this->$key = $widgetData[$key];
				$result = true;
			}
		}
		
		return $result;
	}
	
	public function load()
	{
		$result = false;
		if($this->id >= 1)
		{
			$OS = getOS();
			
			$osWidgetHandlerOps = $OS->getWidgetHandlerOps();
			
			$oneWidgetHandler = $osWidgetHandlerOps->getWidgetHandlerByID($this->id);
			
			if($oneWidgetHandler !== false)
			{
				$widgetData = get_object_vars($oneWidgetHandler);
				
				$this->set($widgetData);
				
				$this->loadSettings();
					
				$result = true;
			}
		}
		return $result;
	}
	
	public function loadSettings()
	{
		$result=false;
		
		if ($this->id)
		{
			if ($settings=getOS()->getWidgetHandlerOps()->getWidgetSettings($this))
			{
				$this->settings=$settings;
				
				$result=true;
			}
		}
		
		return $result;
	}

	public function saveSettings($settings)
	{
		$result=false;
		
		if ($this->id)
		{
			$settings=getOS()->getWidgetHandlerOps()->saveWidgetSettings($this,$settings);
			
			if ($settings!==false)
			{
				$this->settings=$settings;
				
				$result=true;
			}
		}
		
		return $result;
	}
	
	//register widget
	public function loadWidget()
	{
		$result = false;
		
		$OS = getOS();
			
		$osWidgetHandlerOps = $OS->getWidgetHandlerOps();
		
		if($osWidgetPlugin = $osWidgetHandlerOps->getWidgetPluginByName($this->name))
		{
			$classMethods = get_class_methods($osWidgetPlugin);
							
			$this->widgetData =	array(
				'object' =>$osWidgetPlugin,
				'methods' => array_flip($classMethods)	
				); 
			
			$result = $osWidgetPlugin;				
		}
		
		return $result;
	}
	
	public function processRequest()
	{
		return $this->execWidgetPluginMethod('processRequest',$this->getWidgetRequest());
	}
	
	public function getWidgetRequest()
	{
		$widgetRequest=array('view'=>false,'params'=>false);
		$bulk=($_SERVER['REQUEST_METHOD']=='POST'?$_POST:$_GET);unset($bulk['wid']);
		
		if (!empty($bulk['view']))
		{
			$widgetRequest['view']=$bulk['view'];
			unset($bulk['view']);
		}
		
		if (!empty($bulk)) $widgetRequest['params']=$bulk;
		
		return $widgetRequest;
	}
	
	public function getWidgetUserPath($user_id = false)
	{
		$result=false;
		
		if (!$user_id)
		{
			$user=getOS()->getUser();
			
			if ($user->id > -1)
			{
				$user_id=$user->id;
			}
		}
		
		if ($user_id)
		{
			$user_id = str_pad($user_id,3,'0',STR_PAD_LEFT);
			$result = os_join_path(getOS()->getConfigVar('storage_path'),'users',$user_id[0],$user_id[1],$user_id[2],$user_id,'widgets',$this->name);
		}
		
		return $result;
	}
	
	public function getWidgetStoragePath()
	{
		return os_join_path(getOS()->getConfigVar('storage_path'),'widgets',$this->name);
	}
	
	public function getWidgetCachePath()
	{
		return os_join_path(getOS()->getConfigVar('cache_path'),'widgets',$this->name);
	}
		
	public function execWidgetPluginMethod($method_name,$method_params = false)
	{
		$result = false;
		
		if(!is_null($this->widgetData))
		{
			if(isset($this->widgetData['methods'][$method_name]))
			{
				if($method_params!==false)
				{
					$result = $this->widgetData['object']->$method_name($method_params);	
				} 
				else
				{
					$result = $this->widgetData['object']->$method_name();	
				}
			}
		}
		
		return $result;
	}
	
	public function & getWidgetPlugin()
	{
		$result = false;
		$load = false;
		
		if (!$this->_widget)
		{
			$osWidgetHandlerOps = getOS()->getWidgetHandlerOps();
			
			if ($this->_widget = $osWidgetHandlerOps->getWidgetPluginByName($this->name))
			{
				$result = $this->_widget;
				$load = true;
			}
		}
		else
		{
			$result = $this->_widget;
		}
		
		if ($load)
		{
			$osWidgetOps = getOS()->getWidgetOps();
			
			if ($oneWidget = $osWidgetOps->getWidgetByName($this->name))
			{
				$this->app_id = $oneWidget->id;
			}
		}
		
		return $result;
	}	
}	
?>