<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_WidgetHandlerOperations
{
	private static $_instance;
	
	protected function __construct() {}

	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_WidgetHandlerOperations();
		}
		return self::$_instance;
	}
	
	
	//get a list of all widgets linked to a user 
	public function &getWidgetsByUserID($user_id)
	{
		if( $user_id < 1 ) return false;
		
		$db = getOS()->getDb();

		$result = array();

		$query = "SELECT * FROM ".$db->dbPrefix()."widgets_users WHERE `user_id` = ?  ORDER BY `position` ASC";
		$dbresult = $db->query($query,array($user_id));
		while ($row = $db->fetchRow($dbresult))
		{
			$oneWidget = new OS_WidgetHandler();
			$oneWidget->set($row);
			
			$result[$row['id']] = $oneWidget;
		}

		return $result;	
	}
	
	//get a list of all widgets linked to a project
	public function &getWidgetsByProjectID($project_id)
	{
		if( $project_id < 1 ) return false;
		
		$db = getOS()->getDb();

		$result = array();

		$query = "SELECT * FROM ".$db->dbPrefix()."widgets_users WHERE `project_id` = ?  ORDER BY `position` ASC";
		$dbresult = $db->query($query,array($project_id));
		while ($row = $db->fetchRow($dbresult))
		{
			$oneWidget = new OS_WidgetHandler();
			$oneWidget->set($row);
			
			$result[$row['id']] = $oneWidget;
		}

		return $result;
	}
	
	//get a list of all widgets linked to a section
	public function &getWidgetsBySectionID($section_id)
	{
		if( $section_id < 1 ) return false;
		
		$db = getOS()->getDb();

		$result = array();

		$query = "SELECT * FROM ".$db->dbPrefix()."widgets_users WHERE `section_id` = ?  ORDER BY `position` ASC";
		$dbresult = $db->query($query,array($section_id));
		while ($row = $db->fetchRow($dbresult))
		{
			$oneWidget = new OS_WidgetHandler();
			$oneWidget->set($row);
			
			$result[$row['id']] = $oneWidget;
		}

		return $result;
	}
	
	//get a widget handler by id
	public function &getWidgetHandlerByID($widget_id)
	{
		if( $widget_id < 1 ) return false;
		
		$db = getOS()->getDb();

		$result = false;

		$query = "SELECT * FROM ".$db->dbPrefix()."widgets_users WHERE `id` = ?";
		$dbresult = $db->query($query,array($widget_id));
		if ($row = $db->fetchRow($dbresult))
		{
			$oneWidget = new OS_WidgetHandler();
			$oneWidget->set($row);
			
			$result = $oneWidget;
		}

		return $result;
	}
	
	public function getAddedWidgetsDetails($user_id,$project_id)
	{
		$result=false;
		
		$availableWidgets=getOS()->getWidgetOps()->getAvailableWidgetsDetails();
		
		$db=getOS()->getDb();
		
		$query="SELECT * FROM ".$db->dbPrefix()."widgets_users WHERE user_id=? AND project_id=?";
		$dbresult=$db->query($query,array($user_id,$project_id));
		while ($row=$db->fetchRow($dbresult))
		{
			if (isset($availableWidgets[$row['main_widget_id']]))
			{
				$apps=(isset($availableWidgets[$row['main_widget_id']]['manifest']['dependencies'])?array_keys($availableWidgets[$row['main_widget_id']]['manifest']['dependencies']):array());
				
				$result[$row['name']]=array(
					'id'=>$row['id'],
					'name'=>$row['name'],
					'main_widget_id'=>$row['main_widget_id'],
					'apps'=>$apps
				);
			}
		}
		
		return $result;
	}
	
	//get projects ids links by Widget ID
	public function getUsersByWidgetID($widget_id)
	{
		$result =  array();
		
		if($widget_id >= 1)
		{
			$db = getOS()->getDb();
			
			$query = "SELECT * FROM ".$db->dbPrefix()."widgets_users WHERE `main_widget_id`= ?";
			$dbresult = $db->query($query,array($widget_id));
			while($row = $db->fetchRow($dbresult))
			{
				$result[] = $row['user_id'];
			}
		}
		
		return $result;		
	}

	public function removeUsersWidgetsByWidgetID($widget_id)
	{
		$result = false;
		
		$db = getOS()->getDb();
		
		$dbresult = $db->query("DELETE FROM ".$db->dbPrefix()."widgets_users_settings WHERE `main_widget_id`=?",array($widget_id));
		
		if ($dbresult !== false)
		{
			$dbresult = $db->query("DELETE FROM ".$db->dbPrefix()."widgets_users WHERE `main_widget_id`=?",array($widget_id));
			
			if ($dbresult !== false)
			{
				$result = true;
			}
		}
		
		return $result;
	}
	
	public function saveWidgetSettings($widget,$settings)
	{
		$result=false;
		
		if ($this->removeWidgetSettings($widget))
		{
			$db=getOS()->getDb();
			$user_id=getOS()->getUser()->id;
			$project_id=getOS()->getProject()->id;
			
			$result=array();
			
			foreach ($settings as $var=>$details)
			{
				$query="INSERT INTO ".$db->dbPrefix()."widgets_users_settings (main_widget_id,user_id,project_id,widget_id,var,type,val_".$details['type'].") VALUES (?,?,?,?,?,?,?)";
				$dbresult=$db->query($query,array($widget->main_widget_id,$user_id,$project_id,$widget->id,$var,$details['type'],$details['value']));
				
				if ($dbresult!==false)
				{
					$result[$var]=$details['value'];
				}
			}
		}
		
		return $result;
	}
	
	public function getWidgetSettings($widget)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$user_id=getOS()->getUser()->id;
		
		$query="SELECT * FROM ".$db->dbPrefix()."widgets_users_settings WHERE widget_id=? AND user_id=?";
		$dbresult=$db->query($query,array($widget->id,$user_id));
		while ($row=$db->fetchRow($dbresult))
		{
			$result[$row['var']]=$row['val_'.$row['type']];
		}
		
		return $result;
	}	
	
	public function removeWidgetSettings($widget)
	{
		$result=false;
		
		$db=getOS()->getDb();
		$user_id=getOS()->getUser()->id;
		
		$query="DELETE FROM ".$db->dbPrefix()."widgets_users_settings WHERE id=? AND user_id=?";
		$dbresult=$db->query($query,array($widget->id,$user_id));
		
		if ($dbresult!==false)
		{
			$result=true;
		}
		
		return $result;
	}
	
	//handle a widget move operation
	public function handleWidgetMove($oneWidget, $new_column_id, $new_position)
	{
		$result = false;
		
		if($oneWidget!==false)
		{
			$db = getOS()->getDb();
			
			$old_column_id = $oneWidget->column_id;
			$old_position = $oneWidget->position;
			
			
			//update widget position
			$query = "SELECT * FROM ".$db->dbPrefix()."widgets_users WHERE `project_id` = ? AND `user_id` = ? AND `section_id` = ? AND `column_id` = ? AND `id` = ?";
			$dbresult = $db->query($query,array($oneWidget->project_id, $oneWidget->user_id, $oneWidget->section_id,$oneWidget->column_id,$oneWidget->id));
			if ($row = $db->fetchRow($dbresult))
			{
				$query = "UPDATE ".$db->dbPrefix()."widgets_users SET `position` = position+1 WHERE `project_id` = ? AND `user_id` = ? AND `section_id` = ? AND `column_id` = ? AND `position` >= ?";
				$dbresult = $db->query($query, array($oneWidget->project_id, $oneWidget->user_id, $oneWidget->section_id,$oneWidget->column_id,$new_position));
				
				$query = "UPDATE ".$db->dbPrefix()."widgets_users SET `column_id` = ?, `position` = ? WHERE `id` = ?";
				$dbresult = $db->query($query, array($new_column_id, $new_position, $row['id']));
			}
			
			
			if($old_column_id != $new_column_id)
			{
				//update source column widgets positions
				$this->refreshWidgetsPositions($oneWidget);
			}

			
			//update destination column widgets positions
			$oneWidget->column_id = $new_column_id;
			$oneWidget->position = $new_position;
			
			//update destination column widgets positions
			$this->refreshWidgetsPositions($oneWidget);
			
			$result = true;
		}
		return $result;
	}
	
	//refresh positions of all widgets within current column
	public function refreshWidgetsPositions($oneWidget)
	{
		$result = false;
		
		if($oneWidget!==false)
		{
			$db = getOS()->getDb();
			
			$position = 0; $updateStack = array();
			$query = "SELECT * FROM ".$db->dbPrefix()."widgets_users WHERE `user_id` = ? AND `project_id` = ?  AND `section_id` = ? AND `column_id` = ? ORDER BY `position` ASC";
			$dbresult = $db->query($query,array($oneWidget->user_id,$oneWidget->project_id,$oneWidget->section_id,$oneWidget->column_id));
			while ($row = $db->fetchRow($dbresult))
			{
				$position++;
				$updateStack[] = array('position'=>$position,'widget_id'=>$row['id']);
			}
			
			if(!empty($updateStack))
			{
				$query = "UPDATE ".$db->dbPrefix()."widgets_users SET `position` = ? WHERE `id` = ?";
				
				foreach($updateStack  as $data)
				{
					$dbresult = $db->query($query, array($data['position'], $data['widget_id']));
					$result  = true;
				}
			}
		}
		return $result;
	}
	
	
	//Saves a new widget to the database.
	public function insertWidgetHandler($widget)
	{
		$result = -1; 
		
		$OS = getOS();

		$db = $OS->getDb();

		//get current user
		$user_id = $OS->getUser()->id;
		if(is_null($user_id))  $user_id = -1;
		
		//get current project
		$osProject = $OS->getProject();
		
		$time = $db->DBTimeStamp(time());
		$query = "INSERT INTO ".$db->dbPrefix()."widgets_users (`user_id`,`project_id`,`main_widget_id`,`name`,`title`,`section_id`,`column_id`,`position`,`background_color`,`insert_dt`,`insert_ip`,`insert_by`) VALUES (?,?,?,?,?,?,?,?,?,?,?,?)";
		$dbresult = $db->query($query, array($widget->user_id, $widget->project_id,  $widget->main_widget_id, $widget->name, $widget->title, $widget->section_id, $widget->column_id, $widget->position, $widget->background_color, $time, $_SERVER['REMOTE_ADDR'], $user_id ));
		
		if ($dbresult !== false)
		{
			$newid = $db->getInsertId();
			
			$result = $newid;

			$this->refreshWidgetsPositions($widget);
			
			$widgetStatsOps=getOS()->getWidgetStatsOps();
			$widgetStatsOps->log($widget->main_widget_id,$widget->name,'add');
		}
		
		return $result;
	}
	
	//Updates an existing widget in the database.
	public function updateWidgetHandler($widget)
	{
		$result = false;
		
		$OS = getOS(); 

		$db = $OS->getDb();
		
		//execute the update query
		$time = $db->DBTimeStamp(time());
		
		//get current user
		$user_id = $OS->getUser()->id;
		if(is_null($user_id))  $user_id = -1; 
		
		$query = "UPDATE ".$db->dbPrefix()."widgets_users SET `title` = ?, `section_id` = ?, `column_id` = ?, `position` = ?, `background_color` = ?, `collapsed` = ?, `update_dt` = ?, `update_ip` = ?, `update_by` = ?, `updates` = updates+1 WHERE `project_id` = ? AND `user_id` = ? AND `id` = ?";
		$dbresult = $db->query($query, array($widget->title, $widget->section_id, $widget->column_id, $widget->position, $widget->background_color, $widget->collapsed, $time, $_SERVER['REMOTE_ADDR'], $user_id, $widget->project_id, $widget->user_id, $widget->id));
		if ($dbresult !== false)
		{
			$result = true;
		}

		return $result;
	}	

	//Deletes an existing section from the database.
	public function deleteWidgetHandlerByID($id)
	{
		if( $id < 1 ) return false;

 		$result = false;

		$db = getOS()->getDb();
 		
		$query = "DELETE FROM ".$db->dbPrefix()."widgets_users WHERE `id` = ?";
		$dbresult = $db->query($query, array($id));

		if ($dbresult !== false)
		{
			$result = true;
		}

		return $result;	
	}
	
	//Get developed widget object
	public function getWidgetPluginByName($widget_name)
	{
		$result = false;
		
		$OS = getOS();
		
		//use getWidgetPath method (located in ...)
		$widget_path = $OS->getConfigVar('root_path').'/widgets/'.$widget_name.'/init.php';
		
		if(file_exists($widget_path))
		{
			include_once($widget_path);
			
			$className = 'OS_WIDGET_'.$widget_name;
			
			if(class_exists($className))
			{
				$osWidgetPlugin = new $className();
				
				$result = $osWidgetPlugin;
			}
		}
		return $result;
	}
}	
?>