<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

class OS_WidgetOperations
{
	private static $_instance;
	
	protected function __construct() {}

	public static function &get_instance()
	{
		if( !is_object(self::$_instance) )
		{
			self::$_instance = new OS_WidgetOperations();
		}
		return self::$_instance;
	}
	
	public function getAvailableWidgets()
	{
		$db = getOS()->getDb();
		$result = array();
		
		$query = "SELECT * FROM ".$db->dbPrefix()."widgets WHERE `status`='E'";
		$dbresult = $db->query($query);
		while ($row = $db->fetchRow($dbresult))
		{
			$oneWidget = new OS_Widget();
			$oneWidget->set($row);
			
			$result[$row['id']] = $oneWidget;
		}
		
		return $result;		
	}
	
	public function getAvailableWidgetsDetails()
	{
		$db = getOS()->getDb();
		$result = array();
		
		$query = "SELECT * FROM ".$db->dbPrefix()."widgets WHERE `status`='E'";
		$dbresult = $db->query($query);
		while ($row = $db->fetchRow($dbresult))
		{
			if (!empty($row['manifest']))
			{
				$row['manifest']=json_decode($row['manifest'],true);
			}
			
			$result[$row['id']] = $row;
		}
		
		return $result;		
	}
	
	//Get a widget by id.
	public function &getWidgetByID($widget_id)
	{
		return $this->getWidgetByDetail(array('id'=>$widget_id));
	}

	//Get a widget by name.
	public function &getWidgetByName($widget_name)
	{
		return $this->getWidgetByDetail(array('name'=>$widget_name));
	}
	
	public function &getWidgetByDetail($details)
	{
		$result = false;
		$query  = false;

		$db = getOS()->getDb();

		if(isset($details['id']))  $query = "SELECT * FROM ".$db->dbPrefix()."widgets WHERE id = ?";	
		elseif(isset($details['name'])) $query = "SELECT * FROM ".$db->dbPrefix()."widgets WHERE name = ?";
		
		if($query)
		{
			$dbresult = $db->query($query, array_values($details));
			
			if ($row = $db->fetchRow($dbresult))
			{
				$oneWidget = new OS_Widget();
				$oneWidget->set($row);
				$result = $oneWidget;
			}
				
		}
		return $result;
	}
	
	
	 
	//insert widget data into widgets_available table
	public function insertWidget($widget)
	{
		$result = false;
		
		$OS = getOS();
		
		$db = $OS->getDb();
		
		$time = $db->DBTimeStamp(time());
		
		$ip = (!empty($_SERVER['REMOTE_ADDR'])?$_SERVER['REMOTE_ADDR']:'0.0.0.0');
		
		$user_id = $OS->getUser()->id;
		if(is_null($user_id))  $user_id = -1;
		
		$query = "INSERT INTO ".$db->dbPrefix()."widgets (name,title,description,version,insert_dt,insert_ip,insert_by,status,status_dt,status_ip,status_by,manifest) VALUES (?,?,?,?,?,?,?,?,?,?,?,?)";
		$dbresult = $db->query($query,array($widget->name,$widget->title,$widget->description,$widget->version,$time,$ip,$user_id,'E',$time,$ip,$user_id,$widget->manifest));
		
		if ($dbresult !== false)
		{
			$result = $db->getInsertId();
		}
		
		return $result;
	}
	
	//update widget data into widgets_available table
	public function updateWidget($widget)
	{
		$result = false;
		
		$OS = getOS();
		
		$db = $OS->getDb();
		
		$time = $db->DBTimeStamp(time());
		
		$ip = (!empty($_SERVER['REMOTE_ADDR'])?$_SERVER['REMOTE_ADDR']:'0.0.0.0');
		
		$user_id = $OS->getUser()->id;
		if(is_null($user_id))  $user_id = -1;
		
		$query = "UPDATE ".$db->dbPrefix()."widgets SET `title`=?,`description`=?,`version`=?,updates=updates+1,`update_dt`=?,`update_ip`=?,`update_by`=?,`manifest`=? WHERE `id`=?";
		
		$dbresult = $db->query($query, array($widget->title,$widget->description,$widget->version,$time,$ip,$user_id,$widget->manifest,$widget->id));
		
		if ($dbresult !== false)
		{
			$result = true;
		}
		
		return $result;
		
	}
	
	//delete widget data from widgets_available table
	public function deleteWidgetById($widget_id)
	{
		$result=true;
		
		$OS=getOS();
		
		return $result;
	}
	
	public function getUninstalledWidgets()
	{
		$result = false;
		
		$widgets_path = os_join_path(getOS()->getConfigVar('root_path'),'widgets');
		
		$uninstalled = glob(os_join_path($widgets_path,"*_uninstalled"));
		foreach ($uninstalled as $uninstalled_widget_path)
		{
			$widget_name = str_replace(array(os_join_path($widgets_path,''),'_uninstalled'),'',$uninstalled_widget_path);
			
			$result[$widget_name] = $uninstalled_widget_path;
		}
		
		return $result;
	}
	
	public function isUninstalledWidget($widget_name)
	{
		$result = false;
		
		$widget_path = $this->getUninstalledWidgetPath($widget_name);
		
		return (file_exists($widget_path));
	}
	
	public function getUninstalledWidgetPath($widget_name)
	{
		return os_join_path(getOS()->getConfigVar('root_path'),'widgets',$widget_name.'_uninstalled');
	}
	
	public function removeUninstalledWidget($widget_name)
	{
		$result = false;
		
		if ($this->isUninstalledWidget($widget_name))
		{
			$result = getOS()->getUtils()->removeDir($widget_path);
		}
		
		return $result;
	}
	
	public function isAvailableWidget($widget_id)
	{
		$result = false;
		
		$widgets = $this->getAvailableWidgets();
		if ((isset($widgets[$widget_id])) && ($widgets[$widget_id]->status=='E'))
		{
			$result = true;
		}
		
		return $result;
	}
	
	//install current widget
	public function installWidget($widgetKitPath)
	{
		$OS = getOS();
		$result = false;
		
		$responseData = array('tests' => array(),'notifications' => array());
		
		$validateResult = $this->validateWidgetKit($widgetKitPath);
		
		$validationOK = $validateResult['result'];
		
		if(!empty($validateResult['tests']))
		{
			$responseData['tests'] = array_merge($responseData['tests'], $validateResult['tests']);
		}
		
		if($validationOK)
		{
			$widgetInfo = $this->buildWidgetInfo($widgetKitPath);
			
			$oneWidget = new OS_Widget();
			$oneWidget->set($widgetInfo['details']);
			$oneWidget->manifest = json_encode($widgetInfo);
			
			//check if needs install or update
			if($testWidget = $this->getWidgetByName($oneWidget->name))
			{
				$oneWidget->id = $testWidget->id;
			}
			$widgetResult = $oneWidget->save();  
			
			
			$tmpTests  = array();
			
			if($widgetResult == false)
			{
				$returnType = array('type'=>'error', 'message'=>_('Unable to install Widget'));
			}
			elseif(!$oneWidget->isValid())
			{
				$returnType = array('type'=>'error', 'message'=>_('Widget details are invalid'));	
			}
			else
			{
				//sql sync tables
				$osDbOps = $OS->getDbOps();
				
				//move widget to /widgets/widgetname
				$widgetFilesPath = os_join_path($widgetKitPath,'widget');
				$widgetFinalPath = os_join_path($OS->getConfigVar('root_path'),'widgets',$oneWidget->name);
				
				$osUtils = $OS->getUtils();
				$copyResult = $osUtils->copyDir($widgetFilesPath, $widgetFinalPath);
				
				if($copyResult == false)
				{
					$returnType = array('type'=>'error', 'message'=>_('Widget cannot be moved to widgets directory'));
				}
				else
				{
					$result = true;
					
					//run widget developer custom functions 
					$widgetInstallPath = os_join_path($widgetKitPath, 'manage', 'manage.php');
					if (file_exists($widgetInstallPath))
					{
						include_once($widgetInstallPath);
						
						$installClassName = "OS_WIDGET_".$oneWidget->name."_Manage";
						 
						$strtolowerClass = strtolower($installClassName);
						
						if(class_exists($strtolowerClass) )
						{
							$installClass = new $strtolowerClass;
							
							if(method_exists($installClass, 'run'))
							{
								$resultInstall = $installClass->run();
								
								$result = true;
								
								if (!empty($resultInstall))
								{
									if(isset($resultInstall['tests']))
									{
										$tmpTests = array_merge($tmpTests, $resultInstall['tests']);
									}
								}
							}
						}	
					}
					
					//delete garbage _unistalled dir
					$deleteWidgetKitResult = $osUtils->removeDir($widgetKitPath);
					
					if($deleteWidgetKitResult === false)
					{
						$returnType = array('type'=>'warning' , 'message' => _("Widget Kit could not be deleted"));
					}
					else
					{
						$returnType = array('type'=>'success');	
					}					
				
				}
			}
			
			if($result)
			{
				$widgetStats=$OS->getWidgetStatsOps();
				
				$appstore = $OS->getAppStoreApi();
				$appstore->installWidget(array('widget_name'=>$oneWidget->name));
			}
			
			$responseData['tests'][] = array('test'=>array('message'=> _('Installing widget')),'result'=> $returnType);
			
			if(!empty($tmpTests)) $responseData['tests'] = array_merge($responseData['tests'], $tmpTests); 
		}	
		
		$responseData['result'] = $result;
		
		return $responseData;
	}
	

	//uninstall current widget
	public function uninstallWidget($widget_name)
	{
		$OS = getOS();
		
		$result = false;
		$responseData = array('tests' => array(), 'notifications' => array());
		
		$oneWidget = $this->getWidgetByName($widget_name);
		$widgetIsValid = ($oneWidget !== false);
		
		if($widgetIsValid) $returnType = array('type'=> 'success');
		else $returnType = array('type'=> 'error', 'message' => _("Widget not found !"));
		$responseData['tests'][] = array('test'=>array('message'=> _('Test if Widget is installed')),'result'=> $returnType);
		
		if($widgetIsValid)
		{
			$db = $OS->getDb();
			
			$widget_id = $oneWidget->id;
			
			//find the users using the widget
			$widgetHandler = new OS_WidgetHandler();
			$widgetHandler->main_widget_id = $widget_id;
			$widgetHandler->name = $widget_name;
			
			$widgetHandlerOps=$OS->getWidgetHandlerOps();
			$user_ids = $widgetHandlerOps->getUsersByWidgetID($widget_id);			
			
			//users and user settings
			$widgetHandlerOps->removeUsersWidgetsByWidgetID($widget_id);
			
			//available
			$this->deleteWidgetByID($widget_id);
			
			//widget stats
			$widgetStatsOps=$OS->getWidgetStatsOps();
			$widgetStatsOps->deleteWidgetStatsFull($widget_id);
			
			//datasources
			$datasourceOps=$OS->getDatasourceOps();
			$datasourceOps->unregisterDatasourcesByModule('widget', $widget_name);
			
			//event handlers
			OS_Events::removeEventHandlersByModule('widget', $widget_name);
			if ($events=OS_Events::getEventsByModule('widget', $widget_name))
			{
				foreach ($events as $event_details)
				{
					OS_Events::removeAllEventHandlers($event_details['name']);
					OS_Events::removeEvent($event_details['name']);
				}
			}
			
			//unregister crons
			OS_Crons::unregisterCronsByModule('widget',$widget_name);
			
			//widget-specific uninstall handling
			$uninstall_script_file=os_join_path($OS->getConfigVar('root_path'),'widgets', $widget_name, $widget_name.'_uninstall.php');
			if (file_exists($uninstall_script_file))
			{
				include($uninstall_script_file);
			}
			
			$utils=$OS->getUtils();
			
			//delete storage files
			$widget_storage_path = $widgetHandler->getWidgetStoragePath();
			if (file_exists($widget_storage_path))
			{
				$utils->removeDir($widget_storage_path);
			}
			
			//delete user files
			foreach ($user_ids as $user_id)
			{
				$widget_user_path=$widgetHandler->getWidgetUserPath($user_id);
				
				if (file_exists($widget_user_path))
				{
					$utils->removeDir($widget_user_path);
				}
			}
			
			//delete cache files
			$widget_storage_path=$widgetHandler->getWidgetCachePath();
			if (file_exists($widget_storage_path))
			{
				$utils->removeDir($widget_storage_path);
			}
			
			//delete actual widget files
			$widget_storage_path=os_join_path($OS->getConfigVar('root_path'), 'widgets', $widget_name);
			if (file_exists($widget_storage_path))
			{
				$utils->removeDir($widget_storage_path);
			}
			
			$result = true;
			
			if($result)
			{
				//notify appstore of uninstall
				$appstore = $OS->getWidgetStoreApi();
				$appstore->uninstallWidget(array('widget_name'=>$widget_name));
				$responseData['notifications'][] = array('type'=>'success', 'message'=>_("Widget succesfully uninstalled !"));
				$responseData['widget_action'] = 'install';
			}
		}
		
		$responseData['result'] = $result;
		
		return $responseData;		
	}
	
	public function validateWidgetKit($widgetKitPath)
	{
		$OS = getOS();
		
		$result = false;
		$responseData = array('tests' => array(),'notifications' => array());
		
		//test if widget kit exists
		$widgetPathExists = (file_exists($widgetKitPath));
		
		if($widgetPathExists) $resultType = array('type'=>'success'); 
		else $resultType = array('type'=>'error', 'message'=>_('Widget Kit not found'));
		$responseData['tests'][] = array('test'=>array('message'=>_('Check if Widget Kit exists')),'result'=> $resultType);
		
		if($widgetPathExists)
		{
			//test if widget has manifest file
			$manifestFilePath = os_join_path($widgetKitPath, 'osManifest.ini');
			
			$widgetManifestPathExists = (file_exists($manifestFilePath));
			if($widgetManifestPathExists) $resultType = array('type'=>'success'); 
			else $resultType = array('type'=>'error', 'message'=>_('Widget Manifest not found'));
			$responseData['tests'][] = array('test'=>array('message'=>_('Check if Widget Manifest file exists')),'result'=> $resultType);
			
			if($widgetManifestPathExists)
			{
				//test if manifest file is valid
				$widgetInfo = $this->buildWidgetInfo($widgetKitPath);
				
				//validate widget manifest file
				$validateResult = $this->validateWidgetManifest($widgetInfo);
				$widgetManifestIsValid = $validateResult['result'];
				
				if(!empty($validateResult['tests']))
				{
					$responseData['tests'] = array_merge($responseData['tests'], $validateResult['tests']);
				}
				
				if($widgetManifestIsValid) $resultType = array('type' => 'success');
				$responseData['tests'][] = array('test'=>array('message'=>_('Check if Widget Manifest file is valid')),'result'=> $resultType);
				
				
				if($widgetManifestIsValid)
				{
					//widget version compare
					if($oneWidget = $this->getWidgetByName($widgetInfo['details']['name']))
					{
						if ($oneWidget->requireUpdate($widgetInfo['details']['version']))
						{
							$resultType = array('type'=>'info','message'=>_('Installed Widget has an older version (it will be updated)'), 'value'=> $widgetInfo['details']['version']);	
						}
						else 
						{
							$resultType = array('type'=>'info','message'=>_('Installed Widget has the newest version'), 'value'=> $widgetInfo['details']['version']);
						}
					}
					else
					{
						$resultType = array('type'=>'success', 'value'=> $widgetInfo['details']['version']);
					}
					
					$responseData['tests'][] = array('test'=>array('message'=>_('Check Widget version'), 'value'=> $widgetInfo['details']['version']), 'result' => $resultType);
		
					$widgetRequirementsResult = $this->checkWidgetRequirements($widgetInfo);
					
					$responseData['tests'] = array_merge($responseData['tests'], $widgetRequirementsResult['tests']);
					
					if ($widgetRequirementsResult['result'])
					{
						//verify signature
						$widgetIsSigned = false;
				
						$appstore = $OS->getAppStoreApi();
						$response = $appstore->checkWidgetSignature(array('widget_info'=>$widgetInfo,'signature'=>$this->generateWidgetSignature($widgetKitPath)));
						
						if ($appstore->success)
						{
							if ($response['widgetSigned'])
							{
								$widgetIsSigned=true;
							}
						}
						
						if($widgetIsSigned)
						{
							$resultType = array('type'=>'success');
						} 
						else
						{
							$resultType = array('type'=>'warning','message'=>_('Widget signature invalid'));
						}
						
						$responseData['tests'][] = array('test'=>array('message'=>_('Checking Widget signature')),'result'=> $resultType);
						
						
						//check install path
						$widgetInstallPath = os_join_path($widgetKitPath,'manage' , 'manage.php');
						$widget_has_manage_file = (file_exists($widgetInstallPath));
	
						if($widget_has_manage_file)
						{
							$resultType = array('type'=>'success');
						}
						else
						{
							$resultType = array('type'=>'error','message'=>_('Managemeng file not found'));
						}
						$responseData['tests'][] = array('test'=>array('message'=>_("Checking widget install management")),'result'=> $resultType);
						
						
						if ($widget_has_manage_file)
						{
							include_once($widgetInstallPath);
							
							$installClassName = "OS_WIDGET_".$widgetInfo['details']['name']."_Manage";
							 
							$lowerClassName = strtolower($installClassName);
							
							$checkClassExists = (class_exists($lowerClassName));
							if($checkClassExists) $returnType = array('type'=>'success');
							else $returnType = array('type'=>'error','message'=> sprintf(_('Class %s not found in %s'), $lowerClassName, $widgetInstallPath));
							$responseData['tests'][] = array('test'=>array('message'=>_("Loading widget install class")),'result'=> $returnType);
							
							if($checkClassExists)
							{
								$installClass = new $lowerClassName;
								
								//also check if has run method
								$checkValidMetodExists = (method_exists($installClass, 'check'));
								if($checkValidMetodExists) $returnType = array('type'=>'success');
								else $returnType = array('type'=>'error','message'=> sprintf(_('Method %s not found in %s'), 'check', $lowerClassName));
								$responseData['tests'][] = array('test'=>array('message'=>_("Running widget internal tests")),'result'=> $returnType);
								
								if($checkValidMetodExists)
								{
									$installResponse = $installClass->check();
									
									$result = true;
									
									if(!empty($installResponse))
									{
										if(is_array($installResponse))
										{
											if(isset($installResponse['tests']))
											{
												foreach($installResponse['tests'] as $test)
												{
													$responseData['tests'][] = $test;
												}
											}
										}
									}
								}
							}
						}
					}
				}
			}
		}				
		
		$responseData['result'] = $result;
		
		return $responseData;		
	}
	
	
	public function checkWidgetRequirements($widgetManifest)
	{
		$OS = getOS();
		$result = true;
		$responseData = array('tests'=> array(), 'notifications' => array());

		$tmpTest = array('test'=>array('message'=>_('Check if OpenS version is valid for widget'), 'value'=> sprintf(_("Required %s"), $widgetManifest['requirements']['os_min_version'])));
		
		//Check OpenS version
		$osVersion = $OS->getVersion(); 
		if (empty($widgetManifest['requirements']['os_min_version']))
		{
			$tmpTest['result'] = array('type'=>'error','message'=>_('OpenS minimum required version missing in info file'), 'value'=> sprintf(_("You have %s"), $osVersion));
			$result = false;
		}
		elseif (version_compare($osVersion,$widgetManifest['requirements']['os_min_version']) < 0)
		{
			$tmpTest['result'] = array('type'=>'error','message'=>_('This widget requires a newer version of OpenS'), 'value'=> sprintf(_("You have %s"), $osVersion));
			$result = false;
		}
		else
		{
			$tmpTest['result'] = array('type'=>'success', 'value'=> sprintf(_("You have %s"), $osVersion));
		}
		
		$responseData['tests'][] = $tmpTest;
			
		
		//Check Widget dependencies
		if (!empty($widgetManifest['dependencies']))
		{
			$appOps=$OS->getAppOps();
			//$dependenciesOK = true;
			foreach ($widgetManifest['dependencies'] as $dep_app_name => $details)
			{
				if(is_array($details))
				{
					$dep_app_title = $details['title'];
					$dep_app_version = $details['version'];
				}
				else
				{
					$dep_app_title = ucfirst($dep_app_name);
					$dep_app_version = $details;
				}	
				
				$tmpTest = array('test'=>array('message'=>sprintf(_("Checking if `%s` is valid"), $dep_app_title), 'value'=> sprintf(_("Required %s"), $dep_app_version)));
				
				if (!$dep_app = $appOps->getAppByName($dep_app_name))
				{
					$tmpTest['result'] = array('type'=>'error','message'=>_('Widget not installed'), 'value' => _("Not Installed"));
					$result = false;
				}
				elseif ($dep_app->requireUpdate($dep_app_version))
				{
					$tmpTest['result'] = array('type'=>'error','message'=>_('Widget version too old, please update'), 'value' => sprintf(_("You Have %s"), $dep_app->version));
					$result = false;
				}
				else
				{
					$tmpTest['result'] = array('type'=>'success', 'value' => sprintf(_("You Have %s"), $dep_app->version));
				}

				$responseData['tests'][] = $tmpTest; 
			}
		}
		
		$responseData['result'] = $result;
		
		return $responseData;
	}
	
	public function validateWidgetManifest($widgetManifest)
	{
		$result = true;
		$responseData = array('tests' => array(),'notifications' => array()); 
		
		$manifestIsParsable = (is_array($widgetManifest)); 
		if($manifestIsParsable) $resutType= array('type'=>'success');
		else{
			$resutType = array('type'=>'error', 'message' =>_("Manifest data could not be parsed")); 
			$result = false;
			}  
		$responseData['tests'][] = array('test' => array('message'=>_('Trying to parse Manifest')), 'result'=> $resutType);
		
		if($manifestIsParsable)
		{
			$manifestHasDetails = (isset($widgetManifest['details'])); 
			if(!$manifestHasDetails) 
			{
				$resutType= array('type'=>'error', 'message' =>_("Widget Details Not Found"));
				$result = false;
			}
			else
			{
				$widgetDetails = array('name','description','version','title','category');
				$flag = true;
				
				foreach($widgetDetails as $detail)
					if($flag) if(!isset($widgetManifest['details'][$detail]))
					{
						$resutType= array('type'=>'error', 'message' => sprintf(_("Widget Detail [%s] Not Found"), $detail));
						$flag = false; $result = false;
					}

				if($flag) $resutType = array('type'=>'success');
			}
			$responseData['tests'][] = array('test' => array('message'=>_('Checking Manifest details')), 'result'=> $resutType);
			
			$manifestHasReqs = (isset($widgetManifest['requirements'])); 
			if(!$manifestHasReqs)
			{
				$resutType= array('type'=>'error', 'message' =>_("Widget Details Missing"));	
			} 
			else
			{
				$widgetReqs = array('os_min_version');
				$flag = true;
				
				foreach($widgetReqs as $req)
					if($flag) if(!isset($widgetManifest['requirements'][$req]))
					{
						$resutType= array('type'=>'error', 'message' => sprintf(_("Widget Requirement [%s] Not Found"), $req));
						$flag = false;$result = false;
					}

				if($flag) $resutType = array('type'=>'success');
				
				$resutType = array('type'=>'success');  
			}
			
			$responseData['tests'][] = array('test' => array('message' => _('Checking Manifest requirements')), 'result'=> $resutType);
		}

		$responseData['result'] = $result;
		
		return $responseData;
	}	
		
	public function buildWidgetInfo($widgetPath)
	{
		$result = false;
		
		$infoFilePath = os_join_path($widgetPath, 'osManifest.ini');
		
		if(file_exists($infoFilePath))
		{
			$osUtils = getOS()->getUtils();
			
			$confData = $osUtils->confRead($infoFilePath);
			
			if($confData !== false)
			{
				$result = $confData;
			}
		}
		
		return $result;
	}
	
	public function generateWidgetSignature($widgetKitPath)
	{
		$result = false;
		
		if(file_exists($widgetKitPath))
		{
			$osUtils = getOS()->getUtils();
			
			$widgetFiles =$osUtils->getDir($widgetKitPath,'*',true);
			
			$filesize = 0; $md5 = '';
			foreach ($widgetFiles as $file)
			{
				if (is_file($file))
				{
					$filesize += filesize($file);
					$md5 .= md5_file($file);
				}
			}
			
			$result = array('key'=>md5($md5),'size'=>$filesize);
		}
		
		return $result;
	}
	
	public function getWidgetFromURL($downloadUrl, $archiveName = false) 
	{
		$result = false;
		$responseData = array('tests' => array(),'notifications' => array(), 'validationResult' => false);
		
		$OS = getOS();
		
		$validator = $OS->getValidator();
		
		$url = $downloadUrl;
		
		if (!$validator->is_url($url))
		{
			$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid Widget Install URL"));
		}
		else
		{
			$http = $OS->getHttp();
			
			$response = $http->get($url);
			
			if (empty($response))
			{
				$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Unable to download widget from the provided link"));
			}
			else
			{
				$osUtils = $OS->getUtils();
				
				if($archiveName == false)
				{
					$widgetKitName = strtolower(str_replace('.tar.gz','_uninstalled',basename(parse_url($url,PHP_URL_PATH))));	
				}
				else
				{
					$widgetKitName = strtolower($archiveName.'_uninstalled');	
				}
				
				$archive_path = $osUtils->getTempFile('tar.gz');
				
				$responseData['widgetKitName'] = $widgetKitName;
				
				$writeResult = $osUtils->fileWrite($archive_path,$response);
				
				if($writeResult === false)
				{
					$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid archive [1]"));
				}
				elseif(!file_exists($archive_path))
				{
					$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid archive [2]"));
				}
				else
				{
					//unpack widget kit
					
					//move installed details to /widgets
					$extractDetails = $this->extractWidgetFromArchive($archive_path,$widgetKitName);
			
					$responseData = array_merge($responseData, $extractDetails);
					
					if($extractDetails['result'])
					{
						$widgetKitPath = os_join_path($OS->getConfigVar('root_path'),'widgets',$widgetKitName);
						
						$result = true;	
						
						//verify widget manifest file
						 $validateKitResult = $this->validateWidgetKit($widgetKitPath);
						 
						 $responseData = array_merge($responseData, $validateKitResult);	
						
						//get widget manifest
						$widgetInfo = $this->buildWidgetInfo($widgetKitPath);
						if($widgetInfo !== false) if(isset($widgetInfo['details'])) $responseData['widgetInfo'] = $widgetInfo['details'];
						
						$flag = true;
						if(isset($responseData['tests']))
						{
							foreach($responseData['tests'] as $test)
							{
								if(isset($test['result']['type']))
								{
									if($test['result']['type'] == 'error') $flag = false;
								}
							}
						}
						
						if($flag)
						{
							$responseData['validationResult'] = true;
						} 
					}	
					
				}	
			}
		}
		
		$responseData['result'] = $result; 
			
		return $responseData;
	}
	
	public function getWidgetFromUpload($uploadObj, $archiveName = false)
	{
		$result = false;
		$responseData = array('tests' => array(),'notifications' => array(), 'validationResult' => false);
		
		//verify upload OBJ
		if(!isset($uploadObj['name']))
		{
			$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid archive - Archive not found"));
		}
		else
		{
			$fileInfo = pathinfo($uploadObj['name']);
			
			if(!isset($fileInfo['extension']))
			{
				$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid Archive - Extension missing"));
			}
			elseif($fileInfo['extension'] != 'gz')
			{
				$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid Archive - Accepted only tar.gz archives"));
			}
			elseif(strpos($uploadObj['name'],'.tar.gz') == false)
			{
				$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid Archive - Accepted only tar.gz archives"));
			}
			else
			{
				$OS = getOS();
				
				//move uploaded filed file to tmpDir
				$osUtils = $OS->getUtils();
				
				if($archiveName == false)
				{
					$widgetKitName = strtolower(str_replace('.tar.gz','_uninstalled', $uploadObj['name']));	
				}
				else
				{
					$widgetKitName = strtolower($archiveName.'_uninstalled');	
				}
				
				$archive_path = $osUtils->getTempFile('tar.gz');
				
				$responseData['widgetKitName'] = $widgetKitName;
				
				$uploadResult = move_uploaded_file($uploadObj['tmp_name'], $archive_path);
				
				if($uploadResult === false)
				{
					$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid archive - File cannot be uploaded"));
				}
				elseif(!file_exists($archive_path))
				{
					$responseData['notifications'][] = array('type'=>'error', 'message'=>_("Invalid archive - File cannot be uploaded"));
				}
				else
				{
					//unpack widget kit
					$extractDetails = $this->extractWidgetFromArchive($archive_path,$widgetKitName);
			
					$responseData = array_merge($responseData, $extractDetails);
					
					if($extractDetails['result'])
					{
						$widgetKitPath = os_join_path($OS->getConfigVar('root_path'),'apps',$widgetKitName);
						
						$result = true;
						
						//verify app manifest file
						$validateKitResult = $this->validateWidgetKit($widgetKitPath);
						 
						$responseData = array_merge($responseData, $validateKitResult);	
						
						//get app manifest
						$widgetInfo = $this->buildWidgetInfo($widgetKitPath);
						if($widgetInfo !== false) if(isset($widgetInfo['details'])) $responseData['widgetInfo'] = $widgetInfo['details'];
						
						//check tests for errors
						$flag = true;
						if(isset($responseData['tests']))
						{
							foreach($responseData['tests'] as $test)
							{
								if(isset($test['result']['type']))
								{
									if($test['result']['type'] == 'error') $flag = false;
								}
							}
						}
						
						if($flag)
						{
							$responseData['validationResult'] = true;
						} 
					}	
				}			
			}
		}
		
		$responseData['result'] = $result;
			
		return $responseData;	
	}	
	
	public function extractWidgetFromArchive($widget_archive,$widget_kit_name)
	{
		$OS = getOS();
		$utils = $OS->getUtils();
		
		$result = false;
		
		$responseData = array('tests'=>array(), 'notifications'=>array());
		
		$widget_temp_path = $utils->getTempDir();
		
		$tmpTest = array('test'=>array('message'=>_('Unpack Widget Kit')));
		
		//extract widgetkit from archive
		try{$extractArchiveResult = $utils->extractArchive($widget_archive, $widget_temp_path);}
		catch(Exception $e) {$tmpTest['result'] = array('type'=>'error', 'message'=>_("Widget cannot be unpacked"));}
				
		if($extractArchiveResult === false) $tmpTest['result'] = array('type' => 'error', 'message'=> _('Unable to extract widget files'));
		else $tmpTest['result'] = array('type' => 'success');
		
		$responseData['tests'][] = $tmpTest;
		
		if($extractArchiveResult !== false)
		{
			$widget_kit_final_path = os_join_path($OS->getConfigVar('root_path'),'widgets', $widget_kit_name);

			$moveDirResult = $utils->moveDir($widget_temp_path,$widget_kit_final_path);
			
			$tmpTest = array('test'=>array('message'=>_('Move Widget Kit')));
			if($moveDirResult === false)
			{
				$tmpTest['result'] = array('type' => 'error', 'message'=> _('Unable to move widget to the widgets folder'));	
			}
			elseif(!is_dir($widget_kit_final_path))
			{
				$tmpTest['result'] = array('type' => 'error', 'message'=> _('Unable to move widget to the widgets folder'));
			}
			else
			{
				$tmpTest['result'] = array('type' => 'success');
				$result = true;
			}
			
			$responseData['tests'][] = $tmpTest;
		}
		
		$unlinkResult = unlink($widget_archive);
		
		
		$tmpTest = array('test'=>array('message'=>_('Cleaning up')));
		if(!$unlinkResult) $tmpTest['result'] = array('type' => 'warning', 'message'=>_('Cannot delete widget archive'));
		else $tmpTest['result'] = array('type' => 'success');
		$responseData['tests'][] = $tmpTest;
		
		$responseData['result'] = $result;
		
		return $responseData;
	}	
	
	public function installWidgetFromPath($widgetKitName)
	{
		$result = false;
		$responseData = array('tests' => array(),'notifications' => array());
		
		if(!empty($widgetKitName))
		{
			$OS = getOS();
			
			$widgetKitPath = os_join_path($OS->getConfigVar('root_path'),'widgets',$widgetKitName); 
			
			$installWidgetResult = $this->installWidget($widgetKitPath);
			
			$result = $installWidgetResult['result'];
			$responseData['tests'] = $installWidgetResult['tests'];
		}
		
		$responseData['result'] = $result;
		
		return $responseData;
	}		
	

}	
?>