<?php
class OS_PLUGIN_Backlinks_Moz
{
	private static $_instance;
	
	private $authData=false;
	
	public $hasAuth=true;
	public $requireAuth=true;
	
	public $engineDetails=array(
		'name'=>'moz',
		'title'=>"Moz - Mozscape API",
		'auth'=>array(
			'type'=>'input',
			'external_link'=>array('text'=>"Get Mozscape API details",'url'=>'http://moz.com/products/api/keys'),
			'fields'=>array(
				'access_id'=>array('name'=>"Access ID",'required'=>true),
				'secret_key'=>array('name'=>"Secret Key",'required'=>true)
			)
		),
		'cachingTime'=>2592000
	);
	
	public $apiToNice;
	
	public function __construct()
	{
		$this->engineDetails['auth']['external_link']['text']=_("Get Mozscape API details");
		
		$this->apiToNice=array(
			'urlmetrics'=>json_decode('{"ut":"title","uu":"url","ufq":"subdomain","upl":"root","ueid":"external_links","feid":"subdomain_external_links","peid":"root_external_links","ujid":"juice_links","uifq":"subdomains_linking","uipl":"roots_linking","uid":"links","fid":"subdomain_subdomains_linking","pid":"root_roots_linking","umrp":"mozrank","fmrp":"subdomain_mozrank","pmrp":"root_mozrank","utrp":"moztrust","ftrp":"subdomain_moztrust","ptrp":"root_moztrust","uemrp":"external_mozrank","fejp":"subdomain_external_juice","pejp":"root_external_juice","fjp":"subdomain_juice","pjp":"root_juice","fuid":"subdomain_links","puid":"root_links","fipl":"subdomain_roots_linking","upa":"page_authority","pda":"domain_authority"}',true),
			'linkmetrics'=>json_decode('{"lf":"flags","lt":"anchor","lnt":"normalized_anchor","lmrp":"mozrank_passed"}',true)
		);
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_PLUGIN_Backlinks_Moz();
		}
		
		return self::$_instance;
	}
	
	public function setAuthData($auth)
	{
		$result=true;
		
		foreach ($this->engineDetails['auth']['fields'] as $field=>$details)
		{
			if (isset($auth[$field]))
			{
				$this->authData[$field]=$auth[$field];
			}
			elseif ($details['required'])
			{
				$result=false;
				break;
			}
		}
		
		return $result;
	}
	
	public function getAuthData()
	{
		return $this->authData;
	}
	
	public function getEngineDetails()
	{
		$result=array(
			'hasAuth'=>$this->hasAuth,
			'requireAuth'=>$this->requireAuth,
			'engineDetails'=>$this->engineDetails
		);
		
		return $result;
	}
	
	public function getBacklinks($url,$count=1000)
	{
		$result=false;
		
		if ($this->authData)
		{
			$osUtils=getOS()->getUtils();
			
			$url=$osUtils->appendSlashIfNoPath($url);
			
			$apiUrl=$requestUrl = "http://lsapi.seomoz.com/linkscape/links/".urlencode($url)."?SourceCols=133982846973&TargetCols=133982846973&LinkCols=130015&Scope=page_to_domain&Sort=page_authority&Filter=external&Limit=1000&AccessID=".$this->authData['access_id']."&Expires=".(time()+86400)."&Signature=".$this->generateSignature();
			
			$osHttp=getOS()->getHttp();
			
			$osHttp->setTimeout(0);
			
			if ($response=$osHttp->get($apiUrl) AND $osHttp->success())
			{
				if ($response=json_decode($response,true))
				{
					foreach ($response as $link)
					{
						$nice_link=array(
							'source'=>$osUtils->prependHTTP($link['uu']),
							'target'=>$osUtils->prependHTTP($link['luuu']),
							'anchor'=>(isset($link['lnt'])?$link['lnt']:$link['lt']),
							'nofollow'=>($link['lf'] & 1?true:false)
						);
						
						foreach ($this->apiToNice['urlmetrics'] as $key=>$val)
						{
							if (isset($link[$key]))
							{
								$nice_link['source_'.$val]=$link[$key];
							}
							
							if (isset($link['lu'.$key]))
							{
								$nice_link['target_'.$val]=$link['lu'.$key];
							}
						}
						
						foreach ($this->apiToNice['linkmetrics'] as $key=>$val)
						{
							if (isset($link[$key]))
							{
								$nice_link['link_'.$val]=$link[$key];
							}
						}
						
						ksort($nice_link);
						
						$result[]=$nice_link;
					}
				}
			}
		}
		
		return $result;
	}
	
	public function getUrlsMetrics($urls)
	{
		$result=false;
		
		if ($this->authData)
		{
			$apiUrl = "http://lsapi.seomoz.com/linkscape/url-metrics/?Cols=133982846973&AccessID=".$this->authData['access_id']."&Expires=".(time()+86400)."&Signature=".$this->generateSignature();
			
			$osHttp=getOS()->getHttp();
			$osUtils=getOS()->getUtils();
			
			$urls=array_chunk($urls,10);
			
			foreach ($urls as $urls_chunk)
			{
				foreach ($urls_chunk as $key=>$url)
				{
					$urls_chunk[$key]=$osUtils->appendSlashIfNoPath($url);
					
					$result[$url]=false;
				}

				if ($response=$osHttp->post($apiUrl,json_encode($urls_chunk)) AND $osHttp->success())
				{
					if ($response=json_decode($response,true))
					{
						foreach ($response as $response_url)
						{
							$test_url='http://'.$response_url['uu'];
							
							if (!isset($result[$test_url]))
							{
								$test_url=$osUtils->stripEndingSlash($test_url);
							}
							
							if (isset($result[$test_url]))
							{
								foreach ($this->apiToNice['urlmetrics'] as $key=>$val)
								{
									if (isset($response_url[$key]))
									{
										$result[$test_url][$val]=$response_url[$key];
									}
								}
							}
						}
					}
				}
			}
		}
		
		return $result;
	}
	
	private function generateSignature()
	{
		$result=false;
		
		if ($this->authData)
		{
			$expires=time()+86400;
			$stringToSign = $this->authData['access_id']."\n".$expires;
			$binarySignature = hash_hmac('sha1', $stringToSign, $this->authData['secret_key'], true);
			
			$result=urlencode(base64_encode($binarySignature));
		}
		
		return $result;
	}
}
?>