<?php
class OS_PLUGIN_Cache_apc
{
	private static $_instance;
	
	private $apc;
	
	private $bucket=false;
	
	public $cacheType='memory';
	
	public function __construct()
	{
		if (getOS()->getSettingsVar('cache_engine')=='apc')
		{
			$this->apc=true;
		}
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_PLUGIN_Cache_apc();
		}
		
		return self::$_instance;
	}
	
	public function setBucket($bucket)
	{
		$result=false;
		
		if ($this->apc)
		{
			$this->bucket=(is_array($bucket)?$bucket:array($bucket));
			
			$result=true;
		}
		
		return $result;
	}
	
	public function set($key,$value,$expire)
	{
		$result=false;
		
		if ($this->apc)
		{
			$key=$this->getCacheKey($key);
			
			$result=apc_store($key,$value,$expire);
		}
		
		return $result;
	}
	
	public function get($key)
	{
		$result=false;
		
		if ($this->apc)
		{
			$key=$this->getCacheKey($key);
			
			$result=apc_fetch($key);
		}
		
		return $result;
	}
	
	public function delete($key)
	{
		$result=false;
		
		if ($this->apc)
		{
			$key=$this->getCacheKey($key);
			
			$result=apc_delete($key);
		}
		
		return $result;
	}
	
	public function getCacheKey($key)
	{
		$result=false;
		
		if ($this->apc)
		{
			if ($this->bucket)
			{
				$result=implode('_',$this->bucket).'_'.$key;
			}
			else
			{
				$result=$key;
			}
		}
		
		return $result;
	}
	
	public function purge()
	{
		$result=false;
		
		if ($this->apc)
		{
			$result=apc_clear_cache('user');
		}
		
		return $result;
	}
}
?>