<?php
class OS_PLUGIN_Cache_filesystem
{
	private static $_instance;
	
	private $cachePath;
	
	private $bucket=false;
	
	public $cacheType='disk';
	
	public function __construct()
	{
		if (getOS()->getSettingsVar('cache_engine')=='filesystem')
		{
			$this->cachePath=getOS()->getConfigVar('cache_path');
		}
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_PLUGIN_Cache_filesystem();
		}
		
		return self::$_instance;
	}
	
	public function setBucket($bucket)
	{
		$result=false;
		
		if ($this->cachePath)
		{
			$this->bucket=(is_array($bucket)?$bucket:array($bucket));
			
			$result=true;
		}
		
		return $result;
	}
	
	public function set($key,$value,$expire)
	{
		$result=false;
		
		if ($this->cachePath)
		{
			$cachePath=$this->getCachePath($key);
			
			$utils=getOS()->getUtils();
			
			$expirePath=os_join_path($cachePath,'.expire');
			$dataPath=os_join_path($cachePath,'data.php');
			
			if ($utils->fileWrite($expirePath,$expire))
			{
				$result=$utils->jsonWrite($dataPath,$value);
			}
		}
		
		return $result;
	}
	
	public function get($key)
	{
		$result=false;

		if ($this->cachePath)
		{
			$cachePath=$this->getCachePath($key);

			if (file_exists($cachePath))
			{
				$expirePath=os_join_path($cachePath,'.expire');

				if (file_exists($expirePath))
				{
					$utils=getOS()->getUtils();
					
					$expire_time=$utils->fileRead($expirePath);
					
					$dataPath=os_join_path($cachePath,'data.php');
					
					if (file_exists($dataPath))
					{
						if (time()-filemtime($dataPath)<$expire_time OR $expire_time==0)
						{
							$result=$utils->jsonRead($dataPath);
						}
						else
						{
							$this->delete($key);
						}
					}
				}
			}
		}
		
		return $result;
	}
	
	public function delete($key)
	{
		$result=false;
		
		if ($this->cachePath)
		{
			$cachePath=$this->getCachePath($key);
			
			if (file_exists($cachePath))
			{
				$utils=getOS()->getUtils();
				
				$result=$utils->removeDir($cachePath);
				$this->removeDirUpwards($cachePath);
			}
			else
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	public function purge()
	{
		$result=false;
		
		if ($this->cachePath)
		{
			if (file_exists($this->cachePath))
			{
				$utils=getOS()->getUtils();
				
				$result=$utils->removeDir($this->cachePath);
			}
			else
			{
				$result=true;
			}
		}
		
		return $result;
	}
	
	private function getCachePath($key)
	{
		$result=$this->cachePath;
		
		if ($this->bucket)
		{
			foreach ($this->bucket as $bucket_part)
			{
				$result=os_join_path($result,$bucket_part);
			}
		}
		
		$key_hash=md5($key);
		
		$result=os_join_path($result,$key_hash[0],$key_hash[1],$key_hash[2],$key_hash);
		
		return $result;
	}
	
	private function removeDirUpwards($dir)
	{
		$utils=getOS()->getUtils();
		
		$dir=explode(DIRECTORY_SEPARATOR,$dir);
		array_pop($dir);
		$dir=implode(DIRECTORY_SEPARATOR,$dir);
		
		if ($dir!=$this->cachePath)
		{
			if ($utils->isEmptyDir($dir))
			{
				if ($utils->removeDir($dir))
				{
					$this->removeDirUpwards($dir);
				}
			}
		}
	}
}
?>