<?php
class OS_PLUGIN_SearchEngine_google
{
	private static $_instance;
	
	private $locales;
	
	public $hasLocales=true;
	
	public $title='Google';
	
	public function __construct()
	{
		$this->locales=array();
	}
	
	public static function &get_instance()
	{
		if (!is_object(self::$_instance))
		{
			self::$_instance=new OS_PLUGIN_SearchEngine_google();
		}
		
		return self::$_instance;
	}
	
	public function loadLocale($locale)
	{
		$result=false;
		
		if (!isset($this->locales[$locale]))
		{
			$localeClass="OS_PLUGIN_SearchEngine_google_".$locale;
			
			$this->locales[$locale]=call_user_func(array($localeClass,'get_instance'));
//			$this->locales[$locale]=$localeClass::get_instance();
			
			$result=true;
		}
		elseif (is_object($this->locales[$locale]))
		{
			$result=true;
		}
		
		return $result;
	}
	
	public function getLocaleDetails($locale)
	{
		$result=false;
		
		$locale=strtolower($locale);
		
		if ($this->loadLocale($locale))
		{
			$result=array(
				'title'=>$this->locales[$locale]->title,
				'searchUrlPattern'=>$this->locales[$locale]->searchUrlPattern,
				'serpReferral'=>$this->locales[$locale]->serpReferral,
				'domain'=>$this->locales[$locale]->domain,
			);
		}
		
		return $result;
	}
	
	public function getSearchUrl($query,$locale,$offset=false,$results_per_page=false)
	{
		$result=false;
		
		$locale=strtolower($locale);
		
		if ($this->loadLocale($locale))
		{
			$result=$this->locales[$locale]->getSearchUrl($query,$offset,$results_per_page);
		}
		
		return $result;
	}
	
	public function getDomain($locale)
	{
		$result=false;
		
		$locale=strtolower($locale);
		
		if ($this->loadLocale($locale))
		{
			$result=$this->locales[$locale]->getDomain();
		}
		
		return $result;
	}
	
	public function getResults($serp,$locale)
	{
		$result=false;
		
		$locale=strtolower($locale);
		
		if ($this->loadLocale($locale))
		{
			$result=$this->locales[$locale]->getResults($serp);
		}
		
		return $result;
	}
	
	public function getResultsNumber($serp,$locale)
	{
		$result=false;
		
		$locale=strtolower($locale);
		
		if ($this->loadLocale($locale))
		{
			$result=$this->locales[$locale]->getResultsNumber($serp);
		}
		
		return $result;
	}
	
	public function setResultsPerPage($results_per_page,$locale=false)
	{
		$result=false;
		
		if ($locale)
		{
			$locale=strtolower($locale);
			
			if ($this->loadLocale($locale))
			{
				$result=$this->locales[$locale]->setResultsPerPage($results_per_page);
			}
		}
		elseif (!empty($this->locales))
		{
			foreach ($this->locales as $locale_name=>$locale)
			{
				$result[$locale_name]=$this->locales[$locale_name]->setResultsPerPage($results_per_page);
			}
		}
		
		return $result;
	}
	
	public function setOffset($offset,$locale=false)
	{
		$result=false;
		
		if ($locale)
		{
			$locale=strtolower($locale);
			
			if ($this->loadLocale($locale))
			{
				$result=$this->locales[$locale]->setOffset($offset);
			}
		}
		elseif (!empty($this->locales))
		{
			foreach ($this->locales as $locale_name=>$locale)
			{
				$result[$locale_name]=$this->locales[$locale_name]->setOffset($offset);
			}
		}
		
		return $result;
	}
	
	public function setOption($option,$value,$locale=false)
	{
		$result=false;
		
		if ($locale)
		{
			$locale=strtolower($locale);
			
			if ($this->loadLocale($locale))
			{
				$result=$this->locales[$locale]->setOption($option,$value);
			}
		}
		elseif (!empty($this->locales))
		{
			foreach ($this->locales as $locale_name=>$locale)
			{
				$result[$locale_name]=$this->locales[$locale_name]->setOption($option,$value);
			}
		}
		
		return $result;
	}
}
?>