<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

//return the global OS Object
function &getOS()
{
  if( class_exists('OS_Core') )
    return OS_Core::get_instance();
}

//return the global installer Object
function &getOSInstaller()
{
  	$OS = getOS();
  	
	$fn = os_join_path($OS->getConfigVar('root_path'),'install','lib','classes',"class.os_installer.php");
	
	if(file_exists($fn))
	{
		require_once($fn);
		
		if( class_exists('OS_Installer') )
		{
			return OS_Installer::get_instance();
		}
	}
}


function stack_trace()
{
  $stack = debug_backtrace();
  foreach( $stack as $elem )
    {
      if( $elem['function'] == 'stack_trace' ) continue;
      if( isset($elem['file'])  )
	{
	  echo $elem['file'].':'.$elem['line'].' - '.$elem['function'].'<br/>';
	}
      else
	{
	  echo ' - '.$elem['function'].'<br/>';
	}
    }
}


//joins a path together using proper directory separators
function os_join_path()
{
	$args = func_get_args();
	return implode(DIRECTORY_SEPARATOR,$args);
}

//sanitize input to prevent against XSS, SQL injection and other stuff.
function os_clean_value($val)
{
	if ($val == "") return $val;
		
	//Replace odd spaces with safe ones
	$val = str_replace(" ", " ", $val);
	$val = str_replace(chr(0xCA), "", $val);

	//Encode any HTML to entities (including \n --> <br />)
	$val = os_clean_html($val);

	//Double-check special chars and remove carriage returns
	//For increased SQL security
	$val = preg_replace("/\\\$/", "$", $val);
	$val = preg_replace("/\r/", "", $val);
	$val = str_replace("!", "!", $val);
	$val = str_replace("'", "'", $val);

	//Allow unicode (?)
	$val = preg_replace("/&amp;#([0-9]+);/s", "&#\\1;", $val);

	//Swap user-inputted backslashes (?)
	$val = preg_replace("/\\\(?!&amp;#|\?#)/", "\\", $val);
	return $val;
}


function os_clean_email($email)
{
	$email = os_clean_value(trim(strtolower($email)));
	
	if(strpos($email,'www.')===0) $email= substr($email,4);
	
	return $email;
}

//
function os_clean_html($string, $remove = false)
{
	if ($remove)
	{
		$string = strip_tags($string);
	} 
	else
	{
		$patterns = array("/\&/", "/%/", "/</", "/>/", '/"/', "/'/", "/\(/", "/\)/", "/\+/", "/-/");
		$replacements = array("&amp;", "&#37;", "&lt;", "&gt;", "&quot;", "&#39;", "&#40;", "&#41;", "&#43;", "&#45;");
		$string = preg_replace($patterns, $replacements, $string);
	}
	return $string;
}


//begin install functions
function ilang()
{
	$result = '';
	
	if (func_num_args() > 0)
	{
		$string = func_get_arg(0);
		
		if (func_num_args() == 2 && is_array(func_get_arg(1)))
		{
			$params = func_get_arg(1);
		}
		elseif (func_num_args() > 1)
		{
			$params = array_slice(func_get_args(), 1);
		}
		else
		{
			$params = array();
		}
		
		if (count($params) > 0)
		{
			$result = vsprintf($string, $params);
		}
		else
		{
			$result = $string;
		}
	}

	return $result;
}

//end install functions

//Gettext fix
if (!function_exists('_'))
{
	function _($text)
	{
		return $text;
	}
}


//A function for auto-loading classes.
function __os_load($filepath)
{
  static $_cumulative = 0;
  $mem = memory_get_usage();
  require_once($filepath);
  $mem = memory_get_usage() - $mem;
  $_cumulative += $mem;
  
  //echo "{$filepath} tmem: {$_cumulative}<br>";
  //debug_buffer("Loading $filename = $mem bytes for an approximate total of $_cumulative");
}

function os_autoloader($classname)
{
  	$os_root_path = OS_ROOT_PATH;
	
  	$lowercase = strtolower($classname);
  
  if (0===strpos($lowercase,'os_app_'))
  {
  	if (false!==strpos($lowercase,'_',strpos($lowercase,'os_app_')+strlen('os_app_')+1))
  	{
  		//app subclass
  		$app_name=explode('_',substr($lowercase,strlen('os_app_')));
  		$app_name=$app_name[0];
  		
  		$fn = os_join_path($os_root_path,'apps',$app_name,'lib',"class.{$lowercase}.php");
  	}
  	else
  	{
  		//app class
  		$app_name=str_replace('os_app_','',$lowercase);
  		
  		$fn = os_join_path($os_root_path,'apps',$app_name,'init.php');
  	}
  }
  elseif (0===strpos($lowercase,'os_appcron_'))
  {
  	//app cron
	$app_name=explode('_',substr($lowercase,strlen('os_appcron_')));
	$app_name=$app_name[0];
	
	$fn = os_join_path($os_root_path,'apps',$app_name,'crons',"class.{$lowercase}.php");
  }
  elseif (0===strpos($lowercase,'os_appdaemon_'))
  {
  	//app daemon
	$app_name=explode('_',substr($lowercase,strlen('os_appdaemon_')));
	$app_name=$app_name[0];
	
	$fn = os_join_path($os_root_path,'apps',$app_name,'daemons',"class.{$lowercase}.php");
  }
  elseif (0===strpos($lowercase,'os_appfork_'))
  {
  	//app forkable code
  	$app_name=explode('_',substr($lowercase,strlen('os_appfork_')));
  	$app_name=$app_name[0];
  	
  	$fn=os_join_path($os_root_path,'apps',$app_name,'forks',"class.{$lowercase}.php");
  }
  elseif (0===strpos($lowercase,'os_appview_'))
  {
  	//app view code
  	$app_name=explode('_',substr($lowercase,strlen('os_appview_')));
  	$actual_app_name=$app_name[0];
  	unset($app_name[0]);
  	$view_name=implode('_',$app_name);
  	
  	$fn=os_join_path($os_root_path,'apps',$actual_app_name,'views',"{$view_name}.php");
  }
  elseif (0===strpos($lowercase,'os_appevent_'))
  {
  	//app event code
  	$app_name=explode('_',substr($lowercase,strlen('os_appevent_')));
  	$app_name=$app_name[0];
  	
  	$fn=os_join_path($os_root_path,'apps',$app_name,'events',"class.{$lowercase}.php");
  }
  elseif (0===strpos($lowercase,'os_widget_'))
  {
  	if (false!==strpos($lowercase,'_',strpos($lowercase,'os_widget_')+strlen('os_widget_')+1))
  	{
  		//widget subclass
  		$widget_name=explode('_',substr($lowercase,strlen('os_widget_')));
  		$widget_name=$widget_name[0];
  		
  		$fn = os_join_path($os_root_path,'widgets',$widget_name,'lib',"class.{$lowercase}.php");
  	}
  	else
  	{
  		//widget class
  		$widget_name=str_replace('os_widget_','',$lowercase);
  		
  		$fn = os_join_path($os_root_path,'widgets',$widget_name,'init.php');
  	}
  }
	elseif (0===strpos($lowercase,'os_widgetview_'))
	{
		//widget view code
		$wiget_name=explode('_',substr($lowercase,strlen('os_widgetview_')));
		$actual_widget_name=$wiget_name[0];
		unset($wiget_name[0]);
		
		$view_name=implode('_',$wiget_name);
		
		$fn=os_join_path($os_root_path,'widgets',$actual_widget_name,'views',"{$view_name}.php");
	}
  elseif (0===strpos($lowercase,'os_plugin_'))
  {
  	if (false!==strpos($lowercase,'_',strpos($lowercase,'os_plugin_')+strlen('os_plugin_')+1))
  	{
  		$plugin_details=explode('_',substr($lowercase,strlen('os_plugin_')));
  		$wrapper_name=$plugin_details[0];
  		$plugin_name=$plugin_details[1];
  		unset($plugin_details[0],$plugin_details[1]);
  		
  		if (count($plugin_details)>0)
  		{
  			//plugin subclass
  			$plugin_subclass=implode('_',$plugin_details);
  			
  			$fn = os_join_path($os_root_path,'lib','classes','plugins',$wrapper_name,$plugin_name,'lib',"class.{$lowercase}.php");
  		}
  		else
  		{
  			//plugin class
	  		$fn = os_join_path($os_root_path,'lib','classes','plugins',$wrapper_name,$plugin_name,"class.{$lowercase}.php");
  		}
  	}
  }
  elseif (0===strpos($lowercase,'os_cron_'))
  {
  	//cron
  	$fn=os_join_path($os_root_path,'crons',"class.{$lowercase}.php");
  }
  elseif (0===strpos($lowercase,'os_fork_'))
  {
  	//forkable code
  	$fn=os_join_path($os_root_path,'forks',"class.{$lowercase}.php");
  }
  elseif (0===strpos($lowercase,'os_daemon_'))
  {
  	//daemon
  	$fn=os_join_path($os_root_path,'daemons',"class.{$lowercase}.php");
  }
  else
  {
	  //standard class
	  $fn = os_join_path($os_root_path,'lib','classes',"class.{$lowercase}.php");
  }

  if( file_exists($fn) )
    {
      __os_load($fn);
      return;
    }
}

spl_autoload_register('os_autoloader');
?>