/*
 * Script from NETTUTS.com [by James Padolsey]
 * @requires jQuery($), jQuery UI & sortable/draggable UI modules
 */

var iNettuts = {
    
    jQuery : $,
    
    moveNewColumnID : null,
    
    moveNewPosition : null,
    
    settings : {
        columns : '.panel-column',
        widgetSelector: '.widget-container',
        handleSelector: '.widget-head',
        contentSelector: '.widget-content',
        widgetDefault : {
            movable: true,
            removable: true,
            collapsible: true,
            editable: true,
            colorClasses : ['color-yellow', 'color-red', 'color-blue', 'color-white', 'color-orange', 'color-green']
        },
        widgetIndividual : {
            intro : {
                movable: false,
                removable: false,
                collapsible: false,
                editable: false
            }
        }
    },

    init : function () {
        //this.attachStylesheet('inettuts.js.css');
        this.addWidgetControls();
        this.makeSortable();
    },
    
    getWidgetSettings : function (id) {
        var $ = this.jQuery,
            settings = this.settings;
        return (id&&settings.widgetIndividual[id]) ? $.extend({},settings.widgetDefault,settings.widgetIndividual[id]) : settings.widgetDefault;
    },
    
    addWidgetControls : function () {
        var iNettuts = this,
            $ = this.jQuery,
            settings = this.settings;
            
        $(settings.widgetSelector, $(settings.columns)).each(function () {
            var thisWidgetSettings = iNettuts.getWidgetSettings(this.id);
            
            if (thisWidgetSettings.removable) {
                $('<a href="#" class="remove">CLOSE</a>')
                .mousedown(function (e) {e.stopPropagation();})
                .click(iNettuts.handleWidgetRemove).appendTo($(settings.handleSelector, this));
            }
            
            if (thisWidgetSettings.editable) {
                $('<a href="#" class="edit">EDIT</a>').mousedown(function (e) {e.stopPropagation();})
                .toggle(function () {
                    $(this).css({backgroundPosition: '-66px 0', width: '55px'})
                        .parents(settings.widgetSelector)
                        .find('.edit-box').show().find('input').focus();
                    return false;
                },function () {
                    $(this).css({backgroundPosition: '', width: ''})
                        .parents(settings.widgetSelector)
                        .find('.edit-box').hide();
                    return false;
                }).appendTo($(settings.handleSelector,this));
                
                $('<div class="edit-box" style="display:none;"/>')
                    .append('<ul><li class="item"><label>Change the title?</label><input value="' + $('h3',this).text() + '"/></li>')
                    .append((function(){
                        var colorList = '<li class="item"><label>Available colors:</label><ul class="colors">';
                        $(thisWidgetSettings.colorClasses).each(function () {
                            colorList += '<li class="' + this + '"/>';
                        });
                        return colorList + '</ul>';
                    })())
                    .append('</ul>')
                    .insertAfter($(settings.handleSelector,this));
            }
            
            if (thisWidgetSettings.collapsible)
            	{
	                var osWidget = osDashboard.getWidgetByID(this.id);
	                var collapseBtn = $('<a href="#" class="collapse">COLLAPSE</a>');
	                var isCollapsed = false;

	                if(osWidget !== false) if(osWidget.collapsed == "Y") isCollapsed = true;
                
	                if(isCollapsed)
	                {
                    	collapseBtn.css({backgroundPosition: '-38px 0'});
        	            $(this).find(settings.contentSelector).hide();
        	            collapseBtn.toggle(iNettuts.handleCollapseShow,iNettuts.handleCollapseHide);
	                }
	                else
	                {
	                	collapseBtn.toggle(iNettuts.handleCollapseHide,iNettuts.handleCollapseShow);
	                }	
                	
	                collapseBtn.mousedown(function (e) {e.stopPropagation();})
	                	.prependTo($(settings.handleSelector,this));
            	}
        });
        
        $('.edit-box').each(function ()
        	{
            $('input',this).keyup(function ()
            	{
               	$(this).parents(settings.widgetSelector).find('h3').text( $(this).val().length>20 ? $(this).val().substr(0,20)+'...' : $(this).val() );
            	});
            
            $('ul.colors li',this).click(function ()
            	{
                
                var colorStylePattern = /\bcolor-[\w]{1,}\b/,
                    thisWidgetColorClass = $(this).parents(settings.widgetSelector).attr('class').match(colorStylePattern)
                    
                if (thisWidgetColorClass)
                	{
                    $(this).parents(settings.widgetSelector)
                        .removeClass(thisWidgetColorClass[0])
                        .addClass($(this).attr('class').match(colorStylePattern)[0]);
                	}
                return false;
                
            	});
        	});
        
    },
    
    attachStylesheet : function (href) {
        var $ = this.jQuery;
        return $('<link href="' + href + '" rel="stylesheet" type="text/css" />').appendTo('head');
    },
    
    makeSortable : function () {
    	
    	var iNettuts = this,
            $ = this.jQuery,
            settings = this.settings,
            $sortableItems = (function () {
            	
            	var notSortable = '';
            	
            	$(settings.widgetSelector,$(settings.columns)).each(function (i) {
                    if (!iNettuts.getWidgetSettings(this.id).movable) {
                        if(!this.id) {
                            this.id = 'widget-no-id-' + i;
                        }
                        notSortable += '#' + this.id + ',';
                    }
                });
            	
            	var sortableID = (notSortable=='' ? '> li' : '> li:not(' + notSortable + ')');
            	
            	return $(sortableID, settings.columns);
            })();
        
        $sortableItems.find(settings.handleSelector).css({
            cursor: 'move'
        }).mousedown(function (e) {
            $sortableItems.css({width:''});
            $(this).parent().css({
                width: $(this).parent().width() + 'px'
            });
        }).mouseup(function () {
            if(!$(this).parent().hasClass('dragging')) {
                $(this).parent().css({width:''});
            } else {
                $(settings.columns).sortable('disable');
            }
        });
        

        $(settings.columns).sortable({
            items: $sortableItems,
            connectWith: $(settings.columns),
            handle: settings.handleSelector,
            placeholder: 'widget-placeholder',
            forcePlaceholderSize: true,
            revert: 300,
            delay: 100,
            opacity: 0.8,
            containment: 'document',
            start: iNettuts.handleWidgetStart,
            stop: iNettuts.handleWidgetStop,
            update: iNettuts.handleWidgetUpdate,
            over: iNettuts.handleWidgetOver,
            receive: iNettuts.handleWidgetReceive
        });
    },
    
    handleWidgetStart : function (e,ui)
    {
    	console.log('handleWidgetStart');
    	
    	jQuery(ui.helper).addClass('dragging');
    },

    handleWidgetStop : function (e,ui)
    {
    	console.log('handleWidgetStop');
    	
    	var widgetID = $(ui.item).attr("id");
    	
    	//check if widget moved from other column
    	if(iNettuts.moveNewColumnID == null || iNettuts.moveNewPosition == null)
    	{
	    	var columnIDParts = $(this).attr("id").split("-");
	    	var elements_order = $(this).find('li.widget');
	    	
	    	var position = 1; var flag = false;
	    	$.each(elements_order, function(index,widgetContainer)
	    		{
	    		if(!flag)
	    			{
	    			if(widgetContainer.id == widgetID) flag = true;
	    			else position++;
	    			}
	    		});

	    	iNettuts.moveNewColumnID = columnIDParts[2];
	    	iNettuts.moveNewPosition = position;
    	}

    	
    	if(iNettuts.moveNewColumnID != null && iNettuts.moveNewPosition != null)
    		{
        	xHttp.Post({
        		section: 'dashboard', 
        		action:'moveWidgetContainer',
        		params: {widgetID:widgetID, newColumnID: iNettuts.moveNewColumnID, newPosition: iNettuts.moveNewPosition}, 
        		callback : iNettuts.moveWidgetContainerResponse
        		});
        	
        	iNettuts.moveNewColumnID = null;
        	iNettuts.moveNewPosition = null;
    		}
    	
    	jQuery(ui.item).css({width:''}).removeClass('dragging');
    	jQuery(iNettuts.settings.columns).sortable('enable');
    },

    handleWidgetUpdate : function (e,ui)
    {
    	console.log('handleWidgetUpdate');
    },

    handleWidgetOver : function (e,ui)
    {
    	console.log('handleWidgetOver');
    },

    handleWidgetReceive : function (e,ui)
    {
    	console.log('handleWidgetReceive');
    	
    	var widgetID = $(ui.item).attr("id");
    	var columnIDParts = $(this).attr("id").split("-");
    	
    	var elements_order = $(this).find('li.widget');
    	
    	var position = 1; var flag = false;
    	$.each(elements_order, function(index,widgetContainer)
    		{
    		if(!flag)
    			{
    			if(widgetContainer.id == widgetID) flag = true;
    			else position++;
    			}
    		});
    	
    	iNettuts.moveNewColumnID = columnIDParts[2];
    	iNettuts.moveNewPosition = position;
    },
    
    moveWidgetContainerResponse : function(responseData)
    {
    	if(responseData.actionStatus === true)
		{
    		//update widgets data
    		osDashboard.widgetsData = responseData.actionData.dashboardData.widgets;
		}		
    },
    
    handleCollapseHide : function()
    {
    	var widgetID = $(this).parent().parent().attr("id");
    	
    	xHttp.Post({section: 'dashboard', action:'hideWidgetContainer',params: {widgetID:widgetID}, callback : iNettuts.hideWidgetContainerResponse});
    	
    	return false;
    },
    
    hideWidgetContainerResponse : function(responseData)
    {
    	if(responseData.actionStatus === true)
    		{
    		var widgetID = responseData.actionData.widgetID;
    		
    		var collapseBtn = $($('#'+widgetID).find('a.collapse'))[0];
    		
    		var settings = iNettuts.settings;

    		$(collapseBtn).css({backgroundPosition: '-38px 0'})
            .parents(settings.widgetSelector)
                .find(settings.contentSelector).hide();
    		}
    },
    
    handleCollapseShow : function()
    {
    	var widgetID = $(this).parent().parent().attr("id");
    	
    	xHttp.Post({section: 'dashboard', action:'showWidgetContainer',params: {widgetID:widgetID}, callback : iNettuts.showWidgetContainerResponse});
    	
    	return false;
    },
    
    showWidgetContainerResponse : function(responseData)
    {
    	if(responseData.actionStatus === true)
			{
    		var widgetID = responseData.actionData.widgetID;
    		
    		var collapseBtn = $($('#'+widgetID).find('a.collapse'))[0];
    		
    		var settings = iNettuts.settings;
	
	    	$(collapseBtn).css({backgroundPosition: ''})
	        .parents(settings.widgetSelector)
	            .find(settings.contentSelector).show();
	    	
			}
    },
    
    handleWidgetRemove : function()
    {
    	var widgetID = $(this).parent().parent().attr("id");
    	
        if(confirm('This widget will be removed, ok?'))
        {
        	xHttp.Post({section: 'dashboard', action:'removeWidget',params: {widgetID:widgetID}, callback : iNettuts.removeWidgetResponse});
        }
        return false;
    },

    removeWidgetResponse : function(responseData)
    {
    	if(responseData.actionStatus === true)
		{
			var widgetID = responseData.actionData.widgetID;
			
			var removeBtn = $($('#'+widgetID).find('a.remove'))[0];
			
			var settings = iNettuts.settings;
			
			//remove current widget data
			var removeResult = osDashboard.removeWidgetData(widgetID);
			
			$(removeBtn).parents(settings.widgetSelector).animate({
	            opacity: 0    
	        },function () {
	            $(this).wrap('<div/>').parent().slideUp(function () {
	                
	            	$(this).remove();
	            });
	        });		
		}
    }
};