Raphael.fn.pieChart = function (values, legend, options) {
    var paper = this,
        rad = Math.PI / 180,
        chart = this.set();

    var r = options.radius || 100,
    	cx = options.center_x || r+250,
    	cy = options.center_y || r+250,
    	strokecolor = options.strokecolor || '#000',
    	strokewidth = options.strokewidth || 2,
    	chartpadding = options.chart_padding || 20,
    	legendposition = options.legend_position || 'none',
    	legend_padding_left = options.legend_padding_left || 0,
    	legend_padding_top = options.legend_padding_top || 0,
    	legend_width = options.legend_width,
    	legend_height = options.legend_height,
    	links = options.links || false;

    function sector(cx, cy, r, startAngle, endAngle, params) {
        var x1 = cx + r * Math.cos(-startAngle * rad),
            x2 = cx + r * Math.cos(-endAngle * rad),
            y1 = cy + r * Math.sin(-startAngle * rad),
            y2 = cy + r * Math.sin(-endAngle * rad);
		if (startAngle==0 && endAngle==360) { y2=y1+0.1; }
        return paper.path(["M", cx, cy, "L", x1, y1, "A", r, r, 0, +(endAngle - startAngle > 180), 0, x2, y2, "z"]).attr(params);
    }
    var angle = 0,
        total = 0,
        start = 0,
        process = function (j) {
            var value = values[j],
                angleplus = 360 * value / total,
                popangle = angle + (angleplus / 2),
                color = Raphael.hsb(start, .75, 1),
                ms = 200,
                delta = 5,
                bcolor = Raphael.hsb(start, 1, 1),
                forcedcolor = (options.colors?(options.colors[j] || false):false),
                p = sector(cx, cy, r, angle, angle + angleplus, {fill: (forcedcolor?forcedcolor:"90-" + bcolor + "-" + color), stroke: strokecolor, "stroke-width": strokewidth});

            if (legendposition!='none')
            {
                var txt = paper.text(legend_padding_left+30, legend_padding_top+10+j*22, legend[j]+' - '+Math.round(100*value/total)+'%').attr({'text-anchor':'start',fill: strokecolor, stroke: "none", opacity: 1, "font-size": 12}),
                	dot = paper.circle(legend_padding_left+15, legend_padding_top+10+j*22, 7).attr({fill: (forcedcolor?forcedcolor:bcolor), stroke: strokecolor, "stroke-width": 1});
            }
            
            var mClick = false;
            
            if (links)
            {
            	if (links[j])
            	{
            		mClick = function () { top.location=links[j]; }
            	}
            }
            
            var mOver = function () { p.toFront().stop().animate({transform: "s 1.05 1.05 "+cx+' '+cy}, ms, "linear"); if (legendposition!='none') { dot.attr("r",10);txt.attr("font-weight",'800'); } },
                mOut = function () { p.stop().animate({transform: ""}, ms, "linear"); if (legendposition!='none') { txt.attr("font-weight",'500');dot.attr("r",7); } };
                
            p.mouseover(mOver).mouseout(mOut);
            
            if (mClick)
            {
            	p.click(mClick);
            	p.attr({cursor:"pointer"});
            }
            
            if (legendposition!='none')
            {
            	txt.mouseover(mOver).mouseout(mOut);
            	dot.mouseover(mOver).mouseout(mOut);
            	
            	if (mClick)
            	{
            		txt.click(mClick);
            		txt.attr({cursor:"pointer"});
            		dot.click(mClick);
            		dot.attr({cursor:"pointer"});
            	}
            }
            
            angle += angleplus;
            chart.push(p);
            
            if (legendposition!='none')
            {
	            chart.push(txt);
	            chart.push(dot);
	        }
	        
            start += .1;
        };
    for (var i = 0, ii = values.length; i < ii; i++) {
        total += values[i];
    }
    for (i = 0; i < ii; i++) {
        process(i);
    }
    
    if (legendposition!='none')
    {
    	var legendBox = paper.rect(legend_padding_left,legend_padding_top-2,legend_width+2,legend_height+4,10).attr({stroke: strokecolor, "stroke-width": 1});
    	chart.push(legendBox);
    }
    
    return chart;
};