// Filename: app2.js
define([
  'jquery',
  'underscore',
  'backbone',
  'vm',
  'events',
  'text!templates/layout.html'
], function($, _, Backbone, Vm, Events, layoutTemplate){

	Backbone.debug = false;
	  
	 /*Override default sync*/
	Backbone.sync = function(method, model, options)
	{
		var self = this;
		var currentModel = model;
		
		var params = {type: 'POST', dataType: 'json', data:{}};
		
		//define currentUrl
		if (!options.url)
		{
		    params.url = getValue(model, 'url') || urlError();
		}
		
		if (model)
		{
			//params.contentType = 'application/json';
			params.data['params'] = model.toJSON();
		}
		
		Backbone.log("Backbone.sync :: model.toJSON()");
		Backbone.log(model.toJSON());
		
		//define currentAction
		if(currentModel._meta)
		{
			if(currentModel._meta.methodMap)
			{
				if(currentModel._meta.methodMap[method])
				{
					params.data['action'] = currentModel._meta.methodMap[method];
				}
			}
		}
		//params.data = JSON.stringify(params.data); //jsonify ?
		
		var oldSuccess = options.success;
		var handleResponse = function(r,s,x)
			{
				Backbone.handleNotifications(r);	
			
				if (Backbone.validResponse(r))
				{
					oldSuccess(r,s,x);
				} 
			}
		
		options.success = handleResponse;
		
		var response=$.ajax(_.extend(params, options));
		
		return response;		
	}
	
	/*Attach a log function to Backbone*/
	Backbone.log = function(string)
	{
		if(Backbone.debug === true) if(console) if(console.log) console.log(string);
	}
	
	
	_.extend(Backbone.Model.prototype, {
		
		/*Overwrite default Backbone.Model.parse*/
		parse : function(resp, xhr)
	    {
			modelData = {};
			
			if(resp.data)
	    	{
	    		if(resp.data.actionData)
	    		{
	    			if(resp.data.actionData.modelDetails)
	    			{
	    				modelData = resp.data.actionData.modelDetails;	
	    			}	
	    		}	
	    	}
			
			return modelData;
	    } 
	});
	
	
	_.extend(Backbone.Collection.prototype, {
		
		/*Overwrite default Backbone.Collection.parse*/
		parse : function(resp, xhr)
	    {
			collectionData = {};
			
			if(resp.data)
	    	{
	    		if(resp.data.actionData)
	    		{
	    			if(resp.data.actionData.collectionDetails)
	    			{
	    				collectionData =  _.toArray(resp.data.actionData.collectionDetails);	
	    			}	
	    		}	
	    	}	
			
			return collectionData;
	    } 
	});	
	
	
	/*Attach setMeta to Backbone */
	Backbone.setMeta = function(Obj, prop, value)
   {
   	if (value === undefined)
       {
           return Obj._meta[prop];
       } 
       else
       {
    	   Obj._meta[prop] = value;
       }
   }
	
	/*Attach validResponse to Backbone */
	Backbone.validResponse = function(resp)
	{
		var result = false;
		
		if(resp)
		{
			if(resp.status && resp.data)
			{
				if(resp.data.actionData)
				{
					//check if user has permissions 
					if(resp.data.actionData.permissionRequired) 
					{
						var permissionRequired = resp.data.actionData.permissionRequired;
						var permissionUrl = false;
						
						if(permissionRequired == 'checkUserLogged') permissionUrl = "../users/logout.php";
						else if(permissionRequired == 'checkUserAdmin') permissionUrl = "../users/projects_list.php?msg=noperms";
						else if(permissionRequired == 'checkUserProject') permissionUrl = "../users/projects_list.php?msg=selectprj";
						else if(permissionRequired == 'checkAppstore') permissionUrl = "admin.php#admin_credentials";
						if(permissionUrl) window.location = permissionUrl;
					}
						
					if(resp.status == 'OK')
					{
						result = true;	
					}	
				}	
			}
		}	
		
		return result;
	}
	
	
	/*Attach notifications to Backbone */
	Backbone.handleNotifications = function(responseData)
	{
		if(responseData)
		{
			var notifications = [];
			
			if(responseData.notifications)
			{
				notifications = responseData.notifications;
			}
			
			if(responseData.data)
			{
				if(responseData.data.actionData)
				{
					if(responseData.data.actionData.notifications)
					{
						notifications = responseData.data.actionData.notifications;
					}
				}
			}
			
			if (notifications.length > 0)
			{
				var notificationsData = {'success': [],'error': [], 'warning': [], 'info': []}
				
	    		_.each(notifications, function(item)
	    			{
	    				if(item.type) if(notificationsData[item.type]) notificationsData[item.type].push(item.message); 
	    			});
				
	    		_.each(notificationsData, function(item, key)
	    		{
					if(item.length > 0)
					{
		    			message = item.join('<br>');
			    		if(key == 'error') osKernel.showErrorSplash(message);
		    			else if(key == 'success') osKernel.showSuccessSplash(message);
		    			else if(key == 'warning') osKernel.showWarningSplash(message);
		    			else if(key == 'info') osKernel.showInfoSplash(message);
					}
	    		});
			}	
		}
	}	
	
	var getValue = function(object, prop)
	{
		if (!(object && object[prop])) return null;
		return _.isFunction(object[prop]) ? object[prop]() : object[prop];
	};

   var urlError = function() {throw new Error('A "url" property or function must be specified');};
	
  var AppView = Backbone.View.extend({
      el: "#livedash-container",
      
	  initialize: function ()
	  {
        var NestedView2 = Backbone.View.extend({});
        var NestedView1 = Backbone.View.extend({
          initialize: function () {
            var nestedView2 = Vm.create(this, 'Nested View 2', NestedView2);
          }
        });
        var nestedView1 = Vm.create(this, 'Nested View 1', NestedView1);		  
	  },
	  
	  render: function ()
	  {
		  $(this.el).html(layoutTemplate);
	  }
  });
  
  return AppView;
});