// Filename: router.js
define([
  'jquery',
  'underscore',
  'backbone',
  'vm'
], function ($, _, Backbone, Vm) {
  var AppRouter = Backbone.Router.extend({
    routes: {
    	// Pages
		'widgets': 'widgetsview',
		'apps': 'appsview',
		'apps/:app': 'appsview_app',
		'apps/:app/:view': 'appsview_app_view',
		'apps/:app/:view/:params': 'appsview_app_view_params',
		'market': 'marketview',
		'apps_manager': 'apps_manager',
		'widgets_manager': 'widgets_manager',
		'admin_market': 'admin_market',
		'connectors_manager': 'connectors_manager',
		'crons_manager': 'crons_manager',
		'interactions_manager': 'interactions_manager',
		'events_manager': 'events_manager',
		'proxies_manager': 'proxies_manager',
		'datasources_manager': 'datasources_manager',
		'admin_settings': 'admin_settings',
		'admin_credentials': 'admin_credentials',
		'change_project/:projectID': 'change_project',
    
		// Default
		'*actions': 'defaultAction'
    },
  
	  updateMenuOption: function(activeOption)
	  {
	  	if ($.window)
	  	{
	  		$.window.closeAll(true);
	  	}
	
	  	if (!$('#page').find('#loadingSpinner').length)
	  	{
	  		$('#page').html("<div id='loadingSpinner' class='spinner'></div>");
	  		
	  		if ('false'==$('.nav-collapse').attr('aria-hidden'))
	  		{
	  			navigation.toggle();
	  		}
	  		
	  		$('#livedash-waiting-overlay').css({visibility: 'hidden'});
	  	}
	  	
	  	$('ul.menu-left').find('li').each(function(){
				
	  		var currentMenuBlock = $(this);	
				var currentOption =  currentMenuBlock.find('a').attr("id");
				
				if(currentOption == 'menu_item_'+activeOption) currentMenuBlock.addClass("current");
				else  currentMenuBlock.removeClass("current");
			});
	  }	  
  
  });

var initialize = function(options)
  	 {

	  var appView = options.appView;
    
	  var router = new AppRouter(options);

	  router.on('route:widgetsview', function (actions) 
	  {
	  	require(['views/widgets/page'], function (WidgetsPage)
	  	{
	  		router.updateMenuOption('widgetsview');
	  		
	  		var widgetsPage = Vm.create(appView, 'WidgetsPage', WidgetsPage);
	  	});
	  });
	  
	  router.on('route:appsview', function (actions) 
	  {
	  	require(['views/apps/page'], function (AppsViewPage)
	  	{
	  		router.updateMenuOption('appsview');
	  		
	  		var appsViewPage = Vm.create(appView, 'AppsViewPage', AppsViewPage);
	  	});
	  });
	  
	  router.on('route:appsview_app', function (actions) 
	  {
	  	require(['views/apps/page'], function (AppsViewPage)
	  	{
	  		router.updateMenuOption('appsview');
	  		
	  		var appsViewPage = Vm.create(appView, 'AppsViewPage', AppsViewPage, {active_app: actions});
	  	});
	  });
	  
	  router.on('route:appsview_app_view', function (app, view) 
	  {
	  	require(['views/apps/page'], function (AppsViewPage)
	  	{
	  		router.updateMenuOption('appsview');
	  		
	  		var appsViewPage = Vm.create(appView, 'AppsViewPage', AppsViewPage, {active_app: app, active_app_view: view});
	  	});
	  });
	  
	  router.on('route:appsview_app_view_params', function (app, view, params) 
	  {
	  	require(['views/apps/page'], function (AppsViewPage)
	  	{
	  		router.updateMenuOption('appsview');
	  		
	  		var appsViewPage = Vm.create(appView, 'AppsViewPage', AppsViewPage, {active_app: app, active_app_view: view, active_app_params: params});
	  	});
	  });
	  
	  router.on('route:marketview', function (actions) 
	  {
	  	require(['views/market/page'], function (MarketPage)
	  	{
	  		router.updateMenuOption('marketview');
	  		
	  		var marketPage = Vm.create(appView, 'MarketPage', MarketPage);
	  	});
	  });
	  
	  
	  router.on('route:apps_manager', function (actions) 
	  {
	  	require(['views/admin_apps_manager/page'], function (AppsManagerPage)
	  	{
	  		router.updateMenuOption('admin_list');
	  		
	  		var appsManagerPage = Vm.create(appView, 'AppsManagerPage', AppsManagerPage);
	  	});
	  });
	  
	  router.on('route:widgets_manager', function (actions) 
	  {
	  	require(['views/admin_widgets_manager/page'], function (WidgetsManagerPage)
	  	{
	  		router.updateMenuOption('admin_list');
	  		
	  		var widgetsManagerPage = Vm.create(appView, 'WidgetsManagerPage', WidgetsManagerPage);
	  	});
	  });	  

	  router.on('route:admin_market', function (actions) 
	  {
	  	require(['views/admin_market/page'], function (AdminMarketPage)
	  	{
	  		router.updateMenuOption('admin_list');
	  		
	  		var adminMarketPage = Vm.create(appView, 'AdminMarketPage', AdminMarketPage);
	  	});
	  });
	  
	  router.on('route:connectors_manager', function (actions) 
	  {
	  	require(['views/admin_connectors/page'], function (ConnectorsManagerPage)
	  	{
	  		router.updateMenuOption('admin_list');
	  		
	  		var connectorsManagerPage = Vm.create(appView, 'ConnectorsManagerPage', ConnectorsManagerPage);
	  	});
	  });	  

	  router.on('route:crons_manager', function (actions) 
	  {
	  	require(['views/admin_crons/page'], function (CronsManagerPage)
	  	{
	  		router.updateMenuOption('admin_list');
	  		
	  		var cronsManagerPage = Vm.create(appView, 'CronsManagerPage', CronsManagerPage);
	  	});
	  });	  
	  
      router.on('route:interactions_manager', function (actions) 
	  {
	  	require(['views/admin_interactions/page'], function (InteractionsManagerPage)
	  	{
	  		router.updateMenuOption('admin_list');
	  		
	  		var interactionsManagerPage = Vm.create(appView, 'InteractionsManagerPage', InteractionsManagerPage);
	  	});
	  });	
	  
	  router.on('route:events_manager', function (actions) 
	  {
	  	require(['views/admin_events/page'], function (EventsManagerPage)
	  	{
	  		router.updateMenuOption('admin_list');
	  		
	  		var eventsManagerPage = Vm.create(appView, 'EventsManagerPage', EventsManagerPage);
	  	});
	  });
	  
	  router.on('route:proxies_manager', function (actions) 
	  {
	  	require(['views/admin_proxies/page'], function (ProxiesManagerPage)
	  	{
	  		router.updateMenuOption('admin_list');
	  		
	  		var proxiesManagerPage = Vm.create(appView, 'ProxiesManagerPage', ProxiesManagerPage);
	  	});
	  });	  
	  
	  router.on('route:datasources_manager', function (actions) 
	  {
	  	require(['views/admin_datasources/page'], function (DatasourcesManagerPage)
	  	{
	  		router.updateMenuOption('admin_list');
	  		
	  		var datasourcesManagerPage = Vm.create(appView, 'DatasourcesManagerPage', DatasourcesManagerPage);
	  	});
	  });
	  
	  router.on('route:admin_settings', function (actions) 
	  {
	  	require(['views/admin_settings/page'], function (AdminSettingsPage)
	  	{
	  		router.updateMenuOption('admin_list');
	  		
	  		var adminSettingsPage = Vm.create(appView, 'AdminSettingsPage', AdminSettingsPage);
	  	});
	  });
	  
	  router.on('route:admin_credentials', function (actions) 
	  {
	  	require(['views/admin_credentials/page'], function (AdminCredentialsPage)
	  	{
	  		router.updateMenuOption('admin_list');
	  		
	  		var adminCredentialsPage = Vm.create(appView, 'AdminSettingsPage', AdminCredentialsPage);
	  	});
	  });
	  
	  router.on('route:change_project', function (actions) 
	  {
		require(['views/project_manager/project'], function (ProjectViewPage)
		{
			var projectViewPage = Vm.create(appView, 'ProjectViewPage', ProjectViewPage, {project_id: actions});	  
		});		  
	  });
	  
    
	  router.on('route:defaultAction', function (actions) 
	  {
		require(['views/project_manager/page'], function (MainPageView)
		{
			var mainPageView = Vm.create(appView, 'MainPageView', MainPageView);	  
		});		  

		//jump to default page 
  		//router.navigate('page', {trigger: true});
	  });
	  
  
	  Backbone.history.start();
	  
	  //add router to main backbone structure
	  Backbone.router = router;
  	 };
  return {
    initialize: initialize
  };
});