// Filename: views/home/main
define([
  'jquery',
  'underscore',
  'backbone',
  'jqueryui',
  'jqwindow',
  'text!templates/admin_apps_manager/appitem.html'
], function($, _, Backbone, jQueryUI, jqWindow, appTemplate){

  var appView = Backbone.View.extend(
  {
	  	tagName : "li",
	  
	  	events : {
  			'mouseover .appBoardItem' : 'showControls',
  			'mouseout .appBoardItem' : 'hideControls',
  			'click span#app-update-badge-btn' : 'handleAppUpdate',
  			'click .app-title-box' : 'openAppWindow'
  		},
  		
	    initialize : function (options)
	    {
	    	Backbone.log("admin_apps_manager appView init");
	    	
	    	this.model.bind('change',this.render,this);
	    },
	    
	    render : function ()
	    {
	    	Backbone.log("admin_apps_manager appView render");
	    	
	    	var appStatus = (this.model.has("status") ? this.model.get("status") : "E");
	    	
	    	var appItemId = (this.model.has("id") ? this.model.get("id") : "1");
	    	
	    	var appLink = (this.model.has("app_link") ? this.model.get("app_link"): '#');
	    	
	    	var data = {
	    		id: appItemId,
	    		url: appLink,
	    		status: appStatus,
	    		title: this.model.get("title"),
	    		icon: this.model.get("app_icon_board"),
	    		version: parseInt(this.model.get("version")).toPrecision(2),
	    		show_update_badge: (this.model.get("install_type") == 'update' ? true : false) 
	    	};
	    	
	        var compiledTemplate = _.template( appTemplate, data );
	        $(this.el).html(compiledTemplate);
	        
	        $(this.el).addClass('appBoardItemWrapper');
	        
	        return this;
	    },
	    
	    showControls : function ()
	    {
	    	//$(this.el).find('.app-icon-overlay').addClass('show-overlay');
	    },
	    
	    hideControls : function ()
	    {
	    	//$(this.el).find('.app-icon-overlay').removeClass('show-overlay');
	    },
	    
	    openAppWindow: function()
	    {
	    	$.window.prepare({
    		   dock: 'bottom', 
    		   animationSpeed: 500,  
    		   minWinLong: 180
    		});
	    	
	    	$.window({
	    		title : this.model.get("title"),
	    		url : this.model.get("app_link"),
	    		width : 800,
	    		height : 600,
	    		scrollable: 'auto',
	    		resizable : true,
	    		bookmarkable: false,
	    		//checkBoundary: true,
	    		icon : this.model.get("app_icon_board")
    		});	
	    },
	    
	    openAppSettings: function()
	    {
	    	$.window.prepare({
    		   dock: 'bottom', 
    		   animationSpeed: 500,  
    		   minWinLong: 180
    		});
	    	
	    	$.window({
	    		title : this.model.get("settings_title"),
	    		url : this.model.get("settings_link"),
	    		width : 800,
	    		height : 600,
	    		scrollable: 'auto',
	    		resizable : true,
	    		bookmarkable: false,
	    		//checkBoundary: true,
	    		icon : this.model.get("app_icon_board")
    		});	
	    },
	    
	    handleAppUpdate: function()
	    {
	    	Backbone.log("handleAppUpdate fired");
	    	
	    	if (window.confirm('Are you sure you want to update this app ?'))
	        {
		    	this.model.set({'current_op': 'update'});
		    	this.model.save();
	        }	
	    }
  });
  
  return appView;
});