// Filename: views/home/main
define([
  'jquery',
  'underscore',
  'backbone',
  'jqtransport',
  'views/ajax_upload/mainitem',
  'text!templates/admin_apps_manager/newappitem.html',
  'text!templates/basic/testdisplay.html'
], function($, _, Backbone, jqTransport, mainItemView, newAppItemTemplate, testTemplate){

  var newAppView = Backbone.View.extend(
  {
  		el: '#add-app-container',
  		
	  	events :
	  	{	
	  		'click button.add-app-btn' : 'handleAppAdd',
  			'click button#get-app-upload-btn.blue' : 'processAppUploadForm',
  			'click button#get-app-url-btn.blue' : 'processAppUrlForm',
  			'click button#install-app-btn.blue' : 'processInstallApp'
  		},
  		
	    initialize : function (options)
	    {
	    	Backbone.log("newAppView init");
	    	
	    	this.page = options['page'];
	    	
	    	this.model.bind('change', this.handleModelChange ,this);
	    },
	    
	    render : function ()
	    {
	    	Backbone.log("newAppView render");
	    	
	    	var compiledTemplate = _.template( newAppItemTemplate, {});
	        $(this.el).html(compiledTemplate);
	        
	    	return this;
	    },
	    
	    
	    processAppUploadForm: function()
	    {
	    	Backbone.log("processAppUploadForm trigerred");
	    	
	    	var get_app_upload_box =  $(this.el).find("#get_app_upload_box").val();
	    	var testNotifications = [];
	    	
	    	if(get_app_upload_box)
    		{
	    		var self = this;
	    		this.handleActionOverlay('enable');

	    		var intputElement = $(this.el).find("#get_app_upload_box");
	    		var uploadData = {action: 'doAppUpload', 'rand': this.getRnd()};
	    		var self = this;
	    		
	    		$.ajax(this.model.url, {files: intputElement, type: 'POST', iframe: true, dataType: 'json', data: uploadData, processData: false})
					.always(function(data, textStatus, jqXHR){self.handleUploading(data, textStatus, jqXHR, self)})
					.done(function(data, textStatus, jqXHR){self.handleDone(data, textStatus, jqXHR, self)})
					.fail(function(jqXHR){self.handleFail(jqXHR, self)});
	    		
	    		//show loading spinner
		    	$(this.el).find("#app-tests-details-container").show();
    		}
	    	else
    		{
	    		testNotifications.push({'type': 'error', 'message': 'Upload Field is empty'});
    		}
	    	
	    	
	    	if(testNotifications.length > 0)
	    	{
	    		Backbone.handleNotifications({'notifications': testNotifications});
	    	}	
	    },
	    
	    processAppUrlForm: function()
	    {
	    	Backbone.log("processAppUrlForm trigerred");
	    	
	    	var get_app_url_box =  $(this.el).find("#get_app_url_box").val();
	    	var testNotifications = [];
	    	
	    	if(get_app_url_box)
	    	{
	    		var self = this;
	    		this.handleActionOverlay('enable');
	    		
	    		var details = {
	    			'current_step': "validate", 
	    			'get_app_url_box': get_app_url_box, 
	    			'tests': false,
	    			'rand': this.getRnd()
	    			};
	    		
	    		this.model.set(details);
	    		this.model.save({}, {success: function(model, resp) {self.handleModelSave(model, resp)}});
		    	
		    	$(this.el).find("#app-tests-details-container").show();
	    	}
	    	else
	    	{
	    		testNotifications.push({'type': 'error', 'message': 'Url Field is empty'});
	    	}
	    	
	    	if(testNotifications.length > 0)
	    	{
	    		Backbone.handleNotifications({'notifications': testNotifications});
	    	}	
	    },	    
	    
	    processInstallApp: function()
	    {
	    	Backbone.log("processInstallApp trigerred");
	    	
	    	var self = this;
	    	
	    	this.model.set({'current_step': "install", 'rand': this.getRnd()});
	    	this.model.save({},{success: function(resp, model) {self.processInstallAppSuccess(resp,model);}});
	    	
    		//disable acceptInstallBtn
	    	this.handleActionOverlay('enable');
    		this.handleAcceptInstallBtn('disable');
	    },
	    
	    processInstallAppSuccess: function(model, resp)
	    {
	    	this.handleActionOverlay('disable');
	    	
	    	var installAppSuccess = (this.model.has('installResult') ? this.model.get('installResult') : false);
	    	
	    	if(installAppSuccess)
    		{
	    		//refresh installedAppSet & uninstalledAppSet
	    		this.page.installedAppSet.fetch();
	    		this.page.uninstalledAppSet.fetch();
    		}
	    },
	    
	    getRnd: function()
	    {
	    	return Math.floor(Math.random()*11);	    	
	    },
	    
	    handleAppAdd: function()
	    {
	    	Backbone.log("handleAppAdd triggered");
	    	
	    	var self = this;
	    	
	    	$(this.el).find('#add-app-options').slideToggle('slow', false, function(){self.slideToggleCallback(self)});
	    },
	    
	    slideToggleCallback: function(view)
	    {
	    	//refresh view after slide up
	    	if($(view.el).find('#add-app-options').css("display") == 'none')
	    	{
	    		view.render();
	    	}
	    },
	    
	    handleUploading: function(data, textStatus, jqXHR, el)
	    {
	    	Backbone.log("handleUploading triggered");
	    },
	    
	    handleDone: function(data, textStatus, jqXHR, el)
	    {
	    	this.handleActionOverlay('disable');
	    	this.handleAcceptInstallBtn('disable');
	    	
	    	Backbone.log("handleDone triggered");
	    	
	    	var resp = data;
	    	
	    	if(!resp.data)
	    	{
	    		resp.notifications = [{'type': 'error', 'message': 'App Upload Failed'}];
	    	}
	    	else if(!resp.data.actionData)
    		{
    			resp.notifications = [{'type': 'error', 'message': 'App Upload Failed'}];
    		}
    		else
    		{
    			if(resp.data.actionData.modelDetails)
    			{
    				//update current model
    				el.model.set(resp.data.actionData.modelDetails);
    			}	
    		}
	    	
	    	Backbone.handleNotifications(resp);
	    },

	    handleFail: function(jqXHR)
	    {
	    	Backbone.log("handleFail triggered");
	    	
	    	this.handleActionOverlay('disable');
	    	this.handleAcceptInstallBtn('disable');
	    	
	    	Backbone.handleNotifications({notifications:[{type:'error', message:'File could not be uploaded! Please try again.'}]});
	    },
	    
	    handleAcceptInstallBtn: function(action)
	    {
	    	if(action == 'enable')
	    	{
	    		$(this.el).find("#install-app-btn").show();	
	    	}	
	    	else if(action == 'disable')
	    	{
	    		$(this.el).find("#install-app-btn").hide();	
	    	}	
	    },
	    
	    handleModelChange: function(ev)
	    {
	    	var hasTestsDetails = (this.model.has("unpackTests") ? true : (this.model.has("installTests")));
	    	var successValidationResult = (this.model.has("validationResult") ? this.model.get("validationResult") : false); 
	    	var currentStep = this.model.get("current_step");
	    	
	    	//check if widget is valid (there are no errors)
	    	var accept_install = (((currentStep == 'validate') && (hasTestsDetails) && (successValidationResult !== false)) ?  true : false);
	    	
	        //add test template
	        if(hasTestsDetails)
        	{
	        	var testDetails = [];
	        	
	        	if(this.model.has("unpackTests"))
	        	{
	        		testDetails = this.model.get("unpackTests"); 	
	        	}
	        	else if(this.model.has("installTests"))
        		{
	        		testDetails = this.model.get("installTests");
        		}
	        	
	        	if(this.model.has("appInfo"))
	        	{
		    		var appDetails = this.model.get("appInfo");
		    		$(this.el).find('#app-details-title-container').html('Installation Process - '+appDetails.title);
	        	}
	        	
		    	if(accept_install)
		    	{
		    		this.handleAcceptInstallBtn('enable');
		    	}	
		    		
	        	var compiledTemplate = _.template( testTemplate, {'testDetails': testDetails} );
	        	$(this.el).find('#add-app-test-details').empty().append(compiledTemplate);
        	}
	        
	        //autocomplete app_url_box
	        var get_app_url_box =  this.model.get("get_app_url_box");
	    	if(get_app_url_box) $(this.el).find("#get_app_url_box").val(get_app_url_box);
	    },
	    
	    handleModelSave: function()
	    {
	    	Backbone.log("handleModelSave triggered");
	    	
	    	var appIsValid = (this.model.has('validationResult') ? this.model.get('validationResult') : false);
	    	
	    	this.handleActionOverlay('disable');
	    	this.handleAcceptInstallBtn((appIsValid ? 'enable' : 'disable'));
	    },
	    
	    handleActionOverlay: function(action)
	    {
	    	Backbone.log("handleActionOverlay triggered: "+action);
	    	
	    	if(action == 'enable')
	    	{
	    		//appdetails-container
	    		var tmpContainer = $(this.el);
	    		var tmpContainerOffset = tmpContainer.offset();
	    		
	    		$('#livedash-waiting-overlay').css({
	    			'visibility': 'visible', 
	    			'width': $(tmpContainer)[0].offsetWidth+'px', 
	    			'height': $(tmpContainer)[0].offsetHeight+'px', 
	    			'top': tmpContainerOffset.top, 
	    			'left': tmpContainerOffset.left
	    			});
	    	}
	    	else if(action == 'disable')
	    	{
	    		$('#livedash-waiting-overlay').css({visibility: 'hidden'});
	    	}
	    }
	    
  });
  
  return newAppView;
});