// Filename: views/admin_connectors/connectoritem
define([
  'jquery',
  'underscore',
  'backbone',
], function($, _, Backbone){

	var connectorItemView = Backbone.View.extend(
	{
	    tagName : "tr",
	    
	  	events :
	  	{
  			'click button#admin_save_connector' : 'handleSaveConnector',
  			'click a#admin_delete_connector' : 'handleDeleteConnector'
  		},
	    
	    initialize : function (options)
	    {
	        Backbone.log("connectorItemView initialize");
	        
	        this.page = options["page"];
	        
	        $(this.el).attr("id","admin_connector_item_"+this.model.get("id"));
	        $(this.el).attr("align","center");
	        
	    	//set collection events
	        
	        this.model.bind("change", this.render, this);
	        //this.model.bind("all", this.eventAll, this);
	    },
	    
	    render : function ()
	    {
	    	Backbone.log("connectorItemView render");
	    	
	    	var connectorAuth=this.model.get('auth');
	    	
	    	var connectorAuthHtml = '<div class="col_12">';
	    	
	    	if (connectorAuth.type=='input')
	    	{
	    		connectorAuthHtml+='<div class="col_12 center"><table>';
	    		
	    		var firstField=true;
	    		
	    		for (var i in connectorAuth.fields)
	    		{
	    			connectorAuthHtml += '<tr><td nowrap style="width:50px;border:0;">'+connectorAuth.fields[i].name+'</td><td style="width:400px;border:0;"><input class="col_6" type="text" id="'+this.model.get('id')+'_'+i+'" value="'+connectorAuth.fields[i].value+'"></td>';
	    			
	    			if (firstField)
	    			{
	    				connectorAuthHtml += '<td rowspan="'+Object.keys(connectorAuth.fields).length+'" style="border:0;"><button type="button" id="admin_save_connector" class="small blue">Save details</button></td>';
	    				firstField=false;
	    			}
	    			
	    			connectorAuthHtml += '</tr>';
	    		}
	    		connectorAuthHtml += '</table></div><div class="col_12 center"></div>';
	    	}
	    	
	    	connectorAuthHtml+='</div>';
	    	
	    	var connectorActionsHtml='';
	    	
	    	if (this.model.get('currentDataAvailable'))
	    	{
	    		connectorActionsHtml='<a href="javascript:void(0);" id="admin_delete_connector" class="button small red">Delete details</a>';
	    	}
	    	else
	    	{
	    		connectorActionsHtml=' - <a href="'+connectorAuth.external_link.url+'" target="_blank">'+connectorAuth.external_link.text+'</a>';
	    	}
	    	
	    	$(this.el).empty();
	    	$(this.el).attr('class','first');
	    	$(this.el).append($("<td/>",{'class': 'alignCenter', html: this.model.get('type_title')}));
	    	$(this.el).append($("<td/>",{html: '<div class="col_12"><b>'+this.model.get('title')+'</b> '+connectorActionsHtml+'</div>'+connectorAuthHtml }));
	    	
	        return this;
	    },
	    
	    
	    handleSaveConnector : function()
	    {
	    	Backbone.log("handleSaveConnector triggered");

	    	var self = this;
	    	this.handleActionOverlay('enable');
	    	
	    	var connectorFields=this.model.get('auth').fields;
	    	var connectorID=this.model.get('id');
	    	
	    	for (var i in connectorFields)
	    	{
	    		this.model.attributes.auth.fields[i].value=$(this.el).find('#'+connectorID+'_'+i).val();
	    	}
	    	
	    	this.model.set({'current_op': 'save_details'});
	    	this.model.save({}, {success: function() {self.handleModelSave()}});
	    },
	    
	    handleDeleteConnector : function()
	    {
	    	Backbone.log("handleDeleteConnector triggered");
	    	
	    	var self = this;
	    	this.handleActionOverlay('enable');
	    	
	    	this.model.set({'current_op': 'delete_details'});
	    	this.model.save({}, {success: function() {self.handleModelSave()}});
	    },
	    
	    handleModelSave: function()
	    {
	    	Backbone.log("handleModelSave triggered");
	    	this.handleActionOverlay('disable');
	    },
	    
	    eventAll : function(event, model, options)
	    {
	    	Backbone.log("boardModel  fired event "+event);
	    },
	    
	    handleActionOverlay: function(action)
	    {
	    	Backbone.log("handleActionOverlay triggered: "+action);
	    	
	    	if(action == 'enable')
	    	{
	    		//appdetails-container
	    		var tmpContainer = $(this.el);
	    		var tmpContainerOffset = tmpContainer.offset();
	    		
	    		$('#livedash-waiting-overlay').css({
	    			'visibility': 'visible', 
	    			'width': $(tmpContainer)[0].offsetWidth+'px', 
	    			'height': $(tmpContainer)[0].offsetHeight+'px', 
	    			'top': tmpContainerOffset.top, 
	    			'left': tmpContainerOffset.left
	    			});
	    	}
	    	else if(action == 'disable')
	    	{
	    		$('#livedash-waiting-overlay').css({visibility: 'hidden'});
	    	}
	    }
	})

  return connectorItemView;
});