// Filename: views/admin_datasources/datasourceitem
define([
  'jquery',
  'underscore',
  'backbone',
  'text!templates/admin_datasources/datasourceitem.html'
], function($, _, Backbone, datasourceItemTemplate){

	var datasourceItemView = Backbone.View.extend(
	{
	    tagName : "tr",
	    
	  	events :
	  	{
  			'click button#admin_enable_datasource' : 'handleEnableDatasource',
  			'click button#admin_disable_datasource' : 'handleDisableDatasource'
  		},
	    
	    initialize : function (options)
	    {
	        Backbone.log("datasourceItemView initialize");
	        
	        this.page = options["page"];
	        
	        $(this.el).attr("id","admin_datasource_item_"+this.model.get("name"));
	        $(this.el).attr("align","center");
	        
	    	//set collection datasources
	        
	        this.model.bind("change", this.render, this);
	    },
	    
	    render : function ()
	    {
	    	Backbone.log("datasourceItemView render");
	    	
	    	//Backbone.log(this.model.toJSON());

	    	var data = {
	    		status: this.model.get('status'),
	    		name: this.model.get('name'),
	    		module_title: this.model.get('_module_title'),
	    		connections: false
	    		};
	    	
	    	//check if current datasource had connections
	    	if(this.page.availableConnections[this.model.get('name')])
	    	{
	    		data['connections'] = this.page.availableConnections[this.model.get('name')];
	    	}	
		    	
	    	var compiledTemplate = _.template( datasourceItemTemplate, data );
	        
	        $(this.el).html(compiledTemplate);
	    	
	        return this;
	    },
	    
	    
	    handleEnableDatasource : function()
	    {
	    	Backbone.log("handleEnableDatasource triggered");

	    	var self = this;
	    	this.handleActionOverlay('enable');
	    	
	    	this.model.set({'current_op': 'enable_datasource'});
	    	this.model.save({}, {success: function() {self.handleModelSave()}});
	    },

	    handleDisableDatasource : function()
	    {
	    	Backbone.log("handleDisableDatasource triggered");

	    	var self = this;
	    	this.handleActionOverlay('enable');
	    	
	    	this.model.set({'current_op': 'disable_datasource'});
	    	this.model.save({}, {success: function() {self.handleModelSave()}});
	    },
	    
	    handleModelSave: function()
	    {
	    	Backbone.log("handleModelSave triggered");
	    	this.handleActionOverlay('disable');
	    },
	    
	    handleActionOverlay: function(action)
	    {
	    	Backbone.log("handleActionOverlay triggered: "+action);
	    	
	    	if(action == 'enable')
	    	{
	    		//appdetails-container
	    		var tmpContainer = $(this.el);
	    		var tmpContainerOffset = tmpContainer.offset();
	    		
	    		$('#livedash-waiting-overlay').css({
	    			'visibility': 'visible', 
	    			'width': $(tmpContainer)[0].offsetWidth+'px', 
	    			'height': $(tmpContainer)[0].offsetHeight+'px', 
	    			'top': tmpContainerOffset.top, 
	    			'left': tmpContainerOffset.left
	    			});
	    	}
	    	else if(action == 'disable')
	    	{
	    		$('#livedash-waiting-overlay').css({visibility: 'hidden'});
	    	}
	    }
	})

  return datasourceItemView;
});