// Filename: views/admin_events/eventitem
define([
  'jquery',
  'underscore',
  'backbone',
], function($, _, Backbone){

	var eventItemView = Backbone.View.extend(
	{
	    tagName : "tr",
	    
	  	events :
	  	{
  			'click button#admin_enable_event' : 'handleEnableEvent',
  			'click button#admin_disable_event' : 'handleDisableEvent'
  		},
	    
	    initialize : function (options)
	    {
	        Backbone.log("eventItemView initialize");
	        
	        this.page = options["page"];
	        
	        $(this.el).attr("id","admin_event_item_"+this.model.get("id"));
	        $(this.el).attr("align","center");
	        
	    	//set collection events
	        
	        this.model.bind("change", this.render, this);
	    },
	    
	    render : function ()
	    {
	    	Backbone.log("eventItemView render");
	    	
	    	if(this.model.get('status') == 'E')
	    	{
	    		var eventActionHtml = $("<button/>",{id:'admin_disable_event', type:'button', 'class': 'small blue', html: 'Disable Event'});
	    		var eventStatusHtml = '<span class="icon green medium" data-icon="C" style="display:inline;">C</span>';
	    	}
	    	else
	    	{
	    		var eventActionHtml = $("<button/>",{id:'admin_enable_event', type:'button', 'class': 'small blue', html: 'Enable Event'});
	    		var eventStatusHtml = '<span class="icon red medium" data-icon="x" style="display:inline;">x</span>';
	    	}
	    	
	    	$(this.el).empty();
	    	$(this.el).attr('class','first');
	    	$(this.el).append($("<td/>",{'class': 'alignCenter', html: eventStatusHtml}));
	    	$(this.el).append($("<td/>",{html: this.model.get('name')}));
	    	$(this.el).append($("<td/>",{'class': 'alignCenter', html:  eventActionHtml}));
	    	
	        return this;
	    },
	    
	    
	    handleEnableEvent : function()
	    {
	    	Backbone.log("handleEnableEvent triggered");

	    	var self = this;
	    	this.handleActionOverlay('enable');
	    	
	    	this.model.set({'current_op': 'enable_event'});
	    	this.model.save({}, {success: function() {self.handleModelSave()}});
	    },

	    handleDisableEvent : function()
	    {
	    	Backbone.log("handleDisableEvent triggered");

	    	var self = this;
	    	this.handleActionOverlay('enable');
	    	
	    	this.model.set({'current_op': 'disable_event'});
	    	this.model.save({}, {success: function() {self.handleModelSave()}});
	    },
	    
	    handleModelSave: function()
	    {
	    	Backbone.log("handleModelSave triggered");
	    	this.handleActionOverlay('disable');
	    },
	    
	    handleActionOverlay: function(action)
	    {
	    	Backbone.log("handleActionOverlay triggered: "+action);
	    	
	    	if(action == 'enable')
	    	{
	    		//appdetails-container
	    		var tmpContainer = $(this.el);
	    		var tmpContainerOffset = tmpContainer.offset();
	    		
	    		$('#livedash-waiting-overlay').css({
	    			'visibility': 'visible', 
	    			'width': $(tmpContainer)[0].offsetWidth+'px', 
	    			'height': $(tmpContainer)[0].offsetHeight+'px', 
	    			'top': tmpContainerOffset.top, 
	    			'left': tmpContainerOffset.left
	    			});
	    	}
	    	else if(action == 'disable')
	    	{
	    		$('#livedash-waiting-overlay').css({visibility: 'hidden'});
	    	}
	    }
	})

  return eventItemView;
});