// Filename: views/admin_market/appdetails
define([
  'jquery',
  'underscore',
  'backbone',
  'text!templates/admin_market/appdetails.html',
  'text!templates/basic/testdisplay.html'
], function($, _, Backbone, appDetailsTemplate, testTemplate){

  var appDetailsView = Backbone.View.extend(
  {
  		el: "#appstore-placeholder",
  		
	  	events :
	  	{
  			'click button.back-btn' : 'showCategoryDetails',
  			'click button#app-update-btn.green' : 'handleAppUpdate',
  			'click button#app-install-btn.green' : 'handleAppInstall',
  			'click button#app-uninstall-btn.red' : 'handleAppUninstall',
  			'click button#write-review-btn' : 'handleWriteReview',
  			'click button#submit-review-btn' : 'handleSubmitReview'
  		},
  		
	    initialize : function(options)
	    {
	    	Backbone.log("appDetailsView init");
	    	
	    	this.page = options['page'];
	    	
	    	this.model.bind('change',this.handleModelChange,this);
	    },

	    render : function ()
	    {
	    	Backbone.log("appDetailsView render");
	    	
	    	var self = this;
	    	
	    	//check dependencies
	    	var dependencies_errors =  self.getDependenciesErrors();
	    	
	    	var data = {
	    		icon_board: this.model.get("icon_board"),
	    		app_title: this.model.get("title"),
	    		app_name: this.model.get("name"),
	    		developer_name: this.model.get("developer_name"),
	    		app_version: this.model.get("version"),
	    		review_stars: this.model.get("review_stars"),
	    		review_stars_total: (parseInt(this.model.get("review_stars"))*2),
	    		review_total: this.model.get("review_total"),
	    		total_installs: this.model.get("total_installs"),
	    		last_update_date: this.model.get("last_update_date"),
	    		kit_size: this.model.get("kit_size"),
	    		app_action: this.model.get("app_action"),
	    		description: this.model.get("description"),
	    		is_logged: this.model.get("is_logged"),
	    		app_is_installed : this.model.get("app_is_installed"),
	    		review_is_new: (this.model.has("my_review")? false: true),
	    		reviews: (this.model.has("reviews") ? this.model.get("reviews") : false),
	    		changelog: (this.model.has("changelog") ? this.model.get("changelog") : false),
	    		dependencies_errors: dependencies_errors
	    		};
	    	
	    	var compiledTemplate = _.template( appDetailsTemplate, data );
	        $(this.el).html(compiledTemplate);
	        
	    	//handle action buttons
	        this.handleActionButtons((dependencies_errors > 0 ? 'disable' : 'enable'));
	        
    		//auto-complete details for my review
	        this.addReviewData();
	        
    		//add requirements and dependencies
	        this.addDependenciesData();
	        
	    	setTimeout(function(){self.page.buildTabs()}, 100);
	    },
	    
	    showCategoryDetails : function ()
	    {
	    	Backbone.log("showCategoryDetails fired");
	    	
	    	if(this.model.has("category"))
    		{
	    		this.page.viewCategoryDetails(this.model.get("category"));
    		}
	    },
	    
	    handleAppUpdate: function()
	    {
	    	Backbone.log("handleAppUpdate fired");
	    	
	    	if(window.confirm("Are you sure you want to update this app ?"))
	    	{
	    		var self = this;
	    		
	    		this.page.handleActionOverlay('enable');
		    	this.model.set({'current_op': 'update'});
		    	this.model.save({}, {success: function() {self.handleModelSave()}});
	    	}	
	    },

	    handleAppInstall: function()
	    {
	    	Backbone.log("handleAppInstall fired");
	    	
	    	var self = this;
	    	
	    	this.page.handleActionOverlay('enable');
	    	this.model.set({'current_op': 'install'});
	    	this.model.save({}, {success: function() {self.handleModelSave()}});
	    },

	    handleAppUninstall: function()
	    {
	    	Backbone.log("handleAppUninstall fired");
	    	
	    	if(window.confirm("Are you sure you want to uninstall this app ?"))
	    	{
	    		this.page.handleActionOverlay('enable');
	    		
	    		var self = this;
	    		this.model.set({'current_op': 'uninstall'});
	    		this.model.save({}, {success: function() {self.handleModelSave()}});
	    	}
	    },
	    
	    handleWriteReview: function()
	    {
	    	Backbone.log("handleWriteReview fired");
	    	
	    	$('#write-review-box').toggle();
	    },
	    
	    handleSubmitReview: function()
	    {
	    	Backbone.log("handleSubmitReview fired");
	    	
	    	var self = this;
	    	var review_title = $(this.el).find('#app-new-review-title').val();
	    	var review_comment = $(this.el).find('#app-new-review-comment').val();
	    	
	    	this.page.handleActionOverlay('enable');
	    	this.model.set({'current_op': 'submit_review', 'user_review_title': review_title, 'user_review_comment': review_comment});
	    	this.model.save({}, {success: function() {self.handleModelSave()}});
	    },
	    
	    handleModelChange: function(model)
	    {
	    	Backbone.log("handleModelChange fired");
	    	
	    	if(model.get('current_op') != 'submit_review')
    		{
		    	$(this.el).find(".app-details-tabs-container").removeClass('tabs-visible');
		    	this.render();
    		}
	    },
	    
	    handleActionButtons: function(action)
	    {
	    	Backbone.log("handleActionButtons triggered: " +action);
	    	
	    	if(action == 'enable')
	    	{
	    		$(this.el).find("#app-install-btn").removeClass("grey").addClass("green");
	    		$(this.el).find("#app-uninstall-btn").removeClass("grey").addClass("red");
	    	}	
	    	else if(action == 'disable')
	    	{
	    		$(this.el).find("#app-install-btn").removeClass("green").addClass("grey");
	    		$(this.el).find("#app-uninstall-btn").removeClass("red").addClass("grey");
	    	}
	    },
	    
	    getDependenciesErrors: function()
	    {
	    	//count dependencies errors
	    	var dependencies_errors = 0;
	    	if(this.model.get("dependencies_result") == false)
    		{
	    		_.each(dependenciesTests, function(test){
	    			if(test.result)
	    			{
	    				if(test.result.type)
	    				{
	    					if(test.result.type == 'error')
	    					{
	    						dependencies_errors++;	
	    					}
	    				}	
	    			}	
	    		});
    		}
	    	
	    	return dependencies_errors;
	    },

	    getDependenciesTests: function()
	    {
	    	var dependenciesTests = false;
	    	
	    	if(this.model.has("dependencies")) dependenciesTests = this.model.get("dependencies");
	    	if(this.model.has("download_tests")) dependenciesTests = this.model.get("download_tests");
	    	if(this.model.has("install_tests")) dependenciesTests = this.model.get("install_tests");
	    	
	    	return dependenciesTests;
	    },
	    
	    addReviewData: function()
	    {
	        if(this.model.has("my_review"))
    		{
	        	var myReview = this.model.get("my_review");
	        	
	        	$(this.el).find('#app-new-review-title').val(myReview["title"]);
	        	$(this.el).find('#app-new-review-comment').val(myReview["message"]);
    		}
	    },
	    
	    addDependenciesData: function()
	    {
	    	var dependenciesTests = this.getDependenciesTests();
	    	
	    	if(dependenciesTests !== false)
	    	{
	    		var compiledTemplate = _.template( testTemplate, {'testDetails': dependenciesTests});
	    		$(this.el).find('#list-dependencies').empty().append(compiledTemplate);
	    	}
	    }, 
	    
	    handleModelSave: function()
	    {
	    	Backbone.log("handleModelSave triggered");
	    	this.page.handleActionOverlay('disable');
	    }
  });
  
  return appDetailsView;
});