// Filename: views/admin_market/page
define([
  'jquery',
  'underscore',
  'backbone',
  'collections/admin_market/appset',
  'collections/admin_market/categoryset',
  'models/admin_market/page',
  'views/admin_market/appset',
  'views/admin_market/categoryset',
  'views/admin_market/categorysettouch',
  'models/admin_market/appdetails',
  'views/admin_market/appdetails',
  'text!templates/admin_market/page.html',
], function($, _, Backbone, appSet, categorySet, PageModel, appSetView, categorySetView, categorySetTouchView, appDetailsModel, appDetailsView, pageTemplate){

  var pageView = Backbone.View.extend(
  {
	    el: '#page',
	    
	    initialize : function ()
	    {
	    	Backbone.log("admin_appstore pageView init");
	    	
	    	var self = this;
	    	
	    	this.model = new PageModel();
	    	
	    	this.appstore = new appSet();
	    	this.appDetails = new appDetailsModel();
	    	this.categories =  new categorySet();

	    	this.appSetView = null;
	    	this.categoriesSetView = null;
	    	
	    	this.currentView = 'appStore';
	    	
	    	this.currentCategory = false;
	    	
	    	//handle events
	    	this.model.bind("change", this.render, this);
	    	
	        this.model.fetch();
	    },
	    
	    render : function ()
	    {
	    	Backbone.log('pageView render');
	    	
	    	var self = this;
	    	
	    	$(this.el).empty();
	    	
	        //Draw admin_appstore template
	    	var data = {};
	        var compiledTemplate = _.template( pageTemplate, data );
	        $(this.el).html( compiledTemplate );
	    	
	        //handle app appstore view ... 
	    	
	    	
	    	//populate categories collection from pageModel (only if empty)
	        if((this.categories.models.length == 0) && (this.model.has("categoriesItems")))
        	{
	        	this.categories.add(_.toArray(this.model.get("categoriesItems")));
        	}
	    	
	    	if((!this.currentCategory) && (this.categories.models.length > 0))
	    	{
	    		this.currentCategory = this.categories.models[0].get("name");	
	    	}
	    	
	    	//populate apps collection from pageModel (only if empty)
	    	if((this.appstore.models.length == 0) && (this.model.has("featuredItems")))
    		{
	    		this.appstore.add(_.toArray(this.model.get("featuredItems")));
    		}
	    	
	        //Render appStore categories
	        this.categoriesSetView = new categorySetView({model: this.categories, page: this});
	        this.categoriesSetView.render();
	        
	        //Render appStore categories for touch interfaces
	        this.categoriesSetTouchView = new categorySetTouchView({model: this.categories, page: this});
	        this.categoriesSetTouchView.render();
	        
	        //Render MainPanel
	        if(this.currentView == 'appDetails')
	        {
		        //Render appDetailsView
		        this.appDetailsView = new appDetailsView({model: this.appDetails, page: this});
		        this.appDetailsView.render();
	        }
	        else if(this.currentView == 'appStore')
	        {
		        //Render appSetView
		        this.appSetView = new appSetView({model: this.appstore, page: this});
		        this.appSetView.render();
	        }
	    },
	    
	    viewCategoryDetails: function(categoryItemName)
	    {
	    	if(categoryItemName !== false)
    		{
		    	var self = this;

		    	//set activate category
		    	this.currentCategory = categoryItemName;
		    	
		    	//reset all current apps
		    	this.model.set({"featuredItems": null});
		    	
		    	this.handleActionOverlay('enable');
		    	
		    	//this must be changed
		    	this.appstore.fetch({
		    		data: {action: self.appstore._meta.methodMap.read, params:{categoryName: categoryItemName}},
		    		success: function(model, resp) { self.handleAppstoreFetch(model, resp);}
		    		});
    		}
	    },

	    handleAppstoreFetch: function(model, resp)
	    {
			this.currentView = 'appStore';
			this.handleActionOverlay('disable');
			this.render();
	    },
	    
	    buildTabs: function()
	    {
	    	// tab setup
	    	$(this.el).find('.tab-content').addClass('clearfix').not(':first').hide();
	    	
	    	$(this.el).find('ul.tabs').each(function(){
	    		var current = $(this).find('li.current');
	    		if(current.length < 1) { $(this).find('li:first').addClass('current'); }
	    		current = $(this).find('li.current a').attr('target');
	    		$(current).show();
	    	});

	    	$(this.el).find('ul.tabs a[target^="#"]').live('click', function(e){
	    		e.preventDefault();
	    		var tabs = $(this).parents('ul.tabs').find('li');
	    		var tab_next = $(this).attr('target');
	    		var tab_current = tabs.filter('.current').find('a').attr('target');
	    		$(tab_current).hide();
	    		tabs.removeClass('current');
	    		$(this).parent().addClass('current');
	    		$(tab_next).show();
	    		return false;
	    	});
	    	
	    	$(this.el).find(".app-details-tabs-container").addClass("tabs-visible");
	    },
	    
	    handleAppStoreRefresh: function(event, model, options)
	    {
	    	Backbone.log("handleAppStoreRefresh fired");
	    	
	    	//render new 
	    	this.appSetView.render();
	    },
	    
	    handleActionOverlay: function(action)
	    {
	    	Backbone.log("handleActionOverlay triggered: "+action);
	    	
	    	if(action == 'enable')
	    	{
	    		//appdetails-container
	    		var appStoreContainer = $(this.el).find('#appstore-placeholder');
	    		var appStoreContainerOffset = appStoreContainer.offset();
	    		
	    		$('#livedash-waiting-overlay').css({
	    			'visibility': 'visible', 
	    			'width': $(appStoreContainer)[0].offsetWidth+'px', 
	    			'height': $(appStoreContainer)[0].offsetHeight+'px', 
	    			'top': appStoreContainerOffset.top, 
	    			'left': appStoreContainerOffset.left
	    			});
	    	}
	    	else if(action == 'disable')
	    	{
	    		$('#livedash-waiting-overlay').css({visibility: 'hidden'});
	    	}
	    }
  });
  
  return pageView;
});