// Filename: views/home/main
define([
  'jquery',
  'underscore',
  'backbone',
  'jqtransport',
  'text!templates/admin_proxies/newproxyitem.html'
], function($, _, Backbone, mainItemView, newProxyItemTemplate){

  var newProxyView = Backbone.View.extend(
  {
  		el: '#add-proxy-container',
  		
	  	events :
	  	{	
	  		'click button.add-proxy-btn' : 'handleProxyAdd',
	  		'click button#add-new-proxy-btn' : 'handleNewProxyAdd',
	  		'click button#add-bulk-proxy-btn' : 'handleBulkProxyAdd',
	  	},
  		
	    initialize : function (options)
	    {
	    	Backbone.log("newProxyView init");
	    	
	    	this.page = options['page'];
	    	
	    	this.model.bind('change', this.handleModelChange ,this);
	    },
	    
	    render : function ()
	    {
	    	Backbone.log("newProxyView render");
	    	
	    	var compiledTemplate = _.template( newProxyItemTemplate, {});
	        $(this.el).html(compiledTemplate);
	        
	    	return this;
	    },
	    
	    
	    handleNewProxyAdd: function()
	    {
	    	Backbone.log("newProxyView handleNewProxyAdd trigerred");
	    	
	    	var proxy_ip_box_val =  $(this.el).find("#proxy_ip_box").val();
	    	var proxy_port_box_val =  $(this.el).find("#proxy_port_box").val();
	    	var testNotifications = [];    	
	    	
	    	if(proxy_ip_box_val.length == 0)
	    	{
	    		testNotifications.push({'type': 'error', 'message': 'Proxy Ip Address is missing'});
	    	}
	    	else if(proxy_port_box_val.length == 0)
	    	{
	    		testNotifications.push({'type': 'error', 'message': 'Proxy Port is missing'});
	    	}	
	    	else
    		{
	    		this.handleActionOverlay('enable');
	    		
	    		var details = {
	    			'current_op': "new_proxy", 
	    			'proxy_ip_box': proxy_ip_box_val,
	    			'proxy_port_box': proxy_port_box_val,
	    			'tests': false,
	    			'rand': this.page.getRnd()
	    			};
		    	
		    	var self = this;
	    		this.model.set(details);
		    	this.model.save({},{success: function(resp, model) {self.addProxySuccess(resp,model);}});
    		}
	    	
	    	if(testNotifications.length > 0)
	    	{
	    		Backbone.handleNotifications({'notifications': testNotifications});
	    	}	
	    },
	    
	    handleBulkProxyAdd: function()
	    {
	    	Backbone.log("newProxyView handleBulkProxyAdd trigerred");
	    	
	    	var proxy_bulk_box_val =  $(this.el).find("#proxy_bulk_box").val();
	    	var testNotifications = [];    	
	    	
	    	if(proxy_bulk_box_val)
    		{
	    		this.handleActionOverlay('enable');
	    		
	    		var details = {
        			'current_op': "bulk_proxy", 
        			'proxy_bulk_box': proxy_bulk_box_val, 
        			'rand': this.page.getRnd()
        			};
	        		
		    	var self = this;
		    	this.model.set(details);
	    		this.model.save({},{success: function(resp, model) {self.addProxySuccess(resp,model);}});
    		}
	    	else
	    	{
	    		testNotifications.push({'type': 'error', 'message': 'Proxies List is empty'});
	    	}
	    	
	    	if(testNotifications.length > 0)
	    	{
	    		Backbone.handleNotifications({'notifications': testNotifications});
	    	}	
	    },
	    
	    addProxySuccess: function(model, resp)
	    {
	    	this.handleActionOverlay('disable');
	    	
	    	var addNewProxySuccess = false;
	    	
	    	if(resp)
	    	{
	    		if(resp.data)
	    		{
	    			if(resp.data.actionStatus)
	    			{
	    				addNewProxySuccess = resp.data.actionStatus;
	    			}
	    		}
	    	}	
	    	
	    	if(addNewProxySuccess)
    		{
	    		//refresh main model (must change this to only refresh proxyset)
	    		this.page.model.fetch();
    		}
	    },
	    
	    handleProxyAdd: function()
	    {
	    	Backbone.log("handleProxyAdd triggered");
	    	
	    	var self = this;
	    	
	    	$(this.el).find('#add-proxy-options').slideToggle('slow', false, function(){self.slideToggleCallback(self)});
	    },
	    
	    slideToggleCallback: function(view)
	    {
	    	//refresh view after slide up
	    	if($(view.el).find('#add-proxy-options').css("display") == 'none')
	    	{
	    		view.render();
	    	}
	    },
	    
	    handleModelChange: function(ev)
	    {
	    	Backbone.log("newProxyView handleModelChange triggered");	
	    },
	    
	    handleModelSave: function()
	    {
	    	Backbone.log("handleModelSave triggered");
	    	this.handleActionOverlay('disable');
	    },
	    
	    handleActionOverlay: function(action)
	    {
	    	Backbone.log("handleActionOverlay triggered: "+action);
	    	
	    	if(action == 'enable')
	    	{
	    		//appdetails-container
	    		var tmpContainer = $(this.el);
	    		var tmpContainerOffset = tmpContainer.offset();
	    		
	    		$('#livedash-waiting-overlay').css({
	    			'visibility': 'visible', 
	    			'width': $(tmpContainer)[0].offsetWidth+'px', 
	    			'height': $(tmpContainer)[0].offsetHeight+'px', 
	    			'top': tmpContainerOffset.top, 
	    			'left': tmpContainerOffset.left
	    			});
	    	}
	    	else if(action == 'disable')
	    	{
	    		$('#livedash-waiting-overlay').css({visibility: 'hidden'});
	    	}
	    }
	    
  });
  
  return newProxyView;
});