// Filename: views/admin_proxies/proxyitem
define([
  'jquery',
  'underscore',
  'backbone',
  'text!templates/admin_proxies/proxyitem.html'
], function($, _, Backbone, proxyItemTemplate){

	var proxyItemView = Backbone.View.extend(
	{
	    tagName : "tr",
	    
	  	events :
	  	{
	  		'click button#admin-enable-proxy' : 'handleProxyEnable',
	  		'click button#admin-disable-proxy' : 'handleProxyDisable',
	  		'click button#admin-edit-proxy' : 'handleProxyEdit',
	  		'click button#admin-check-proxy' : 'handleProxyCheck',
	  		'click button#admin-delete-proxy' : 'handleProxyDelete',
	  		'click button#edit-update-proxy-btn' : 'processProxyEdit'
  		},
	    
	    initialize : function (options)
	    {
	        Backbone.log("proxyItemView initialize");
	        
	        this.page = options["page"];
	        
	        $(this.el).attr("id","admin_proxy_item_"+this.model.get("name"));
	        $(this.el).attr("align","center");
	        
	        this.model.bind("change", this.handleModelChange, this);
	    },
	    
	    render : function ()
	    {
	    	Backbone.log("proxyItemView render");
	    	//Backbone.log(this.model.toJSON());

	    	var data = {
	    		proxy_ip: this.model.get("proxy_ip"),
	    		proxy_port: this.model.get("proxy_port"),
	    		request_time: (this.model.get("request_time") > 0? this.model.get("request_time") : false),
	    		status: this.model.get("status"),
	    		status_reason: (this.model.get("status_reason") != ''? this.model.get("status_reason") : false)
	    		};
	    	
	    	var compiledTemplate = _.template( proxyItemTemplate, data );
	        $(this.el).html(compiledTemplate);
	        
	        
	        $(this.el).find('#edit_proxy_ip_box').val(this.model.get("proxy_ip"));
	        $(this.el).find('#edit_proxy_port_box').val(this.model.get("proxy_port"));
	    	
	        return this;
	    },
	    
	    
	    handleProxyEnable : function()
	    {
	    	Backbone.log("handleProxyEnable triggered");

	    	var self = this;
	    	this.handleActionOverlay('enable');
	    	
	    	this.model.set({'current_op': 'enable_proxy'});
	    	this.model.save({}, {success: function() {self.handleModelSave()}});
	    },

	    handleProxyDisable : function()
	    {
	    	Backbone.log("handleProxyDisable triggered");

	    	var self = this;
	    	this.handleActionOverlay('enable');
	    	
	    	this.model.set({'current_op': 'disable_proxy'});
	    	this.model.save({}, {success: function() {self.handleModelSave()}});
	    },
	    
	    handleProxyEdit: function()
	    {
	    	Backbone.log("handleProxyEdit triggered");
	    	
	    	$(this.el).find('#proxy-edit-container').slideToggle('slow');
	    },
	    
	    handleProxyCheck: function()
	    {
	    	Backbone.log("handleProxyCheck triggered");
	    	
	    	var self = this;
	    	this.handleActionOverlay('enable');
	    	
	    	this.model.set({'current_op': 'check_proxy'});
	    	this.model.save({},{success: function(resp, model) {self.handleProxySuccess(resp,model);}});
	    },

	    handleProxyDelete: function()
	    {
	    	Backbone.log("handleProxyDelete triggered");
	    	
	    	var confirm = window.confirm("Are you sure you want to delete this proxy ?");
	    	
	    	if(confirm)
	    	{
	    		var self = this;
	    		this.handleActionOverlay('enable');
	    		
	    		this.model.set({'current_op': 'delete_proxy'});
		    	this.model.save({},{success: function(resp, model) {self.handleProxySuccess(resp,model);}});
	    	}	
	    },
	    
	    handleModelSave: function()
	    {
	    	Backbone.log("handleModelSave triggered");
	    	this.handleActionOverlay('disable');
	    },
	    
	    processProxyEdit: function()
	    {
	    	Backbone.log("processProxyEdit triggered");
	    	
	    	var edit_proxy_ip_box = $(this.el).find('#edit_proxy_ip_box').val();
	    	var edit_proxy_port_box = $(this.el).find('#edit_proxy_port_box').val();
	    	
	    	if(edit_proxy_ip_box.length && edit_proxy_port_box.length)
	    	{
	    		var self = this;
	    		this.handleActionOverlay('enable');
	    		
	    		var details = {
	    			'current_op': 'edit_proxy', 
	    			'proxy_ip': edit_proxy_ip_box, 
	    			'proxy_port': edit_proxy_port_box,	
	    			'rand': this.page.getRnd()	
	    			};
	    		
		    	this.model.set(details);	    		
		    	this.model.save({},{success: function(resp, model) {self.handleProxySuccess(resp,model);}});
	    	}	
	    },
	    
	    handleProxySuccess: function(model, resp)
	    {
	    	this.handleActionOverlay('disable');
	    	
	    	var operationSuccess = false;
	    	
	    	if(resp)
	    	{
	    		if(resp.data)
	    		{
	    			if(resp.data.actionStatus)
	    			{
	    				operationSuccess = resp.data.actionStatus;
	    			}
	    		}
	    	}	
	    	
	    	if(operationSuccess)
    		{
	    		//refresh main model (must change this to only refresh proxyset)
	    		this.page.model.fetch();
    		}
	    },
	    
	    handleModelChange: function()
	    {
	    	var execRender = true;
	    	
	    	if(this.model.has('current_op'))
    		{
    			if(this.model.get('current_op') == 'edit_proxy')
    			{
    				execRender = false;
    			}	
    		}
	    	
	    	if(execRender) this.render();
	    },

	    handleModelSave: function()
	    {
	    	Backbone.log("handleModelSave triggered");
	    	this.handleActionOverlay('disable');
	    },
	    
	    handleActionOverlay: function(action)
	    {
	    	Backbone.log("handleActionOverlay triggered: "+action);
	    	
	    	if(action == 'enable')
	    	{
	    		//appdetails-container
	    		var tmpContainer = $(this.el);
	    		var tmpContainerOffset = tmpContainer.offset();
	    		
	    		$('#livedash-waiting-overlay').css({
	    			'visibility': 'visible', 
	    			'width': $(tmpContainer)[0].offsetWidth+'px', 
	    			'height': $(tmpContainer)[0].offsetHeight+'px', 
	    			'top': tmpContainerOffset.top, 
	    			'left': tmpContainerOffset.left
	    			});
	    	}
	    	else if(action == 'disable')
	    	{
	    		$('#livedash-waiting-overlay').css({visibility: 'hidden'});
	    	}
	    }
	})

  return proxyItemView;
});