// Filename: views/admin_settings/page
define([
  'jquery',
  'underscore',
  'backbone',
  'collections/admin_settings/sectionset',
  'models/admin_settings/page',
  'views/admin_settings/sectionset',
  'views/admin_settings/sectionsettouch',
  'views/admin_settings/pagebasic',
  'views/admin_settings/pageapi',
  'views/admin_settings/pagemail',
  'text!templates/admin_settings/page.html'
], function($, _, Backbone, sectionSet, PageModel, sectionSetView, sectionSetTouchView, basicSettingsView, apiSettingsView, mailSettingsView, pageTemplate){

  var adminSettingsView = Backbone.View.extend(
  {
	    el: $('#page'),
	    
	    initialize : function ()
	    {
	    	Backbone.log("admin_settings pageView init");
	    	
	    	var self = this;
	    	
	    	this.model = new PageModel();
	    	
	    	//handle events
	    	this.model.bind("change", this.render, this);
	    	
	    	this.sections =  new sectionSet();
	    	
	    	this.currentSection = false;
	    	
	    	this.currentSectionView = null;
	    	
	        this.model.fetch();
	    },
	    
	    render : function ()
	    {
	    	Backbone.log('adminSettingsView render');
	    	
	    	var self = this;
	    	
	        var compiledTemplate = _.template( pageTemplate, {} );
	        $(this.el).empty().html( compiledTemplate );
	        
	    	//populate sections collection from pageModel
	        if(this.sections.models.length == 0)
	        {
	        	this.sections.add(_.toArray(self.model.get("sectionsItems")));	
	        }
	    	
	    	if(!this.currentSection) this.currentSection = this.sections.models[0].get("name");

	    	//Render admin settings sections
	        this.sectionSetView = new sectionSetView({model: this.sections, page: this});
	        this.sectionSetView.render();
	        
	        //Render admin settings sections for touch interfaces
	        this.sectionSetTouchView = new sectionSetTouchView({model: this.sections, page: this});
	        this.sectionSetTouchView.render();
	        
	        //Render MainPanel
	        settingsMainPanel = $(this.el).find("#admin-settings-placeholder");
	        if(this.currentSection == 'basic')
	        {
	        	//Render basic panel
		        this.currentSectionView = new basicSettingsView({page: this});
	        }
	        else if(this.currentSection == 'opensapi')
	        {
	        	//Render opens api
		        this.currentSectionView = new apiSettingsView({page: this});
	        }
	        else if(this.currentSection == 'mailservice')
	        {
	        	//Render mail service
	        	this.currentSectionView = new mailSettingsView({page: this});
	        }
	        
	        settingsMainPanel.html(this.currentSectionView.render().el);
	    },
	    
	    viewSectionDetails: function(sectionItemName)
	    {
	    	if(sectionItemName !== false)
    		{
		    	//set activate category
		    	this.currentSection = sectionItemName;
    			this.render();
    		}
	    },
	    
	    getRnd: function()
	    {
	    	return Math.floor(Math.random()*11);	    	
	    }
	    
  });
  
  return adminSettingsView;
});