// Filename: views/home/main
define([
  'jquery',
  'underscore',
  'backbone',
  'jqtransport',
  'views/ajax_upload/mainitem',
  'text!templates/admin_widgets_manager/newwidgetitem.html',
  'text!templates/basic/testdisplay.html'
], function($, _, Backbone, jqTransport, mainItemView, newWidgetItemTemplate, testTemplate){

  var newWidgetView = Backbone.View.extend(
  {
  		el: '#add-widget-container',
  		
	  	events :
	  	{	
	  		'click button.add-widget-btn' : 'handleWidgetAdd',
  			'click button#get-widget-btn.blue' : 'processNewWidgetForm',
  			'click button#install-widget-btn.blue' : 'processInstallWidget',
  			'change input#get_widget_upload_box' : 'activateInstallWidgetBtn',
  			'change input#get_widget_url_box' : 'activateInstallWidgetBtn',
  		},
  		
	    initialize : function (options)
	    {
	    	Backbone.log("newWidgetView init");
	    	
	    	this.page = options['page'];
	    	
	    	this.model.bind('change', this.handleModelChange ,this);
	    },
	    
	    render : function ()
	    {
	    	Backbone.log("newWidgetView render");
	    	
	    	var compiledTemplate = _.template( newWidgetItemTemplate, {});
	        $(this.el).html(compiledTemplate);
	        
	    	return this;
	    },
	    
	    
	    processNewWidgetForm: function()
	    {
	    	Backbone.log("processNewWidgetForm trigerred");
	    	
	    	var get_widget_upload_box =  $(this.el).find("#get_widget_upload_box").val();
	    	var get_widget_url_box =  $(this.el).find("#get_widget_url_box").val();
	    	
	    	if(get_widget_upload_box)
    		{
	    		var intputElement = $(this.el).find("#get_widget_upload_box");
	    		var uploadData = {action: 'doWidgetUpload'};
	    		var self = this;
	    		
	    		$.ajax(this.model.url, {files: intputElement, type: 'POST', iframe: true, dataType: 'json', data: uploadData, processData: false})
					.always(function(data, textStatus, jqXHR){self.handleUploading(data, textStatus, jqXHR, self)})
					.done(function(data, textStatus, jqXHR){self.handleDone(data, textStatus, jqXHR, self)})
					.fail(function(jqXHR){self.handleFail(jqXHR, self)});
	    		
	    		//show loading spinner
	    		this.deactivateInstallWidgetBtn();
		    	$(this.el).find("#widget-tests-details-container").show();
		    	$(this.el).find('#add-widget-test-details').empty().append('<div class="spinner" id="loadingSpinner"></div>');
    		}
	    	else if(get_widget_url_box)
	    	{
	    		var details = {
	    			'current_step': "validate", 
	    			'get_widget_url_box': get_widget_url_box, 
	    			'tests': false,
	    			'rand': this.getRnd()
	    			};
	    		
	    		this.model.set(details);
		    	this.model.save();
		    	
		    	this.deactivateInstallWidgetBtn();
		    	$(this.el).find("#widget-tests-details-container").show();
		    	$(this.el).find('#add-widget-test-details').empty().append('<div class="spinner" id="loadingSpinner"></div>');
	    	}
	    },
	    
	    processInstallWidget: function()
	    {
	    	Backbone.log("processInstallWidget trigerred");
	    	
	    	var self = this;
	    	
	    	this.model.set({'current_step': "install", 'rand': this.getRnd()});
	    	this.model.save({},{success: function(resp, model) {self.processInstallWidgetSuccess(resp,model);}});
	    	
    		//disable acceptInstallBtn
    		this.deactivateAcceptInstallBtn();
    		$(this.el).find('#add-widget-test-details').empty().append('<div class="spinner" id="loadingSpinner"></div>');
	    },
	    
	    processInstallWidgetSuccess: function(model, resp)
	    {
	    	//parse resp and check if it's ok
	    	var installWidgetSuccess = false;
	    	
	    	if(resp)
	    	{
	    		if(resp.data)
	    		{
	    			if(resp.data.actionStatus)
	    			{
	    				if(resp.data.actionStatus === true)
	    				{
	    					installWidgetSuccess = true;
	    				}
	    			}
	    		}
	    	}	
    		
	    	if(installWidgetSuccess)
    		{
	    		//refresh installedWidgetSet & uninstalledWidgetSet
	    		this.page.installedWidgetSet.fetch();
	    		this.page.uninstalledWidgetSet.fetch();
    		}
	    },
	    
	    getRnd: function()
	    {
	    	return Math.floor(Math.random()*11);	    	
	    },
	    
	    handleWidgetAdd: function()
	    {
	    	Backbone.log("handleWidgetAdd triggered");
	    	
	    	var self = this;
	    	
	    	$(this.el).find('#add-widget-options').slideToggle('slow', false, function(){self.slideToggleCallback(self)});
	    },
	    
	    slideToggleCallback: function(view)
	    {
	    	//refresh view after slide up
	    	if($(view.el).find('#add-widget-options').css("display") == 'none')
	    	{
	    		view.render();
	    	}
	    },
	    
	    handleUploading: function(data, textStatus, jqXHR, el)
	    {
	    	Backbone.log("handleUploading triggered");
	    },
	    
	    handleDone: function(data, textStatus, jqXHR, el)
	    {
	    	Backbone.log("handleDone triggered");
	    	
	    	Backbone.handleNotifications(data);
	    	
	    	var resp = data;
	    	
	    	if(resp.data)
    		{
	    		if(resp.data.actionData)
	    		{
	    			if(resp.data.actionData.modelDetails)
	    			{
	    				//update current model
	    				el.model.set(resp.data.actionData.modelDetails);
	    			}	
	    		}	
    		}
	    },

	    handleFail: function(jqXHR)
	    {
	    	Backbone.log("handleFail triggered");
	    	
	    	var resp = {notifications:[{type:'error', message:'File could not be uploaded! Please try again.'}]};
	    	Backbone.handleNotifications(resp);
	    },
	    
	    activateInstallWidgetBtn: function()
	    {
	    	$(this.el).find("#get-widget-btn").removeClass("white").addClass("green");
	    },
	    
	    deactivateInstallWidgetBtn: function()
	    {
	    	$(this.el).find("#get-widget-btn").removeClass("green").addClass("white");
	    },
	    
	    activateAcceptInstallBtn: function()
	    {
	    	$(this.el).find("#install-widget-btn").removeClass("white").addClass("green");
	    },
	    
	    deactivateAcceptInstallBtn: function()
	    {
	    	$(this.el).find("#install-widget-btn").removeClass("green").addClass("white");
	    },
	    
	    handleModelChange: function(ev)
	    {
	    	var hasTestsDetails = (this.model.has("unpackTests") ? true : (this.model.has("installTests")));
	    	var successValidationResult = (this.model.has("validationResult") ? this.model.get("validationResult") : false); 
	    	var currentStep = this.model.get("current_step");
	    	
	    	//check if widget is valid (there are no errors)
	    	var accept_install = ((currentStep == 'validate') && (hasTestsDetails) && (successValidationResult) ?  true : false);
	    	
	        //add test template
	        if(hasTestsDetails)
        	{
	        	var testDetails = [];
	        	
	        	if(this.model.has("unpackTests"))
	        	{
	        		testDetails = this.model.get("unpackTests"); 	
	        	}
	        	else if(this.model.has("installTests"))
        		{
	        		testDetails = this.model.get("installTests");
        		}
	        	
	        	if(this.model.has("widgetInfo"))
	        	{
		    		var widgetDetails = this.model.get("widgetInfo");
		    		$(this.el).find('#widget-details-title-container').html('Installation Process - '+widgetDetails.title);
	        	}
	        	
		    	if(accept_install)
		    	{
		    		$(this.el).find("#install-widget-btn").show();
		    		this.activateAcceptInstallBtn();
		    	}	
		    		
	        	
	        	var compiledTemplate = _.template( testTemplate, {'testDetails': testDetails} );
	        	$(this.el).find('#add-widget-test-details').empty().append(compiledTemplate);
        	}
	        
	        //autocomplete widget_url_box
	        var get_widget_url_box =  this.model.get("get_widget_url_box");
	    	if(get_widget_url_box) $(this.el).find("#get_widget_url_box").val(get_widget_url_box);
	    }
  });
  
  return newWidgetView;
});