// Filename: views/home/main
define([
  'jquery',
  'underscore',
  'backbone',
  'jqueryui',
  'models/admin_widgets_manager/page',
  'collections/admin_widgets_manager/installedwidgetset',
  'views/admin_widgets_manager/installedwidgetset',
  'collections/admin_widgets_manager/uninstalledwidgetset',
  'views/admin_widgets_manager/uninstalledwidgetset',
  'collections/admin_boardset/boardset',
  'views/admin_boardset/boardset',
  'models/admin_widgets_manager/newwidgetitem',
  'views/admin_widgets_manager/newwidgetitem',
  'text!templates/admin_widgets_manager/page.html',
], function($, _, Backbone, jqueryUI, PageModel, installedWidgetSet, installedWidgetSetView, uninstalledWidgetSet, uninstalledWidgetSetView, boardSet, boardSetView, newWidgetModel, newWidgetView, widgetsManagerTemplate){

  var pageView = Backbone.View.extend(
  {
	    el: $('#page'),
	    
	    initialize : function ()
	    {
	    	Backbone.log("admin_widgets_manager pageView init");
	    	
	    	var self = this;
	    	
	    	this.model = new PageModel();
	    	
	    	this.boardSet = new boardSet();
	    	this.boardSetView = null;
	    		
	    	this.installedWidgetSet = new installedWidgetSet();
	    	this.installedWidgetSetView = null;
	    	
	    	this.uninstalledWidgetSet = new uninstalledWidgetSet();
	    	this.uninstalledWidgetSetView = null;
	    	
	        this.newWidgetModel =  new newWidgetModel();
	        this.newWidgetView = null;
	        
	        this.model.bind("change", this.render, this);
	    	
	        this.model.fetch();
	    },
	    
	    render : function ()
	    {
	    	var self = this;
	    	
	    	Backbone.log('admin_widgets_manager pageView render');
	    	
	    	var  data = {};
	    	var compiledTemplate = _.template( widgetsManagerTemplate, data );
	        $(this.el).html(compiledTemplate);
	        
	        //draw avaiable tabs list
	        if(this.model.has("boards"))
	        {
	        	this.activeBoardName = "widgets_manager";
	        	
	        	if(this.boardSet.models.length == 0)
	        	{
	        		this.boardSet.add(_.toArray(this.model.get("boards")));
	        	}

		        //create boardSetView and render it
		        this.boardSetView = new boardSetView({model: this.boardSet, page: this});
		        this.boardSetView.render();
	        }
	        
	        //handle app manager view ... 	        

	        //add newwidget form
	        //$(this.el).find('#add-widget-options').empty().append(this.newWidgetView.render().el);
	        this.newWidgetView = new newWidgetView({model: this.newWidgetModel, page: this});
	        this.newWidgetView.render();
	        
	        
	        if(this.model.has("installedWidgets"))
	        {
		        //populate installedWidgetSet collection from pageModel
		        this.installedWidgetSet.add(_.toArray(this.model.get("installedWidgets")));
		        
		        //create installedWidgetSetView and render it
		        this.installedWidgetSetView = new installedWidgetSetView({model: this.installedWidgetSet, page: this});
		        this.installedWidgetSetView.render();
	        }
	        
	        
	        //populate uninstalledWidgetSet collection from pageModel
	        if(this.model.has("uninstalledWidgets"))
	        {
	        	var uninstalledWidgets = _.toArray(this.model.get("uninstalledWidgets"));
	        	
	        	if(uninstalledWidgets.length)
        		{
	        		$('.uninstalled-widgets-box').addClass('uninstalled-widgets-box-show');
        		}
	        	
	        	this.uninstalledWidgetSet.add(uninstalledWidgets);
		        
		        //create uninstalledWidgetSetView and render it
		        this.uninstalledWidgetSetView = new uninstalledWidgetSetView({model: this.uninstalledWidgetSet, page: this});
		        this.uninstalledWidgetSetView.render();
	        }
	        
	    }
  });
  
  return pageView;
});