// Filename: views/home/main
define([
  'jquery',
  'underscore',
  'backbone',
  'jqueryui',
  'jqwindow',
  'text!templates/admin_widgets_manager/widgetitem.html'
], function($, _, Backbone, jQueryUI, jqWindow, widgetTemplate){

  var widgetView = Backbone.View.extend(
  {
	  	tagName : "li",
	  
	  	events : {
  			'mouseover .widgetBoardItem' : 'showControls',
  			'mouseout .widgetBoardItem' : 'hideControls',
  			'click span#widget-update-badge-btn' : 'handleWidgetUpdate',
  			'click .widget-title-box' : 'openWidgetWindow'
  		},
  		
	    initialize : function (options)
	    {
	    	Backbone.log("admin_widgets_manager widgetView init");
	    	
	    	this.model.bind('change',this.render,this);
	    },
	    
	    render : function ()
	    {
	    	Backbone.log("admin_widgets_manager widgetView render");
	    	
	    	var widgetStatus = (this.model.has("status") ? this.model.get("status") : "E");
	    	
	    	var widgetItemId = (this.model.has("id") ? this.model.get("id") : "1");
	    	
	    	var widgetLink = (this.model.has("widget_link") ? this.model.get("widget_link"): '#');
	    	
	    	var data = {
	    		id: widgetItemId,
	    		url: widgetLink,
	    		status: widgetStatus,
	    		title: this.model.get("title"),
	    		icon: this.model.get("widget_icon_board"),
	    		version: parseInt(this.model.get("version")).toPrecision(2),
	    		show_update_badge: (this.model.get("install_type")== 'update' ? true : false)
	    	};
	    	
	        var compiledTemplate = _.template( widgetTemplate, data );
	        $(this.el).html(compiledTemplate);
	        
	        $(this.el).addClass('widgetBoardItemWrapper');
	        
	        return this;
	    },
	    
	    showControls : function ()
	    {
	    	//$(this.el).find('.widget-icon-overlay').addClass('show-overlay');
	    },
	    
	    hideControls : function ()
	    {
	    	//$(this.el).find('.widget-icon-overlay').removeClass('show-overlay');
	    },
	    
	    openWidgetWindow: function()
	    {
	    	$.window.prepare({
    		   dock: 'bottom', 
    		   animationSpeed: 500,  
    		   minWinLong: 180 
    		});
	    	
	    	$.window({
	    		title : this.model.get("title"),
	    		url : this.model.get("widget_link"),
	    		width : 800,
	    		height : 600,
	    		resizable : true,
	    		scrollable: 'auto',
	    		bookmarkable: false,
	    		//checkBoundary: true,
	    		icon : this.model.get("widget_icon_board")
    		});	
	    },
	    
	    openWidgetSettings: function()
	    {
	    	$.window.prepare({
    		   dock: 'bottom', 
    		   animationSpeed: 500,  
    		   minWinLong: 180 
    		});
	    	
	    	$.window({
	    		title : this.model.get("settings_title"),
	    		url : this.model.get("settings_link"),
	    		width : 800,
	    		height : 600,
	    		resizable : true,
	    		scrollable: 'auto',
	    		bookmarkable: false,
	    		//checkBoundary: true,
	    		icon : this.model.get("widget_icon_board")
    		});	
	    },
	    
	    
	    handleWidgetUpdate: function()
	    {
	    	Backbone.log("handleWidgetUpdate fired");
	    	
	    	if (window.confirm('Are you sure you want to update this widget ?'))
	        {
		    	this.model.set({'current_op': 'update'});
		    	this.model.save();
	        }	
	    }
  });
  
  return widgetView;
});