// Filename: views/ajax_upload/fileinputitem
define([
  'jquery',
  'underscore',
  'backbone',
], function($, _, Backbone){

  var fileInputView = Backbone.View.extend({

      tagName: 'input',
      
      url: "../controllers/ajax_upload/index.php",
      
      events:
      {
    	  'change': 'handleInputChange'
      },
	  
      initialize: function(options)
      {
    	 Backbone.log("fileInputView initialize");
    	 
    	 console.log(options);
    	 
		  this.$el = $(this.el);
		  
    	  _.bindAll(this, 'fail', 'uploading', 'done');
    	  
    	  options = options || {};
    		  
	      if(options.url) this.url = options.url;
	      
	      this.data = options.data || {};
	      
	      this._name = options.name || 'files[]';
	      
	      this._multiple = options.hasOwnProperty('multiple') ? options.multiple : false;
	      
	      this._enabled = options.hasOwnProperty('enabled') ? options.enabled : true;
	      
	      return this;
      },
      
      render: function()
      {
    	  Backbone.log("fileInputView render");
    	  
    	  this.$el.attr('type', 'file').attr('name', this._name);
        
    	  if (this._multiple)
    	  {
    		  this.$el.attr('multiple', true);
    	  }
    	  if (!this._enabled)
    	  {
    		  this.$el.attr('disabled', 'disabled');
    	  }
    	  
    	  this.$input = this.$el;

    	  return this;
      },
      
      enable: function(enable)
      {
    	Backbone.log("fileInputView enable triggered");
    	
    	if (this._enabled != enable)
        {
        	this._enabled = enable;
        	
        	if (enable)
        	{
        		this.$input.removeAttr('disabled');
        	} 
        	else
        	{
        		this.$input.attr('disabled', 'disabled');
        	}
          this.trigger('enabled', enable);
        }
      },
      
      toggle_enable: function()
      {
    	  Backbone.log("fileInputView toggle_enable triggered");
    	  
    	  this.enable(!this._enabled);
      },
      
      handleInputChange: function(ev)
      {
    	  Backbone.log("fileInputView handleChangeInput triggered");
    	  
    	  if (this._enabled)
    	  {
    		 $.ajax(this.url, {files: this.$input, type: 'POST', iframe: true, dataType: 'json', data: this.data, processData: false})
				.always(this.uploading)
				.done(this.done)
				.fail(this.fail);
    	  }
      },
      
      done: function(data, textStatus, jqXHR)
      {
    	  Backbone.log("fileInputView done triggered");
    	  
    	  this.$el.removeClass('loading');
    	  
    	  console.log(data);
    	  console.log(textStatus);
    	  console.log(jqXHR);
    	  
    	  this.collection.add(data);
    	  this.trigger('done', this.collection, data, textStatus, jqXHR);
      },
      
      fail: function(jqXHR)
      {
    	  Backbone.log("fileInputView fail triggered");
    	  
    	  this.$el.removeClass('loading');
    	  this.trigger('fail', JSON.parse(jqXHR.responseText), jqXHR);
      },
      
      uploading: function(data, textStatus, jqXHR)
      {
    	  Backbone.log("fileInputView uploading triggered");
    	  
    	  this.$el.addClass('loading');
    	  this.trigger('uploading');
    	  this.$input.val('');
      }
  });
  
  return fileInputView;
});