// Filename: views/apps/app
define([
  'jquery',
  'underscore',
  'backbone',
  'jqueryui',
  'jqwindow',
  'models/apps/app',
  'text!templates/apps/app.html'
], function($, _, Backbone, jQueryUI, jqWindow, appModel, appTemplate){

  var appView = Backbone.View.extend(
  {
	  	tagName : "li",
	  
	  	events : {
  			'mouseover .appBoardItem' : 'showControls',
  			'mouseout .appBoardItem' : 'hideControls',
  			'click .app-title-box' : 'openAppWindow',
  			'click .appBoardItemControlsStart' : 'startApp',
  			'click .appBoardItemControlsStop' : 'stopApp',
  			'click .appBoardItemControlsSettings' : 'openAppSettings',
  		},
  		
	    initialize : function (options)
	    {
	    	Backbone.log("appView init");
	    	
	    	this.page = options['page'];
	    	
	        $(this.el).attr('appName',this.model.get('name'));
	        
	        $(this.el).attr('id','app_'+this.options.temp);
	        
	        $(this.el).addClass('appBoardItemWrapper');
	        
	        this.model.bind('change',this.render,this);
	    },
	    
	    render : function ()
	    {
	    	Backbone.log("appView render");
	    	
	    	//attach model to element
	    	$(this.el).data('model',this.model);
	    	
	    	var data = {
	    		id: this.model.get("id"),
	    		title: this.model.get("title"),
	    		url: this.model.get("app_link"),
	    		icon: this.model.get("app_icon_board"),
	    		icon_inactive: this.model.get("app_icon_board"), //TODO: actual inactive icon
	    		status: this.model.get("status"),
	    		has_settings: this.model.get("has_settings")
	    	};
	    	
	        var compiledTemplate = _.template( appTemplate, data );
	        $(this.el).html(compiledTemplate);
	        
	        if (this.page.active_app)
	        {
	        	if (this.page.active_app == this.model.get('name'))
	        	{
	        		this.openAppWindow(null,this.page.active_app_view,this.page.active_app_params);
	        	}
	        }
	        
	        return this;
	    },	    
	    
	    showControls : function ()
	    {
	    	$(this.el).find('.app-icon-overlay').addClass('show-overlay');
	    },
	    
	    hideControls : function ()
	    {
	    	$(this.el).find('.app-icon-overlay').removeClass('show-overlay');
	    },
	    
	    startApp : function ()
	    {
	    	this.model.set({ status:'E' });
	    	this.model.save();
	    },
	    
	    stopApp : function ()
	    {
	    	this.model.set({ status:'D' });
	    	this.model.save();
	    },
	    
	    openAppWindow: function(event,view,params)
	    {
	    	$.window.prepare({
    		   dock: 'bottom', 
    		   animationSpeed: 500,  
    		   minWinLong: 180 
    		});
	    	
	    	var appUrl=this.model.get("app_link");
	    	
	    	if (view)
	    	{
	    		appUrl+='&view='+view;
	    		
	    		if (params)
	    		{
	    			appUrl+='&'+params;
	    		}
	    	}
	    	
	    	if ($(window).width()<1025)
	    	{
	    		window.location=appUrl;
	    	}
	    	else
	    	{
		    	$('#app-window-container').window({
		    		title : this.model.get("title"),
		    		url : appUrl,
		    		width : $(window).width()/10*9,
		    		height : $(window).height()/4*3,
		    		resizable : true,
		    		bookmarkable: false,
		    		scrollable: 'auto',
		    		checkBoundary: true,
		    		showFooter: false,
		    		icon : this.model.get("app_icon_board")
	    		});
	    	}	
	    },
	    
	    openAppSettings: function()
	    {
	    	if (this.model.get('has_settings'))
	    	{
		    	$.window.prepare({
	    		   dock: 'bottom', 
	    		   animationSpeed: 500,  
	    		   minWinLong: 180 
	    		});
		    	
		    	if ($(window).width()<1025)
		    	{
		    		window.location=this.model.get("settings_link");
		    	}
		    	else
		    	{
			    	$('#app-window-container').window({
			    		title : this.model.get("settings_title"),
			    		url : this.model.get("settings_link"),
			    		width : $(window).width()/10*9,
			    		height : $(window).height()/4*3,
			    		resizable : true,
			    		bookmarkable: false,
			    		checkBoundary: true,
			    		scrollable: 'auto',
			    		showFooter: false,	    		
			    		icon : this.model.get("app_icon_board")
		    		});	
		    	}
		    }
	    }
  });
  
  return appView;
});