// Filename: views/apps/board
define([
  'jquery',
  'underscore',
  'backbone',
  'jqueryui',
  'collections/apps/board',
  'models/apps/app',
  'views/apps/app',
], function($, _, Backbone, jqueryUI, appCollection, appModel, appView){

  var appBoardView = Backbone.View.extend(
  {
	    el: $('#page'),
	    
	    initialize : function ()
	    {
	    	Backbone.log("appBoardView init");
	    	
	    	this.appboard = new appCollection();
	    	
	    	this.appItems_views = {};
	    	
	    	this.appboard.bind("reset", this.render, this);
	    	
	    	var self = this;
	        this.appboard.fetch();
	    },
	    
	    render : function ()
	    {
	    	var self=this;
	    	Backbone.log('appBoardView render');
	    	
	    	$(self.el).html("<div class='tab-content tab-content-livedash clearfix tab-content-opens-margin-fix'><ul id='appBoardContainer'></ul></div>");
	    	
	    	var i=0; $('#appBoardContainer').empty();
        	_.each(this.appboard.models, function (item) 
        	{
        		i++;
        		
        		var appItemId = item.get("id");
        		
        		currentAppItemView = new appView({temp:i, model:item, boardView: self});
        		
        		self.appItems_views[appItemId] = currentAppItemView; 
        		
        		$('#appBoardContainer').append(currentAppItemView.render().el);
        	});
        	
        	$('#appBoardContainer').sortable(
    		{
    			placeholder: 'appboard-item-placeholder',
    			start: function(event,ui) {self.handleAppItemDragStart(event, ui, this)},
    			stop: function(event,ui) {self.handleAppItemDragStop(event, ui, this)}
    		});
        	
        	$('#appBoardContainer').disableSelection();
	    },
	    
	    handleAppItemDragStart: function(event, ui, el)
	    {
	    	Backbone.log('handleAppItemDragStart fired');
	    	
	    	//undelegate appItemView events to prevent onmouseover while dragging
	    	var currentAppItem = $(ui.item);
	    	var parts = currentAppItem.find(".appBoardItem").attr("id").split("_");
	    	var currentAppItemId = parts[1];
	    	
	    	if(this.appItems_views[currentAppItemId])
	    	{
	    		this.appItems_views[currentAppItemId].undelegateEvents();
	    	}
	    	
	    	currentAppItem.find('.app-icon-overlay').removeClass("show-overlay");
	    	currentAppItem.find('.app-icon-container').addClass('app-dragging-disabled');
	    },

	    handleAppItemDragStop: function(event, ui, el)
	    {
	    	Backbone.log('handleAppItemDragStop fired');
	    	
	    	var movedApp = $(ui.item).data('model');
			
	        var i = 1;
	        $(el).find(".appBoardItemWrapper").each(function ()
	        {
	            var model = $(this).data("model");
	            model.set({"position" : i++});
	        });
	        
	        movedApp.save();
	        
	        //redelegate appItemView events
	    	var currentAppItem = $(ui.item);
	    	var parts = currentAppItem.find(".appBoardItem").attr("id").split("_");
	    	var currentAppItemId = parts[1];
	    	
	    	if(this.appItems_views[currentAppItemId])
	    	{
	    		this.appItems_views[currentAppItemId].delegateEvents();
	    	}
	    	
	    	currentAppItem.find('.app-icon-container').removeClass('app-dragging-disabled');
	    }
  });
  
  return appBoardView;
});