// Filename: views/market/appdetails
define([
  'jquery',
  'underscore',
  'backbone',
  'text!templates/market/appdetails.html',
  'text!templates/basic/testdisplay.html'
], function($, _, Backbone, appDetailsTemplate, testTemplate){

  var appDetailsView = Backbone.View.extend(
  {
  		el: "#appstore-placeholder",
  		
	  	events :
	  	{
  			'click button.back-btn' : 'showCategoryDetails',
  			'click button#app-add-btn' : 'handleAppAdd',
  			'click button#app-remove-btn' : 'handleAppRemove'
  		},
  		
	    initialize : function(options)
	    {
	    	Backbone.log("appDetailsView init");
	    	
	    	this.page = options['page'];
	    	
	    	this.disabled_buttons = false;
	    	
	    	this.model.bind('change',this.handleModelChange,this);
	    },

	    render : function ()
	    {
	    	Backbone.log("appDetailsView render");
	    	
	    	var self = this;
	    	
	    	var appDetails = this.model.get("appDetails");
	    	
	    	var data = {
	    		icon_board: appDetails["icon_board"],
	    		app_title: appDetails["title"],
	    		app_name: appDetails["name"],
	    		app_version: appDetails["version"],
	    		app_action: appDetails["app_action"],
	    		description: appDetails["description"],
	    		is_added: appDetails["is_added"],
	    		};
	    	
	    	var compiledTemplate = _.template( appDetailsTemplate, data );
	        $(this.el).html(compiledTemplate);
	        
	    	return this;
	    },
	    
	    showCategoryDetails : function ()
	    {
	    	Backbone.log("showCategoryDetails fired");
	    	
	    	var appDetails = this.model.get("appDetails");

	    	categoryItemName = appDetails.category;
	    	
	    	if(categoryItemName !== false)
    		{
	    		this.page.viewCategoryDetails(categoryItemName);
    		}
	    },
	    
	    handleAppAdd: function()
	    {
	    	Backbone.log("handleAppAdd fired");
	    	
	    	var self = this;
	    	
	    	this.page.handleActionOverlay('enable');
	    	
	    	this.model.set({'is_added': 1, 'app_action':'remove'});
	    	this.model.save({}, {success: function() {self.handleModelSave()}});
	    },

	    handleAppRemove: function()
	    {
	    	Backbone.log("handleAppRemove fired");
	    	
	    	var self = this;
	    	
	    	this.page.handleActionOverlay('enable');
	    	this.model.set({'is_added': 0, 'app_action':'add'});
	    	this.model.save({}, {success: function() {self.handleModelSave()}});
	    },
	    
	    handleModelSave: function()
	    {
	    	Backbone.log("handleModelSave triggered");
	    	this.page.handleActionOverlay('disable');
	    },
	    
	    handleModelChange: function(model)
	    {
	    	this.render();
	    }
  });
  
  return appDetailsView;
});