// Filename: views/market/appitem
define([
  'jquery',
  'underscore',
  'backbone',
  'models/market/appitem',
  'text!templates/market/appitem.html'
], function($, _, Backbone, storeItem, storeItemTemplate){

  var appItemView = Backbone.View.extend(
  {
	  tagName: "li",

	  events : {
  			'click button#add-btn' : 'addApp',
  			'click button#remove-btn' : 'removeApp',
  			//'click img#app-item-icon' : 'showAppDetails',
  		},
  		
	    initialize: function (options)
	    {
	    	Backbone.log("appItemView initialize");
	    	
	    	$(this.el).addClass("col_6");
	    	
	    	this.model.bind('change',this.render,this);
	    	
	    	this.page = options['page'];
	    },
	    
	    addApp: function ()
	    {
	    	var self = this;
	    	
	    	this.handleActionOverlay('enable');
	    	this.model.set({ 'is_added':1,'app_action':'remove' });
	    	this.model.save({}, {success: function() {self.handleModelSave()}});
	    },
	    
	    removeApp: function ()
	    {
	    	var self = this;
	    	
	    	this.handleActionOverlay('enable');
	    	this.model.set({ 'is_added':0,'app_action':'add' });
	    	this.model.save({}, {success: function() {self.handleModelSave()}});
	    },
	    
	    
	    render: function ()
	    {
	    	Backbone.log("appItemView render");
	    	
	    	var data = {
	    		id: this.model.get("name"),
	    		version: this.model.get("version"),
	    		title: this.model.get("title"),
	    		description: this.model.get("description"),
	    		icon_board: this.model.get("icon_board"),
	    		icon_bar: this.model.get("icon_bar"),
	    		icon_manager: this.model.get("icon_manager"),
	    		app_action: this.model.get("app_action"),
	    	};
	    	
	    	var compiledTemplate = _.template( storeItemTemplate, data );
	        
	        $(this.el).html(compiledTemplate);
	    	
	    	return this;
	    },
	    
	    showAppDetails: function()
	    {
	    	Backbone.log("showAppDetails fired");
	    	
	    	this.page.handleActionOverlay('enable');
	    	
	    	var appItemID = this.model.get("app_id");
	    	var self = this;
	    	
	    	//this must be changed
	    	this.page.appDetails.fetch(
	    		{
	    		data: {action: this.page.appDetails._meta.methodMap.read, params:{app_id: appItemID}},
	    		success: function(model, resp) { self.handleappDetailsFetch(model, resp);}
	    		});
	    },
	    
	    handleappDetailsFetch: function(model, resp)
	    {
	    	this.page.currentView = 'appDetails';
	    	this.page.render();
	    	this.page.handleActionOverlay('disable');
	    },
	    
	    handleModelSave: function()
	    {
	    	Backbone.log("handleModelSave triggered");
	    	this.handleActionOverlay('disable');
	    },
	    
	    handleActionOverlay: function(action)
	    {
	    	Backbone.log("handleActionOverlay triggered: "+action);
	    	
	    	if(action == 'enable')
	    	{
	    		//appdetails-container
	    		var appItemContainer = $(this.el).find('#market-appitem-container');
	    		var appItemContainerOffset = appItemContainer.offset();
	    		
	    	
	    	}
	    	else if(action == 'disable')
	    	{
	    		$('#livedash-waiting-overlay').css({visibility: 'hidden'});
	    	}
	    }
  });
  
  return appItemView;
});