// Filename: views/widgets/board
define([
  'jquery',
  'underscore',
  'backbone',
  'views/widgets/widgetset',
  'text!templates/widgets/board.html'
], function($, _, Backbone, widgetSetView, boardOptionsTemplate){

	var boardView = Backbone.View.extend(
	{
	    //el : $("#board-options"),
		tagName: 'div',
		
		events:
	    {
	        "click .change-layout" : "changeBoardLayout",
	        'keyup input#section-title': 'keyupSectionTitle',
	        'blur input#section-title': 'blurSectionTitle',
	        "click #destroy" : 'destroy'
	    },
	    
	    initialize : function (options)
	    {
	    	Backbone.log("boardView initialized");
	    	
	    	this.page = options['page'];
	    	
	    	this.model.bind("change", this.handleChange, this);
	    },
	    
	    render : function ()
	    {
	        //draw an options template here
	    	Backbone.log("boardView render");
	    	
	    	var self = this;
	    	
	    	var boardLayout = this.model.get("layout"); 
	    	
	        //draw boardset template
	    	var data = {
	    		title: this.model.get("name"),
	    		layout: this.model.get("layout")
	    		};
	    	
	    	var compiledTemplate = _.template( boardOptionsTemplate, data );
	        $(this.el).html( compiledTemplate );
	        
	        //find active layout for current board
	        var activeLayout = $(this.el).find("#change-layout-"+boardLayout);
	        
	        if(activeLayout) $(activeLayout).addClass("active-layout");
	        
	        //Draw widgets list
	        this.widgetSetView = new widgetSetView({model:this.page.widgetSet, page: this.page});
	        
	        $(this.el).find("#widgets-list")
	        	.empty()
	        	.append(self.widgetSetView.render().el);
	        
	        $(".panel-column").addClass("storyset-padding-min");
	        
	    	return this;
	    },
	    
	    destroy: function ()
	    {
	    	Backbone.log("boardView model destroy");
	    	
	    	var self = this;
	    	
	    	if (window.confirm('Are you sure ?'))
	        {
	            this.model.destroy({
	                success: function () {
	                	//TODO: must change this, it's a hack
	                	self.page.activeBoard = self.page.boards.models[0];

	                	self.page.render();
	                	
	                	Backbone.log("Object Destroyed");
	                }
	            });
	        }

	    },
	    
	    changeBoardLayout: function(event)
	    {
	    	Backbone.log("boardView changeBoardLayout");
	    	
	    	var self = this;
	    	
	    	var parts = $(event.target).attr("id").split("-");
	    	
	    	var layoutBtnID = parts[2];
	    	
	    	Backbone.log({layout: layoutBtnID});
	    	this.model.set({layout: layoutBtnID})
	    	this.model.save({},{success: function() {self.render()}});
	    },
	    
	    handleToggleOptions: function()
	    {
	    	Backbone.log("boardView handleToggleOptions triggered");
	    	
	    	//$(this.el).parent().slideToggle('fast');
	    	$(this.el).parent().toggle();
	    },
	    
	    handleChange: function()
	    {
	    	Backbone.log("boardView handleChange triggered");
	    	
	    	//get model's previous values
	    	var prevAttrs = this.model._previousAttributes;
	    	
	    	var self = this;
	    	
	    	//handle changed section name
	    	if(this.model.get("name") != prevAttrs['name'])
	    	{
	    		//bad: using global selector instead of using BoardItemview
	    		$("li#boarditem-"+this.model.get("id")).find('a').html(this.model.get("name"));
	    	}
	    	
	    	//handle changed layout
	    	if(this.model.get("layout") != prevAttrs['layout'])
	    	{
	    		var activeBoardID = this.page.activeBoard.get("id");
		    	
		    	var newLayout =  this.model.get("layout");
		    	
		    	var currentStorySets = this.page.storysets_views;
		    	
		    	if(currentStorySets[activeBoardID])
	    		{
		    		_.each(currentStorySets[activeBoardID], function (currentStorySetView,index) 
					{
		    			currentStorySetView.updateLayout(newLayout);	
					});
	    		}
	    	}
	    },
	    
	    keyupSectionTitle: function(e)
	    {
	    	Backbone.log("boardView keyupSectionTitle triggered");
	    	
	    	var newSectionTitle = $(this.el).find("#section-title").val();
	    	
	    	this.model.set({name: newSectionTitle});
	    },
	    
	    blurSectionTitle: function(e)
	    {
	    	Backbone.log("boardView blurSectionTitle triggered");
	    	
	    	//get model's previous values
	    	var prevAttrs = this.model._previousAttributes;
	    	
	    	//save it only if different from prev value
    		this.model.save();

    		//refresh curent boardItem
    		var activeBoardID = this.page.activeBoard.get("id");
    		
	    	this.page.boardSetView.boardsItemViews[activeBoardID].render();
	    }
	    
	})
	
  return boardView;
});


