// Filename: views/widgets/boarditem
define([
  'jquery',
  'underscore',
  'backbone',
], function($, _, Backbone){

	var boardItemView = Backbone.View.extend(
	{
	    tagName : "li",
	    
	    events:
	    {
	        "click span.board-option-item" : "make_active",
	        "click span.board-edit" : "handleBoardEdit"
	    },
	    
	    initialize : function (options)
	    {
	        Backbone.log("boardItemView initialize");
	        
	        this.page = options["page"];
	        
	        this.editBoxEnabled = false;
	        
	    	$(this.el).attr("id", "boarditem-" + this.model.get("id"));
	    },
	    
	    render : function ()
	    {
	    	Backbone.log("boardItemView render");
	    	
	    	var currentBoardId = this.model.get("id");
	    	
	        var boardItemHTML = $("<a/>",{ id: 'board-panel-'+currentBoardId, 'class': "board-option-item1", href: "javascript:void(0)", html: '<span class="board-option-item">'+this.model.get("name")+'</span>'});
	        
	        $(this.el).html(boardItemHTML);
	        
	        //if active make it editable
	       var activeBoardId = (this.page.activeBoard != null ? this.page.activeBoard.get('id') : currentBoardId);
	       
	       var boardOptionItem = $(boardItemHTML).find('span.board-option-item');
	        
	        if(currentBoardId == activeBoardId)
	        {
	        	var editBoxDataIcon = (this.editBoxEnabled ? "~" : "|"); 
	        	
	        	boardEditHtml = $("<span/>",{ 'data-icon': editBoxDataIcon, 'class': "board-edit icon grey", style: "cursor:pointer; display: inline-block;", html: '<span aria-hidden="true">'+editBoxDataIcon+'</span>'});
	        	
	        	//$(this.el).siblings().removeClass("current");
	        	$(this.el).addClass("current");
	        	
	        	$(boardItemHTML).append(boardEditHtml);
	        	
	        	boardOptionItem.css({"padding":"0 10px 0 0", "display":"inline-block"});
	        }
	        else
	        {
	        	boardOptionItem.css("padding","9px 15px");
	        }
	        
	        return this;
	    },
	    
	    make_active : function ()
	    {
	    	Backbone.log("boardItemView make_active");
	    	
	    	$(this.el).siblings().removeClass("active");
	        $(this.el).addClass("active");
	        
	        this.page.activeBoard = this.model;
	        
	        this.page.render();
	    },
	    
	    handleBoardEdit: function()
	    {
	    	Backbone.log("boardItemView handleBoardEdit triggered");
	    	
	    	this.editBoxEnabled = ($("#board-options").css("display") == "none" ? true : false);
	    	
	    	$(this.el).toggleClass('boardOptionsVisible');
	    	
	    	this.page.boardOptionsView.handleToggleOptions();
	    	
	    	this.render();
	    }
	})

  return boardItemView;
});