// Filename: views/widgets/boardset
define([
  'jquery',
  'underscore',
  'backbone',
  'collections/widgets/boardset',
  'models/widgets/board',
  'collections/widgets/storyset',
  'collections/widgets/widgetset',
  'views/widgets/board',
  'views/widgets/boarditem',
  'views/widgets/storyset',
  'text!templates/widgets/boardset.html',
], function($, _, Backbone, boardSet, boardModel, storySet, widgetSet, boardView, boardItemView, storySetView, boardSetTemplate){

  var boardSetView = Backbone.View.extend(
  {
	    el : $("#page"),
	    
	    events :
	    {
	        "click span#new_board_btn" : "new_board"
	    },
	    
	    initialize : function ()
	    {
	    	Backbone.log("BoardSetView initialize");
	    	
	    	var self = this;
	    	
	    	this.boards = new boardSet();
	    	
	    	this.widgetSet = new widgetSet();
	    	
	    	this.activeBoard = null;
	    	
	    	this.boardOptionsView = null;
	    	
	    	this.stories = {};
	    	
	    	this.storysets_views = {};
	    	
	    	this.boarditem_views = {};
	    	
	    	//in IE works only like this
	    	
	    	//set collection events
	    	//var currentModel = new this.boards.model();
	    	//currentModel.bind("all", this.eventAll, this);
	    	
	    	this.boards.bind("reset", this.eventReset, this);
	    	
	    	this.boards.bind("remove", this.eventRemove, this);
	    	
	        this.boards.fetch();
	    },
	    
	    render : function ()
	    {
	    	var self = this;
	    	
	    	Backbone.log("boardSetView render");
	    	
	        //Draw boardset template
	    	var data = {};
	        var compiledTemplate = _.template( boardSetTemplate, data );
	        $(this.el).html( boardSetTemplate );
	        
	        //draw sections list (tabs)
	        this.pushAllBoards();
	        
	        Backbone.log("this.activeBoard: "+this.activeBoard);
	        
	    	if(this.activeBoard)
	    	{
		    	//Populate current widgetSet collection (only if not populated)
	    		if(self.widgetSet.models.length == 0)
	    		{
	    			var availableWidgets = this.boards._meta.availableWidgets;
	    			_.each(availableWidgets, function(val, key) {self.widgetSet.add(val);});
	    		}
		    	
		    	//define active section
		    	var activeBoard = this.activeBoard;
		    	
		    	//get active section id
		    	var activeBoardID = this.activeBoard.get("id");
		    	
		    	var activeLayout = this.activeBoard.get("layout");
		    	
		    	Backbone.log("activeBoardID: "+activeBoardID)
		    	
		    	//get active section WidgetsData
		    	var sectionWidgets = this.activeBoard.get("sectionWidgets");
		    	
		    	//Populate stories collections  for current board (must be done here?)
		    	if(!this.stories[activeBoardID])
	    		{
			    	//create storySets
		    		this.storysets_views[activeBoardID] = {};
		    		this.stories[activeBoardID] = {};
			    	for(var i=1;i<=3;i++) this.stories[activeBoardID][i] = new storySet(); 
			    		
			    	_.each(sectionWidgets, function(storyData, widget_id) 
		    		{
			    		if(storyData.section_id == activeBoardID) self.stories[activeBoardID][storyData.column_id].add(storyData);
		    		});
	    		}			    	

	        	//Draw Widgets Columns
	        	var panelContainer = $(this.el).find("#panel-container"); 
	        	panelContainer.empty();
	        	
	        	_.each(this.stories[activeBoardID], function (currentStorySet,column_id) 
   	        	{
	        		//populate storysets_views
	        		var currentStorySetView = new storySetView({model: currentStorySet, column_id: column_id, section_id: activeBoardID});
	        		
	        		self.storysets_views[activeBoardID][column_id] = currentStorySetView; 
	        		
	        		currentStorySetView.updateLayout(activeLayout);
	        		
	        		panelContainer.append(currentStorySetView.render().el);
   	        	});
	        	
	        	
		        //Draw board options
	        	this.boardOptionsView = new boardView({model: activeBoard, boardSetView: this});
	        	$(this.el).find("#board-options")
	        		.empty()
		        	.prepend(this.boardOptionsView.render().el);
	        	
	    	}
	    	
	        return this;
	    },

	    new_board : function ()
	    {
	    	Backbone.log("boardModel save");
	    	
	    	var board_title = window.prompt("Title ?");
	        if (!board_title) return;
	        
	        var self = this;
	        
	        var board = new boardModel();
	        
	        board.save({"name": board_title},{success:function(boardItemModel){
	        	var totalBoards = self.boards.models.length;
	        	
	        	self.boards.add(boardItemModel);
	        	self.pushOneBoard(boardItemModel, self);
	        	
	        	//if first board make it active
	        	if(totalBoards == 0)
	        	{
	        		self.activeBoard = boardItemModel;
	        		self.render();
	        	}	
	        }});
	    },
	    
	    
	    pushOneBoard: function(boardItemModel, boardSetView)
	    {
	    	var currentBoardItemView = new boardItemView({model: boardItemModel, boardSetView: boardSetView});
    		
    		var boardId = boardItemModel.get("id");
    		
    		boardSetView.boarditem_views[boardId] = currentBoardItemView;
    		
    		$(boardSetView.el).find("ul#select-board").append(currentBoardItemView.render().el);
	    },

	    pushAllBoards: function()
	    {
	        //draw sections list (tabs)
	    	
	        //append new tab button
	        var addSectionTab = $("<li/>", {'class': "last", id: "new-board-btn",  html:"<span data-icon='+' title='Add New Board' id='new_board_btn' class='new_board icon green' style='display: inline-block;'><span aria-hidden='true'>+</span></span>"});
	        $(this.el).find("ul#select-board").empty().append(addSectionTab);
	        
	        var self = this;
	    	this.boards.each(function(model){self.pushOneBoard(model, self)});
	    },
	    
	    eventAll : function(event, model, options)
	    {
	    	Backbone.log("boardModel  fired event "+event);
	    	//Backbone.log(model);
	    },
	    
	    eventReset : function(model,options)
	    {
	    	Backbone.log("boardSet eventReset fired");
	    	
	    	//define active section
	    	if(this.boards.models.length > 0)
	    	{
	    		this.activeBoard = this.boards.models[0];	
	    	}	

	    	//render current page
	    	this.render();
	    },
	    
	    eventBoardChange : function(model, options)
	    {
	    	Backbone.log("boardSet eventBoardChange fired");

	    	//define active section
	    	//this.activeBoard = this.boards.models[0];

	    	//render current page
	    	this.render();
	    }
  });
  return boardSetView;
});