// Filename: views/widgets/page
define([
	'jquery',
	'underscore',
	'backbone',
	'collections/widgets/boardset',
	'models/widgets/page',
	'collections/widgets/storyset',
	'collections/widgets/widgetset',
	'views/widgets/boardset',
	'views/widgets/storyset',
	'views/widgets/board',
	'text!templates/widgets/page.html'
  ], function($, _, Backbone, boardSet, pageModel, storySet, widgetSet, boardSetView, storySetView, boardView, pageTemplate){

  var pageView = Backbone.View.extend(
  {
	    el : $("#page"),
	    
	    initialize : function ()
	    {
	    	Backbone.log("pageView initialize");
	    	
	    	Backbone.log("BoardSetView initialize");
	    	
	    	var self = this;
	    	
	    	this.model = new pageModel();
	    	
	    	this.boards = new boardSet();
	    	
	    	this.widgetSet = new widgetSet();
	    	
	    	this.activeBoard = null;
	    	
	    	this.boardSetView = null;
	    	
	    	this.boardOptionsView = null;
	    	
	    	this.stories = {};
	    	
	    	this.storysets_views = {};
	    	
	    	//handle events
	    	this.model.bind("change", this.render, this);
	    	
	    	this.boards.bind("reset", this.handleBoardsReset, this);
	    	
	        this.model.fetch();	    	
	    },
	    
	    render: function ()
	    {
	    	var self = this;
	    	
	    	Backbone.log("pageView render");
	    	
	    	if((this.model.has('sections')) && (this.model.has('allwidgets')))
	    	{
				var sectiondData = this.model.get('sections');
				var widgetsData = this.model.get('allwidgets');

				 //Populate boards models
				 _.each(sectiondData, function(val, key)
				{
					//Populate an array for each section
					 var sectionWidgets = [];
				  	_.each(widgetsData, function(storyData, wid){if(storyData.section_id == val.id) sectionWidgets.push(storyData);});
				  	
				  	sectiondData[val.id]['sectionWidgets'] = sectionWidgets;
				});
				 
		    	if(this.boards.models.length == 0)
				{//change this
		    		this.boards.add(_.toArray(sectiondData));
		    		if(this.boards.models.length > 0) this.activeBoard = this.boards.models[0];
				}				 
				 
		    	//Populate current widgetSet collection (only if not populated)
	    		if((this.widgetSet.models.length == 0) && (this.model.has("availablewidgets")))
	    		{
	    			this.widgetSet.add(_.toArray(this.model.get("availablewidgets")))
	    		}
	    		
		        //Draw page template
		        $(this.el).html( pageTemplate );
		        
		        //Render  sections list (tabs)
		        this.boardSetView = new boardSetView({model: this.boards, page: this});
		        this.boardSetView.render();
		        
		    	if(this.activeBoard)
		    	{
			    	//get active section id
			    	var activeBoardID = this.activeBoard.get("id");
			    	
			    	var activeLayout = this.activeBoard.get("layout");
			    	
			    	Backbone.log("activeBoardID: "+activeBoardID)
			    	
			    	//get active section WidgetsData
			    	var sectionWidgets = this.activeBoard.get("sectionWidgets");
			    	
			    	//Populate stories collections  for current board (must be done here?)
			    	if(!this.stories[activeBoardID])
		    		{
				    	//create storySets
			    		this.storysets_views[activeBoardID] = {};
			    		this.stories[activeBoardID] = {};
				    	for(var i=1;i<=3;i++) this.stories[activeBoardID][i] = new storySet(); 
				    		
				    	_.each(sectionWidgets, function(storyData, widget_id) 
			    		{
				    		if(storyData.section_id == activeBoardID) self.stories[activeBoardID][storyData.column_id].add(storyData);
			    		});
		    		}			    	

		        	//Draw Widgets Columns
		        	var panelContainer = $(this.el).find("#panel-container"); 
		        	panelContainer.empty();
		        	
		        	_.each(this.stories[activeBoardID], function (currentStorySet,column_id) 
	   	        	{
		        		//populate storysets_views
		        		var currentStorySetView = new storySetView({page: self, model: currentStorySet, column_id: column_id, section_id: activeBoardID});
		        		
		        		self.storysets_views[activeBoardID][column_id] = currentStorySetView; 
		        		
		        		currentStorySetView.updateLayout(activeLayout);
		        		
		        		panelContainer.append(currentStorySetView.render().el);
		        		
		        		currentStorySetView.triggerWidgetsLoad();
	   	        	});
		        	
			        //Draw board options
		        	this.boardOptionsView = new boardView({model: this.activeBoard, page: this});
		        	$(this.el).find("#board-options").empty().prepend(this.boardOptionsView.render().el);
		    	}		
	    	}	
	    	
	        return this;
	    },
	    
	    handleBoardsReset: function(model,options)
	    {
	    	Backbone.log("handleBoardsReset fired");
	    	
	    	//define active section
	    	if(this.boards.models.length > 0)
	    	{
	    		this.activeBoard = this.boards.models[0];	
	    	}	

	    	//render current page
	    	this.render();
	    },
	    
	    eventBoardChange : function(model, options)
	    {
	    	Backbone.log("boardSet eventBoardChange fired");

	    	//define active section
	    	//this.activeBoard = this.boards.models[0];

	    	//render current page
	    	this.render();
	    }	    

  });
  return pageView;
});