// Filename: views/widgets/story
define([
  'jquery',
  'underscore',
  'backbone',
  'text!templates/widgets/story.html'
], function($, _, Backbone, storyTemplate){

var storyView = Backbone.View.extend({
	tagName : "li",

	events :
    {
		'click a.remove' : 'removeWidget',
		'click ul.colors li': 'changeContainerColor',
		'mousedown a.collapse': 'preventDrag',
		'mousedown a.remove': 'preventDrag',
        'mousedown a.edit': 'preventDrag',
        'mousedown a.settings': 'preventDrag',
        'mousedown a.apps': 'preventDrag',
        'mousedown a.refresh': 'preventDrag',
        'mousedown a.share': 'preventDrag',
        'mousedown a.help': 'preventDrag',
        'mouseover div.widget-head': 'handleWidgetHeadMOver',
        'mouseout div.widget-head': 'handleWidgetHeadMOut',
        'click a.settings' : 'showWidgetSettings',
        'click a.refresh' : 'refreshWidget',
        'click a.share' : 'shareWidget'
		//'keyup input.widget-title-box': 'keyupWidgetTitle',
        //'blur input.widget-title-box': 'blurWidgetTitle'
    },
	  
	initialize: function(options)
	{
		Backbone.log("storyView initialize");
		
		$(this.el).addClass("widget-container color-"+this.model.get("background_color"));
		
		this.widgetContainerID = (this.model.has("id") ? "widget-id-"+this.model.get("id"): 'widget-id-temp');
		$(this.el).attr("id", this.widgetContainerID);
		$(this.el).attr("widgetitemid", this.widgetContainerID);

		//hook to storySetView
		this.storySetView = options['storySetView'];
		
		this.page = options['page'];
		
		this.iframeData = {};
		
		if(this.model.has("id"))
		{
			this.widgetIframeId = 'iframe-elem-'+this.model.get("id");
				
			this.widgetIframeBaseUrl = '../users/widget.php?wid='+this.model.get("id");
		}	
		
		//model binding 
		this.model.bind("change",this.handleChange,this);
	},
	  
    render: function()
    {
    	Backbone.log("storyView render");
    	
    	//get widgets settings form storySetView
    	var settings = this.storySetView.settings;
    	
    	var self = this;
    	
    	var iframeHTML = false;
    	
    	var isCollapsed = (this.model.get("collapsed") == "Y" ? true: false);
    	
        //attach model to element
        $(this.el).data("model",this.model);
        
        var data = {
            id : 1,
        	title : this.model.get("title"),
        	collapsed : this.model.get("collapsed"),
        	widget_favicon: this.model.get("widget_icon"),
        	position : this.model.get("position"),
        	dashboardFeatures : this.model.get("dashboard_features"),
        	apps : this.model.get("apps")
        };
        
        //handle widget iframe
        if(this.model.has("id"))
        {
        	var modelID = this.model.get("id");
        	data['id'] = modelID;
        	
        	var tpl_cache_time = this.model.get("tpl_cache_time");
        	
        	var iframe_src = this.widgetIframeBaseUrl+(tpl_cache_time !== false ? '&cache_time='+tpl_cache_time : '');
        	
            iframeHTML = $('<iframe/>',{src: iframe_src, frameborder: "0", id: this.widgetIframeId}).css({width: "100%", height: "0", 'overflow-y': 'auto'});
            
            iframeHTML.bind("load", function(){
            		
            	//handle current iframe
            	var iframe = this;
            	var iframe_id = $(iframe).attr("id");
        		var flag = false;
        		
        		$(self.el).find(".spinner").remove();
        		
        		//make iframe visible
        		$(iframe).css({height: '100%'});
        		
        		$(iframe).parent().css({height: $(iframe).contents().height()+'px'});
        		
        		//mark current iframe as loaded
        		self.setStoryContent({'loaded': true});
        		
        		//handle next iframes
        		self.storySetView.triggerWidgetsLoad();
        	});	
        }
        
        this.setStoryContent({'iframe_id' : this.widgetIframeId, 'widget-container-id': this.widgetContainerID, 'loaded': false, 'isCollapsed': isCollapsed, 'iframeHTML': iframeHTML});
        
        //show template
    	var compiledTemplate = _.template( storyTemplate, data );
        $(this.el).html( compiledTemplate );
        
        //enable selection on input boxes
        $(this.el).find("li.item")
        	.bind('mousedown.ui-disableSelection', function(e) {e.stopImmediatePropagation();});
        
        //set widget container height
        //$(this.el).find('.widget-content').css({height: data.dashboardFeatures.height+'px'});
        $(this.el).find('.widget-content').css({height: '75px'});
        
        //handle Widget Collapse Button (now?)
        var collapseBtn = $(this.el).find('a.collapse');
        
		var handleBtnShow = function(){self.handleCollapseShow(self);}
		var handleBtnHide = function(){self.handleCollapseHide(self);}
		
		if(isCollapsed)
        {
			$(this.el).find(settings.contentSelector).css({height:'0px'});
			
			collapseBtn.attr('title',"Show widget");
			
			$(collapseBtn).addClass("collapse-activated").toggle(handleBtnShow,handleBtnHide);
        }
        else
        {
        	collapseBtn.attr('title',"Collapse widget");
        	$(collapseBtn).toggle(handleBtnHide,handleBtnShow);
        }
		
		//handle Widget Edit
		var editBtn = $(this.el).find('a.edit');
		$(editBtn).toggle(function(){self.handleEditShow(self);},function(){self.handleEditHide(self);});
		
		//handler widget apps
		var appsBtn = $(this.el).find('a.apps');
		$(appsBtn).toggle(function(){self.handleAppsShow(self);},function(){self.handleAppsHide(self);});
		
		//handle widget help
		var helpBtn = $(this.el).find('a.help');
		$(helpBtn).toggle(function(){self.handleHelpShow(self);},function(){self.handleHelpHide(self);});
		
		if ($(window).width()<=1024)
		{
			self.handleWidgetHeadMOver();
		}

    	return this;
    },
    
    removeWidget: function()
    {
    	var self = this;
    	
    	if (window.confirm('Are you sure you want to delete the '+this.model.get('title')+' widget?'))
        {
        	//remove view from storysetviews
    		var storyID = this.model.get("id");
    		if(this.storySetView.story_views[storyID])
    		{
    			delete this.storySetView.story_views[storyID];
    		}	
    		
    		//remove story model
    		this.model.destroy();
    		
    		//remove story view
        	this.remove();
        	this.render();
        }
    },
    
    changeContainerColor: function(e)
    {
    	var colorBtn = e.target;
    	var self = this;
    	
    	//search for existing background colors
    	var colorStylePattern = /\bcolor-[\w]{1,}\b/,
    	newColorClass = $(colorBtn).attr('class').match(colorStylePattern)[0];
    	parts = newColorClass.split("-");
    	
    	this.model.set({background_color: parts[1]});
    	this.model.save();
    	
	    return false;
    },
    
    mousedown: function()
    {
    	var settings = this.storySetView.settings;
    	
    	var sortableItems = this.storySetView.sortableItems;
    	
    	var handleSelector = $(this.el).find(settings.handleSelector);
    	
       sortableItems.css({width:''});
       
       $(handleSelector).parent().css({
            width: $(handleSelector).parent().width() + 'px'
        });
    },
    
    mouseup: function()
    {
    	var settings = this.storySetView.settings;
    	
    	var handleSelector = $(this.el).find(settings.handleSelector); 
    	
    	if(!$(handleSelector).parent().hasClass('dragging'))
        {
    		$(handleSelector).parent().css({width:''});
        } 
        else
        {
            $(settings.columns).sortable('disable');
        }
    },
    
    preventDrag: function(e) {e.stopPropagation()},
    
    showWidgetSettings: function()
    {
    	$(this.el).find('#'+this.widgetIframeId).attr('src', this.widgetIframeBaseUrl+'&view=settings');
    },
    
    refreshWidget: function()
    {
    	var widgetIframe = $(this.el).find('#'+this.widgetIframeId);
    	
    	widgetIframe.css({height: '0px'});
    	widgetIframe.attr('src', this.widgetIframeBaseUrl+'&cache_time=0');
    	
    	$(this.el).find('.widget-content').prepend($('<div/>',{'class': 'spinner', 'id': 'loading'}));
    },
    
    shareWidget: function()
    {
    	$(this.el).find('#'+this.widgetIframeId).attr('src', this.widgetIframeBaseUrl+'&view=share');
    },
    
    handleEditShow: function(currentView)
    {
    	var editBtn = $(currentView.el).find('a.edit');
    	var editBox = $(currentView.el).find('div.edit-box');
    	
    	$(editBtn).addClass("edit-activated");
        $(editBox).show();
        //$(editBox).find('input').focus();
        
    	return false;
    },
    
    handleEditHide: function(currentView)
    {
    	var editBtn = $(currentView.el).find('a.edit');
    	var editBox = $(currentView.el).find('div.edit-box');;
    	
    	$(editBtn).removeClass("edit-activated");
        $(editBox).hide();
        
        return false;
    },
    
    handleAppsShow: function(currentView)
    {
    	var appsBtn = $(currentView.el).find('a.apps');
    	var appsBox = $(currentView.el).find('div.apps-box');;
    	
    	$(appsBtn).addClass("apps-activated");
        $(appsBox).show();
        
    	return false;
    },
    
    handleAppsHide: function(currentView)
    {
    	var appsBtn = $(currentView.el).find('a.apps');
    	var appsBox = $(currentView.el).find('div.apps-box');;
    	
    	$(appsBtn).removeClass("apps-activated");
        $(appsBox).hide();
        
        return false;
    },
    
    handleHelpShow: function(currentView)
    {
    	var appsBtn = $(currentView.el).find('a.help');
    	var appsBox = $(currentView.el).find('div.help-box');;
    	
    	$(appsBtn).addClass("help-activated");
        $(appsBox).show();
        
    	return false;
    },
    
    handleHelpHide: function(currentView)
    {
    	var helpBtn = $(currentView.el).find('a.help');
    	var helpBox = $(currentView.el).find('div.help-box');;
    	
    	$(helpBtn).removeClass("help-activated");
        $(helpBox).hide();
        
        return false;
    },
    
    handleCollapseShow: function(currentView)
    {
    	//save data for current widget
    	
    	$(currentView.el).find("a.collapse").attr('title',"Collapse widget");
    	
    	var currentWidget = currentView.model;
    	currentWidget.set({collapsed: ""});
    	currentWidget.save();
    	
    	var self = this;
    	
    	//activate widget's iframe
    	self.setStoryContent({'isCollapsed': false});
    	
		self.storySetView.triggerWidgetsLoad();
    },
    
    handleCollapseHide : function(currentView)
    {
    	$(currentView.el).find("a.collapse").attr('title',"Show widget");
    	
    	//save data for current widget
    	var currentWidget = currentView.model;
    	currentWidget.set({collapsed: "Y"});
    	currentWidget.save();
    },
    
    blurWidgetTitle: function(e)
    {
    	Backbone.log("blurWidgetTitle fired");
    },
    
    keyupWidgetTitle: function(e)
    {
    	//Backbone.log("keyupWidgetTitle triggered");
    	var titleBoxValue = $(e.target).val();
    	this.model.set({title: titleBoxValue});
    },
    
    handleRemove: function()
    {
    	Backbone.log("Object Destroyed");
    },
    
    handleChange: function()
    {
    	//Backbone.log("handleChange triggered");
    	
    	//get model's previous values
    	var prevAttrs = this.model._previousAttributes;
    	
    	//get widgets settings form storySetView
    	var settings = this.storySetView.settings;
    	
    	//handle changed title
    	if(this.model.get("title") != prevAttrs['title'])
    	{
        	$(this.el).find("span#widget-title").html(this.model.get("title"));
    	}
    	
    	//change container colors
    	if(this.model.get("background_color") != prevAttrs['background_color'])
		{
        	var colorStylePattern = /\bcolor-[\w]{1,}\b/,
        	thisWidgetColorClass = $(this.el).attr('class').match(colorStylePattern);
        	
        	if (thisWidgetColorClass)
    	    	{
        		$(this.el)
    	            .removeClass(thisWidgetColorClass[0])
    	            .addClass("color-"+this.model.get("background_color"));
    	    	}
		}

    	if(this.model.get("collapsed") != prevAttrs['collapsed'])
		{
        	//handle collapsed Show HTML event
        	var collapseBtn = $(this.el).find('a.collapse')[0];
    		
        	var isCollapsed = (this.model.get("collapsed") == "Y" ? true: false);
        	
        	if(isCollapsed)
        	{
        		$(collapseBtn).addClass("collapse-activated")
                .parents(settings.widgetSelector).find(settings.contentSelector).hide();
        	}
        	else
        	{
        		$(collapseBtn).removeClass("collapse-activated")
                .parents(settings.widgetSelector)
                	.find(settings.contentSelector)
                		.css({"height": this.model.get("dashboard_features").height+'px'})
                		.show();
        	}
		}
    },
    
    handleWidgetHeadMOver: function()
    {
    	$(this.el).find("span.collapsable-container").addClass("widget-head-show").removeClass("widget-head-hide");
    	$(this.el).find("span.favicon-container").addClass("widget-head-hide").removeClass("widget-head-show");
    	$(this.el).find("span.bar-options-container").addClass("widget-head-show").removeClass("widget-head-hide");
    },
    
    handleWidgetHeadMOut: function()
    {
    	$(this.el).find("span.collapsable-container").addClass("widget-head-hide").removeClass("widget-head-show");
    	$(this.el).find("span.favicon-container").addClass("widget-head-show").removeClass("widget-head-hide");
    	$(this.el).find("span.bar-options-container").addClass("widget-head-hide").removeClass("widget-head-show");
    },
    
    setStoryContent: function(iframeData)
    {
    	for(var i in iframeData)
    	{
    		this.iframeData[i] = iframeData[i];	
    	}	
    },
    
    getStoryContent: function()
    {
    	return this.iframeData;
    }    
  });

  return storyView;
});
