// Filename: views/home/main
define([
  'jquery',
  'underscore',
  'backbone',
  'models/widgets/story',
  'views/widgets/story'
], function($, _, Backbone, storyModel, storyView){
	
  var storySetView = Backbone.View.extend({
	tagName : "ul",
	
	initialize: function(options)
	{
		Backbone.log("storySetView initialize");
		
		this.page = options['page'];
		
		this.column_id = options['column_id'];
		
		this.section_id = options['section_id'];
		
		$(this.el).addClass("panel-column col_4");
		$(this.el).attr("id","panel-column-"+this.column_id);

		//this.model.bind("reset", this.render, this);
        //this.model.bind("add", this.render, this);
        
        var self = this;
        
        this.story_views = {};
        
        var settings = {
        	columns : '.panel-column',
            widgetSelector: '.widget-container',
            handleSelector: '.widget-head',
            contentSelector: '.widget-content',
            widgetPlaceholder: 'widget-placeholder',
            colorClasses : ['color-yellow', 'color-red', 'color-blue', 'color-white', 'color-orange', 'color-green'],
            iframeFix: true
        };
        
        this.settings = settings;
        
        this.sortableItems =  $('> li', settings.columns);
        
        $(this.el).sortable({
        	//items: "div:not(.not-sortable)",//this.sortableItems
            connectWith: settings.columns,
            handle: settings.handleSelector,
            placeholder: settings.widgetPlaceholder,
            forcePlaceholderSize: true,
            containment: 'document',
            revert: "invert",//300
            opacity: 0.8,
            tolerance: 'pointer',
            //delay: 100,
            distance: 10,
            start: function(event,ui) {self.handleStorySetStart(event, ui, this)},
            stop: function(event,ui) {self.handleStorySetStop(event, ui, this)},
            receive: function(event,ui) {self.handleStorySetReceive(event, ui, this)},
            remove: function(event,ui) {self.handleStorySetRemove(event, ui, this)},
            //change: function(event,ui) {self.handleStorySetChange(event, ui, this)},
            //update: function(event,ui) {self.handleStorySetUpdate(event, ui, this)},
            over: function(event,ui) {self.handleStorySetOver(event, ui, this)}
        }).disableSelection();
	},
	
    render: function()
    {
    	Backbone.log("storySetView render");
    	
    	var self = this;
    	
    	$(this.el).empty();
        _.each(this.model.models, function (story)
        	{
        		var currentStoryView = new storyView({model:story, storySetView: self, page: self.page});
        		self.story_views[story.get("id")] = currentStoryView;
        	
        		$(self.el).append(currentStoryView.render().el);
        	});
        
        
        return this;
    },
    
    handleStorySetStart : function (event, ui, el)
    {
    	//Backbone.log("handleStorySetStart trigerred");
    	
    	//activate iframeFix
    	$(".widget-placeholder").height($(ui.item[0]).height()-10);
    	$(".widget-content").each(function() {

    		var iframeOverlay = $('<div class="ui-draggable-iframeFix" style="background: #fff;"></div>')
			.css({
				width: this.offsetWidth+"px", height: this.offsetHeight+"px",
				position: "absolute", opacity: 0.001, zIndex: 1000, top: 0, left: 0
			})
    		
			$(this).append(iframeOverlay);
		});

    	//add padding to drop-zones (for locking)
    	$(".panel-column").removeClass("storyset-padding-min");
    },
    
    handleStorySetChange: function (event, ui, el)
    {
    	Backbone.log("handleStorySetChange trigerred");
    },
    
    handleStorySetUpdate: function (event, ui, el)
    {
    	Backbone.log("handleStorySetUpdate trigerred");
    },
    
    handleStorySetStop : function (event, ui, el) 
    {
    	//Backbone.log("handleStorySetStop trigerred");
    	
    	//remove iframeFix
		$("div.ui-draggable-iframeFix").each(function() {this.parentNode.removeChild(this);}); 
		
		//remove padding from drop-zones
		$(".panel-column").addClass("storyset-padding-min");
		
    	var currentStorySet = this.model;
    	var self = this;
    	var currentWidgetModel = $(ui.item).data("model");
    	
    	/*
    	var currentWidgetIdParts = $(ui.item).attr("id").split("-");
    	var wid = currentWidgetIdParts[2];
    	*/
    	
        //Ordering items 
        var i = 1;
        $(el).find("li.widget-container").each(function ()
        {
            var model = $(this).data("model");
            var new_position = i++;
            model.set({"position" : new_position});
        });
        
        
        if(currentWidgetModel)
    	{
        	var hasMoved = currentWidgetModel.get("moved");
        	if(!hasMoved) currentWidgetModel.save();
        	currentWidgetModel.attributes.moved = false;
    	}

        //sort current storySet
        currentStorySet.sort();
    },
    
    handleStorySetReceive: function(event, ui, el)
    {
    	//Backbone.log("handleStorySetReceive triggered");
    	
    	var self = this;
    	
    	var currentStorySet = this.model;
    	
    	var currentWidgetModel = $(ui.item).data("model");
    	
    	var columnIDParts = $(el).attr("id").split("-");
    	var new_column_id = columnIDParts[2];
    	
    	var currentWidgetId = $(ui.item).attr("widgetitemid");
    	var currentWidgetIdParts = currentWidgetId.split("-");
    	
    	var isNewStory = false;
    	
    	//check if is new item or draggable
    	if(currentWidgetIdParts[0] == 'widgetitem')
		{
    		var currentSectionID = this.section_id;

    		var story = new storyModel({
					main_widget_id: currentWidgetModel.get("main_widget_id"), 
					section_id: currentSectionID, 
					column_id: new_column_id, 
					title: currentWidgetModel.get("title"),
					position: 1,
					collapsed: "",
					background_color: 'white',
					dashboard_features: currentWidgetModel.get("dashboard_features"),
					apps: currentWidgetModel.get("apps")
					});
    		
			currentWidgetModel = story;
			$(ui.item).data("model",currentWidgetModel);
			
			isNewStory = true;
		}
    	
    	if(currentWidgetModel)
		{
    		currentWidgetModel.set({column_id: new_column_id});
        	
        	currentStorySet.add(currentWidgetModel);
        	
            //Ordering items 
            var i = 1;
            $(el).find("li.widget-container").each(function ()
            {
                var model = $(this).data("model");
                model.set({"position" : i++});
            });

            if(isNewStory)
            {
            	$(self.el).find(".widgetset-item").replaceWith(new storyView({model:currentWidgetModel, storySetView: self}).render().el);	
            }
            
            currentWidgetModel.attributes.moved = "Y";
            $(ui.item).data("model",currentWidgetModel);
            
            currentWidgetModel.save({},{success: function(new_story)
            	{
		  	      	if(isNewStory)
		  	      	{
		            	//render the current story
			 	 	    var currentStoryView = new storyView({model:new_story, storySetView: self});
			 	 	    self.story_views[new_story.get("id")] = currentStoryView;
			 	 	    
			 	 	    $(self.el).find("#widget-id-temp").replaceWith(currentStoryView.render().el);
			 	 	    self.triggerWidgetsLoad();
		  	      	}
		  	      	
		  	      $(ui.item).data("model",new_story);	
		  	      
	 	 	      currentStorySet.sort();
            	}	
            });
		}
   },
   
   createNewWidget: function(options)
   {
       var self = this;
       
	   var story = new storyModel();
	   
       story.save(options,
       	{
   			success: function(new_story)
       		{
       			Backbone.log("Current Widget saved");
       			
       			activeBoardID = self.page.activeBoard.get("id");
       			
       			//add new widget to the first column
       			self.page.stories[activeBoardID][new_story.get("column_id")].add(new_story);
       			
       			//and render the current storyset
       			var currentStoryView = new storyView({model:new_story, storySetView: self});
       			self.story_views[new_story.get("id")] = currentStoryView;
       	        
       			$(self.el).append(currentStoryView.render().el);
       	       
       			self.triggerWidgetsLoad();
       	       
       			//attach model to html element
       			$(currentStoryView.el).data("model",new_story);
       		}
       	});		
   },
   
    handleStorySetRemove: function(event, ui, el)
    {
    	//Backbone.log("handleStorySetRemove triggered");
    	
    	var currentStorySet = this.model;
    	var currentWidgetModel = $(ui.item).data("model");
    	
    	currentStorySet.remove(currentWidgetModel);

        //Ordering items
        var i = 1;
        $(el).find("li.widget-container").each(function ()
        {
            var model = $(this).data("model");
            if(model) model.set({"position" : i++});
        });
        
       //sort current storySet
        currentStorySet.sort();
   },
   
   
   handleStorySetOver: function(event, ui, el)
   {
	   //Backbone.log("handleStorySetOver trigerred");
	   
	   //calculate widget container width
	   var currentPanelContainer = $(el);
	   var currentWidgetContainer = $(ui.item);
	   
	   var totalValue = 0; 
	   var sides = ["margin-left","margin-right","padding-left","padding-right"];
	   _.each(sides, function (side){totalValue += parseInt(currentWidgetContainer.css(side).replace("px",""));});
	   currentWidgetContainer.width(currentPanelContainer.width()-totalValue);
   },
   
    updateLayout : function (newLayout)
    {
		Backbone.log("updateLayout trigerred");
		
		var layoutClasses = {
				1 : ['col_12','col_6','col_6'], 	
				2 : ['col_4','col_4','col_4'],
				3 : ['col_6','col_6','col_12']
				};

		var index = (this.column_id-1);

		var currentStorySetViewHTML = $(this.el);
		
    	var panelWidthPattern = /\bcol_[\w]{1,}\b/,
    	thisPanelWidthClass = $(currentStorySetViewHTML).attr('class').match(panelWidthPattern);
    	
    	$(currentStorySetViewHTML)
    		.removeClass(thisPanelWidthClass[0])
			.addClass(layoutClasses[newLayout][index]);
    },
   
    triggerWidgetsLoad: function()
    {
    	//Backbone.log("triggerWidgetsLoad triggered");
    	var self = this;
    	var flag = false;

    	//Render next first iframe

		_.each(this.story_views, function(storyView, index)
		{
			if(!flag)
			{
				var tmpData = storyView.getStoryContent();

				if((!tmpData['loaded']) && (!tmpData['isCollapsed']))
				{
					$("#"+tmpData['widget-container-id']).find('.widget-content').append(tmpData['iframeHTML']);
					flag = true;
				}	
			}	
		});
    }
  });
  return storySetView;
});
