// Filename: views/widgets/widgetitem
define([
  'jquery',
  'underscore',
  'backbone',
  'models/widgets/story',
  'views/widgets/story',
  'text!templates/widgets/widgetitem.html'
], function($, _, Backbone, storyModel, storyView, widgetItemTemplate){

	var widgetItemView = Backbone.View.extend(
	{
	    tagName : "li",
	    
	    events :
	    {
	         'click #add-widget' : 'new_widget',
	         'mousedown' : 'handleDropZones'
	    },
	    
	    initialize : function (options)
	    {
	        Backbone.log("widgetItemView initialize");
	        
	        //hook to page
			this.page = options['page'];
			
			var self = this;
	        
	    	$(this.el).attr("id", "widgetitem-" + this.model.get("main_widget_id"));
	    	$(this.el).addClass("widgetset-item");
	    	$(this.el).attr("widgetitemid", "widgetitem-" + this.model.get("main_widget_id"));
	    	
			$(this.el).draggable({
				connectToSortable: '.panel-column',
				placeholder: 'widget-placeholder',
	            forcePlaceholderSize: true,
	            helper: "clone",
	            revert: false,
	            distance: 20,
	            opacity: 0.8,
	            containment: "document",
                start: function(event,ui) {self.handleWidgetItemStart(event, ui, this)},
                stop: function(event,ui) {self.handleWidgetItemStop(event, ui, this)}
			}).disableSelection();
	    	
	    	//attach model to htmlview
	    	$(this.el).data("model", this.model);
	    },
	    
	    render : function ()
	    {
	    	Backbone.log("widgetItemView render");
	    	
	    	var data = {
	    		title: this.model.get("title"),
	    		widget_icon_manager: this.model.get("widget_icon_manager"),
	        	dashboardFeatures : this.model.get("dashboard_features"),
	        	apps : this.model.get("apps")
	    		};
	    	
	        var compiledTemplate = _.template( widgetItemTemplate, data );
	        $(this.el).html(compiledTemplate);
	        
	        return this;
	    },
	    
	    new_widget: function()
	    {
	    	Backbone.log("new_widget executed");
	    	
	    	var main_widget_id = this.model.get("main_widget_id");
	    	
	    	var activeBoardID = this.page.activeBoard.get("id");
	    	
	    	//get first storysetview
	    	var addToSection=0;
	    	var sectionHeight=0;
	    	
	    	for (var i in this.page.storysets_views[activeBoardID])
	    	{
	    		var currentSectionHeight=0;
	    		
	    		for (var j in this.page.storysets_views[activeBoardID][i].story_views)
	    		{
	    			currentSectionHeight+=$('#widget-id-'+j).height();
	    		}
	    		
	    		if (addToSection == 0)
	    		{
	    			addToSection=i;
	    			sectionHeight=currentSectionHeight;
	    		}
	    		else if (currentSectionHeight < sectionHeight)
	    		{
	    			addToSection=i;
	    			sectionHeight=currentSectionHeight;
	    		}
	    	}

	    	var storySetView = this.page.storysets_views[activeBoardID][addToSection];
	    	
	    	storySetView.createNewWidget({"main_widget_id": main_widget_id, "section_id": activeBoardID, "column_id": addToSection});
	    },
	    
	    handleWidgetItemStart: function(event, ui, el)
	    {
	    	//activate iframeFix
	    	$(".widget-content").each(function() {

	    		var iframeOverlay = $('<div class="ui-draggable-iframeFix" style="background: #fff;"></div>')
				.css({
					width: this.offsetWidth+"px", height: this.offsetHeight+"px",
					position: "relative", opacity: 0.001, zIndex: 1000, 'margin-top': '-150px'
				})
	    		
				$(this).append(iframeOverlay);
			});
	    	
	    	//add padding to drop-zones (for locking)
	    	$(".panel-column").removeClass("storyset-padding-min");
	    },
	    
	    handleWidgetItemStop: function(event, ui, el)
	    {
	    	//remove iframeFix
			$("div.ui-draggable-iframeFix").each(function() {this.parentNode.removeChild(this);});
			
			//remove padding from drop-zones
			$(".panel-column").addClass("storyset-padding-min");
	    },
	    
	    create_new_widget: function()
	    {
	    	Backbone.log("create_new_widget executed");
	    	
	    	var main_widget_id = this.model.get("main_widget_id");
	    	
	        var story = new storyModel({main_widget_id: main_widget_id});
	    	
	        return story;
	    },
	    
	    handleDropZones: function()
	    {
	    	Backbone.log("handleDropZones trigerred");

	    	//add padding to drop-zones (for locking)
	    	$(".panel-column").removeClass("storyset-padding-min");
	    }
	})

  return widgetItemView;
});