
var
// asynchronous tracker (or proxy)
_osaq = _osaq || [],

// OpenS singleton and namespace
osTracker =    osTracker || (function () {
    "use strict";

    var expireDateTime,

    /* plugins */
    plugins = {},

    /* alias frequently used globals for added minification */
    documentAlias = document,
    navigatorAlias = navigator,
    screenAlias = screen,
    windowAlias = window,
    bodyAlias = document.getElementsByTagName('body').item(0) || false,

    /* DOM Ready */
    hasLoaded = false,
    
    loadHandlerEvent = null,
    
    registeredOnLoadHandlers = [],
    
    registeredPluginsEvents = [],

    /* encode */
    encodeWrapper = windowAlias.encodeURIComponent,

    /* decode */
    decodeWrapper = windowAlias.decodeURIComponent,

    /* urldecode */
    urldecode = unescape,

    /* asynchronous tracker */
    asyncTracker,

    /* iterator */
    i;

    
    /************************************************************
     * Private methods
     ************************************************************/

    /*
     * Is property defined?
     */
    function isDefined(property) {
        // workaround https://github.com/douglascrockford/JSLint/commit/24f63ada2f9d7ad65afc90e6d949f631935c2480
        return 'undefined' !== typeof property;
    }
    
    function isNull(property){
    	return property == null;
    }
    
    function ObjectCount(obj) {
        var size = 0, key;
        for (key in obj) {
            if (obj.hasOwnProperty(key)) size++;
        }
        return size;
    };

    /*
     * Is property a function?
     */
    function isFunction(property) {
        return typeof property === 'function';
    }

    /*
     * Is property an object?
     *
     * @return bool Returns true if property is null, an Object, or subclass of Object (i.e., an instanceof String, Date, etc.)
     */
    function isObject(property) {
        return typeof property === 'object';
    }

    /*
     * Is property a string?
     */
    function isString(property) {
        return typeof property === 'string' || property instanceof String;
    }

    /*
     * apply wrapper
     *
     * @param array parameterArray An array comprising either:
     *      [ 'methodName', optional_parameters ]
     * or:
     *      [ functionObject, optional_parameters ]
     */
    function apply() {
        var i, f, parameterArray;

        for (i = 0; i < arguments.length; i += 1) {
            parameterArray = arguments[i];
            f = parameterArray.shift();

            if (isString(f)) {
                asyncTracker[f].apply(asyncTracker, parameterArray);
            } else {
                f.apply(asyncTracker, parameterArray);
            }
        }
    }

    /*
     * Cross-browser helper function to add event handler
     */
    function addEventListener(element, eventType, eventHandler, useCapture) {
        if (element.addEventListener) {
        	element.addEventListener(eventType, eventHandler, useCapture);
            return true;
        }

        if (element.attachEvent) {
        	return element.attachEvent('on' + eventType, eventHandler);
        }

        element['on' + eventType] = eventHandler;
    }

    /*
     * Call plugin hook methods
     */
    function executePluginMethod(methodName, callback) {
        var result = '',
            i,
            pluginMethod;
        
        for (i in plugins) {
            if (Object.prototype.hasOwnProperty.call(plugins, i)) {
            	pluginMethod = plugins[i][methodName];
                if (isFunction(pluginMethod)) {
                    result += pluginMethod(callback);
                }
            }
        }

        return result;
    }

    
    /*
     * Handle beforeunload event
     *
     * Subject to Safari's "Runaway JavaScript Timer" and
     * Chrome V8 extension that terminates JS that exhibits
     * "slow unload", i.e., calling getTime() > 1000 times
     */
    function beforeUnloadHandler() {
        var now;

        executePluginMethod('unload');

        /*
         * Delay/pause (blocks UI)
         */
        if (expireDateTime) {
            // the things we do for backwards compatibility...
            // in ECMA-262 5th ed., we could simply use:
            //     while (Date.now() < expireDateTime) { }
            do {
                now = new Date();
            } while (now.getTimeAlias() < expireDateTime);
        }
    }

    /*
     * Handler for onload event
     */
    function loadHandler(evt) {
        var i;

        if (!hasLoaded) {
            hasLoaded = true;
            executePluginMethod('load');
            
            if(console) console.log("loadHandler triggered");
            
            loadHandlerEvent = evt;
            
            for (i = 0; i < registeredOnLoadHandlers.length; i++) {
                registeredOnLoadHandlers[i]();
            }
        }
        return true;
    }

    /*
     * Add onload or DOM ready handler
     */
    function addReadyListener() {
        var _timer;

        if(console) console.log("addReadyListener triggered");
        
        if (documentAlias.addEventListener) {
            addEventListener(documentAlias, 'DOMContentLoaded', function ready(evt) {
                documentAlias.removeEventListener('DOMContentLoaded', ready, false);
                loadHandler(evt);
            });
        } else if (documentAlias.attachEvent) {
            documentAlias.attachEvent('onreadystatechange', function ready(evt) {
                if (documentAlias.readyState === 'complete') {
                    documentAlias.detachEvent('onreadystatechange', ready);
                    loadHandler(evt);
                }
            });

            if (documentAlias.documentElement.doScroll && windowAlias === windowAlias.top) {
                (function ready(evt) {
                    if (!hasLoaded) {
                        try {
                            documentAlias.documentElement.doScroll('left');
                        } catch (error) {
                            setTimeout(ready, 0);
                            return;
                        }
                        loadHandler(evt);
                    }
                }());
            }
        }

        // sniff for older WebKit versions
        if ((new RegExp('WebKit')).test(navigatorAlias.userAgent)) {
            _timer = setInterval(function (evt) {
                if (hasLoaded || /loaded|complete/.test(documentAlias.readyState)) {
                    clearInterval(_timer);
                    loadHandler(evt);
                }
            }, 10);
        }

        // fallback
        addEventListener(windowAlias, 'load', loadHandler, false);
    }

    /*
     * Get page referrer
     */
    function getReferrer() {
        var referrer = '';

        try {
            referrer = windowAlias.top.document.referrer;
        } catch (e) {
            if (windowAlias.parent) {
                try {
                    referrer = windowAlias.parent.document.referrer;
                } catch (e2) {
                    referrer = '';
                }
            }
        }
        if (referrer === '') {
            referrer = documentAlias.referrer;
        }
        
        return referrer;
    }

    /*
     * Extract scheme/protocol from URL
     */
    function getProtocolScheme(url) {
        var e = new RegExp('^([a-z]+):'),
            matches = e.exec(url);

        return matches ? matches[1] : null;
    }

    /*
     * Extract hostname from URL
     */
    function getHostName(url) {
        // scheme : // [username [: password] @] hostame [: port] [/ [path] [? query] [# fragment]]
        var e = new RegExp('^(?:(?:https?|ftp):)/*(?:[^@]+@)?([^:/#]+)'),
            matches = e.exec(url);

        return matches ? matches[1] : url;
    }

    /*
     * Extract parameter from URL
     */
    function getParameter(url, name) {
        // scheme : // [username [: password] @] hostame [: port] [/ [path] [? query] [# fragment]]
        var e = new RegExp('^(?:https?|ftp)(?::/*(?:[^?]+)[?])([^#]+)'),
            matches = e.exec(url),
            f = new RegExp('(?:^|&)' + name + '=([^&]*)'),
            result = matches ? f.exec(matches[1]) : 0;

        return result ? decodeWrapper(result[1]) : '';
    }

    /*
     * UTF-8 encoding
     */
    function utf8_encode(argString) {
        return urldecode(encodeWrapper(argString));
    }

    /*
     * Fix-up URL when page rendered from search engine cache or translated page
     */
    function urlFixup(hostName, href, referrer) {
        if (hostName === 'translate.googleusercontent.com') {        // Google
            if (referrer === '') {
                referrer = href;
            }
            href = getParameter(href, 'u');
            hostName = getHostName(href);
        } else if (hostName === 'cc.bingj.com' ||                    // Bing
                hostName === 'webcache.googleusercontent.com' ||    // Google
                hostName.slice(0, 5) === '74.6.') {                    // Yahoo (via Inktomi 74.6.0.0/16)
            href = documentAlias.links[0].href;
            hostName = getHostName(href);
        }

        return [hostName, href, referrer];
    }

    /*
     * Fix-up domain
     */
    function domainFixup(domain) {
        var dl = domain.length;

        // remove trailing '.'
        if (domain.charAt(--dl) === '.') {
            domain = domain.slice(0, dl);
        }

        // remove leading '*'
        if (domain.slice(0, 2) === '*.') {
            domain = domain.slice(1);
        }

        return domain;
    }

    /*
     * Title fixup
     */
    function titleFixup(title) {
        if (!isString(title)) {
            title = title.text || '';

            var tmp = documentAlias.getElementsByTagName('title');

            if (tmp && isDefined(tmp[0])) {
                title = tmp[0].text;
            }
        }
        return title;
    }
    
    

    /*
     * OpenS Tracker class
     *
     * trackerUrl and trackerProjectAccount are optional arguments to the constructor
     *
     * See: Tracker.setTrackerUrl() and Tracker.setAccount()
     */
    function Tracker(trackerUrl, siteId) {

        /************************************************************
         * Private members
         ************************************************************/

        var
/*<DEBUG>*/
            /*
             * registered test hooks
             */
            registeredHooks = {},
            
            jsDebug = false,
/*</DEBUG>*/

            // Current URL and Referrer URL
            locationArray = urlFixup(documentAlias.domain, windowAlias.location.href, getReferrer()),
            domainAlias = domainFixup(locationArray[0]),
            locationHrefAlias = locationArray[1],
            configReferrerUrl = locationArray[2],

            // Request method (GET or POST)
            configRequestMethod = 'GET',

            // Tracker URL
            configTrackerUrl = trackerUrl || '',
            
            // Tracker Host
            configTrackerHost = '',
            
            // Site ID
            configTrackerProjectAccount = siteId || '',

            // Document URL
            configCustomUrl,

            // Document title
            configTitle = documentAlias.title,

            // Hosts or alias(es) to not treat as outlinks
            configHostsAlias = [domainAlias],

            // HTML anchor element classes to not track
            configIgnoreClasses = [],

            // HTML anchor element classes to treat as downloads
            configDownloadClasses = [],

            // HTML anchor element classes to treat at outlinks
            configLinkClasses = [],

            // Maximum delay to wait for web bug image to be fetched (in milliseconds)
            configTrackerPause = 500,

            // Minimum visit time after initial page view (in milliseconds)
            configMinimumVisitTime,

            // Recurring heart beat after initial ping (in milliseconds)
            configHeartBeatTimer,

            // Disallow hash tags in URL
            configDiscardHashTag,

            // Custom data
            configCustomData,


            // First-party cookie name prefix
            configCookieNamePrefix = '_os_',

            // First-party cookie domain
            // User agent defaults to origin hostname
            configCookieDomain,

            // First-party cookie path
            // Default is user agent defined.
            configCookiePath,

            // Cookies are disabled
            configCookiesDisabled = false,

            // Do Not Track
            configDoNotTrack,

            // Count sites which are pre-rendered
            configCountPreRendered,

            // Do we attribute the conversion to the first referrer or the most recent referrer?
            configConversionAttributionFirstReferrer,

            // Life of the visitor cookie (in milliseconds)
            configVisitorCookieTimeout = 63072000000, // 2 years

            // Life of the session cookie (in milliseconds)
            configSessionCookieTimeout = 1800000, // 30 minutes

            // Life of the referral cookie (in milliseconds)
            configReferralCookieTimeout = 15768000000, // 6 months

            // Should cookies have the secure flag set
            cookieSecure = documentAlias.location.protocol === 'https',

            // Custom Variables read from cookie, scope "visit"
            customVariables = false,

            // Custom Variables, scope "page"
            customVariablesPage = {},

            // Custom Variables names and values are each truncated before being sent in the request or recorded in the cookie
            customVariableMaximumLength = 200,

            // Browser features via client-side data collection
            browserFeatures = {},


            // Domain hash value
            domainHash,
            
            registeredEventListeners = {},
            
            registeredEventHandlers = {},
            
            eventRequestDetails = {},

            // Visitor UUID
            visitorUUID;

        
        /*
         * Set cookie value
         */
        function setCookie(cookieName, value, msToExpire, path, domain, secure) {
            if (configCookiesDisabled) {
                return;
            }

            var expiryDate;

            // relative time to expire in milliseconds
            if (msToExpire) {
                expiryDate = new Date();
                expiryDate.setTime(expiryDate.getTime() + msToExpire);
            }

            documentAlias.cookie = cookieName + '=' + encodeWrapper(value) +
                (msToExpire ? ';expires=' + expiryDate.toGMTString() : '') +
                ';path=' + (path || '/') +
                (domain ? ';domain=' + domain : '') +
                (secure ? ';secure' : '');
        }

        /*
         * Get cookie value
         */
        function getCookie(cookieName) {
            if (configCookiesDisabled) {
                return 0;
            }

            var cookiePattern = new RegExp('(^|;)[ ]*' + cookieName + '=([^;]*)'),
                cookieMatch = cookiePattern.exec(documentAlias.cookie);

            return cookieMatch ? decodeWrapper(cookieMatch[2]) : 0;
        }

        /*
         * Removes hash tag from the URL
         *
         * URLs are purified before being recorded in the cookie,
         * or before being sent as GET parameters
         */
        function purify(url) {
            var targetPattern;

            if (configDiscardHashTag) {
                targetPattern = new RegExp('#.*');
                return url.replace(targetPattern, '');
            }

            return url;
        }

        /*
         * Resolve relative reference
         *
         * Note: not as described in rfc3986 section 5.2
         */
        function resolveRelativeReference(baseUrl, url) {
            var protocol = getProtocolScheme(url),
                i;

            if (protocol) {
                return url;
            }

            if (url.slice(0, 1) === '/') {
                return getProtocolScheme(baseUrl) + '://' + getHostName(baseUrl) + url;
            }

            baseUrl = purify(baseUrl);
            if ((i = baseUrl.indexOf('?')) >= 0) {
                baseUrl = baseUrl.slice(0, i);
            }

            if ((i = baseUrl.lastIndexOf('/')) !== baseUrl.length - 1) {
                baseUrl = baseUrl.slice(0, i + 1);
            }

            return baseUrl + url;
        }

        /*
         * Is the host local? (i.e., not an outlink)
         */
        function isSiteHostName(hostName) {
            var i,
                alias,
                offset;

            for (i = 0; i < configHostsAlias.length; i++) {
                alias = domainFixup(configHostsAlias[i].toLowerCase());

                if (hostName === alias) {
                    return true;
                }

                if (alias.slice(0, 1) === '.') {
                    if (hostName === alias.slice(1)) {
                        return true;
                    }

                    offset = hostName.length - alias.length;
                    if ((offset > 0) && (hostName.slice(offset) === alias)) {
                        return true;
                    }
                }
            }
            return false;
        }

        /*
         * Send image request to OpenS server using GET.
         * The infamous web bug (or beacon) is a transparent, single pixel (1x1) image
         */
        function getImage(request) {
            
        	if(configTrackerUrl)
        	{
            	var image = new Image(1, 1);

                image.onload = function () { };
                image.src = configTrackerUrl + (configTrackerUrl.indexOf('?') < 0 ? '?' : '&') + request;
        	}
        }

        /*
         * POST request to OpenS server using XMLHttpRequest.
         */
        function sendXmlHttpRequest(request) {
            try {
                // we use the progid Microsoft.XMLHTTP because
                // IE5.5 included MSXML 2.5; the progid MSXML2.XMLHTTP
                // is pinned to MSXML2.XMLHTTP.3.0
                var xhr = windowAlias.XMLHttpRequest ? new windowAlias.XMLHttpRequest() :
                        windowAlias.ActiveXObject ? new ActiveXObject('Microsoft.XMLHTTP') :
                                null;

                xhr.open('POST', configTrackerUrl, true);

                // fallback on error
                xhr.onreadystatechange = function () {
                    if (this.readyState === 4 && this.status !== 200) {
                        getImage(request);
                    }
                };

                // see XMLHttpRequest Level 2 spec, section 4.7.2 for invalid headers
                // @link http://dvcs.w3.org/hg/xhr/raw-file/tip/Overview.html
                xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded; charset=UTF-8');

                xhr.send(request);
            } catch (e) {
                // fallback
                getImage(request);
            }
        }

        /*
         * Send request
         */
        function sendRequest(request, delay) {
            var now = new Date();

            if (!configDoNotTrack) {
                if (configRequestMethod === 'POST') {
                    sendXmlHttpRequest(request);
                } else {
                    getImage(request);
                }

                expireDateTime = now.getTime() + delay;
            }
        }

        /*
         * Get cookie name with prefix and domain hash
         */
        function getCookieName(baseName) {
            // will attempt to discover first party cookies. eg. See the PHP Client method getVisitorId()
            return configCookieNamePrefix + baseName + '.' + configTrackerProjectAccount + '.' + domainHash;
        }

        /*
         * Does browser have cookies enabled (for this site)?
         */
        function hasCookies() {
            if (configCookiesDisabled) {
                return '0';
            }

            if (!isDefined(navigatorAlias.cookieEnabled)) {
                var testCookieName = getCookieName('testcookie');
                setCookie(testCookieName, '1');

                return getCookie(testCookieName) === '1' ? '1' : '0';
            }

            return navigatorAlias.cookieEnabled ? '1' : '0';
        }

        /*
         * Update domain hash
         */
        function updateDomainHash() {
            //domainHash = hash((configCookieDomain || domainAlias) + (configCookiePath || '/')).slice(0, 4); // 4 hexits = 16 bits
        	domainHash = "";
        }

        /*m
         * Lazy loads the custom variables from the cookie, only once during this page view
         */
        function loadCustomVariables() {
            if (customVariables === false) {
                customVariables = getCustomVariablesFromCookie();
            }
        }
        
        
        function getRequest(requestDetails)
        {
        	
        	if(configTrackerProjectAccount)
        	{
        		//add other stuff here
            	var data = {
            		'pa': configTrackerProjectAccount,
            		'r': String(Math.random()).slice(2, 8), 
            		'apps': {},
            		'extra': {},
            	};
            	
            	for(var index in requestDetails)
            	{
            		data['apps'][index] = requestDetails[index];
            	}
            	
            	// browser features
                for (i in browserFeatures)
                {
                    if (Object.prototype.hasOwnProperty.call(browserFeatures, i))
                    {
                    	data['extra'][i] = browserFeatures[i];
                    }
                }

            	return buildHttpQuery(data);
        	}
        	
        	return false;
        }
        
        /*
         * Browser prefixm
         */
        function prefixPropertyName(prefix, propertyName)
        {
            if (prefix !== '')
            {
                return prefix + propertyName.charAt(0).toUpperCase() + propertyName.slice(1);
            }

            return propertyName;
        }
        
    	function buildHttpQuery (formdata, numeric_prefix, arg_separator)
    	{
		  // http://kevin.vanzonneveld.net
		  var value, key, tmp = [],
		    that = this;

		  var _http_build_query_helper = function (key, val, arg_separator) {
			    var k, tmp = [];
			    if (val === true)
			    {
			      val = "1";
			    } else if (val === false)
			    {
			      val = "0";
			    }
			    
			    if (val != null)
			    {
			    	if(typeof(val) === "object")
			    	{
			    		for (k in val)
			    		{
			    			if (val[k] != null)
			    			{
			    				tmp.push(_http_build_query_helper(key + "[" + k + "]", val[k], arg_separator));
			    			}
			    		}
			    		return tmp.join(arg_separator);
			    	}
			    	else if (typeof(val) !== "function")
			    	{
			    		return urlEncode(key) + "=" + urlEncode(val);
			    	}
			    	else
			    	{
			    		throw new Error('There was an error processing for http_build_query().');
			    	}
			  }
			  else
			  {
				  return '';
			  }
		  };

		  if (!arg_separator)
		  {
			  arg_separator = "&";
		  }
		  for (key in formdata)
		  {
			  value = formdata[key];
			  if (numeric_prefix && !isNaN(key))
			  {
				  key = String(numeric_prefix) + key;
			  }
			  var query=_http_build_query_helper(key, value, arg_separator);
		    
			  if(query != '')
			  {
				  tmp.push(query);
			  }
		  }

		  return tmp.join(arg_separator);
   		}
    	
    	function urlEncode(s)  
    	{
    		return encodeURIComponent( s ).replace( /\%20/g, '+' ).replace( /!/g, '%21' ).replace( /'/g, '%27' ).replace( /\(/g, '%28' ).replace( /\)/g, '%29' ).replace( /\*/g, '%2A' ).replace( /\~/g, '%7E' );
    	}
       
    	function urlDecode(s)
    	{
    		return decodeURIComponent( s.replace( /\+/g, '%20' ).replace( /\%21/g, '!' ).replace( /\%27/g, "'" ).replace( /\%28/g, '(' ).replace( /\%29/g, ')' ).replace( /\%2A/g, '*' ).replace( /\%7E/g, '~' ) );
    	}
        
        /*
         * Check for pre-rendered web pages, and log the page view/link/goal
         * according to the configuration and/or visibility
         *
         * @see http://dvcs.w3.org/hg/webperf/raw-file/tip/specs/PageVisibility/Overview.html
         */
        function trackCallback(callback)
        {
            var isPreRendered,
                i,
                // Chrome 13, IE10, FF10
                prefixes = ['', 'webkit', 'ms', 'moz'],
                prefix;

            if (!configCountPreRendered) {
                for (i = 0; i < prefixes.length; i++) {
                    prefix = prefixes[i];

                    // does this browser support the page visibility API?
                    if (Object.prototype.hasOwnProperty.call(documentAlias, prefixPropertyName(prefix, 'hidden'))) {
                        // if pre-rendered, then defer callback until page visibility changes
                        if (documentAlias[prefixPropertyName(prefix, 'visibilityState')] === 'prerender') {
                            isPreRendered = true;
                        }
                        break;
                    }
                }
            }

            if (isPreRendered) {
                // note: the event name doesn't follow the same naming convention as vendor properties
                addEventListener(documentAlias, prefix + 'visibilitychange', function ready() {
                    documentAlias.removeEventListener(prefix + 'visibilitychange', ready, false);
                    callback();
                });
                return;
            }

            // configCountPreRendered === true || isPreRendered === false
            callback();
        }
        

        /*
         * Construct regular expression of classes
         */
        function getClassesRegExp(configClasses, defaultClass)
        {
            var i,
                classesRegExp = '(^| )(opens[_-]' + defaultClass;

            if (configClasses) {
                for (i = 0; i < configClasses.length; i++) {
                    classesRegExp += '|' + configClasses[i];
                }
            }

            classesRegExp += ')( |$)';

            return new RegExp(classesRegExp);
        }
        
        
        function getExtraData()
        {
        	// browser features
        	var extraData = {};
        	
            for (i in browserFeatures)
            {
                if (Object.prototype.hasOwnProperty.call(browserFeatures, i))
                {
                	extraData[i] = browserFeatures[i];
                }
            }
            
            return extraData;
        }
        
        /*
         * Browser features (plugins, resolution, cookies)
         */
        function detectBrowserFeatures() {
            var i,
                mimeType,
                pluginMap = {
                    // document types
                    pdf: 'application/pdf',

                    // media players
                    qt: 'video/quicktime',
                    realp: 'audio/x-pn-realaudio-plugin',
                    wma: 'application/x-mplayer2',

                    // interactive multimedia
                    dir: 'application/x-director',
                    fla: 'application/x-shockwave-flash',

                    // RIA
                    java: 'application/x-java-vm',
                    gears: 'application/x-googlegears',
                    ag: 'application/x-silverlight'
                };

            if (!((new RegExp('MSIE')).test(navigatorAlias.userAgent))) {
                // general plugin detection
                if (navigatorAlias.mimeTypes && navigatorAlias.mimeTypes.length) {
                    for (i in pluginMap) {
                        if (Object.prototype.hasOwnProperty.call(pluginMap, i)) {
                            mimeType = navigatorAlias.mimeTypes[pluginMap[i]];
                            browserFeatures[i] = (mimeType && mimeType.enabledPlugin) ? '1' : '0';
                        }
                    }
                }

                // Safari and Opera
                // IE6/IE7 navigator.javaEnabled can't be aliased, so test directly
                if (typeof navigator.javaEnabled !== 'unknown' &&
                        isDefined(navigatorAlias.javaEnabled) &&
                        navigatorAlias.javaEnabled()) {
                    browserFeatures.java = '1';
                }

                // Firefox
                if (isFunction(windowAlias.GearsFactory)) {
                    browserFeatures.gears = '1';
                }

                // other browser features
                browserFeatures.cookie = hasCookies();
            }

            // screen resolution
            browserFeatures.res = screenAlias.width + 'x' + screenAlias.height;
            
        	
            //current page url
            var currentUrl = configCustomUrl || locationHrefAlias;
    		
            browserFeatures.url = encodeWrapper(purify(currentUrl));
        	

        	//visitor referer
            if(configReferrerUrl.length)
    		{
        		browserFeatures.urlref = encodeWrapper(purify(configReferrerUrl));
    		}
            
            //domain name
            browserFeatures.dm = (document.domain?document.domain:'');
            
            //local url
            //browserFeatures.lc = (document.location?document.location:'');
            
            //page title
            browserFeatures.pt = (document.title?document.title:'');
            
            //visitor time
            browserFeatures.vt = Math.round(new Date().getTime()/1000);
            
            //browser language
            browserFeatures.lg = (window.navigator.language?window.navigator.language:'');
            
            //browser app name
            browserFeatures.an = (window.navigator.appName?window.navigator.appName:'');
            
            //browser app version
            browserFeatures.av = (window.navigator.appVersion?window.navigator.appVersion:'');
            
            //browser sys oscpu
            browserFeatures.oc = (window.navigator.oscpu?window.navigator.oscpu:'');
            
            //browser os platform
            browserFeatures.pf = (window.navigator.platform?window.navigator.platform:'');
            
            //broser os product
            browserFeatures.pd = (window.navigator.product?window.navigator.product:'');
            
        }
        
        function hookSetEvent(hookObj)
        {
        	//check if already loaded
        	var eventLoaded = registeredEventListeners[hookObj.appName] || false;
        	
        	if(!eventLoaded)
        	{
        		registeredEventListeners[hookObj.appName] = true;
        		
        		var result = hookObj.execEvents();
        		
        		//handle Hook Events
        		if(result.hookEvents)
        		{
        			if(result.hookEvents.length)
        			{
        				for(i in result.hookEvents)
            			{
            				var eventDetails = result.hookEvents[i];
            				
            				if(eventDetails.length == 4)
            				{
            					var eventName = eventDetails[0],
            					eventElement = eventDetails[1],
            					eventType = eventDetails[2],
            					elementHash = generateObjectHash(eventElement);
            					
            					eventDetails.push(elementHash);
            					
            					if(!registeredEventHandlers[eventType]) registeredEventHandlers[eventType] = {};
            					if(!registeredEventHandlers[eventType][elementHash]) registeredEventHandlers[eventType][elementHash] = {};
            					registeredEventHandlers[eventType][elementHash][eventName] = {'exec': false, 'data': null};
            					
            					//detect if current event is window.onload
            					var isPageOnLoadEvent = false;
            					if(eventDetails[1].self) if(eventDetails[1].self == windowAlias.self) isPageOnLoadEvent = true;
            					
            					if(isPageOnLoadEvent)
            					{
            						hookHandleEvent(loadHandlerEvent, hookObj, eventName, elementHash);
            					}
            					else
            					{
            						setEventListener(eventDetails, hookObj);
            					}
            				}	
            			}	
        			}	
        		}
        	}
        }
        
        function hookHandleEvent(evt, hookObj, eventName, elementHash)
        {
        	var handlerResult, tmpData, requestData, pluginName, elHash, 
        		processRequest = true,
        		extraData = {},
        		handleEvent = false,
        		eventRequestDetails = {},
        		badEventTypes = {'DOMContentLoaded':'load', '':'load'},
        		eventType = "";

        	//Define event Type
        	if(evt) if(evt.type) eventType = evt.type;
        	
        	if(badEventTypes[eventType]) eventType = badEventTypes[eventType];
        	
        	//check if valid registered event 
        	if(registeredEventHandlers[eventType])
        	{
        		if(registeredEventHandlers[eventType][elementHash])
        		{
        			if(registeredEventHandlers[eventType][elementHash][eventName])
    				{
        				handleEvent = true;	
    				}
        		}	
        	}
        	
        	if(handleEvent)
        	{
        		registeredEventHandlers[eventType][elementHash][eventName]['exec'] = true;
        		
        		extraData = getExtraData();
        		extraData['evt'] = evt; 
            	
        		handlerResult = hookObj.execHandler(eventName, extraData);
        		
        		EventLog(eventName+" Result:");
        		EventLog(handlerResult);
        		
        		if(handlerResult)
        		{
        			//attach result to main request data
        			registeredEventHandlers[eventType][elementHash][eventName]['data'] = {'appName': hookObj.appName, 'handlerResult': handlerResult};
        		}
            	
            	//check executed event handlers
            	if(registeredEventHandlers[eventType])
            	{
            		for(elHash in registeredEventHandlers[eventType])
            		{
            			for(pluginName in registeredEventHandlers[eventType][elHash])
            			{
            				if(registeredEventHandlers[eventType][elHash][pluginName]['exec'] === false) processRequest = true;	
            			}	
            		}
            		
            		if(processRequest)
            		{
            			//clean all plugin handlers
                		for(elHash in registeredEventHandlers[eventType])
                		{
                			for(pluginName in registeredEventHandlers[eventType][elHash])
                			{
                				if(registeredEventHandlers[eventType][elHash][pluginName]['exec'] === false) processRequest = false;
                				
                				tmpData = registeredEventHandlers[eventType][elHash][pluginName];
                				
                				if(!isNull(tmpData['data']))
                				{
                					eventRequestDetails[pluginName] = tmpData['data']
                				}
                				
                				registeredEventHandlers[eventType][elHash][pluginName] = {'exec': false, 'data': null};
                			}	
                		}
                		
                		EventLog(eventRequestDetails);
            			
            			if (ObjectCount(eventRequestDetails) > 0)
            			{
                			requestData = getRequest(eventRequestDetails);
                			
                			sendRequest(requestData, configTrackerPause);
            			}	
            		}	
            	}	        		
        	}
        }
        
        function activateRegisteredHooks()
        {
        	for(var hookName in registeredHooks)
        	{
        		addHookOnLoadHandler(registeredHooks[hookName]);
        	}
        }
        
        function addHookOnLoadHandler(currentHook)
        {
        	if (hasLoaded) {hookSetEvent(currentHook);}
			else {registeredOnLoadHandlers.push(function(){ hookSetEvent(currentHook);});} 
        }
        
        function setEventListener(eventDetails, hookObj)
        {
			var eventName = eventDetails[0],
				eventElement = eventDetails[1],
				eventType = eventDetails[2],
				elementHash = eventDetails[4];

        	addEventListener(eventElement, eventType, function(evt) {hookHandleEvent(evt, hookObj, eventName, elementHash);}, false);
        }
        
        function generateObjectHash(Obj)
        {
        	Obj.hashID = Obj.hashID || ('hashID_' + String(Math.random()).slice(2, 8));
        	return Obj.hashID;
        }
        
        
        function EventLog(message)
        {
        	if(jsDebug === true)
        	{
        		if(console) if(console.log)
        		{
        			console.log(message);
        		}
        	}	
        }
       

/*<DEBUG>*/
        /*
         * Register a test hook. Using eval() permits access to otherwise
         * privileged members.
         */
        function registerHook(hookName, userHook) {
            var hookObj = null;

            if (isString(hookName) && !isDefined(registeredHooks[hookName]) && userHook) {
                if (isObject(userHook)) {
                    hookObj = userHook;
                } else if (isString(userHook)) {
                    try {
                        eval('hookObj =' + userHook);
                    } catch (e) { }
                }

                registeredHooks[hookName] = hookObj;
            }
            
            return hookObj;
        }
/*</DEBUG>*/

        /************************************************************
         * Constructor
         ************************************************************/

        /*
         * initialize tracker
         */
        detectBrowserFeatures();
        updateDomainHash();

/*<DEBUG>*/
        /*
         * initialize test plugin
         */
        executePluginMethod('run', registerHook);
/*</DEBUG>*/

        /************************************************************
         * Public data and methods
         ************************************************************/
        
    
        
    return {
    	
    	/*</DEBUG>*/    	
        /*
         * Test hook accessors
         */
        hook: registeredHooks,
        getHook: function (hookName) {
            return registeredHooks[hookName];
        },
/*</DEBUG>*/
        setTrack: function(currentTrackers)
        {
        	var i;
        	
        	if(isString(currentTrackers)) currentTrackers = [currentTrackers];
        	
        	for(i in currentTrackers)
        	{
        		var hookName = String(currentTrackers[i]).toLowerCase();
        		
        		if(!registeredHooks[hookName])
            	{
            		registerHook(hookName, extDataObj.getPlugin(hookName));
            	}	
        	}
        	
        	activateRegisteredHooks();
        },
        
        enableAppsTracker: function()
        {
        	var availablePlugins = extDataObj.getPlugins();
        	
        	if(ObjectCount(availablePlugins) > 0)
        	{
        		for(var pname in availablePlugins)
        		{
            		var hookName = String(pname).toLowerCase();
            		
            		if(!registeredHooks[hookName])
                	{
                		registerHook(hookName, availablePlugins[pname]);
                	}	
        		}
        		
        		activateRegisteredHooks();
        		
        		//set current project account
        		var currentProjectAccount =  extDataObj.getProjectSettingsItem('projectAccount');
        		
        		if(currentProjectAccount)
    			{
        			configTrackerProjectAccount = currentProjectAccount;
    			}
        		
        		//set current project host
        		var currentProjectHost =  extDataObj.getProjectSettingsItem('projectRootUrl');
        		
        		if(currentProjectHost)
    			{
        			configTrackerHost = (('https:' == document.location.protocol) ? 'https://' : 'http://') + currentProjectHost;
        			this.setTrackerUrl(configTrackerHost+'/tracker/endpoint.php');
    			}
        	}	
        },
        
        
        /**
         * Specify the OpenS server URL
         *
         * @param string trackerUrl
         */
        setTrackerUrl: function (trackerUrl) {
            configTrackerUrl = trackerUrl;
        },
        
        setTrackerHost: function (trackerHost) {
            configTrackerHost = trackerHost;
            this.setTrackerUrl(configTrackerHost+'tracker/endpoint.php');
        },
        
        /**
         * Specify the site ID
         *
         * @param int|string siteId
         */
        setAccount: function (siteId) {
            configTrackerProjectAccount = siteId;
        },
        
        /**
         * Set array of domains to be treated as local
         *
         * @param string|array hostsAlias
         */
        setDomains: function (hostsAlias) {
            configHostsAlias = isString(hostsAlias) ? [hostsAlias] : hostsAlias;
            configHostsAlias.push(domainAlias);
        },

        /**
         * Set array of classes to be ignored if present in link
         *
         * @param string|array ignoreClasses
         */
        setIgnoreClasses: function (ignoreClasses) {
            configIgnoreClasses = isString(ignoreClasses) ? [ignoreClasses] : ignoreClasses;
        },

        /**
         * Set request method
         *
         * @param string method GET or POST; default is GET
         */
        setRequestMethod: function (method) {
            configRequestMethod = method || 'GET';
        },

        /**
         * Override referrer
         *
         * @param string url
         */
        setReferrerUrl: function (url) {
            configReferrerUrl = url;
        }
    	
    	};    
    }
	
    /************************************************************
     * Proxy object
     * - this allows the caller to continue push()'ing to _osaq
     *   after the Tracker has been initialized and loaded
     ************************************************************/

    function TrackerProxy() {
        return {
            push: apply
        };
    }

    /************************************************************
     * Constructor
     ************************************************************/

    // initialize the OpenS Tracker singleton
    addEventListener(windowAlias, 'beforeunload', beforeUnloadHandler, false);
    addReadyListener();
    
    Date.prototype.getTimeAlias = Date.prototype.getTime;

    asyncTracker = new Tracker();

    for (i = 0; i < _osaq.length; i++) {
        apply(_osaq[i]);
    }

    // replace initialization array with proxy object
    _osaq = new TrackerProxy();

    /************************************************************
     * Public data and methods
     ************************************************************/
    
    return {
        /**
         * Add plugin
         *
         * @param string pluginName
         * @param Object pluginObj
         */
        addPlugin: function (pluginName, pluginObj) {
        	plugins[pluginName] = pluginObj;
        },
        
       /**
         * Get Tracker (factory method)
         *
         * @param string OpensTrackerUrl
         * @param int|string siteId
         * @return Tracker
         */
        getTracker: function (opensUrl, siteId) {
            return new Tracker(opensUrl, siteId);
        },

        /**
         * Get internal asynchronous tracker object
         *
         * @return Tracker
         */
        getAsyncTracker: function () {
            return asyncTracker;
        }
    };
}());   
