<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

include "../init.php";

$OS = getOS();

$osUser = $OS->getUser();

//check if user is logged
$osUser->forceUserLogin();

//get user data
$osUserOps = $OS->getUserOps();

//get users statuses
$userStatuses = $osUserOps->getStatuses();


//get timezone data
$osTimezonesList = $OS->getTimezonesList();

//get languages data
$osLanguagesList = $OS->getLanguagesList();



if ($_SERVER['REQUEST_METHOD']=='POST')
{
	$osValidator = $OS->getValidator();
	
	if (empty($_POST['name_box'])) 
	{
		$OS->addFieldError(_("Name missing"),'name');	
	}
	elseif (strlen($_POST['name_box'])<3) 
	{
		$OS->addFieldError(_("Name too short"),'name');	
	}
	elseif (!$osUserOps->isValidName($_POST['name_box'])) 
	{
		$OS->addFieldError(_("Invalid name"),'name');	
	}
	else
	{
		$user_full_name = $_POST['name_box'];
	} 

	
	if (empty($_POST['email_box']))
	{
		$OS->addFieldError(_("Email missing"),'email');	
	} 
	else
	{
		$user_email = trim(strtolower($_POST["email_box"]));
		if(strpos($_POST['email_box'],'www.')===0) $_POST['email_box']=substr($_POST['email_box'],4);
		
		if (!$osValidator->is_email($user_email)) $OS->addFieldError(_("Invalid email")." (".$osValidator->ERROR.")",'email');
		else{
				$oneUser = $osUserOps->getUserByEmail($user_email);
				if($oneUser === false)
				{
					$email_ok = true;	
				} 
				elseif($oneUser->id != $osUser->id)
				{
					$OS->addFieldError(_("Email already registered !"),'email');	
				}
				else
				{
					$email_ok = true;
				}
			}
	}


	if (empty($_POST['password1_box'])) 
	{
		$_POST['password1_box'] = '';
	}
	elseif ($_POST['password1_box'] != $_POST['password2_box']) 
	{
		$OS->addFieldError(_("Passwords do not match"),'password');	
	}
	elseif (strlen($_POST['password1_box'])<6)
	{
		$OS->addFieldError(_("Password too short"),'password');	
	} 
	else 
	{
		$password = $_POST['password1_box'];
	}


	if(empty($_POST['timezone_box'])) 
	{
		$OS->addFieldError(_("Timezone missing"),"timezone");
	}
	elseif(!isset($osTimezonesList[$_POST['timezone_box']])) 
	{
		$OS->addFieldError(_("Invalid timezone"),"timezone");
	}
	else
	{
		$user_timezone = $_POST['timezone_box'];
	}

	if(empty($_POST['language_box'])) 
	{
		$OS->addFieldError(_("Language missing"),"language");
	}
	elseif(!isset($osLanguagesList[$_POST['language_box']])) 
	{
		$OS->addFieldError(_("Invalid language"),"language");
	}
	else
	{
		$user_language = $_POST['language_box'];
	}
	
	
	$user_admin  = (isset($_POST['is_admin_box'])? "Y" : "");

	
	if(!isset($OS->errorMessages))
	{
		$osUser->name = $user_full_name;
		$osUser->email = $user_email;
		$osUser->timezone = $osTimezonesList[$user_timezone];
		$osUser->language = $user_language;
		
		if(!empty($password))
		{
			$osUser->setPassword($password);
		} 
		
		$response = $osUser->save();

		if($response !== false)
		{
			$OS->redirectTO("/users/my_account.php?msg=account_edit_ok");	
		}
		else
		{
			$OS->addBoxError(_("User cannot be modified"));
		}
	}
}
else
{
	$oneUser = $osUserOps->getUserByID($osUser->id);
	
	if($oneUser !== false)
	{
		$_POST['user_box'] = $oneUser->user;
		$_POST['name_box'] = $oneUser->name;
		$_POST['status_box'] = $oneUser->status;
		$_POST['email_box'] = $oneUser->email;
		$_POST['timezone_box'] = array_search($oneUser->timezone,$osTimezonesList);
		$_POST['language_box'] = $oneUser->language;
		//$_POST['admin_box'] = ($oneUser->isadmin?"Y":"");

	}
}


//handle external messages
if(isset($_GET['msg']))
	if($_GET['msg']== 'account_edit_ok') $OS->addInfo(_("Account details updated !"));


//Build timezones data
$allTimezones = array();
if(!empty($osTimezonesList))
{
	foreach($osTimezonesList as $identifier=>$tzname)
	{
		$selected = false;
		if(isset($_POST['timezone_box'])) if($_POST['timezone_box'] == $identifier) $selected = true; 
		
		$allTimezones[$identifier] = array('name'=>$tzname,'is_selected'=> $selected);
	}
}

//Build languages data
$allLanguages = array();
if(!empty($osLanguagesList))
{
	foreach($osLanguagesList as $identifier=>$cdata)
	{
		$allLanguages[$identifier] = array('name'=>$cdata['name'],'is_selected'=>(isset($_POST['language_box']) ? ($_POST['language_box'] == $identifier ? true:false) : false));
	}
}


$tpl = $OS->getTemplate();

//handle page topSection
$tpl->setTopSectionTitle(_("My Account"));

$tpl->setVar('errors',$OS->errorMessages);
$tpl->setVar('info',$OS->infoMessages);

$tpl->setVar('userStatuses',$userStatuses);

$tpl->setVar('allTimezones',$allTimezones);

$tpl->setVar('allLanguages',$allLanguages);



$tpl->bodyTemplateName = 'my_account';

echo $tpl->mainTemplateRender();