<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

include "../init.php";

$OS = getOS();

$osUser = $OS->getUser();
$osUtils = $OS->getUtils();

//verify if user is logged
$osUser->forceUserLogin();

//get project operations
$osProjectOps = $OS->getProjectOps();

$projectStatuses = $osProjectOps->getStatuses();

//get timezone data
$osTimezonesList = $OS->getTimezonesList();

//get languages data
$osLanguagesList = $OS->getLanguagesList();

//crawl options
$crawlFreqList = array(1=>_("Every day"),7=>_("Every 7 days"),15=>_("Every 15 days"),30=>_("Every 30 days"),0=>_("Never (manual only)"));
$crawlMaxLinksList = array(100=>100,500=>500,1000=>1000,5000=>5000,10000=>10000,50000=>50000,100000=>100000,0=>_("Unlimited"));
$crawlDepthList = array(2,3,5,10,15,20,25);
$crawlThreadsList = array(1,2,5,10);
$crawlScopeList = array('entire_host'=>_("Entire host"),'current_dir_subdirs'=>_("Current dir and subdirs"),'current_dir'=>_("Current dir only"));

//get available search engines
$osSearchEngineOps=$OS->getSearchEngineOps();
$osProjectSearchEngineOps=$OS->getProjectSearchEngineOps();
$searchEngines=$osSearchEngineOps->getAvailableSearchEnginesFull();

//handle current operations
$available_ops = array('add','edit');
if(isset($_GET['op'])) $op = $_GET['op']; 
elseif(isset($_POST['op'])) $op = $_POST['op'];
else $op = 'add';
if(!in_array($op,$available_ops)) {$OS->redirectTO("/users/projects_list.php?msg=badop");}

if($op == 'edit')
{
	if(isset($_GET['project_id'])) $project_id = $_GET['project_id']; 
	elseif(isset($_POST['project_id'])) $project_id = $_POST['project_id'];
	else {$OS->redirectTO("/users/projects_list.php?msg=noprjid");}
	
	$currentSearchEngines=array();
	if ($prjSearchEngines=$osProjectSearchEngineOps->getProjectSearchEngines($project_id))
	{
		foreach ($prjSearchEngines as $pse_id=>$pse)
		{
			$currentSearchEngines[(empty($pse->locale)?$pse->engine:$pse->engine.'_'.$pse->locale)]=$pse_id;
		}
	}
}
elseif ($op=='add')
{
	//get all system departments
	$osDepartmentOps = $OS->getDepartmentOps();
	
	$osDepartments = $osDepartmentOps->getDepartments();
	$currentSearchEngines=array();
}

if($_SERVER['REQUEST_METHOD']=='POST')
{
	$osValidator = $OS->getValidator();
	
	if (empty($_POST['name_box'])) 
	{
		$OS->addFieldError(_("Project name missing !"),'name');	
	}
	elseif(strlen($_POST['name_box'])<3) 
	{
		$OS->addFieldError(_("Project name too short (min 3 characters) !"),'name');
	}	
	else
	{
		$project_name = $_POST['name_box'];	
	} 
	
	if (empty($_POST['url_box'])) 
	{
		$OS->addFieldError(_("Project URL missing !"),'url');	
	}
	elseif (strlen($_POST['url_box'])<3) 
	{
		$OS->addFieldError(_("Project URL name too short (min 3 characters) !"),'url');
	}	
	elseif ($osValidator->has_html($_POST['url_box'])) 
	{
		$OS->addFieldError(_("You cannot enter HTML code as project URL !"),'url');
	}
	else
	{
		$_POST['url_box']=$osUtils->prependHTTP($_POST['url_box']);
		
		if(!$osValidator->is_url($_POST['url_box'])) 
		{
			$OS->addFieldError(_("Invalid project URL")." (".$osValidator->ERROR.")",'url');
		} 
		else 
		{
			$osHttp=$OS->getHttp();
			
			if (!$response=$osHttp->get($_POST['url_box']) OR !$osHttp->success())
			{
				$OS->addFieldError(_("Unable to load project URL"),'url');
			}
			else
			{
				$project_url = $osHttp->getInfo(CURLINFO_EFFECTIVE_URL);
			}
		}
	}
	
	if (empty($_POST['client_box']))
	{
		$client_id=0;
	}
	else
	{
		$clientOps=$OS->getClientOps();
		
		if (!$oneClient=$clientOps->getClientByName($_POST['client_box']))
		{
			$OS->addFieldError(_("Unknown client"),'client');
		}
		else
		{
			$client_id=$oneClient->id;
		}
	}
	
	if (empty($_POST['status_box'])) 
	{
		$OS->addFieldError(_("Status missing"),'status');	
	}
	elseif (!isset($projectStatuses[$_POST['status_box']])) 
	{
		$OS->addFieldError(_("Invalid Status"),'status');	
	}
	else
	{
		$project_status = $_POST['status_box'];	
	}
	
	
	if(empty($_POST['timezone_box'])) 
	{
		$OS->addFieldError(_("Timezone missing"),"timezone");
	}
	elseif(!isset($osTimezonesList[$_POST['timezone_box']])) 
	{
		$OS->addFieldError(_("Invalid timezone"),"timezone");
	}
	else
	{
		$project_timezone = $_POST['timezone_box'];
	}

	if(empty($_POST['language_box'])) 
	{
		$OS->addFieldError(_("Language missing"),"language");
	}
	elseif(!isset($osLanguagesList[$_POST['language_box']])) 
	{
		$OS->addFieldError(_("Invalid language"),"language");
	}
	else
	{
		$project_language = $_POST['language_box'];
	}
	
	$selectedSearchEngines=array();
	foreach ($searchEngines as $engine=>$engine_details)
	{
		if ($engine_details['has_locales'])
		{
			foreach ($engine_details['_locales'] as $locale=>$locale_details)
			{
				if (!empty($_POST["se_{$engine}_{$locale}_box"]))
				{
					$selectedSearchEngines["{$engine}_{$locale}"]=array('engine'=>$engine,'locale'=>$locale);
				}
			}
		}
		else
		{
			if (!empty($_POST["se_{$engine}_box"]))
			{
				$selectedSearchEngines[$engine]=array('engine'=>$engine,'locale'=>'');
			}
		}
	}
	if (empty($selectedSearchEngines))
	{
		$OS->addBoxError(_("Select at least one search engine that you are working on for this project"),'search_engines');
	}
	
	if (!isset($_POST['crawl_freq_box']))
	{
		$OS->addFieldError(_("Crawl frequency missing"),'crawl_freq');
	}
	elseif (!isset($crawlFreqList[$_POST['crawl_freq_box']]))
	{
		$OS->addFieldError(_("Invalid crawl frequency"),'crawl_freq');
	}
	else
	{
		$crawl_freq=$_POST['crawl_freq_box'];
	}
	
	if (!isset($_POST['crawl_max_links_box']))
	{
		$OS->addFieldError(_("Maximum number of links missing"),'crawl_max_links');
	}
	elseif (!isset($crawlMaxLinksList[$_POST['crawl_max_links_box']]))
	{
		$OS->addFieldError(_("Invalid maximum number of links"),'crawl_max_links');
	}
	else
	{
		$crawl_max_links=$_POST['crawl_max_links_box'];
	}
	
	if (empty($_POST['crawl_depth_box']))
	{
		$OS->addFieldError(_("Crawl depth missing"),'crawl_depth');
	}
	elseif (!in_array($_POST['crawl_depth_box'],$crawlDepthList))
	{
		$OS->addFieldError(_("Invalid crawl depth"),'crawl_depth');
	}
	else
	{
		$crawl_depth=$_POST['crawl_depth_box'];
	}
	
	if (empty($_POST['crawl_threads_box']))
	{
		$OS->addFieldError(_("Crawl threads missing"),'crawl_threads');
	}
	elseif (!in_array($_POST['crawl_threads_box'],$crawlThreadsList))
	{
		$OS->addFieldError(_("Invalid number of threads"),'crawl_threads');
	}
	else
	{
		$crawl_threads=$_POST['crawl_threads_box'];
	}
	
	$crawl_adv_options=array('images'=>false,'css'=>false,'js'=>false,'scope'=>'entire_host','blacklist'=>array());
	
	if (!empty($_POST['crawl_adv_images_box']))
	{
		$crawl_adv_options['images']=true;
	}
	if (!empty($_POST['crawl_adv_css_box']))
	{
		$crawl_adv_options['css']=true;
	}
	if (!empty($_POST['crawl_adv_js_box']))
	{
		$crawl_adv_options['js']=true;
	}
	if (empty($_POST['crawl_scope_box']))
	{
		$OS->addFieldError(_("Crawl scope missing"),'crawl_scope');
	}
	elseif (!isset($crawlScopeList[$_POST['crawl_scope_box']]))
	{
		$OS->addFieldError(_("Invalid crawl scope"),'crawl_scope');
	}
	else
	{
		$crawl_adv_options['scope']=$_POST['crawl_scope_box'];
	}
	if (!empty($_POST['crawl_blacklist_box']))
	{
		$blacklist=explode("\n",$_POST['crawl_blacklist_box']);
		
		foreach ($blacklist as $blacklist_url)
		{
			if (!empty($blacklist_url))
			{
				$crawl_adv_options['blacklist'][]=$blacklist_url;
			}
		}
	}	
	
	if ($op=='add')
	{
		//crawl now
		if (!empty($_POST['crawl_now_box']))
		{
			$crawl_now=true;
		}
		else
		{
			$crawl_now=false;
		}
		
		//handle project departments
		$newDepartmentsList = array();
		
		foreach($_POST as $key => $val)
		{
			if(strpos($key,"_dep_check_box")!==false)
			{
				$newDepartmentsList[$val] = true;
			}
		}
		
		if (empty($newDepartmentsList))
		{
			$OS->addBoxError(_("Select at least one department that has access to the project"),'departments');
		}
	}

	if(!isset($OS->errorMessages))
	{
		$oneProject = new OS_Project();
		$oneProject->name = $project_name;  
		$oneProject->url = $project_url;
		$oneProject->client_id = $client_id;
		$oneProject->status = $project_status;
		$oneProject->timezone = $osTimezonesList[$project_timezone];
		$oneProject->language = $project_language;
		
		$oneProject->crawl_freq=$crawl_freq;
		$oneProject->crawl_max_links=$crawl_max_links;
		$oneProject->crawl_depth=$crawl_depth;
		$oneProject->crawl_threads=$crawl_threads;
		$oneProject->crawl_adv_options=$crawl_adv_options;
		
		if($op == 'add')
		{
			$oneProject->user_id = $osUser->id;
			$oneProject->user = $osUser->user;
			$oneProject->crawl_dt = '';
			$oneProject->js_tracking = '';
		}
		elseif($op == 'edit')
		{
			$oneProject->id = $project_id;
		}
		
		$response = $oneProject->save();

		if($response !== false)
		{
			$new_search_engines=false;
			foreach ($selectedSearchEngines as $key=>$se_details)
			{
				if (isset($currentSearchEngines[$key]))
				{
					unset($currentSearchEngines[$key]);
				}
				else
				{
					$oneProjectSE=new OS_ProjectSearchEngine();
					
					$oneProjectSE->project_id=$oneProject->id;
					$oneProjectSE->engine=$se_details['engine'];
					$oneProjectSE->locale=$se_details['locale'];
					
					$oneProjectSE->save();
					
					$new_search_engines=true;
				}
			}
			foreach ($currentSearchEngines as $key=>$pse_id)
			{
				$osProjectSearchEngineOps->deleteProjectSearchEngineByID($pse_id);
			}
			
			if ($op=='add')
			{
				foreach($osDepartments as $dep_id => $departmentData)
				{
					if(isset($newDepartmentsList[$dep_id]))
					{
						if (!isset($oldDepartmentsList[$dep_id]))
						{
							$dep_users=$osDepartmentOps->getUsersByDepartmentID($dep_id);
							
							if ($dep_users)
							{
								foreach ($dep_users as $dep_user_id)
								{
									$oneSection=new OS_Section();
									
									$section_data=array(
										'project_id'=>$oneProject->id,
										'user_id'=>$dep_user_id,
										'position'=>1,
										'name'=>$project_name,
										'layout'=>2
									);
									
									$oneSection->set($section_data);
									
									$oneSection->save();
								}
							}
						}
						
						$oneProject->addDepartment($dep_id);
						
						if(isset($oldDepartmentsList[$dep_id]))
						{
							unset($oldDepartmentsList[$dep_id]);
						}
					}
				}
				
				if ($crawl_now)
				{
					OS_Fork::fork('core','','crawl_project',array('project_id'=>$oneProject->id));
				}
			}
			
			if ($new_search_engines)
			{
				$OS->redirectTO("/users/project_manage_keywords_bulk.php?project_id=".$oneProject->id);
			}
			else
			{
				$OS->redirectTO("/users/projects_list.php?msg=project_{$op}_ok");
			}
		}
		else
		{
			$OS->addBoxError(_("Project cannot be modified"));
		}	
	}
}
else
{
	$osFlipTimezonesList = array_flip($osTimezonesList);
	
	//set default values
	if($op == 'add')
	{
		$_POST['language_box']='en';
		
		if (!empty($osUser->timezone) AND isset($osFlipTimezonesList[$osUser->timezone]))
		{
			$_POST['timezone_box'] = $osFlipTimezonesList[$osUser->timezone];
		}
		
		$_POST['client_box']='';
		
		$_POST['status_box'] = "A"; 
		$_POST['crawl_freq_box']=7;
		$_POST['crawl_depth_box']=10;
		$_POST['crawl_max_links_box']=10000;
		$_POST['crawl_threads_box']=10;
		
		$_POST['crawl_adv_images_box']='';
		$_POST['crawl_adv_css_box']='';
		$_POST['crawl_adv_js_box']='';
		$_POST['crawl_scope_box']='entire_host';
		$_POST['crawl_blacklist_box']='';
		
		$_POST['crawl_now_box']='Y';
	}
	elseif($op == 'edit')
	{
		$oneProject = $osProjectOps->getProjectByID($project_id);
		
		if($oneProject !== false)
		{
			$_POST['name_box'] = $oneProject->name;
			$_POST['url_box'] = $oneProject->url;
			$_POST['status_box'] = $oneProject->status;
			$_POST['timezone_box'] = (isset($osFlipTimezonesList[$oneProject->timezone]) ? $osFlipTimezonesList[$oneProject->timezone]: '');
			$_POST['language_box'] = $oneProject->language;
			
			$_POST['client_box']='';
			if (!empty($oneProject->client_id))
			{
				$clientOps=$OS->getClientOps();
				if ($oneClient=$clientOps->getClientByID($oneProject->client_id))
				{
					$_POST['client_box']=$oneClient->name;
				}
			}
			
			$_POST['crawl_freq_box']=$oneProject->crawl_freq;
			$_POST['crawl_depth_box']=$oneProject->crawl_depth;
			$_POST['crawl_max_links_box']=$oneProject->crawl_max_links;
			$_POST['crawl_threads_box']=$oneProject->crawl_threads;
			
			$_POST['crawl_adv_images_box']=(empty($oneProject->crawl_adv_options['images'])?'':'Y');
			$_POST['crawl_adv_css_box']=(empty($oneProject->crawl_adv_options['css'])?'':'Y');
			$_POST['crawl_adv_js_box']=(empty($oneProject->crawl_adv_options['js'])?'':'Y');
			$_POST['crawl_scope_box']=(isset($oneProject->crawl_adv_options['scope'])?$oneProject->crawl_adv_options['scope']:'entire_host');
			if (isset($oneProject->crawl_adv_options['blacklist']))
			{
				$_POST['crawl_blacklist_box']=implode("\n",$oneProject->crawl_adv_options['blacklist']);
			}
			else
			{
				$_POST['crawl_blacklist_box']='';
			}
			
			foreach ($currentSearchEngines as $se=>$se_id)
			{
				$_POST["se_{$se}_box"]=$se;
			}
			
			//TODO: get search engines
			
			if (isset($_GET['crawl_now']))
			{
				$crawlForked=OS_Fork::fork('core','','crawl_project',array('project_id'=>$oneProject->id));
				
				if ($crawlForked)
				{
					$OS->redirectTO("/users/projects_list.php?msg=project_crawl_ok");
				}
			}
		}
	}
}


//Build timezones data
$allTimezones = array();
if(!empty($osTimezonesList))
{
	foreach($osTimezonesList as $identifier=>$tzname)
	{
		$selected = false;
		if(isset($_POST['timezone_box'])) if($_POST['timezone_box'] == $identifier) $selected = true; 
		
		$allTimezones[$identifier] = array('name'=>$tzname,'is_selected'=> $selected);
	}
}

//Build languages data
$allLanguages = array();
if(!empty($osLanguagesList))
{
	foreach($osLanguagesList as $identifier=>$cdata)
	{
		$allLanguages[$identifier] = array('name'=>$cdata['name'],'is_selected'=>(isset($_POST['language_box']) ? ($_POST['language_box'] == $identifier ? true:false) : false));
	}
}

//Build search engines data
$allSearchEngines=array();
if (!empty($searchEngines))
{
	foreach ($searchEngines as $val=>$details)
	{
		if ($details['has_locales'])
		{
			foreach ($details['_locales'] as $locale=>$locale_details)
			{
				$allSearchEngines[$val.'_'.$locale]=array('name'=>$details['title'].' '.$locale_details['title'],'is_selected'=>(!empty($_POST["se_{$val}_{$locale}_box"])?true:false));
			}
		}
		else
		{
			$allSearchEngines[$val]=array('name'=>$details['title'],'is_selected'=>(!empty($_POST["se_{$val}_box"])?true:false));
		}
	}
}

//Build crawl data
$allCrawlFreq=array();
if (!empty($crawlFreqList))
{
	foreach ($crawlFreqList as $val=>$name)
	{
		$allCrawlFreq[$val]=array('name'=>$name,'is_selected'=>(isset($_POST['crawl_freq_box']) AND $_POST['crawl_freq_box']==$val?true:false));
	}
}
$allCrawlMaxLinks=array();
if (!empty($crawlMaxLinksList))
{
	foreach ($crawlMaxLinksList as $val=>$name)
	{
		$allCrawlMaxLinks[$val]=array('name'=>$name,'is_selected'=>(isset($_POST['crawl_max_links_box']) AND $_POST['crawl_max_links_box']==$val?true:false));
	}
}
$allCrawlDepth=array();
if (!empty($crawlDepthList))
{
	foreach ($crawlDepthList as $val)
	{
		$allCrawlDepth[$val]=array('name'=>$val,'is_selected'=>(isset($_POST['crawl_depth_box']) AND $_POST['crawl_depth_box']==$val?true:false));
	}
}
$allCrawlThreads=array();
if (!empty($crawlThreadsList))
{
	foreach ($crawlThreadsList as $val)
	{
		$allCrawlThreads[$val]=array('name'=>$val,'is_selected'=>(isset($_POST['crawl_threads_box']) AND $_POST['crawl_threads_box']==$val?true:false));
	}
}
$allCrawlScopes=array();
if (!empty($crawlScopeList))
{
	foreach ($crawlScopeList as $val=>$name)
	{
		$allCrawlScopes[$val]=array('name'=>$name,'is_selected'=>(isset($_POST['crawl_scope_box']) AND $_POST['crawl_scope_box']==$val?true:false));
	}
}

//setup page title
$ptitle = ($op=='add'?_("Add New Project"):_("Edit Project"));

$headContents="<script type='text/javascript'>
function toggleAdvancedCrawlOptions()
{
	\$('#crawl_adv_options').toggle();
}
</script>";

$tpl = $OS->getTemplate();

$tpl->setHeadContents($headContents);

//handle page topSection
$tpl->setTopSectionTitle($ptitle);
$tpl->addTopSectionOption('cancel',array('type'=>'link','name'=>_("Cancel"),'url'=>$OS->getConfigVar('root_url')."/users/projects_list.php"));

$tpl->setVar('errors',$OS->errorMessages);
$tpl->setVar('info',$OS->infoMessages);



$tpl->setVar('op',$op);

$tpl->setVar('projectStatuses',$projectStatuses);

if ($op=='add')
{
	//Build users departments
	$allDepartments = array();
	if(!empty($osDepartments))
	{
		foreach($osDepartments as $department_id=>$departmentData) 
		{
			if($departmentData->isActive())
			{
				$allDepartments[$department_id] = array('name' => $departmentData->name,'is_selected'=>(isset($_POST["{$department_id}_dep_check_box"]) ? true : false));	
			}
		}	
	}
	
	$tpl->setVar('allDepartments',$allDepartments);
}

$tpl->setVar('allTimezones',$allTimezones);

$tpl->setVar('allLanguages',$allLanguages);

$tpl->setVar('allSearchEngines',$allSearchEngines);

$tpl->setVar('allCrawlFreq',$allCrawlFreq);
$tpl->setVar('allCrawlMaxLinks',$allCrawlMaxLinks);
$tpl->setVar('allCrawlDepth',$allCrawlDepth);
$tpl->setVar('allCrawlThreads',$allCrawlThreads);
$tpl->setVar('allCrawlScopes',$allCrawlScopes);


if($op=='edit')
{
	$tpl->setVar('project_id',$project_id);
	$tpl->setVar('crawlNowUrl',$OS->getConfigVar('root_url')."/users/project_manage.php?op=edit&project_id={$project_id}&crawl_now");
}

$tpl->selectedMenuItem = 'projects_list';

$tpl->bodyTemplateName = 'project_manage';

echo $tpl->mainTemplateRender();
?>