<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

include "../init.php";

$OS = getOS();

$osUser = $OS->getUser();

//verify if user is logged
$osUser->forceUserLogin();

//verify user permissions
$osUser->forcePerm('projects_management','view_projects');

//get user's departments
$osUserDepartments = $osUser->getDepartments();


//get projects data
$projectOps = $OS->getProjectOps();



//handle external operations
if(isset($_GET['op']))
{
	if($_GET['op']=='open')
	{
		if(isset($_GET['project_id']))
		{
			$oneProject = new OS_Project();
			$oneProject->id = $_GET['project_id'];
			$oneProject->user_id = $osUser->id;
			
			$loadResult = $oneProject->open();
			
			if($loadResult === false)
			{
				$OS->addBoxError(_("Project could not be loaded !"),'url');
			}
			else
			{
				$OS->redirectTO("/livedash/index.php#widgets");
			}
		}
	}	
	elseif($_GET['op']=='delete')
	{
		if(isset($_GET['project_id']))
		{
			if ($oneProject=$projectOps->getProjectByID($_GET['project_id']))
			{
				$markResult = $oneProject->markForDeletion();
				
				if($markResult === false)
				{
					$OS->addBoxError(_("Project could not be deleted !"));
				}
				else
				{
					$OS->addInfo(_("Project was deleted !"));
					
					OS_Fork::fork('core','','delete_project',array('project_id'=>$oneProject->id));
				}
			}
		}
	}	
	elseif($_GET['op']=='close_project')
	{
		$osProject = $OS->getProject();
		
		$closeResult = $osProject->close();
	
		if($closeResult === false)
		{
			$OS->addBoxError(_("Project could not be closed !"));
		}
		else
		{
			$OS->addInfo(_("Project was closed !"),'project_closed');
		}
	}
	
}

$client_id=false;
if (!empty($_GET['client_id']))
{
	$clientOps=$OS->getClientOps();
	
	if ($oneClient=$clientOps->getClientByID($_GET['client_id']))
	{
		$client_id=$_GET['client_id'];
	}
}

//get user's projects
$projects = ($client_id?$projectOps->getProjectsByClientID($client_id):$projectOps->getProjects());

$allProjects = array();
if(!empty($projects))
{
	$osUtils=$OS->getUtils();
	$osCompetitorOps=$OS->getCompetitorOps();
	$osProjectKeywordOps=$OS->getProjectKeywordOps();
	
	foreach($projects as $project_id=>$projectData)
	{
		$show_project = false;
		
		if($osUser->isUserAdmin()) $show_project = true;
		else{
				$osProjectDepartments = $projectData->getDepartments();//checkDepartmentACL($osUser)
				
				if($osProjectDepartments !== false && $osUserDepartments !== false)
				{
					$arrInt = array_intersect($osProjectDepartments,$osUserDepartments);
					
					if($arrInt)
					{
						$show_project =  true;
					}
				}
			}
		
		if($show_project)
		{
			$allProjects[$project_id] = array(
				'name' => $projectData->name,
				'url' => $projectData->url,
				'url_stripped' => $osUtils->stripHTTP($projectData->url),
				'js_tracking' => ($projectData->js_tracking=='Y'?true:false),
				'created_date' => date("d F Y",strtotime($projectData->status_dt)),
				'competitors'=>$osCompetitorOps->getCompetitorsCount($project_id),
				'keywords'=>$osProjectKeywordOps->getProjectKeywordsCount($project_id),
				'open_link' => ($osUser->checkPerm('projects_management','view_projects') ? $OS->getConfigVar('root_url')."/users/projects_list.php?op=open&project_id={$project_id}" : false),
				'edit_link' => ($osUser->checkPerm('projects_management','edit_project') ? $OS->getConfigVar('root_url')."/users/project_manage.php?op=edit&project_id={$project_id}" : false),
				'tag_manager_link' => ($osUser->checkPerm('projects_management','edit_project') ? $OS->getConfigVar('root_url')."/users/project_tag_manager.php?project_id={$project_id}" : false),
				'competition_link' => ($osUser->checkPerm('projects_management','edit_project') ? $OS->getConfigVar('root_url')."/users/project_manage_competition.php?project_id={$project_id}" : false),
				'departments_link' => ($osUser->checkPerm('projects_management','edit_project') ? $OS->getConfigVar('root_url')."/users/project_manage_departments.php?op=edit&project_id={$project_id}" : false),
				'delete_link' => ($osUser->checkPerm('projects_management','delete_project') ? $OS->getConfigVar('root_url')."/users/projects_list.php?op=delete&project_id={$project_id}" : false),
			);
		}
	}	
}

//handle external messages
if(isset($_GET['msg']))
	if($_GET['msg']== 'project_add_ok') $OS->addInfo(_("Project Created !"));
	elseif($_GET['msg']== 'project_edit_ok') $OS->addInfo(_("Project Details Saved !"));
	elseif ($_GET['msg']=='prj_departments_ok') $OS->addInfo(_("Project Departments Saved !"));
	elseif ($_GET['msg']=='project_crawl_ok') $OS->addInfo(_("Project crawl started")); 

$tpl = $OS->getTemplate();

//handle page topSection
$tpl->setTopSectionTitle(($client_id?_("Manage Projects for").' '.$oneClient->name:_("Manage Projects")));

//check if current user can add project
if($osUser->checkPerm('projects_management','add_project'))
{
	$tpl->addTopSectionOption('add_project',array('type'=>'link','name'=>_("New Project"),'url'=>$OS->getConfigVar('root_url')."/users/project_manage.php".($client_id?"?client_id={$client_id}":'')));
}

$tpl->setVar('allProjects',$allProjects);

$userTip=$osUser->getTips(1);
if ($userTip)
{
	$userTip=reset($userTip);
}
$tpl->setVar('userTip',$userTip);

$tpl->setVar('errors',$OS->errorMessages);
$tpl->setVar('info',$OS->infoMessages);



$tpl->bodyTemplateName = 'projects_list';

echo $tpl->mainTemplateRender();
?>