<?php
/*                                                                                                                                                                                                    
 *+---------------------------------------------------------------------------+
 *| OpenS v0.1                                                                |
 *| ==========                                                                |
 *|                                                                           |
 *| Copyright (c) 2011-2012 OpenS                                             |
 *| For contact details, see: http://www.opens.org/                           |
 *|                                                                           |
 *| This program is free software; you can redistribute it and/or modify      |
 *| it under the terms of the GNU General Public License as published by      |
 *| the Free Software Foundation; either version 2 of the License, or         |
 *| (at your option) any later version.                                       |
 *|                                                                           |
 *| This program is distributed in the hope that it will be useful,           |
 *| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
 *| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
 *| GNU General Public License for more details.                              |
 *|                                                                           |
 *| You should have received a copy of the GNU General Public License         |
 *| along with this program; if not, write to the Free Software               |
 *| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
 *+---------------------------------------------------------------------------+
 *$Id: os_core.php 2012-01-09$
 */

include "../init.php";

$OS = getOS();

//get info about the current user
$osUser = $OS->getUser();

//check if user is logged
$osUser->forceUserLogin();

//get user data
$userOps = $OS->getUserOps();


//get all system departments
$osDepartmentOps = $OS->getDepartmentOps();

$osDepartments = $osDepartmentOps->getDepartments();

//Build users departments
$allDepartments = array();
if(!empty($osDepartments))
{
	foreach($osDepartments as $department_id=>$departmentData) 
	{
		if($departmentData->isActive())
		{
			$allDepartments[$department_id] = array('name' => $departmentData->name);	
		}
	}	
}

//get all system users
$osUsers = $userOps->getUsers();

//get users statuses
$usersStatuses = $userOps->getStatuses();

//handle mass actions
if ($_SERVER['REQUEST_METHOD']=='POST')
{
	if(isset($_POST['mass_action_btn']))
	{
		if(empty($_POST['mass_department_box']))
		{
			$OS->addFieldError(_("Department is missing"),'mass_department');
		} 
		elseif(!isset($osDepartments[$_POST['mass_department_box']]))
		{
			$OS->addFieldError(_("Invalid Department"),'mass_department');
		}
		else
		{
			$massUsers = array();
			foreach($_POST as $key=>$val)
			{
				if(strpos($key,'_usr_check_box')!==false) $massUsers[]= $val;
			}
			
			if(empty($massUsers))
			{
				$OS->addBoxError(_("You must select at least one user"));
			}
		}
		
		if(!isset($OS->errorMessages))
		{
			$department_id = $_POST['mass_department_box'];
			
			foreach($massUsers  as $user_id)
			{
				if(isset($osUsers[$user_id]))
				{
					$oneUser = $osUsers[$user_id];
					$oneUser->addDepartment($department_id);
				}
			}
		}
	}
}


//handle external operations
if(isset($_GET['op'],$_GET['user_id']))
{
	if($_GET['op'] == 'delete' )
	{
		if(isset($osUsers[$_GET['user_id']]))
		{
			if ($osUser->id==$_GET['user_id'])
			{
				$OS->addBoxError(_("Unable to delete your own user!"),'delete_user');
			}
			else
			{
				$oneUser = new OS_User();
				$oneUser->id = $_GET['user_id'];
				$deleteResult = $oneUser->delete();
				
				if($deleteResult === true)
				{
					unset($osUsers[$_GET['user_id']]);
					$OS->addInfo(_("User Deleted !"));
				}
				else
				{
					$OS->addBoxError(_("User cannot be deteled !"),'delete_user');
				}
			}
		}
		else
		{
			$OS->addBoxError(_("User not found !"),'delete_user');
		}
	}
}

//handle external messages
if(isset($_GET['msg']))
	if($_GET['msg']== 'usr_add_ok') $OS->addInfo(_("User Created !"),'usr_add_ok');
	elseif($_GET['msg']== 'usr_edit_ok') $OS->addInfo(_("User Details Saved !"),'usr_edit_ok');
	elseif($_GET['msg']== 'usrperm_ok') $OS->addInfo(_("User Permissions Saved !"),'usrperm_ok');
	 


//Build allUsers for human view
$allUsers = array();
if(!empty($osUsers))
{
	foreach($osUsers as $user_id=>$userData)
	{
	$allUsers[$user_id] = array(
		'name' => $userData->name,
		'user' => $userData->user,
		'human_status' => $usersStatuses[$userData->status],
		'created_date' => date("d F Y",strtotime($userData->status_dt)),
		'edit_link' => $OS->getConfigVar('root_url')."/users/user_manage.php?op=edit&user_id={$user_id}",
		'permissions_link' => $OS->getConfigVar('root_url')."/users/user_manage_permissions.php?user_id={$user_id}",
		'apps_link' => $OS->getConfigVar('root_url')."/users/user_manage_apps.php?user_id={$user_id}",
		'delete_link' => ($user_id==$osUser->id?false:$OS->getConfigVar('root_url')."/users/users_list.php?op=delete&user_id={$user_id}"),
		);	
	}	
}


$tpl = $OS->getTemplate();

//check if current user can add project
if($osUser->checkPerm('users_management','add_user'))
{
	$tpl->addTopSectionOption('add_user',array('type'=>'link','name'=>_("New User"),'url'=>$OS->getConfigVar('root_url')."/users/user_manage.php?op=add"));
}

//handle page topSection
$tpl->setTopSectionTitle(_("Manage Users"));

$tpl->setVar('errors',$OS->errorMessages);
$tpl->setVar('info',$OS->infoMessages);

$tpl->setVar('allUsers',$allUsers);



$tpl->setVar('allDepartments',$allDepartments);

$tpl->bodyTemplateName = "users_list";

echo $tpl->mainTemplateRender();
?>